@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -497,8 +497,12 @@ class Parser(object):
             repo = str(node.attributes["repo"].value)
         except:
             repo = None
+        try:
+            tex = str(node.attributes["tex"].value)
+        except:
+            tex = None
 
-        return  f, dest, repo
+        return  f, dest, repo, tex
 
 
     def getProbes(self, node):
