@@ -5,7 +5,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -485,6 +485,14 @@ class case:
             r += '_COUPLING'
             if os.path.isdir(r):
                 self.result_dir = os.path.join(r, name)
+            else:
+                r = os.path.join(self.case_dir, 'RESU')
+                err_str = \
+                    '\nResults directory: ' + r + '\n' \
+                    + '               or: ' + r + '_COUPLING' + '\n' \
+                    + 'does not exist.\n' \
+                    + 'Calculation will not be run.\n'
+                raise RunCaseError(err_str)
 
         if os.path.isdir(self.result_dir):
             if not force:
@@ -727,7 +735,7 @@ ${KERNEL_ROOT_DIR}/bin/salome/appli_gen.py --prefix=%(applidir)s --config=%(conf
                           'pythondir': self.package.get_dir('pythondir'),
                           'pkgpythondir': self.package.get_dir('pkgpythondir'),
                           'applidir': os.path.join(self.exec_dir, 'appli'),
-                          'configdir': os.path.join(self.package.get_dir('pkgdatadir'),
+                          'configdir': os.path.join(self.package.get_dir('sysconfdir'),
                                                     'salome',
                                                     'fsi_appli_config.xml')}
 
@@ -863,8 +871,12 @@ export SALOME_INSTANCE=$3
             cmd = '#mpmdbegin %d-%d\n' % (rank_id, rank_id + d.n_procs - 1)
             e.write(cmd)
             s_args = d.solver_command()
-            cmd = '#mpmdcmd ' + os.path.relpath(s_args[1], self.exec_dir) \
-                + s_args[2] \
+            if s_args[1][0:2] == './':
+                s_path = os.path.relpath(os.path.join(s_args[0], s_args[1]),
+                                         self.exec_dir)
+            else:
+                s_path = s_args[1]
+            cmd = '#mpmdcmd ' + s_path + s_args[2] \
                 + ' -w ' + os.path.basename(s_args[0]) + '\n'
             e.write(cmd)
             e.write('#mpmdend\n')
@@ -874,8 +886,12 @@ export SALOME_INSTANCE=$3
             cmd = '#mpmdbegin %d-%d\n' % (rank_id, rank_id + d.n_procs - 1)
             e.write(cmd)
             s_args = d.solver_command()
-            cmd = '#mpmdcmd ' + os.path.relpath(s_args[1], self.exec_dir) \
-                + s_args[2] \
+            if s_args[1][0:2] == './':
+                s_path = os.path.relpath(os.path.join(s_args[0], s_args[1]),
+                                         self.exec_dir)
+            else:
+                s_path = s_args[1]
+            cmd = '#mpmdcmd ' + s_path + s_args[2] \
                 + ' -wdir ' + os.path.basename(s_args[0]) + '\n'
             e.write(cmd)
             e.write('#mpmdend\n')
@@ -1320,7 +1336,7 @@ echo "exit \$?" >> $localexec
         # Set user MPI options if required.
 
         if mpiexec_options != None:
-            exec_env.mpi_env.mpiexec_options = mpiexec_options
+            exec_env.mpi_env.mpiexec_opts = mpiexec_options
 
         # Transfer parameters MPI parameters from user scripts here.
 
@@ -1611,22 +1627,6 @@ echo "exit \$?" >> $localexec
         Main script.
         """
 
-        # Transfer parameters from case parameters or user scripts here
-
-        if len(self.domains) == 1 and len(self.syr_domains) == 0:
-
-            d = self.domains[0]
-
-            if d.user_locals:
-                m = 'define_case_parameters'
-                c = globals()['case']
-                if m in d.user_locals.keys():
-                    eval(m + '(case)', globals(), d.user_locals)
-                    del d.user_locals[m]
-                if hasattr(c, 'n_procs') and n_procs == None:
-                    n_procs = int(c.n_procs)
-                    del(c.n_procs)
-
         # Define scratch directory
         # priority: argument, environment variable, preference setting.
 
