@@ -5,7 +5,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -33,6 +33,7 @@ import sys
 
 from cs_case_domain import *
 from cs_case import *
+import cs_exec_environment
 
 #-------------------------------------------------------------------------------
 # Extract a parameters file name from a shell run sript
@@ -57,19 +58,11 @@ def get_param(path):
         line = line.strip()
         if len(line) == 0:
             continue
-        i = line.find('--param')
-        if i >= 0:
-            i += len('--param')
-            line = line[i:].strip()
-            if not line:
-                continue
-            # Find file name, possibly protected by quotes
-            # (protection by escape character not handled)
-            sep = line[0]
-            if sep == '"' or sep == "'":
-                param = line.split(sep)[1]
-            else:
-                param = line.split()[0]
+        args = cs_exec_environment.separate_args(line)
+        if args.count('run') > 0:
+            if args.index('run') > 0: # "<package.name> run"
+                param = cs_exec_environment.get_command_single_value \
+                    (args, ('--param=', '--param', '-p'))
 
     return param
 
@@ -79,7 +72,8 @@ def get_param(path):
 
 def coupling(package,
              domains,
-             casedir):
+             casedir,
+             package_compute = None):
 
     use_saturne = False
     use_syrthes = False
@@ -90,11 +84,8 @@ def coupling(package,
     config = configparser.ConfigParser()
     config.read(package.get_global_configfile())
 
-    package_compute = None
-    if config.has_option('install', 'compute_versions'):
-        compute_versions = config.get('install', 'compute_versions').split(':')
-        if compute_versions[0]:
-            package_compute = package.get_alternate_version(compute_versions[0])
+    if package_compute == None:
+        package_compute = package
 
     # Initialize code domains
     sat_domains = []
