@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -41,12 +41,13 @@ if not hasattr(sys, 'version_info') or sys.version_info <= (2, 4, 0, 'final'):
 # Third-party modules
 #-------------------------------------------------------------------------------
 
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
-    sip.setapi('QVariant', 2)
-    sip.setapi('QTime', 2)
-    sip.setapi('QUrl', 2)
+# to use PyQt API 2
+#if sys.version_info[0] == 2:
+#    import sip
+#    sip.setapi('QString', 2)
+#    sip.setapi('QVariant', 2)
+#    sip.setapi('QTime', 2)
+#    sip.setapi('QUrl', 2)
 
 try:
     from PyQt4.QtCore import *
@@ -71,8 +72,6 @@ if list(map(int, PYQT_VERSION_STR.split("."))) < [4, 3, 0]:
 #-------------------------------------------------------------------------------
 
 import cs_config
-from Base.MainView import MainView
-import Base.MainView
 
 #-------------------------------------------------------------------------------
 # Processes the passed command line arguments
@@ -191,6 +190,7 @@ def main(argv, pkg):
         app.processEvents()
         QTimer.singleShot(1500, splash.hide)
 
+    from Base.MainView import MainView
     mv = MainView(cmd_package = pkg, cmd_case = case)
 
     try:
