@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -257,13 +257,16 @@ class Parser:
             if len(path) > 0:
                 name = os.path.join(path, name)
             if len(number) > 0:
-                l_args.append('--num ' + number)
+                l_args.append('--num ')
+                l_args.append(number)
             if reorient:
                 l_args.append('--reorient')
             if len(grp_cel) > 0:
-                l_args.append('--grp-cel ' + grp_cel)
+                l_args.append('--grp-cel')
+                l_args.append(grp_cel)
             if len(grp_fac) > 0:
-                l_args.append('--grp-fac ' + grp_fac)
+                l_args.append('--grp-fac')
+                l_args.append(grp_fac)
 
             if len(l_args) >  0:
                 l_args.insert(0, name)
@@ -332,13 +335,6 @@ class Parser:
         if val:
             self.dict['valgrind'] = val
 
-        # Additional fields relative to the run environment
-
-        for key in ['n_procs']:
-            val = getDataFromNode(calc_node, key)
-            if val:
-                self.dict['case_' + key] = val
-
     #---------------------------------------------------------------------------
 
     def getParams(self):
