@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -367,15 +367,15 @@ if test "x$cs_cc_compiler_known" != "xyes" ; then
     cflags_default="-qlanglvl=stdc99 -q64"
     cflags_default_opt="-O3"
     cflags_default_hot="-O3"
-    cflags_default_dbg="-g"
-    cflags_default_prf="-pg"
+    cflags_default_dbg="-g -qfullpath"
+    cflags_default_prf="-pg -qfullpath"
     cflags_default_omp="-qsmp=omp -qthreaded"
 
     # Default  linker flags
     ldflags_default=""
     ldflags_default_opt="-O3"
-    ldflags_default_dbg="-g"
-    ldflags_default_prf="-pg"
+    ldflags_default_dbg="-g -qfullpath"
+    ldflags_default_prf="-pg -qfullpath"
     ldflags_rpath="-R"
 
     # Adjust options for IBM Blue Gene cross-compiler
@@ -1015,7 +1015,7 @@ if test "$?" = "0" ; then
   test -n "$cs_fc_vers_patch" || cs_fc_vers_patch=0
 
   # Default compiler flags
-  fcflags_default="-x f95-cpp-input -Wall"
+  fcflags_default="-x f95-cpp-input -Wall -pedantic-errors -std=f2003"
   fcflags_default_dbg="-g -fcheck=bounds"
   fcflags_default_opt="-O"
   fcflags_default_hot="-O2"
