@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -46,6 +46,7 @@ from PyQt4.QtGui  import *
 
 from Base.BrowserForm import Ui_BrowserForm
 from Base.Toolbox import GuiParam, displaySelectedPage
+from Base.QtPage import to_qvariant, from_qvariant, to_text_string
 
 #-------------------------------------------------------------------------------
 # log config
@@ -109,7 +110,7 @@ class TreeModel(QAbstractItemModel):
         QAbstractItemModel.__init__(self, parent)
 
         rootData = []
-        rootData.append("Pages")
+        rootData.append(to_qvariant("Pages"))
 
         self.rootItem = TreeItem(rootData, "folder")
         self.populateModel(data.split("\n"), self.rootItem)
@@ -138,7 +139,7 @@ class TreeModel(QAbstractItemModel):
         @return: C{QVariant}
         """
         if not index.isValid():
-            return None
+            return to_qvariant()
 
         item = index.internalPointer()
         column = index.column()
@@ -146,7 +147,7 @@ class TreeModel(QAbstractItemModel):
         if role == Qt.DisplayRole:
             # return text for columns
             if column == 0:
-                return item.itemData[column]
+                return to_qvariant(item.itemData[column])
 
         elif role == Qt.DecorationRole:
             # return icon for first column
@@ -162,9 +163,9 @@ class TreeModel(QAbstractItemModel):
                     icon = style.standardIcon(QStyle.SP_FileIcon)
                 elif item.itemType == "file-new":
                     icon = style.standardIcon(QStyle.SP_FileLinkIcon)
-                return icon
+                return to_qvariant(icon)
 
-        return None
+        return to_qvariant()
 
 
     def flags(self, index):
@@ -189,7 +190,7 @@ class TreeModel(QAbstractItemModel):
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
             return self.rootItem.data(section)
 
-        return None
+        return to_qvariant()
 
 
     def index(self, row, column, parent):
@@ -291,7 +292,7 @@ class TreeModel(QAbstractItemModel):
         """
         """
         info = []
-        search_item = str(data)
+        search_item = from_qvariant(to_qvariant(data), to_text_string)
 
         start = self.index(0, 0, QModelIndex())
         indexList = self.match(start, role, search_item, -1, Qt.MatchExactly)
@@ -375,7 +376,7 @@ class BrowserView(QWidget, Ui_BrowserForm):
         self.setupUi(self)
 
         tree = self._browser()
-        self.model = TreeModel(str(tree))
+        self.model = TreeModel(from_qvariant(to_qvariant(tree), to_text_string))
 
         self.treeView.setModel(self.model)
         self.treeView.header().hide()
@@ -414,13 +415,14 @@ Thermophysical models
     Atmospheric flows
     Species transport
 Physical properties
-    Reference values
     Fluid properties
+    Reference values
     Gravity
 Volume conditions
     Volume regions definition
     Initialization
     Head losses
+    Porosity
     Source terms
     Coriolis Source Terms
 Particles and droplets tracking
@@ -659,6 +661,7 @@ Calculation management
         self.setRowClose(self.tr('Fluid structure interaction'))
         self.setRowClose(self.tr('Source terms'))
         self.setRowClose(self.tr('Head losses'))
+        self.setRowClose(self.tr('Porosity'))
         self.setRowClose(self.tr('Lagrangian solution control'))
 
         # Steady flow management
@@ -782,6 +785,7 @@ Calculation management
         node_vol = node_domain.xmlGetNode('volumic_conditions')
         nb_zone = 0
         nb_zone_losses = 0
+        nb_zone_porosity = 0
 
         for node in node_vol.xmlGetChildNodeList('zone'):
             if node['momentum_source_term'] == 'on':
@@ -794,11 +798,15 @@ Calculation management
                 nb_zone = nb_zone + 1
             if node['head_losses'] == 'on':
                 nb_zone_losses = nb_zone_losses + 1
+            if node['porosity'] == 'on':
+                nb_zone_porosity = nb_zone_porosity + 1
 
         if nb_zone > 0:
             self.setRowOpen(self.tr('Source terms'))
         if nb_zone_losses > 0:
             self.setRowOpen(self.tr('Head losses'))
+        if nb_zone_porosity > 0:
+            self.setRowOpen(self.tr('Porosity'))
 
         self.__hideRow()
 
