@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -37,10 +37,6 @@ This module defines the following classes:
 
 import sys
 
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
-
 from PyQt4 import QtGui, QtCore
 
 #-------------------------------------------------------------------------------
