@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -61,6 +61,8 @@ from PyQt4.QtGui  import *
 #-------------------------------------------------------------------------------
 
 import cs_info
+from cs_exec_environment import \
+    separate_args, update_command_single_value, assemble_args, enquote_arg
 
 try:
     from Base.MainForm import Ui_MainForm
@@ -86,7 +88,8 @@ except:
 from Pages.WelcomeView import WelcomeView
 from Pages.IdentityAndPathesModel import IdentityAndPathesModel
 from Pages.XMLEditorView import XMLEditorView
-from Base.QtPage import setGreenColor
+from Base.QtPage import setGreenColor, getexistingdirectory
+from Base.QtPage import from_qvariant, to_text_string, getopenfilename, getsavefilename
 
 
 #-------------------------------------------------------------------------------
@@ -238,10 +241,10 @@ class NewCaseDialogView(QDialog, Ui_NewCaseDialogForm):
         dataPath = os.path.join(path, "..", "DATA")
         if os.path.isdir(dataPath): path = datapath
 
-        dirName = str(QFileDialog.getExistingDirectory(self, title,
-                                                       path,
-                                                       QFileDialog.ShowDirsOnly |
-                                                       QFileDialog.DontResolveSymlinks))
+        dirName = getexistingdirectory(self, title,
+                                       path,
+                                       QFileDialog.ShowDirsOnly |
+                                       QFileDialog.DontResolveSymlinks)
         if not dirName:
             self.copyFromName = None
         else:
@@ -391,13 +394,25 @@ class MainView(object):
 
         settings = QSettings()
 
-        if settings.value("RecentFiles", []) is not None:
-            self.recentFiles = settings.value("RecentFiles", [])
-        else:
-            self.recentFiles = []
-
-        self.restoreGeometry(settings.value("MainWindow/Geometry", QByteArray()))
-        self.restoreState(settings.value("MainWindow/State", QByteArray()))
+        try:
+            # API 2
+            if settings.value("RecentFiles", []) is not None:
+                try:
+                    recentFiles = settings.value("RecentFiles").toStringList()
+                    self.recentFiles = []
+                    for f in recentFiles:
+                        self.recentFiles.append(str(f))
+                except:
+                    self.recentFiles = list(settings.value("RecentFiles", []))
+            else:
+                self.recentFiles = []
+            self.restoreGeometry(settings.value("MainWindow/Geometry", QByteArray()))
+            self.restoreState(settings.value("MainWindow/State", QByteArray()))
+        except:
+            # API 1
+            self.recentFiles = settings.value("RecentFiles").toStringList()
+            self.restoreGeometry(settings.value("MainWindow/Geometry").toByteArray())
+            self.restoreState(settings.value("MainWindow/State").toByteArray())
 
         color = settings.value("MainWindow/Color",
                   self.palette().color(QPalette.Window).name())
@@ -412,7 +427,7 @@ class MainView(object):
 
         if f:
             font = QFont()
-            if (font.fromString(f)):
+            if (font.fromString(from_qvariant(f, to_text_string))):
                 self.setFont(font)
                 app = QCoreApplication.instance()
                 app.setFont(font)
@@ -537,7 +552,10 @@ class MainView(object):
             # :
             # self.recentFiles = self.recentFiles[:8]
             while len(self.recentFiles) > 9:
-                self.recentFiles.pop()
+                try:
+                    self.recentFiles.removeLast()
+                except:
+                    self.recentFiles.pop()
 
 
     def closeEvent(self, event):
@@ -551,7 +569,8 @@ class MainView(object):
             if self.recentFiles:
                 recentFiles = self.recentFiles
             else:
-                recentFiles = None
+                recentFiles = []
+
             settings.setValue("RecentFiles", recentFiles)
             settings.setValue("MainWindow/Geometry",
                               self.saveGeometry())
@@ -833,7 +852,7 @@ class MainView(object):
 
         filetypes = self.tr(self.package.code_name) + self.tr(" GUI files (*.xml);;""All Files (*)")
 
-        file_name = str(QFileDialog.getOpenFileName(self, title, path, filetypes))
+        file_name, _selfilter = getopenfilename(self, title, path, filetypes)
 
         if not file_name:
             msg = self.tr("Loading aborted")
@@ -955,10 +974,10 @@ class MainView(object):
 
         if hasattr(self,'case'):
             filetypes = self.tr(self.package.code_name) + self.tr(" GUI files (*.xml);;""All Files (*)")
-            fname = str(QFileDialog.getSaveFileName(self,
-                                                    self.tr("Save File As"),
-                                                    self.case['data_path'],
-                                                    filetypes))
+            fname, _selfilter = getsavefilename(self,
+                                                self.tr("Save File As"),
+                                                self.case['data_path'],
+                                                filetypes)
 
             if fname:
                 f = str(fname)
@@ -1036,46 +1055,25 @@ class MainView(object):
         """
         Update the run command
         """
+
         cmd_name = self.case['package'].name
         parameters = os.path.basename(self.case['xmlfile'])
         batch_lines = self.batch_lines
 
-        # If filename has whitespace, protect it
-        if parameters.find(' ') > -1:
-            parameters = '"' + parameters + '"'
-
         for i in range(len(batch_lines)):
             if batch_lines[i][0:1] != '#':
-                line = batch_lines[i].strip()
-                index = string.find(line, cmd_name)
+                index = string.find(batch_lines[i], cmd_name)
                 if index < 0:
                     continue
+                line = batch_lines[i]
                 if line[index + len(cmd_name):].strip()[0:3] != 'run':
                     continue
-                index = string.find(line, '--param')
-                if index >= 0:
-                    # Find file name, possibly protected by quotes
-                    # (protection by escape character not handled)
-                    index += len('--param')
-                    end = len(line)
-                    while index < end and line[index] in (' ', '\t'):
-                        index += 1
-                    if index < end:
-                        sep = line[index]
-                        if sep == '"' or sep == "'":
-                            index += 1
-                        else:
-                            sep = ' '
-                        start = index
-                        while index < end and line[index] != sep:
-                            index += 1
-                        end = index
-                        batch_lines[i] = line[0:start].strip() \
-                            + ' ' + parameters + ' ' + line[end:].strip() + '\n'
-                    else:
-                        batch_lines[i] = line + ' --param ' + parameters + '\n'
-                else:
-                    batch_lines[i] = line + ' --param ' + parameters + '\n'
+
+                args = update_command_single_value(separate_args(line.rstrip()),
+                                                   ('--param', '--param=', '-p'),
+                                                   enquote_arg(parameters))
+                batch_lines[i] = assemble_args(args) + '\n'
+                break
 
         self.batch_lines = batch_lines
 
