@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -1594,12 +1594,12 @@ class XMLengineTestCase(unittest.TestCase):
         assert n5 == n6, 'This two node are not identical'
 
         d1 = '<turbulence model="Rij-epsilon">'\
-                '<property label="turb. vi" name="turb_viscosity"/>'\
+                '<property label="turb. vi" name="turbulent_viscosity"/>'\
                 '<variable label="R11" name="component_R11"/>'\
             '</turbulence>'
         d2 = '<turbulence model="Rij-epsilon">'\
                 '<variable label="R11" name="component_R11"/>'\
-                '<property label="turb. vi" name="turb_viscosity"/>'\
+                '<property label="turb. vi" name="turbulent_viscosity"/>'\
             '</turbulence>'
         n5 = self.xmlNodeFromString(d1)
         n6 = XMLDocument().parseString(d2).root()
