@@ -338,7 +338,7 @@ class XMLinit(Variables):
                         if n:
                             n.xmlRemoveNode()
                         ThermalScalarModel(self.case).setThermalModel('potential_temperature')
-                    else:
+                    if (mdl == "humid"):
                         n = node.xmlGetNode('scalar', name="liquid_potential_temperature")
                         if n:
                             n.xmlRemoveNode()
@@ -362,13 +362,13 @@ class XMLinit(Variables):
 
         n = XMLThermoPhysicalNode.xmlGetNode('variable', type='thermal')
         if n:
-            nf = n.xmlGetNode('formula')
-            if nf:
-                status = nf["status"]
-                if not(status) or status == "on":
-                    content = nf.xmlGetTextNode()
-                    content = content.replace(n['label'], n['name'])
-                    nf.xmlSetTextNode(content)
+            for nf in n.xmlGetNodeList('formula'):
+                if nf:
+                    status = nf["status"]
+                    if not(status) or status == "on":
+                        content = nf.xmlGetTextNode()
+                        content = content.replace(n['label'], n['name'])
+                        nf.xmlSetTextNode(content)
 
 
         # update velocity node
