@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -48,10 +48,10 @@ from PyQt4.QtGui  import *
 #-------------------------------------------------------------------------------
 
 from Base.Toolbox import GuiParam
-from AnalysisFeaturesForm import Ui_AnalysisFeaturesForm
 
 import Base.QtPage as QtPage
 
+from Pages.AnalysisFeaturesForm import Ui_AnalysisFeaturesForm
 from Pages.TurbulenceModel import TurbulenceModel
 from Pages.LagrangianModel import LagrangianModel
 from Pages.GasCombustionModel import GasCombustionModel
@@ -301,6 +301,19 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
         self.comboBoxAtmospheric.setEnabled(True)
         self.comboBoxCompressible.setEnabled(True)
 
+        if self.turb.getTurbulenceModel() not in ('k-epsilon',
+                                                  'k-epsilon-PL',
+                                                  'Rij-epsilon',
+                                                  'Rij-SSG',
+                                                  'Rij-EBRSM',
+                                                  'v2f-BL-v2/k',
+                                                  'k-omega-SST',
+                                                  'Spalart-Allmaras'):
+
+            self.comboBoxGasCombustionModel.setEnabled(False)
+            self.comboBoxPulverizedCoal.setEnabled(False)
+            self.comboBoxCompressible.setEnabled(False)
+
 
     def __disableComboBox(self):
         """
