@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -43,13 +43,15 @@ from Pages.CoalCombustionModel import CoalCombustionModel
 from Pages.AtmosphericFlowsModel import AtmosphericFlowsModel
 from Base.XMLvariables import Variables, Model
 
+import cs_exec_environment
+
 #-------------------------------------------------------------------------------
 # Class BatchRunningModel
 #-------------------------------------------------------------------------------
 
 class BatchRunningModel(Model):
     """
-    This class modifies the batch file (runcase_batch)
+    This class modifies the batch file (runcase)
     """
     def __init__(self, parent, case):
         """
@@ -71,11 +73,15 @@ class BatchRunningModel(Model):
         self.dictValues['job_class'] = None
         self.dictValues['job_group'] = None
 
+        # Do we force a number of MPI ranks ?
+
+        self.dictValues['run_nprocs'] = None
+
         # Is a batch file present ?
 
-        self.batch1 = os.path.join(self.case['scripts_path'], self.case['batch'])
+        self.batch = os.path.join(self.case['scripts_path'], self.case['batch'])
 
-        if os.path.isfile(self.batch1):
+        if os.path.isfile(self.batch):
             if self.parent.batch_lines:
                 self.parseBatchFile()
             else:
@@ -95,6 +101,56 @@ class BatchRunningModel(Model):
         return s
 
 
+    def parseBatchRunOptions(self):
+        """
+        Update the run command
+        """
+        cmd_name = self.case['package'].name
+        batch_lines = self.parent.batch_lines
+
+        for i in range(len(batch_lines)):
+            if batch_lines[i][0:1] != '#':
+                index = string.find(batch_lines[i], cmd_name)
+                if index < 0:
+                    continue
+                line = batch_lines[i]
+                if line[index + len(cmd_name):].strip()[0:3] != 'run':
+                    continue
+
+                args = cs_exec_environment.separate_args(line.rstrip())
+                self.dictValues['run_nprocs'] \
+                    = cs_exec_environment.get_command_single_value(args,
+                                                                   ('--nprocs',
+                                                                    '--nprocs=',
+                                                                    '-n'))
+
+
+    def updateBatchRunOptions(self, keyword=None):
+        """
+        Update the run command
+        """
+        cmd_name = self.case['package'].name
+        batch_lines = self.parent.batch_lines
+
+        for i in range(len(batch_lines)):
+            if batch_lines[i][0:1] != '#':
+                index = string.find(batch_lines[i], cmd_name)
+                if index < 0:
+                    continue
+                line = batch_lines[i]
+                if line[index + len(cmd_name):].strip()[0:3] != 'run':
+                    continue
+
+                args = cs_exec_environment.separate_args(line.rstrip())
+
+                if keyword == 'run_nprocs' or not keyword:
+                    args = cs_exec_environment.update_command_single_value \
+                        (args, ('--nprocs', '--nprocs=', '-n'),
+                         self.dictValues['run_nprocs'])
+
+                batch_lines[i] = cs_exec_environment.assemble_args(args) + '\n'
+
+
     def parseBatchCCC(self):
         """
         Parse Platform LSF batch file lines
@@ -288,8 +344,8 @@ class BatchRunningModel(Model):
 
         # TODO: specialize for PBS Professional and TORQUE (OpenPBS has not been
         # maintained since 2004, so we do not support it).
-        # We use the "-l nodes=N:ppn=P" syntax here, which is common to all PBS
-        # variants, but PBS Pro considers the syntax depecated, and prefers its
+        # The "-l nodes=N:ppn=P" syntax is common to all PBS variants,
+        # but PBS Pro considers the syntax depecated, and prefers its
         # own "-l select=N:ncpus=P:mpiprocs=P" syntax.
         # We do not have access to a PBS Professional system, but according to
         # its documentation, it has commands such as "pbs-report" or "pbs_probe"
@@ -309,7 +365,19 @@ class BatchRunningModel(Model):
                     elif arg[0:9] == '-l nodes=':
                         arg_tmp = arg[9:].split(':')
                         self.dictValues['job_nodes'] = arg_tmp[0]
-                        self.dictValues['job_ppn'] = arg_tmp[1].split('=')[1]
+                        for s in arg_tmp[1:]:
+                            j = s.find('ppn=')
+                            if j > -1:
+                                self.dictValues['job_ppn'] \
+                                    = s[j:].split('=')[1]
+                    elif arg[0:10] == '-l select=':
+                        arg_tmp = arg[10:].split(':')
+                        self.dictValues['job_nodes'] = arg_tmp[0]
+                        for s in arg_tmp[1:]:
+                            j = s.find('ncpus=')
+                            if j > -1:
+                                self.dictValues['job_ppn'] \
+                                    = s[j:].split('=')[1]
                     elif arg[0:12] == '-l walltime=':
                         wt = (arg.split('=')[1]).split(':')
                         if len(wt) == 3:
@@ -343,8 +411,33 @@ class BatchRunningModel(Model):
                     if arg[0:2] == '-N':
                         ch = ' -N ' + self.dictValues['job_name'] + ch
                     elif arg[0:9] == '-l nodes=':
-                        ch = ' -l nodes=' + self.dictValues['job_nodes'] \
-                            +  ':ppn=' + self.dictValues['job_ppn'] + ch
+                        arg_tmp = arg[9:].split(':')
+                        ch1 = ' -l nodes=' + self.dictValues['job_nodes']
+                        for s in arg_tmp[1:]:
+                            j = s.find('ppn=')
+                            if j > -1:
+                                ch1 += ':' + s[0:j] \
+                                       + 'ppn=' + self.dictValues['job_ppn']
+                            else:
+                                ch1 += ':' + s
+                        j = ch1.find('\n')
+                        if (j > -1):
+                            ch1 = ch1[0:j]
+                        ch = ch1 + ch
+                    elif arg[0:10] == '-l select=':
+                        arg_tmp = arg[10:].split(':')
+                        ch1 = ' -l select=' + self.dictValues['job_nodes']
+                        for s in arg_tmp[1:]:
+                            j = s.find('ncpus=')
+                            if j > -1:
+                                ch1 += ':' + s[0:j] \
+                                       + 'ncpus=' + self.dictValues['job_ppn']
+                            else:
+                                ch1 += ':' + s
+                        j = ch1.find('\n')
+                        if (j > -1):
+                            ch1 = ch1[0:j]
+                        ch = ch1 + ch
                     elif arg[0:12] == '-l walltime=':
                         wt = self.dictValues['job_walltime']
                         s_wt = '%d:%02d:%02d' % (wt/3600,
@@ -545,14 +638,14 @@ class BatchRunningModel(Model):
         if not self.case['batch']:
             return
 
-        self.batch1 = os.path.join(self.case['scripts_path'], self.case['batch'])
-        if not os.path.isfile(self.batch1):
+        self.batch = os.path.join(self.case['scripts_path'], self.case['batch'])
+        if not os.path.isfile(self.batch):
             return
 
         # Read the batch file line by line.
         # All lines are stored in a list called "self.batch_lines".
 
-        f = open(self.batch1, 'r')
+        f = open(self.batch, 'r')
         batch_lines = f.readlines()
         f.close()
 
@@ -574,6 +667,8 @@ class BatchRunningModel(Model):
 
         # Parse lines depending on batch type
 
+        self.parseBatchRunOptions()
+
         if self.case['batch_type'] == None:
             return
 
@@ -590,6 +685,7 @@ class BatchRunningModel(Model):
         elif self.case['batch_type'][0:5] == 'SLURM':
             self.parseBatchSLURM()
 
+
     def updateBatchFile(self, keyword=None):
         """
         Update the batch file from reading dictionary self.dictValues.
@@ -603,6 +699,8 @@ class BatchRunningModel(Model):
                 self.dictValues[k] = None
         self.isInList(keyword, l)
 
+        self.updateBatchRunOptions()
+
         batch_type = self.case['batch_type']
         if batch_type:
             if batch_type[0:3] == 'CCC':
@@ -619,16 +717,6 @@ class BatchRunningModel(Model):
                 self.updateBatchSLURM()
 
 
-    def _getRegex(self, word):
-        """
-        Get regular expression to extract line without comment
-        """
-        # handles both comments and "$word":
-        regex = re.compile(r"""(^(?#)^\s*(?<!$)""" + word + r""".*$)""")
-
-        return regex
-
-
 #-------------------------------------------------------------------------------
 # BatchRunningModel test class
 #-------------------------------------------------------------------------------
@@ -649,7 +737,7 @@ class BatchRunningModelTestCase(unittest.TestCase):
 
         self.case['batch_type'] = None
         self.case['scripts_path'] = os.getcwd()
-        self.case['batch'] = 'runcase_batch'
+        self.case['batch'] = 'runcase'
 
         lance_PBS = '# test \n'\
         '#\n'\
@@ -709,7 +797,7 @@ class BatchRunningModelTestCase(unittest.TestCase):
         """ Check whether the BatchRunningModel class could update file"""
         mdl = BatchRunningModel(self.case)
         mdl.readBatchFile()
-        mdl.dictValues['N_PROCS']=48
+        mdl.dictValues['job_procs']=48
         dico_updated = mdl.dictValues
         mdl.updateBatchFile()
         mdl.readBatchFile()
