@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -139,6 +139,8 @@ class BoundaryConditionsMeteoView(QWidget, Ui_BoundaryConditionsMeteoForm):
             else:
                 self.checkBoxAutoNature.setChecked(False)
 
+            self.scalarsWidget.showWidget(self.__b)
+
         else:
             self.hideWidget()
 
@@ -159,13 +161,11 @@ class BoundaryConditionsMeteoView(QWidget, Ui_BoundaryConditionsMeteoForm):
             self.checkBoxAutoNature.setEnabled(True)
             self.velocityWidget.hideWidget()
             self.turbulenceWidget.hideWidget()
-            self.scalarsWidget.groupBoxMeteo.hide()
         else:
             self.__boundary.setMeteoDataStatus('off')
             self.checkBoxAutoNature.setChecked(False)
             self.__boundary.setAutomaticNatureStatus('off')
             self.checkBoxAutoNature.setEnabled(False)
-            self.scalarsWidget.showWidget(self.__b)
             if self.__boundary.getNature() == "meteo_inlet":
                 self.velocityWidget.showWidget(self.__b)
                 self.turbulenceWidget.showWidget(self.__b)
@@ -173,6 +173,8 @@ class BoundaryConditionsMeteoView(QWidget, Ui_BoundaryConditionsMeteoForm):
                 self.velocityWidget.hideWidget()
                 self.turbulenceWidget.hideWidget()
 
+        self.scalarsWidget.showWidget(self.__b)
+
 
     def __slotAutoNature(self, bool):
         """
