@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -36,10 +36,6 @@ import logging
 #-------------------------------------------------------------------------------
 # Third-party modules
 #-------------------------------------------------------------------------------
-import sys
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
@@ -48,15 +44,17 @@ from PyQt4.QtGui  import *
 # Application modules import
 #-------------------------------------------------------------------------------
 
-from BoundaryConditionsScalarsForm import Ui_BoundaryConditionsScalarsForm
-
 from Base.Toolbox import GuiParam
-from Base.QtPage import DoubleValidator, ComboModel, setGreenColor
+from Base.QtPage import DoubleValidator, ComboModel, setGreenColor, from_qvariant
+
+from Pages.BoundaryConditionsScalarsForm import Ui_BoundaryConditionsScalarsForm
 from Pages.LocalizationModel import LocalizationModel, Zone
 from Pages.DefineUserScalarsModel import DefineUserScalarsModel
 from Pages.ThermalScalarModel import ThermalScalarModel
 from Pages.QMeiEditorView import QMeiEditorView
 from Pages.Boundary import Boundary
+from Pages.CompressibleModel import CompressibleModel
+from Pages.AtmosphericFlowsModel import AtmosphericFlowsModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -136,6 +134,8 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         self.nature  = boundary.getNature()
         self.therm   = ThermalScalarModel(self.__case)
         self.sca_mo  = DefineUserScalarsModel(self.__case)
+        self.comp    = CompressibleModel(self.__case)
+        self.atm     = AtmosphericFlowsModel(self.__case)
 
         self.modelTypeThermal = ComboModel(self.comboBoxTypeThermal, 1, 1)
         self.modelTypeSpecies = ComboModel(self.comboBoxTypeSpecies, 1, 1)
@@ -184,26 +184,8 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         else:
             self.groupBoxSpecies.hide()
 
-        self.meteo_list = ""
-        self.meteo_list = self.sca_mo.getMeteoScalarsList()
-
-        self.groupBoxMeteo.hide()
-
-        if (self.meteo_list and (self.nature == 'inlet' or self.nature == 'outlet')):
-            label = self.__boundary.getLabel()
-            nature = "meteo_" + self.nature
-            bb = Boundary(nature, label, self.__case)
-
-            if bb.getMeteoDataStatus() == 'off':
-                self.groupBoxMeteo.show()
-                self.modelMeteo = ComboModel(self.comboBoxMeteo, 1, 1)
-                for m in self.meteo_list:
-                    self.modelMeteo.addItem(self.tr(m), m)
-                self.meteo = self.meteo_list[0]
-                self.modelMeteo.setItem(str_model = self.meteo)
-
         self.model_th = self.therm.getThermalScalarModel()
-        if self.model_th != 'off':
+        if self.model_th != 'off' and self.comp.getCompressibleModel() == 'off':
             self.groupBoxThermal.show()
             self.modelThermal = ComboModel(self.comboBoxThermal,1,1)
             self.thermal = self.therm.getThermalScalarLabel()
@@ -212,6 +194,34 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         else:
             self.groupBoxThermal.hide()
 
+        self.meteo_list = ""
+        self.meteo_list = self.sca_mo.getMeteoScalarsList()
+
+        self.groupBoxMeteo.hide()
+
+        if (self.atm.getAtmosphericFlowsModel() != "off" and self.nature == 'wall'):
+            self.groupBoxThermal.hide()
+
+        if (self.atm.getAtmosphericFlowsModel() != "off" and \
+           (self.nature == 'inlet' or self.nature == 'outlet')):
+            label = self.__boundary.getLabel()
+            nature = "meteo_" + self.nature
+            bb = Boundary(nature, label, self.__case)
+
+            if bb.getMeteoDataStatus() == 'off':
+                self.groupBoxMeteo.hide()
+                self.groupBoxThermal.show()
+                self.modelMeteo = ComboModel(self.comboBoxMeteo, 1, 1)
+                if len(self.meteo_list) > 0:
+                    self.groupBoxMeteo.show()
+                    for m in self.meteo_list:
+                        self.modelMeteo.addItem(self.tr(m), m)
+                    self.meteo = self.meteo_list[0]
+                    self.modelMeteo.setItem(str_model = self.meteo)
+            else:
+                self.groupBoxMeteo.hide()
+                self.groupBoxThermal.hide()
+
         self.initializeVariables()
 
 
@@ -233,7 +243,7 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         self.pushButtonThermal.setEnabled(False)
         setGreenColor(self.pushButtonThermal, False)
 
-        if self.model_th != 'off':
+        if self.model_th != 'off' and self.comp.getCompressibleModel() == 'off':
             self.thermal_type = self.__boundary.getScalarChoice(self.thermal)
             self.modelTypeThermal.setItem(str_model = self.thermal_type)
             self.labelValueThermal.setText('Value')
@@ -430,9 +440,14 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
             req = [("flux", "flux")]
         elif self.thermal_type == 'exchange_coefficient_formula':
             req = [(self.thermal, str(self.thermal)),("hc", "heat coefficient")]
-        sym = [('x', 'cell center coordinate'),
-               ('y', 'cell center coordinate'),
-               ('z', 'cell center coordinate')]
+
+        sym = [('x', "X face's gravity center"),
+               ('y', "Y face's gravity center"),
+               ('z', "Z face's gravity center"),
+               ('dt', 'time step'),
+               ('t', 'current time'),
+               ('iter', 'number of iteration')]
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.__case['package'].get_check_syntax(),
                                 expression = exp,
@@ -458,9 +473,14 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
             req = [("flux", "flux")]
         elif self.species_type == 'exchange_coefficient_formula':
             req = [(self.species, str(self.species)),("hc", "heat coefficient")]
-        sym = [('x', 'cell center coordinate'),
-               ('y', 'cell center coordinate'),
-               ('z', 'cell center coordinate')]
+
+        sym = [('x', "X face's gravity center"),
+               ('y', "Y face's gravity center"),
+               ('z', "Z face's gravity center"),
+               ('dt', 'time step'),
+               ('t', 'current time'),
+               ('iter', 'number of iteration')]
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.__case['package'].get_check_syntax(),
                                 expression = exp,
@@ -486,9 +506,14 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
             req = [("flux", "flux")]
         elif self.meteo_type == 'exchange_coefficient_formula':
             req = [(self.meteo, str(self.meteo)),("hc", "heat coefficient")]
-        sym = [('x', 'cell center coordinate'),
-               ('y', 'cell center coordinate'),
-               ('z', 'cell center coordinate')]
+
+        sym = [('x', "X face's gravity center"),
+               ('y', "Y face's gravity center"),
+               ('z', "Z face's gravity center"),
+               ('dt', 'time step'),
+               ('t', 'current time'),
+               ('iter', 'number of iteration')]
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.__case['package'].get_check_syntax(),
                                 expression = exp,
@@ -507,7 +532,7 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         """
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(var)
+            value = from_qvariant(var, float)
             if self.thermal_type in ('dirichlet', 'neumann'):
                 self.__boundary.setScalarValue(self.thermal, self.thermal_type, value)
             elif self.thermal_type == 'exchange_coefficient':
@@ -519,7 +544,7 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         """
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(var)
+            value = from_qvariant(var, float)
             if self.species_type in ('dirichlet', 'neumann'):
                 self.__boundary.setScalarValue(self.species, self.species_type, value)
             elif self.species_type == 'exchange_coefficient' :
@@ -531,7 +556,7 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         """
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(var)
+            value = from_qvariant(var, float)
             if self.meteo_type in ('dirichlet', 'neumann'):
                 self.__boundary.setScalarValue(self.meteo, self.meteo_type, value)
             elif self.meteo_type == 'exchange_coefficient':
@@ -543,7 +568,7 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         """
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(var)
+            value = from_qvariant(var, float)
             self.__boundary.setScalarValue(self.thermal, 'exchange_coefficient', value)
 
 
@@ -552,7 +577,7 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         """
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(var)
+            value = from_qvariant(var, float)
             self.__boundary.setScalarValue(self.species, 'exchange_coefficient', value)
 
 
@@ -561,7 +586,7 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         """
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(var)
+            value = from_qvariant(var, float)
             self.__boundary.setScalarValue(self.meteo, 'exchange_coefficient', value)
 
 
