@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -36,10 +36,6 @@ import string, logging
 #-------------------------------------------------------------------------------
 # Third-party modules
 #-------------------------------------------------------------------------------
-import sys
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
@@ -52,7 +48,7 @@ from Pages.BoundaryConditionsSlidingWallForm import Ui_BoundaryConditionsSliding
 from Pages.MobileMeshModel import MobileMeshModel
 
 from Base.Toolbox import GuiParam
-from Base.QtPage import DoubleValidator, ComboModel
+from Base.QtPage import DoubleValidator, ComboModel, from_qvariant
 from Pages.LocalizationModel import LocalizationModel, Zone
 from Pages.Boundary import Boundary
 
@@ -169,8 +165,8 @@ class BoundaryConditionsSlidingWallView(QWidget, Ui_BoundaryConditionsSlidingWal
         @param text: sliding wall U velocity component.
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(text)
-            self.__boundary.setVelocityComponent(value, 'velocity_U')
+            value = from_qvariant(text, float)
+            self.__boundary.setVelocityComponent(value, '0')
 
 
     @pyqtSignature("const QString&")
@@ -184,8 +180,8 @@ class BoundaryConditionsSlidingWallView(QWidget, Ui_BoundaryConditionsSlidingWal
         @param text: sliding wall V velocity component.
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(text)
-            self.__boundary.setVelocityComponent(value, 'velocity_V')
+            value = from_qvariant(text, float)
+            self.__boundary.setVelocityComponent(value, '1')
 
 
     @pyqtSignature("const QString&")
@@ -199,8 +195,8 @@ class BoundaryConditionsSlidingWallView(QWidget, Ui_BoundaryConditionsSlidingWal
         @param text: sliding wall W velocity component.
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(text)
-            self.__boundary.setVelocityComponent(value, 'velocity_W')
+            value = from_qvariant(text, float)
+            self.__boundary.setVelocityComponent(value, '2')
 
 
     def tr(self, text):
