@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -36,10 +36,6 @@ import string, logging
 #-------------------------------------------------------------------------------
 # Third-party modules
 #-------------------------------------------------------------------------------
-import sys
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
@@ -51,7 +47,7 @@ from PyQt4.QtGui  import *
 from Pages.BoundaryConditionsVelocityInletForm import Ui_BoundaryConditionsVelocityInletForm
 
 from Base.Toolbox import GuiParam
-from Base.QtPage import DoubleValidator, ComboModel, setGreenColor
+from Base.QtPage import DoubleValidator, ComboModel, setGreenColor, from_qvariant
 from Pages.LocalizationModel import LocalizationModel, Zone
 from Pages.Boundary import Boundary
 from Pages.CompressibleModel import CompressibleModel
@@ -398,7 +394,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         @param text: value
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            v = float(text)
+            v = from_qvariant(text, float)
             self.__boundary.setVelocity(v)
 
 
@@ -408,13 +404,15 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         """
         exp = self.__boundary.getVelocity()
         c = self.__boundary.getVelocityChoice()
-        req = [('u_norm', 'Norm of the velocity')]
         if c == 'norm_formula':
             exa = "u_norm = 1.0;"
+            req = [('u_norm', 'Norm of the velocity')]
         elif c == 'flow1_formula':
             exa = "q_m = 1.0;"
+            req = [('q_m', 'mass flow rate')]
         elif c == 'flow2_formula':
             exa = "q_v = 1.0;"
+            req = [('q_v', 'volumic flow rate')]
 
         sym = [('x', "X face's gravity center"),
                ('y', "Y face's gravity center"),
@@ -471,7 +469,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT value into direction of inlet flow
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(text)
+            value = from_qvariant(text, float)
             self.__boundary.setDirection('direction_x', value)
 
 
@@ -481,7 +479,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT value into direction of inlet flow
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(text)
+            value = from_qvariant(text, float)
             self.__boundary.setDirection('direction_y', value)
 
 
@@ -491,7 +489,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT value into direction of inlet flow
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            value = float(text)
+            value = from_qvariant(text, float)
             self.__boundary.setDirection('direction_z', value)
 
 
@@ -593,7 +591,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT inlet Pressure
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            t = float(text)
+            t = from_qvariant(text, float)
             self.__boundary.setThermoValue('pressure', t)
 
 
@@ -603,7 +601,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT inlet Density
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            t = float(text)
+            t = from_qvariant(text, float)
             self.__boundary.setThermoValue('density', t)
 
 
@@ -613,7 +611,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT inlet Temperature
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            t = float(text)
+            t = from_qvariant(text, float)
             self.__boundary.setThermoValue('temperature', t)
 
 
@@ -623,7 +621,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT inlet Energy
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            t = float(text)
+            t = from_qvariant(text, float)
             self.__boundary.setThermoValue('energy', t)
 
 
@@ -633,7 +631,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT inlet total pressure
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            t = float(text)
+            t = from_qvariant(text, float)
             self.__boundary.setThermoValue('total_pressure', t)
 
 
@@ -643,7 +641,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT inlet total enthalpy
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            t = float(text)
+            t = from_qvariant(text, float)
             self.__boundary.setThermoValue('enthalpy', t)
 
 
@@ -653,7 +651,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT inlet temperature
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            t = float(text)
+            t = from_qvariant(text, float)
             self.__boundary.setGasCombustionTemperature(t)
 
 
@@ -663,7 +661,7 @@ class BoundaryConditionsVelocityInletView(QWidget, Ui_BoundaryConditionsVelocity
         INPUT inlet mean mixutre fraction
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            f = float(text)
+            t = from_qvariant(text, float)
             self.__boundary.setMeanMixtureFraction(f)
 
 
