@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -42,10 +42,6 @@ import logging
 #-------------------------------------------------------------------------------
 # Third-party modules
 #-------------------------------------------------------------------------------
-import sys
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
@@ -54,14 +50,14 @@ from PyQt4.QtGui  import *
 # Application modules import
 #-------------------------------------------------------------------------------
 
-from Pages.DefineUserScalarsForm import Ui_DefineUserScalarsForm
-
-from Pages.LocalizationModel import LocalizationModel
-from Pages.DefineUserScalarsModel import DefineUserScalarsModel
-
 from Base.Common import LABEL_LENGTH_MAX
 from Base.Toolbox import GuiParam
 from Base.QtPage import ComboModel, DoubleValidator, RegExpValidator
+from Base.QtPage import to_qvariant, from_qvariant, to_text_string
+
+from Pages.DefineUserScalarsForm import Ui_DefineUserScalarsForm
+from Pages.LocalizationModel import LocalizationModel
+from Pages.DefineUserScalarsModel import DefineUserScalarsModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -97,7 +93,7 @@ class LabelDelegate(QItemDelegate):
 
 
     def setEditorData(self, editor, index):
-        value = str(index.model().data(index, Qt.DisplayRole))
+        value = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
         self.old_plabel = str(value)
         editor.setText(value)
 
@@ -125,7 +121,7 @@ class LabelDelegate(QItemDelegate):
                 else:
                     new_plabel = self.old_plabel
 
-            model.setData(index, str(new_plabel), Qt.DisplayRole)
+            model.setData(index, to_qvariant(str(new_plabel)), Qt.DisplayRole)
 
 #-------------------------------------------------------------------------------
 # Line edit delegate for the variance name
@@ -152,7 +148,7 @@ class VarianceNameDelegate(QItemDelegate):
 
 
     def setEditorData(self, editor, index):
-        value = str(index.model().data(index, Qt.DisplayRole))
+        value = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
         self.old_plabel = str(value)
         editor.setText(value)
 
@@ -180,7 +176,7 @@ class VarianceNameDelegate(QItemDelegate):
                 else:
                     new_plabel = self.old_plabel
 
-            model.setData(index, str(new_plabel), Qt.DisplayRole)
+            model.setData(index, to_qvariant(str(new_plabel)), Qt.DisplayRole)
 
 
 #-------------------------------------------------------------------------------
@@ -205,6 +201,8 @@ class VarianceDelegate(QItemDelegate):
 
     def setEditorData(self, editor, index):
         l1 = index.model().mdl.getScalarLabelsList()
+        for label in index.model().mdl.getThermalScalarLabelsList():
+            l1.append(label)
         for s in index.model().mdl.getScalarsVarianceList():
             if s in l1: l1.remove(s)
 
@@ -215,7 +213,7 @@ class VarianceDelegate(QItemDelegate):
     def setModelData(self, comboBox, model, index):
         txt = str(comboBox.currentText())
         value = self.modelCombo.dicoV2M[txt]
-        model.setData(index, value, Qt.DisplayRole)
+        model.setData(index, to_qvariant(value), Qt.DisplayRole)
 
 
     def tr(self, text):
@@ -249,17 +247,17 @@ class StandardItemModelScalars(QStandardItemModel):
 
     def data(self, index, role):
         if not index.isValid():
-            return
+            return to_qvariant()
 
         row = index.row()
         col = index.column()
 
         if role == Qt.ToolTipRole:
-            return self.toolTipRole[col]
+            return to_qvariant(self.toolTipRole[col])
         if role == Qt.DisplayRole:
-            return self._data[row][col]
+            return to_qvariant(self._data[row][col])
 
-        return
+        return to_qvariant()
 
 
     def flags(self, index):
@@ -270,8 +268,8 @@ class StandardItemModelScalars(QStandardItemModel):
 
     def headerData(self, section, orientation, role):
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
-            return self.headers[section]
-        return
+            return to_qvariant(self.headers[section])
+        return to_qvariant()
 
 
     def setData(self, index, value, role):
@@ -285,7 +283,7 @@ class StandardItemModelScalars(QStandardItemModel):
         # Label
         if col == 0:
             old_plabel = self._data[row][col]
-            new_plabel = str(value)
+            new_plabel = str(from_qvariant(value, to_text_string))
             self._data[row][col] = new_plabel
             self.mdl.renameScalarLabel(old_plabel, new_plabel)
 
@@ -357,17 +355,17 @@ class StandardItemModelVariance(QStandardItemModel):
 
     def data(self, index, role):
         if not index.isValid():
-            return
+            return to_qvariant()
 
         row = index.row()
         col = index.column()
 
         if role == Qt.ToolTipRole:
-            return self.toolTipRole[col]
+            return to_qvariant(self.toolTipRole[col])
         if role == Qt.DisplayRole:
-            return self._data[row][col]
+            return to_qvariant(self._data[row][col])
 
-        return
+        return to_qvariant()
 
 
     def flags(self, index):
@@ -378,8 +376,8 @@ class StandardItemModelVariance(QStandardItemModel):
 
     def headerData(self, section, orientation, role):
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
-            return self.headers[section]
-        return
+            return to_qvariant(self.headers[section])
+        return to_qvariant()
 
 
     def setData(self, index, value, role):
@@ -393,14 +391,14 @@ class StandardItemModelVariance(QStandardItemModel):
         # Label
         if col == 0:
             old_plabel = self._data[row][col]
-            new_plabel = str(value)
+            new_plabel = str(from_qvariant(value, to_text_string))
             self._data[row][col] = new_plabel
             self.mdl.renameScalarLabel(old_plabel, new_plabel)
 
 
         # Variance
         elif col == 1:
-            variance = str(value)
+            variance = str(from_qvariant(value, to_text_string))
             self._data[row][col] = variance
             [label, var] = self._data[row]
             self.mdl.setScalarVariance(label,var)
@@ -418,7 +416,7 @@ class StandardItemModelVariance(QStandardItemModel):
         """
         Add an item in the table view
         """
-        if not self.mdl.getScalarLabelsList():
+        if not self.mdl.getScalarLabelsList() and not self.mdl.getThermalScalarLabelsList():
             title = self.tr("Warning")
             msg   = self.tr("There is no user scalar.\n"\
                             "Please define a user scalar.")
