@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -36,13 +36,21 @@ This module contains the following classes and function:
 
 import logging
 
+#-------------------------------------------------------------------------------
+# EOS
+#-------------------------------------------------------------------------------
+
+EOS = 1
+try:
+   import eosAva
+except:
+   EOS = 0
+else :
+   import eosAva
+
 #-------------------------------------------------------------------------------
 # Third-party modules
 #-------------------------------------------------------------------------------
-import sys
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
@@ -52,7 +60,7 @@ from PyQt4.QtGui  import *
 #-------------------------------------------------------------------------------
 
 from Base.Toolbox import GuiParam
-from Base.QtPage import DoubleValidator, ComboModel, setGreenColor
+from Base.QtPage import DoubleValidator, ComboModel, setGreenColor, from_qvariant
 from Pages.FluidCharacteristicsForm import Ui_FluidCharacteristicsForm
 from Pages.FluidCharacteristicsModel import FluidCharacteristicsModel
 from Pages.DefineUserScalarsModel import DefineUserScalarsModel
@@ -76,12 +84,13 @@ log.setLevel(GuiParam.DEBUG)
 #-------------------------------------------------------------------------------
 
 class FluidCharacteristicsView(QWidget, Ui_FluidCharacteristicsForm):
+
     """
     Class to open Molecular Properties Page.
     """
     density = """# Density of air
+density = 1.293*(273.15 / TempK);
 
-rho = 1.293 * (273.15 / Temp_K);
 
 # density for mixtures of gases
 #
@@ -91,7 +100,7 @@ rho = 1.293 * (273.15 / Temp_K);
 rho1 = 1.25051;
 rho2 = 1.7832;
 A = (Y1 / rho1) + (Y2 /rho2);
-rho = 1.0 / A;
+density = 1.0 / A;
 
 """
     molecular_viscosity="""# Sutherland's Formula
@@ -108,12 +117,12 @@ rho = 1.0 / A;
 
 CST = 120;
 T0 = 291.15;
-mu0 = 18.27e-6;
+mu_ref = 18.27e-6;
 
-if ( Temp_K > 0 && Temp_K < 555) {
-mu = mu0 * (T0+CST / Temp_K+CST) * (Temp_K/T0)^(3./2.);
+if ( TempK > 0 && TempK < 555) {
+molecular_viscosity = mu_ref * (T0+CST / TempK+CST) * (TempK/T0)^(3./2.);
 } else {
-mu = -999.0;
+molecular_viscosity = -999.0;
 }
 
 """
@@ -124,18 +133,18 @@ mu = -999.0;
 
 Cp1 = 520.3;
 Cp2 = 1040.0;
-cp = Y1 * Cp1 + Y2 *Cp2;
+specific_heat = Y1 * Cp1 + Y2 *Cp2;
 """
-    volumic_viscosity="""# volumic_viscosity
+    volume_viscosity="""# volume_viscosity
 """
     thermal_conductivity="""# oxygen
-lambda = 6.2e-5 * Temp_K + 8.1e-3;
+thermal_conductivity = 6.2e-5 * TempK + 8.1e-3;
 
 # nitrogen
-lambda = 6.784141e-5 * Temp_K + 5.564317e-3;
+thermal_conductivity = 6.784141e-5 * TempK + 5.564317e-3;
 
 # hydrogen
-lambda = 4.431e-4 * Temp_K + 5.334e-2;
+thermal_conductivity = 4.431e-4 * TempK + 5.334e-2;
 
 """
     def __init__(self, parent, case):
@@ -153,28 +162,37 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
 
         self.mdl = FluidCharacteristicsModel(self.case)
 
+        if EOS == 1:
+            self.ava = eosAva.EosAvailable()
+
+        import cs_config
+        cfg = cs_config.config()
+        self.freesteam = 0
+        if cfg.libs['freesteam'].have != "no":
+            self.freesteam = 1
+
         if CompressibleModel(self.case).getCompressibleModel() != 'off':
-            list = [('density', 'Rho'),
-                    ('molecular_viscosity', 'Mu'),
-                    ('specific_heat', 'Cp'),
-                    ('thermal_conductivity', 'Al'),
-                    ('volumic_viscosity', 'Viscv0'),
-                    ('dynamic_diffusion', 'Diftl0')]
+            self.lst = [('density', 'Rho'),
+                        ('molecular_viscosity', 'Mu'),
+                        ('specific_heat', 'Cp'),
+                        ('thermal_conductivity', 'Al'),
+                        ('volume_viscosity', 'Viscv0'),
+                        ('dynamic_diffusion', 'Diftl0')]
         elif CoalCombustionModel(self.case).getCoalCombustionModel() != 'off':
-            list = [('density', 'Rho'),
-                    ('molecular_viscosity', 'Mu'),
-                    ('specific_heat', 'Cp'),
-                    ('dynamic_diffusion', 'Diftl0')]
+            self.lst = [('density', 'Rho'),
+                        ('molecular_viscosity', 'Mu'),
+                        ('specific_heat', 'Cp'),
+                        ('dynamic_diffusion', 'Diftl0')]
         elif GasCombustionModel(self.case).getGasCombustionModel() != 'off':
-            list = [('density', 'Rho'),
-                    ('molecular_viscosity', 'Mu'),
-                    ('specific_heat', 'Cp'),
-                    ('dynamic_diffusion', 'Diftl0')]
+            self.lst = [('density', 'Rho'),
+                        ('molecular_viscosity', 'Mu'),
+                        ('specific_heat', 'Cp'),
+                        ('dynamic_diffusion', 'Diftl0')]
         else:
-            list = [('density', 'Rho'),
-                    ('molecular_viscosity', 'Mu'),
-                    ('specific_heat', 'Cp'),
-                    ('thermal_conductivity', 'Al')]
+            self.lst = [('density', 'Rho'),
+                        ('molecular_viscosity', 'Mu'),
+                        ('specific_heat', 'Cp'),
+                        ('thermal_conductivity', 'Al')]
 
         self.list_scalars = []
         self.m_th = ThermalScalarModel(self.case)
@@ -199,45 +217,71 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         self.modelNameDiff = ComboModel(self.comboBoxNameDiff,1,1)
         self.modelViscv0   = ComboModel(self.comboBoxViscv0, 3, 1)
         self.modelDiftl0   = ComboModel(self.comboBoxDiftl0, 3, 1)
+        self.modelMaterial = ComboModel(self.comboBoxMaterial, 1, 1)
+        self.modelMethod   = ComboModel(self.comboBoxMethod, 1, 1)
+        self.modelPhas     = ComboModel(self.comboBoxPhas, 2, 1)
 
         self.modelRho.addItem(self.tr('constant'), 'constant')
-        self.modelRho.addItem(self.tr('user law'), 'user_law')
+        self.modelRho.addItem(self.tr('variable'), 'variable')
+        self.modelRho.addItem(self.tr('thermal law'), 'thermal_law')
         if mdl_atmo != 'off':
             self.modelRho.addItem(self.tr('defined in atphyv'), 'variable')
         elif mdl_joule == 'arc':
             self.modelRho.addItem(self.tr('defined in elphyv'), 'variable')
-        else:
-            self.modelRho.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
 
         self.modelMu.addItem(self.tr('constant'), 'constant')
-        self.modelMu.addItem(self.tr('user law'), 'user_law')
+        self.modelMu.addItem(self.tr('variable'), 'variable')
+        self.modelMu.addItem(self.tr('thermal law'), 'thermal_law')
         if mdl_joule == 'arc':
             self.modelMu.addItem(self.tr('defined in elphyv'), 'variable')
-        else:
-            self.modelMu.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
 
         self.modelCp.addItem(self.tr('constant'), 'constant')
-        self.modelCp.addItem(self.tr('user law'), 'user_law')
+        self.modelCp.addItem(self.tr('variable'), 'variable')
+        self.modelCp.addItem(self.tr('thermal law'), 'thermal_law')
         if mdl_joule == 'arc':
             self.modelCp.addItem(self.tr('defined in elphyv'), 'variable')
-        else:
-            self.modelCp.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
 
         self.modelAl.addItem(self.tr('constant'), 'constant')
-        self.modelAl.addItem(self.tr('user law'), 'user_law')
+        self.modelAl.addItem(self.tr('variable'), 'variable')
+        self.modelAl.addItem(self.tr('thermal law'), 'thermal_law')
         if mdl_joule == 'arc':
             self.modelAl.addItem(self.tr('defined in elphyv'), 'variable')
-        else:
-            self.modelAl.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
 
         self.modelDiff.addItem(self.tr('constant'), 'constant')
-        self.modelDiff.addItem(self.tr('user law'), 'user_law')
+        self.modelDiff.addItem(self.tr('variable'), 'variable')
+
         self.modelViscv0.addItem(self.tr('constant'), 'constant')
-        self.modelViscv0.addItem(self.tr('user law'), 'user_law')
-        self.modelViscv0.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
+        self.modelViscv0.addItem(self.tr('variable'), 'variable')
+        self.modelViscv0.addItem(self.tr('thermal law'), 'thermal_law')
+
         self.modelDiftl0.addItem(self.tr('constant'), 'constant')
-        self.modelDiftl0.addItem(self.tr('user law'), 'user_law')
-        self.modelDiftl0.addItem(self.tr('user subroutine (cs_user_physical_properties)'), 'variable')
+        self.modelDiftl0.addItem(self.tr('variable'), 'variable')
+        self.modelDiftl0.addItem(self.tr('thermal law'), 'thermal_law')
+
+        self.modelPhas.addItem(self.tr('liquid'), 'liquid')
+        self.modelPhas.addItem(self.tr('gas'), 'gas')
+
+        if (self.freesteam == 0 and EOS == 0) or \
+            self.m_th.getThermalScalarModel() == "off" or \
+            mdl_joule != 'off' or mdl_comp != 'off':
+            self.groupBoxTableChoice.hide()
+        else:
+            self.groupBoxTableChoice.show()
+            self.lineEditReference.setEnabled(False)
+            # suppress perfect gas
+            self.modelMaterial.addItem(self.tr('user material'), 'user_material')
+            tmp = ["Argon", "Nitrogen", "Hydrogen", "Oxygen", "Helium", "Air"]
+            if EOS == 1:
+                fls = self.ava.whichFluids()
+                for fli in fls:
+                    if fli not in tmp:
+                        tmp.append(fli)
+                        self.modelMaterial.addItem(self.tr(fli), fli)
+            if self.freesteam == 1 and EOS == 0:
+                self.modelMaterial.addItem(self.tr('Water'), 'Water')
+            material = self.mdl.getMaterials()
+            self.modelMaterial.setItem(str_model=material)
+            self.updateMethod()
 
         self.scalar = ""
         scalar_list = self.m_sca.getUserScalarLabelsList()
@@ -258,6 +302,9 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         self.connect(self.comboBoxDiff,     SIGNAL("activated(const QString&)"), self.slotStateDiff)
         self.connect(self.comboBoxNameDiff, SIGNAL("activated(const QString&)"), self.slotNameDiff)
         self.connect(self.comboBoxViscv0,   SIGNAL("activated(const QString&)"), self.slotStateViscv0)
+        self.connect(self.comboBoxMaterial, SIGNAL("activated(const QString&)"), self.slotMaterial)
+        self.connect(self.comboBoxMethod,   SIGNAL("activated(const QString&)"), self.slotMethod)
+        self.connect(self.comboBoxPhas,     SIGNAL("activated(const QString&)"), self.slotPhas)
         self.connect(self.lineEditRho,      SIGNAL("textChanged(const QString &)"), self.slotRho)
         self.connect(self.lineEditMu,       SIGNAL("textChanged(const QString &)"), self.slotMu)
         self.connect(self.lineEditCp,       SIGNAL("textChanged(const QString &)"), self.slotCp)
@@ -306,7 +353,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
             diff_choice =  self.m_sca.getScalarDiffusivityChoice(self.scalar)
             self.modelDiff.setItem(str_model=diff_choice)
             self.modelNameDiff.setItem(str_model=str(self.scalar))
-            if diff_choice  != 'user_law':
+            if diff_choice  != 'variable':
                 self.pushButtonDiff.setEnabled(False)
                 setGreenColor(self.pushButtonDiff, False)
             else:
@@ -321,20 +368,36 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
 
         # Standard Widget initialization
 
-        for tag, symbol in list:
-            __model  = getattr(self, "model" + symbol)
-            __line   = getattr(self, "lineEdit" + symbol)
+        for tag, symbol in self.lst:
+            __model  = getattr(self, "model"      + symbol)
+            __line   = getattr(self, "lineEdit"   + symbol)
             __button = getattr(self, "pushButton" + symbol)
-            __label  = getattr(self, "label" + symbol)
+            __label  = getattr(self, "label"      + symbol)
+            __labelu = getattr(self, "labelUnit"  + symbol)
             if tag != 'dynamic_diffusion':
+                __labelv = getattr(self, "labelVar"   + symbol)
                 c = self.mdl.getPropertyMode(tag)
                 __model.setItem(str_model=c)
-                if c == 'user_law':
+                if c == 'variable':
                     __button.setEnabled(True)
                     __label.setText(self.tr("Reference value"))
                 else:
                     __button.setEnabled(False)
                     __label.setText(self.tr("Reference value"))
+                if c == 'thermal_law':
+                    __line.hide()
+                    __label.hide()
+                    __labelu.hide()
+                    __labelv.hide()
+                else:
+                    __line.show()
+                    __label.show()
+                    __labelu.show()
+                    __labelv.show()
+                if self.mdl.getMaterials() == "user_material":
+                    __model.disableItem(str_model='thermal_law')
+                else:
+                    __model.enableItem(str_model='thermal_law')
             else:
                 __label.setText(self.tr("Reference value"))
 
@@ -349,7 +412,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         if mdl_gas != 'off' or mdl_coal != 'off':
             self.groupBoxDiftl0.show()
 
-        for tag, symbol in list:
+        for tag, symbol in self.lst:
             __model  = getattr(self, "model" + symbol)
             __line   = getattr(self, "lineEdit" + symbol)
             __button = getattr(self, "pushButton" + symbol)
@@ -367,7 +430,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
                     __line.setText(str(""))
                     __line.setEnabled(False)
                 elif tag == 'dynamic_diffusion':
-                    __model.setItem(str_model='user_law')
+                    __model.setItem(str_model='variable')
                     __combo.setEnabled(False)
                     __button.setEnabled(False)
                 else:
@@ -377,7 +440,6 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
             # Joule
             if mdl_joule == 'arc':
                 __model.disableItem(str_model='constant')
-                __model.disableItem(str_model='user_law')
                 __model.disableItem(str_model='variable')
                 __model.setItem(str_model='variable')
                 __combo.setEnabled(False)
@@ -392,7 +454,6 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
             if mdl_atmo != 'off':
                 if tag == 'density':
                     __model.disableItem(str_model='constant')
-                    __model.disableItem(str_model='user_law')
                     __model.disableItem(str_model='variable')
                     __model.setItem(str_model='variable')
                     __combo.setEnabled(False)
@@ -416,10 +477,10 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
                     self.mdl.setPropertyMode(tag, 'constant')
                     self.groupBoxCp.setTitle('Isobaric specific heat')
 
-                if tag == 'volumic_viscosity':
+                if tag == 'volume_viscosity':
                     __combo.setEnabled(True)
                     c = self.mdl.getPropertyMode(tag)
-                    if c == 'user_law':
+                    if c == 'variable':
                         __button.setEnabled(True)
                     else:
                         __button.setEnabled(False)
@@ -431,6 +492,100 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         self.case.undoStartGlobal()
 
 
+    def updateTypeChoice(self):
+        """
+        add/suppress thermo tables for each proprties
+        """
+        for tag, symbol in self.lst:
+            __model  = getattr(self, "model" + symbol)
+            if self.mdl.getMaterials() == "user_material":
+                __model.disableItem(str_model='thermal_law')
+            else:
+                __model.enableItem(str_model='thermal_law')
+            c = self.mdl.getPropertyMode(tag)
+            __model.setItem(str_model=c)
+
+
+    def updateMethod(self):
+        """
+        update method list with material choice
+        """
+        for nb in range(len(self.modelMethod.getItems())):
+            self.modelMethod.delItem(0)
+
+        self.comboBoxPhas.hide()
+        self.labelPhas.hide()
+
+        if self.mdl.getMaterials() == "user_material":
+            self.modelMethod.addItem(self.tr('user properties'), 'user_properties')
+        else :
+            if EOS == 1:
+                material = self.mdl.getMaterials()
+                self.ava.setMethods(material)
+                fls = self.ava.whichMethods()
+                for fli in fls:
+                    self.modelMethod.addItem(self.tr(fli),fli)
+                if self.mdl.getMethod() != "freesteam":
+                    self.comboBoxPhas.show()
+                    self.labelPhas.show()
+            if self.freesteam == 1 and self.mdl.getMaterials() == "Water":
+                self.modelMethod.addItem(self.tr("freesteam"), "freesteam")
+
+        # update comboBoxMethod
+        method = self.mdl.getMethod()
+        self.modelMethod.setItem(str_model=method)
+
+        self.updateReference()
+
+
+    def updateReference(self):
+        """
+        update Reference with material, method and field nature choice
+        """
+        # update lineEditReference
+        self.lineEditReference.setText(self.mdl.getReference())
+
+
+    @pyqtSignature("const QString &")
+    def slotMaterial(self, text):
+        """
+        Method to call 'setMaterial'
+        """
+        choice = self.modelMaterial.dicoV2M[str(text)]
+        self.mdl.setMaterials(choice)
+        self.updateMethod()
+        self.updateTypeChoice()
+
+
+    @pyqtSignature("const QString &")
+    def slotPhas(self, text):
+        """
+        Method to call 'setFieldNature'
+        """
+        choice = self.modelPhas.dicoV2M[str(text)]
+        self.mdl.setFieldNature(choice)
+
+        self.updateReference()
+
+
+    @pyqtSignature("const QString &")
+    def slotMethod(self, text):
+        """
+        Method to call 'setMethod'
+        """
+        choice = self.modelMethod.dicoV2M[str(text)]
+        self.mdl.setMethod(choice)
+
+        self.comboBoxPhas.hide()
+        self.labelPhas.hide()
+        if self.mdl.getMaterials() != "user_material" and \
+           self.mdl.getMethod() != "freesteam":
+            self.comboBoxPhas.show()
+            self.labelPhas.show()
+
+        self.updateReference()
+
+
     @pyqtSignature("const QString &")
     def slotStateRho(self, text):
         """
@@ -460,7 +615,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         """
         Method to call 'getState' with correct arguements for 'Viscv0'
         """
-        self.__changeChoice(str(text), 'Viscv0', 'volumic_viscosity')
+        self.__changeChoice(str(text), 'Viscv0', 'volume_viscosity')
 
 
     @pyqtSignature("const QString &")
@@ -479,7 +634,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         choice = self.modelDiff.dicoV2M[str(text)]
         log.debug("slotStateDiff -> %s" % (text))
 
-        if choice != 'user_law':
+        if choice != 'variable':
             self.pushButtonDiff.setEnabled(False)
             setGreenColor(self.pushButtonDiff, False)
         else:
@@ -511,16 +666,28 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         __combo  = getattr(self, "comboBox"   + sym)
         __label  = getattr(self, "label"      + sym)
         __button = getattr(self, "pushButton" + sym)
+        __labelu = getattr(self, "labelUnit"  + sym)
+        __labelv = getattr(self, "labelVar"  + sym)
 
         choice = __model.dicoV2M[text]
         log.debug("__changeChoice -> %s, %s" % (text, choice))
 
-        if choice != 'user_law':
+        if choice != 'variable':
             __button.setEnabled(False)
             setGreenColor(__button, False)
         else:
             __button.setEnabled(True)
             setGreenColor(__button, True)
+        if choice == 'thermal_law':
+            __line.hide()
+            __label.hide()
+            __labelu.hide()
+            __labelv.hide()
+        else:
+            __line.show()
+            __label.show()
+            __labelu.show()
+            __labelv.show()
 
         self.mdl.setPropertyMode(tag, choice)
 
@@ -531,7 +698,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         Update the density
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            rho = float(text)
+            rho = from_qvariant(text, float)
             self.mdl.setInitialValueDensity(rho)
 
 
@@ -541,7 +708,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         Update the molecular viscosity
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            mu = float(text)
+            mu = from_qvariant(text, float)
             self.mdl.setInitialValueViscosity(mu)
 
 
@@ -551,7 +718,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         Update the specific heat
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            cp = float(self.lineEditCp.text())
+            cp = from_qvariant(text, float)
             self.mdl.setInitialValueHeat(cp)
 
 
@@ -561,7 +728,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         Update the volumic viscosity
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            viscv0 = float(self.lineEditViscv0.text())
+            viscv0 = from_qvariant(text, float)
             self.mdl.setInitialValueVolumicViscosity(viscv0)
 
 
@@ -571,7 +738,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         Update the thermal conductivity
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            al = float(text)
+            al = from_qvariant(text, float)
             self.mdl.setInitialValueCond(al)
 
 
@@ -581,7 +748,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         Update the thermal conductivity
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            diftl0 = float(text)
+            diftl0 = from_qvariant(text, float)
             self.mdl.setInitialValueDyn(diftl0)
 
 
@@ -591,7 +758,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         Update the thermal conductivity
         """
         if self.sender().validator().state == QValidator.Acceptable:
-            diff = float(text)
+            diff = from_qvariant(text, float)
             self.m_sca.setScalarDiffusivityInitialValue(self.scalar, diff)
 
 
@@ -601,8 +768,15 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         User formula for density
         """
         exp = self.mdl.getFormula('density')
-        req = [('rho', 'Density')]
-        exa = FluidCharacteristicsView.density
+        req = [('density', 'Density')]
+        self.m_th = ThermalScalarModel(self.case)
+        s = self.m_th.getThermalScalarLabel()
+        if s == "TempC":
+            TempInContext = "("+s+" + 273.15)"
+            exa = FluidCharacteristicsView.density.replace("TempK", TempInContext)
+        else:
+            exa = FluidCharacteristicsView.density
+
         setGreenColor(self.sender(), False)
 
         symbols_rho = []
@@ -632,8 +806,14 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         User formula for molecular viscosity
         """
         exp = self.mdl.getFormula('molecular_viscosity')
-        req = [('mu', 'Molecular Viscosity')]
-        exa = FluidCharacteristicsView.molecular_viscosity
+        req = [('molecular_viscosity', 'Molecular Viscosity')]
+        self.m_th = ThermalScalarModel(self.case)
+        s = self.m_th.getThermalScalarLabel()
+        if s == "TempC":
+            TempInContext = "("+s+" + 273.15)"
+            exa = FluidCharacteristicsView.molecular_viscosity.replace("TempK", TempInContext)
+        else:
+            exa = FluidCharacteristicsView.molecular_viscosity
 
         symbols_mu = []
         for s in self.list_scalars:
@@ -669,7 +849,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         User formula for specific heat
         """
         exp = self.mdl.getFormula('specific_heat')
-        req = [('cp', 'Specific heat')]
+        req = [('specific_heat', 'Specific heat')]
         exa = FluidCharacteristicsView.specific_heat
 
         symbols_cp = []
@@ -698,12 +878,12 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         """
         User formula for volumic viscosity
         """
-        exp = self.mdl.getFormula('volumic_viscosity')
-        req = [('viscv', 'Volumic viscosity')]
-        exa = FluidCharacteristicsView.volumic_viscosity
+        exp = self.mdl.getFormula('volume_viscosity')
+        req = [('volume_viscosity', 'Volumic viscosity')]
+        exa = FluidCharacteristicsView.volume_viscosity
         symbols_viscv0 = []
         for s in self.list_scalars:
-           symbols_cp.append(s)
+           symbols_viscv0.append(s)
         viscv0_value = self.mdl.getInitialValueVolumicViscosity()
         ref_pressure = ReferenceValuesModel(self.case).getPressure()
         ref_temperature = ReferenceValuesModel(self.case).getTemperature()
@@ -720,7 +900,7 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         if dialog.exec_():
             result = dialog.get_result()
             log.debug("slotFormulaViscv0 -> %s" % str(result))
-            self.mdl.setFormula('volumic_viscosity', result)
+            self.mdl.setFormula('volume_viscosity', result)
             setGreenColor(self.sender(), False)
 
 
@@ -730,8 +910,14 @@ lambda = 4.431e-4 * Temp_K + 5.334e-2;
         User formula for thermal conductivity
         """
         exp = self.mdl.getFormula('thermal_conductivity')
-        req = [('lambda', 'Thermal conductivity')]
-        exa = FluidCharacteristicsView.thermal_conductivity
+        req = [('thermal_conductivity', 'Thermal conductivity')]
+        self.m_th = ThermalScalarModel(self.case)
+        s = self.m_th.getThermalScalarLabel()
+        if s == "TempC":
+            TempInContext = "("+s+" + 273.15)"
+            exa = FluidCharacteristicsView.thermal_conductivity.replace("TempK", TempInContext)
+        else:
+            exa = FluidCharacteristicsView.thermal_conductivity
 
         symbols_al = []
         for s in self.list_scalars:
