@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -39,9 +39,6 @@ import sys, logging
 #-------------------------------------------------------------------------------
 # Third-party modules
 #-------------------------------------------------------------------------------
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
@@ -51,10 +48,10 @@ from PyQt4.QtGui  import *
 #-------------------------------------------------------------------------------
 
 from Base.Toolbox import GuiParam
+from Base.QtPage import DoubleValidator, ComboModel
+from Base.QtPage import to_qvariant, from_qvariant, to_text_string
 from Pages.HeadLossesForm import Ui_HeadLossesForm
 from Pages.LocalizationModel import LocalizationModel, Zone
-import Base.QtPage as QtPage
-from Base.QtPage import DoubleValidator, ComboModel
 from Pages.HeadLossesModel import HeadLossesModel
 
 #-------------------------------------------------------------------------------
@@ -65,30 +62,6 @@ logging.basicConfig()
 log = logging.getLogger("HeadLossesView")
 log.setLevel(GuiParam.DEBUG)
 
-#-------------------------------------------------------------------------------
-# Line edit delegate with a Double validator (positive value)
-#-------------------------------------------------------------------------------
-
-class ValueDelegate(QItemDelegate):
-    def __init__(self, parent=None):
-        super(ValueDelegate, self).__init__(parent)
-        self.parent = parent
-
-    def createEditor(self, parent, option, index):
-        editor = QLineEdit(parent)
-        validator = DoubleValidator(editor, min=0.)
-        editor.setValidator(validator)
-        return editor
-
-    def setEditorData(self, editor, index):
-        value = str(index.model().data(index, Qt.DisplayRole))
-        editor.setText(value)
-
-    def setModelData(self, editor, model, index):
-        if editor.validator().state == QValidator.Acceptable:
-            value = float(editor.text())
-            model.setData(index, value, Qt.DisplayRole)
-
 #-------------------------------------------------------------------------------
 # StandarItemModel class to display Head Losses Zones in a QTreeView
 #-------------------------------------------------------------------------------
@@ -105,10 +78,10 @@ class StandardItemModelHeadLosses(QStandardItemModel):
 
     def data(self, index, role):
         if not index.isValid():
-            return
+            return to_qvariant()
         if role == Qt.DisplayRole:
-            return self.dataHeadLossesZones[index.row()][index.column()]
-        return
+            return to_qvariant(self.dataHeadLossesZones[index.row()][index.column()])
+        return to_qvariant()
 
     def flags(self, index):
         if not index.isValid():
@@ -118,8 +91,8 @@ class StandardItemModelHeadLosses(QStandardItemModel):
 
     def headerData(self, section, orientation, role):
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
-            return self.headers[section]
-        return
+            return to_qvariant(self.headers[section])
+        return to_qvariant()
 
 
     def setData(self, index, value, role):
@@ -269,7 +242,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setCoefficient(name,'kxx',value )
 
     @pyqtSignature("const QString&")
@@ -280,7 +253,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setCoefficient(name,'kyy',value )
 
     @pyqtSignature("const QString&")
@@ -291,7 +264,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setCoefficient(name,'kzz',value )
 
     @pyqtSignature("bool")
@@ -333,7 +306,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setMatrixComposant(name,'a11',value )
 
     @pyqtSignature("const QString&")
@@ -344,7 +317,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setMatrixComposant(name,'a12',value )
 
     @pyqtSignature("const QString&")
@@ -355,7 +328,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setMatrixComposant(name,'a13',value )
 
     @pyqtSignature("const QString&")
@@ -366,7 +339,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setMatrixComposant(name,'a21',value )
 
     @pyqtSignature("const QString&")
@@ -377,7 +350,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setMatrixComposant(name,'a22',value )
 
     @pyqtSignature("const QString&")
@@ -388,7 +361,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setMatrixComposant(name,'a23',value )
 
     @pyqtSignature("const QString&")
@@ -399,7 +372,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setMatrixComposant(name,'a31',value )
 
     @pyqtSignature("const QString&")
@@ -410,7 +383,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setMatrixComposant(name,'a32',value )
 
     @pyqtSignature("const QString&")
@@ -421,7 +394,7 @@ class HeadLossesView(QWidget, Ui_HeadLossesForm):
             label, name, local = self.modelHeadLosses.getItem(row)
             model = HeadLossesModel(self.case)
             if self.sender().validator().state == QValidator.Acceptable:
-                value = float(text)
+                value = from_qvariant(text, float)
                 model.setMatrixComposant(name,'a33',value )
 
 
