@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -50,6 +50,7 @@ from Pages.DefineUserScalarsModel import DefineUserScalarsModel
 from Pages.LocalizationModel import LocalizationModel
 from Pages.CompressibleModel import CompressibleModel
 from Pages.ElectricalModel import ElectricalModel
+from Pages.ThermalScalarModel import ThermalScalarModel
 
 #-------------------------------------------------------------------------------
 # Variables and Scalar model initialization modelling class
@@ -72,25 +73,15 @@ class InitializationModel(Model):
         self.node_therm      = self.models.xmlGetNode('thermal_scalar', 'model')
         if CompressibleModel(self.case).getCompressibleModel() != 'off':
             self.node_comp = self.models.xmlGetNode('compressible_model', 'model')
-
-        self.VelocityList  = ('velocity_U', 'velocity_V', 'velocity_W')
-        self.Turb_var_List = ('turb_k', 'turb_eps',
-                              'component_R11', 'component_R22', 'component_R33',
-                              'component_R12', 'component_R13', 'component_R23',
-                              'turb_phi', 'turb_al', 'turb_omega', 'turb_nusa',
-                              'turb_alpha')
+            self.node_prop   = self.case.xmlGetNode('physical_properties')
+            self.node_fluid  = self.node_prop.xmlInitNode('fluid_properties')
 
         self.turb = TurbulenceModel(self.case)
+        self.therm = ThermalScalarModel(self.case)
         self.turbulenceModes = ('formula',
                                 'reference_value')
         self.node_scalartherm = self.models.xmlGetNode('thermal_scalar')
 
-        self.thermalModel = ('TempC',
-                             'TempK',
-                             'Enthalpy',
-                             'PotTemp',
-                             'LiqPotTemp')
-
 
     def __defaultValues(self):
         """
@@ -113,13 +104,37 @@ class InitializationModel(Model):
         self.isInList(zone, LocalizationModel('VolumicZone', self.case).getCodeNumbersList())
 
 
+    @Variables.noUndo
+    def getDefaultVelocityFormula(self):
+        formula = """velocity[0] = 0.;
+velocity[1] = 0.;
+velocity[2] = 0.;"""
+        return formula
+
+
+    @Variables.noUndo
+    def getDefaultThermalFormula(self):
+        name = ''
+        formula = ''
+        if self.therm.getThermalScalarModel() == 'enthalpy':
+            name = 'enthalpy'
+            formula = """cp = 1017.24""" + name + """ = 300. * cp;"""
+        if self.therm.getThermalScalarModel() == 'total_energy':
+            name = 'total_energy'
+            formula = name + """ = 0.;"""
+        elif self.therm.getThermalScalarModel() != 'off':
+            name = 'temperature'
+            formula = name + """ = 300.;"""
+        return formula
+
+
     @Variables.noUndo
     def getDefaultTurbFormula(self, turb_model):
         self.isInList(turb_model,self.turb.turbulenceModels())
         if turb_model in ('k-epsilon', 'k-epsilon-PL'):
             formula = """cmu = 0.09;
 k = 1.5*(0.02*uref)^2;
-eps = k^1.5*cmu/almax;"""
+epsilon = k^1.5*cmu/almax;"""
         elif turb_model in ('Rij-epsilon', 'Rij-SSG'):
             formula = """trii   = (0.02*uref)^2;
 cmu = 0.09;
@@ -130,7 +145,7 @@ r12 = 0.;
 r13 = 0.;
 r23 = 0.;
 k = 0.5*(r11+r22+r33);
-eps = k^1.5*cmu/almax;"""
+epsilon = k^1.5*cmu/almax;"""
         elif turb_model == 'Rij-EBRSM':
             formula = """trii   = (0.02*uref)^2;
 cmu = 0.09;
@@ -141,19 +156,19 @@ r12 = 0.;
 r13 = 0.;
 r23 = 0.;
 k = 0.5*(r11+r22+r33);
-eps = k^1.5*cmu/almax;
+epsilon = k^1.5*cmu/almax;
 alpha = 1.;"""
         elif turb_model == 'v2f-BL-v2/k':
             formula = """cmu = 0.22;
 k = 1.5*(0.02*uref)^2;
-eps = k^1.5*cmu/almax;
+epsilon = k^1.5*cmu/almax;
 phi = 2./3.;
-al = 0.;"""
+alpha = 0.;"""
         elif turb_model == 'k-omega-SST':
             formula = """k = 1.5*(0.02*uref)^2;
 omega = k^0.5/almax;"""
         elif turb_model == 'Spalart-Allmaras':
-            formula = """nusa = (cmu * k)/eps;"""
+            formula = """nu_tilda = (cmu * k)/eps;"""
         return formula
 
 
@@ -245,14 +260,13 @@ omega = k^0.5/almax;"""
 
 
     @Variables.undoLocal
-    def setThermalFormula(self, zone, scalar, formula):
+    def setThermalFormula(self, zone, formula):
         """
         Public method.
-        Set the formula for tharmal scalars.
+        Set the formula for thermal scalars.
         """
         self.__verifyZone(zone)
-        self.isInList(scalar, self.thermalModel)
-        node = self.node_scalartherm.xmlGetNode('scalar', label = str(scalar))
+        node = self.node_scalartherm.xmlGetNode('variable')
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
@@ -261,14 +275,13 @@ omega = k^0.5/almax;"""
 
 
     @Variables.noUndo
-    def getThermalFormula(self, zone, scalar):
+    def getThermalFormula(self, zone):
         """
         Public method.
         Return the formula for thermal scalars.
         """
         self.__verifyZone(zone)
-        self.isInList(scalar, self.thermalModel)
-        node = self.node_scalartherm.xmlGetNode('scalar', label = str(scalar))
+        node = self.node_scalartherm.xmlGetNode('variable')
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
@@ -282,7 +295,7 @@ omega = k^0.5/almax;"""
         """
         Return status of Density for the initialisation
         """
-        node = self.node_comp.xmlGetNode('property', name = 'Rho')
+        node = self.node_fluid.xmlGetNode('property', name = 'density')
         n = node.xmlInitNode('formula', 'status', zone_id = zone)
         status = n['status']
         if not status:
@@ -297,7 +310,7 @@ omega = k^0.5/almax;"""
         Put status of Density for the initialisation
         """
         self.isOnOff(status)
-        node = self.node_comp.xmlGetNode('property', name = 'Rho')
+        node = self.node_fluid.xmlGetNode('property', name = 'density')
         n = node.xmlInitNode('formula', 'status', zone_id = zone)
         n['status'] = status
 
@@ -307,7 +320,7 @@ omega = k^0.5/almax;"""
         """
         Return status of Temperature for the initialisation
         """
-        node = self.node_comp.xmlGetNode('scalar', name = 'TempK')
+        node = self.node_comp.xmlGetNode('variable', name = 'temperature')
         n = node.xmlInitNode('formula', 'status', zone_id = zone)
         status = n['status']
         if not status:
@@ -322,7 +335,7 @@ omega = k^0.5/almax;"""
         Put status of Temperature for the initialisation
         """
         self.isOnOff(status)
-        node = self.node_comp.xmlGetNode('scalar', name = 'TempK')
+        node = self.node_comp.xmlGetNode('variable', name = 'temperature')
         n = node.xmlInitNode('formula', 'status', zone_id = zone)
         n['status'] = status
 
@@ -332,7 +345,7 @@ omega = k^0.5/almax;"""
         """
         Return status of total energy for the initialisation
         """
-        node = self.node_comp.xmlGetNode('scalar', name = 'EnergieT')
+        node = self.node_scalartherm.xmlGetNode('variable', name = 'total_energy')
         n = node.xmlInitNode('formula', 'status', zone_id = zone)
         status = n['status']
         if not status:
@@ -347,7 +360,7 @@ omega = k^0.5/almax;"""
         Put status of Energy for the initialisation
         """
         self.isOnOff(status)
-        node = self.node_comp.xmlGetNode('scalar', name = 'EnergieT')
+        node = self.node_scalartherm.xmlGetNode('variable', name = 'total_energy')
         n = node.xmlInitNode('formula', 'status', zone_id = zone)
         n['status'] = status
 
@@ -417,7 +430,7 @@ omega = k^0.5/almax;"""
         Set the formula for density.
         """
         self.__verifyZone(zone)
-        node = self.node_comp.xmlGetNode('property', name = 'Rho')
+        node = self.node_fluid.xmlGetNode('property', name = 'density')
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
@@ -432,7 +445,7 @@ omega = k^0.5/almax;"""
         Return the formula for density.
         """
         self.__verifyZone(zone)
-        node = self.node_comp.xmlGetNode('property', name = 'Rho')
+        node = self.node_fluid.xmlGetNode('property', name = 'density')
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
@@ -448,8 +461,7 @@ omega = k^0.5/almax;"""
         Set the formula for temperature.
         """
         self.__verifyZone(zone)
-        node = self.node_comp.xmlGetNode('scalar', name = 'TempK')
-
+        node = self.node_comp.xmlGetNode('variable', name = 'temperature')
 
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
@@ -465,8 +477,7 @@ omega = k^0.5/almax;"""
         Return the formula for temperature.
         """
         self.__verifyZone(zone)
-        node = self.node_comp.xmlGetNode('scalar', name = 'TempK')
-
+        node = self.node_comp.xmlGetNode('variable', name = 'temperature')
 
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
@@ -483,7 +494,7 @@ omega = k^0.5/almax;"""
         Set the formula for totale energy.
         """
         self.__verifyZone(zone)
-        node = self.node_comp.xmlGetNode('scalar', name = 'EnergieT')
+        node = self.node_scalartherm.xmlGetNode('variable', name = 'total_energy')
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
@@ -498,7 +509,7 @@ omega = k^0.5/almax;"""
         Return the formula for energy.
         """
         self.__verifyZone(zone)
-        node = self.node_comp.xmlGetNode('scalar', name = 'EnergieT')
+        node = self.node_scalartherm.xmlGetNode('variable', name = 'total_energy')
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
@@ -537,7 +548,7 @@ omega = k^0.5/almax;"""
         """
         self.__verifyZone(zone)
         self.isInList(species, DefineUserScalarsModel(self.case).getUserScalarLabelsList())
-        node = self.node_userscalar.xmlGetNode('scalar', label = str(species))
+        node = self.node_userscalar.xmlGetNode('variable', label = str(species))
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
@@ -553,15 +564,12 @@ omega = k^0.5/almax;"""
         """
         self.__verifyZone(zone)
         self.isInList(species, DefineUserScalarsModel(self.case).getUserScalarLabelsList())
-        node = self.node_userscalar.xmlGetNode('scalar', label = str(species))
+        node = self.node_userscalar.xmlGetNode('variable', label = str(species))
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
 
         formula = node.xmlGetString('formula', zone_id=zone)
-        if not formula:
-            formula = str(species)+""" = 0;\n"""
-            self.setSpeciesFormula(zone, species, formula)
 
         return formula
 
@@ -575,7 +583,7 @@ omega = k^0.5/almax;"""
         self.__verifyZone(zone)
         self.isInList(scalar, DefineUserScalarsModel( self.case).getMeteoScalarsList())
         node_atmo = self.models.xmlGetNode('atmospheric_flows')
-        node = node_atmo.xmlGetNode('scalar', label = str(scalar))
+        node = node_atmo.xmlGetNode('variable', label = str(scalar))
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
@@ -592,7 +600,7 @@ omega = k^0.5/almax;"""
         self.__verifyZone(zone)
         self.isInList(scalar, DefineUserScalarsModel( self.case).getMeteoScalarsList())
         node_atmo = self.models.xmlGetNode('atmospheric_flows')
-        node = node_atmo.xmlGetNode('scalar', label = str(scalar))
+        node = node_atmo.xmlGetNode('variable', label = str(scalar))
         if not node:
             msg = "There is an error: this node " + str(node) + "should be existed"
             raise ValueError(msg)
