@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -47,7 +47,7 @@ from PyQt4.QtGui  import *
 #-------------------------------------------------------------------------------
 
 from Base.Toolbox import GuiParam
-import Base.QtPage as QtPage
+from Base.QtPage import getopenfilename
 
 #-------------------------------------------------------------------------------
 # log config
@@ -70,7 +70,7 @@ def preprocessorFile(parent, initdir):
     filetypes = "Preprocessor log (*.log);;All Files (*)"
     filt = "All files (*)"
     initdir = os.path.join(initdir, 'check_mesh')
-    file_name = QFileDialog.getOpenFileName(parent, title, initdir, filetypes)
+    file_name, _selfilter = getopenfilename(parent, title, initdir, filetypes)
     file_name = str(file_name)
 
     if file_name:
