@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -115,9 +115,16 @@ class ProfilesModel(Model):
                 if not label:
                     raise ValueError("Node has no label")
 
-                if not (node['support'] and node['support'] == "boundary"):
-                    if name != 'local_time_step':
-                        self.dicoLabel2Name[label] = name
+                dim = node['dimension']
+                if dim and int(dim) > 1:
+                    for ii in range(int(dim)):
+                        label1 = label + "[" + str(ii) + "]"
+                        if not (node['support'] and node['support'] == "boundary"):
+                            self.dicoLabel2Name[label1] = (name, str(ii))
+                else:
+                    if not (node['support'] and node['support'] == "boundary"):
+                        if name != 'local_time_step':
+                            self.dicoLabel2Name[label] = (name, str(0))
 
         return list(self.dicoLabel2Name.keys())
 
@@ -194,7 +201,8 @@ class ProfilesModel(Model):
         node.xmlAddChild('format', name=format)
         for var in lst:
             self.isInList(var, self.__var_prop_list)
-            node.xmlAddChild('var_prop', name=self.dicoLabel2Name[var])
+            (name, comp) = self.dicoLabel2Name[var]
+            node.xmlAddChild('var_prop', name=name, component=comp)
         node.xmlSetData('output_type', choice)
         node.xmlSetData('output_frequency', freq)
         node['title'] = title
@@ -224,7 +232,8 @@ class ProfilesModel(Model):
             node.xmlAddChild('format', name=format)
             for var in lst:
                 self.isInList(var, self.__var_prop_list)
-                node.xmlAddChild('var_prop', name=self.dicoLabel2Name[var])
+                (name, comp) = self.dicoLabel2Name[var]
+                node.xmlAddChild('var_prop', name=name, component=comp)
             node['label'] = label_xml
             node.xmlSetData('output_type', choice)
             node.xmlSetData('output_frequency', freq)
@@ -271,7 +280,7 @@ class ProfilesModel(Model):
         NbPoint = self.__getNbPoint(label)
         for var in node.xmlGetChildNodeList('var_prop'):
             for name in self.__var_prop_list:
-                if self.dicoLabel2Name[name] == var['name']:
+                if self.dicoLabel2Name[name] == (var['name'], var['component']) :
                     lst.append(name)
         label_xml = node['label']
         label = label_xml
@@ -301,9 +310,9 @@ class ProfilesTestCase(ModelTest):
         mdl.setProfile('prof1.dat', 'title', ['VelocitU', 'VelocitV', 'VelocitW'], 20, 0.1, 0.2, 0.3, 2.1, 2.2, 2.3)
         doc = '''<profiles>
                     <profile label="prof1.dat" title="title">
-                            <var_prop name="velocity_U"/>
-                            <var_prop name="velocity_V"/>
-                            <var_prop name="velocity_W"/>
+                            <var_prop name="velocity" component="0"/>
+                            <var_prop name="velocity" component="1"/>
+                            <var_prop name="velocity" component="2"/>
                             <output_frequency>20</output_frequency>
                             <x1>0.1</x1>
                             <y1>0.2</y1>
@@ -325,7 +334,7 @@ class ProfilesTestCase(ModelTest):
         mdl.replaceProfile('prof1', 'premier', 'title_bis', ['VelocitU'], 30, 0.1, 0.2, 0.3, 2.0, 2.0, 2.0)
         doc = '''<profiles>
                     <profile label="premier" title="title_bis">
-                            <var_prop name="velocity_U"/>
+                            <var_prop name="velocity" component="0"/>
                             <output_frequency>30</output_frequency>
                             <x1>0.1</x1>
                             <y1>0.2</y1>
@@ -349,7 +358,7 @@ class ProfilesTestCase(ModelTest):
         mdl.deleteProfile('prof1')
         doc = '''<profiles>
                     <profile label="prof2.dat" title="title2">
-                            <var_prop name="velocity_U"/>
+                            <var_prop name="velocity" component="0"/>
                             <output_frequency>20</output_frequency>
                             <x1>0.9</x1>
                             <y1>0.8</y1>
