@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -43,10 +43,6 @@ import subprocess
 #-------------------------------------------------------------------------------
 # Third-party modules
 #-------------------------------------------------------------------------------
-import sys
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
@@ -167,12 +163,36 @@ class QMeiEditorView(QDialog, Ui_QMeiDialog):
 
         self.check_syntax = check_syntax
 
+        sym = [('todelete','')]
+        base = []
+        for s,l in symbols:
+            if s.find("[") != -1:
+                idx = s.find("[")
+                if s[:idx] not in base:
+                    sym.append((s[:idx], l))
+                    base.append(s[:idx])
+            else:
+                sym.append((s,l))
+        del sym[0]
+
+        req = [('todelete','')]
+        base = []
+        for s,l in required:
+            if s.find("[") != -1:
+                idx = s.find("[")
+                if s[:idx] not in base:
+                    req.append((s[:idx], l))
+                    base.append(s[:idx])
+            else:
+                req.append((s,l))
+        del req[0]
+
         self.required = required
         self.symbols  = symbols
 
         # Syntax highlighting
-        self.h1 = QMeiHighlighter(self.textEditExpression, required, symbols)
-        self.h2 = QMeiHighlighter(self.textEditExamples, required, symbols)
+        self.h1 = QMeiHighlighter(self.textEditExpression, req, sym)
+        self.h2 = QMeiHighlighter(self.textEditExamples, req, sym)
 
         # Required symbols of the mathematical expression
 
