@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -320,9 +320,7 @@ class ReferenceValuesTestCase(ModelTest):
                     <variable label="Pressure" name="pressure">
                             <reference_pressure>1.3e+06</reference_pressure>
                     </variable>
-                    <variable label="VelocitU" name="velocity_U"/>
-                    <variable label="VelocitV" name="velocity_V"/>
-                    <variable label="VelocitW" name="velocity_W"/>
+                    <variable label="Velocity" name="velocity"/>
                     <property label="total_pressure" name="total_pressure"/>
                     <property label="Yplus" name="yplus" support="boundary"/>
                     <property label="Efforts" name="effort" support="boundary"/>
@@ -341,32 +339,32 @@ class ReferenceValuesTestCase(ModelTest):
         mdl.setTemperature(55.5)
 
         doc = """<solid_fuels model="homogeneous_fuel">
-                    <scalar label="Enthalpy" name="Enthalpy" type="model"><flux_reconstruction status="off"/></scalar>
-                    <scalar label="NP_CP01" name="NP_CP01" type="model"><flux_reconstruction status="off"/></scalar>
-                    <scalar label="XCH_CP01" name="XCH_CP01" type="model"><flux_reconstruction status="off"/></scalar>
-                    <scalar label="XCK_CP01" name="XCK_CP01" type="model"><flux_reconstruction status="off"/></scalar>
-                    <scalar label="ENT_CP01" name="ENT_CP01" type="model"><flux_reconstruction status="off"/></scalar>
-                    <scalar label="Fr_MV101" name="Fr_MV101" type="model"><flux_reconstruction status="off"/></scalar>
-                    <scalar label="Fr_MV201" name="Fr_MV201" type="model"><flux_reconstruction status="off"/></scalar>
-                    <scalar label="Fr_HET" name="Fr_HET" type="model"><flux_reconstruction status="off"/></scalar>
-                    <property label="Temp_GAZ" name="Temp_GAZ"/>
-                    <property label="ROM_GAZ" name="ROM_GAZ"/>
-                    <property label="YM_CHx1m" name="YM_CHx1m"/>
-                    <property label="YM_CHx2m" name="YM_CHx2m"/>
-                    <property label="YM_CO" name="YM_CO"/>
-                    <property label="YM_O2" name="YM_O2"/>
-                    <property label="YM_CO2" name="YM_CO2"/>
-                    <property label="YM_H2O" name="YM_H2O"/>
-                    <property label="YM_N2" name="YM_N2"/>
-                    <property label="XM" name="XM"/>
-                    <property label="Temp_CP01" name="Temp_CP01"/>
-                    <property label="Frm_CP01" name="Frm_CP01"/>
-                    <property label="Rho_CP01" name="Rho_CP01"/>
-                    <property label="Dia_CK01" name="Dia_CK01"/>
-                    <property label="Ga_DCH01" name="Ga_DCH01"/>
-                    <property label="Ga_DV101" name="Ga_DV101"/>
-                    <property label="Ga_DV201" name="Ga_DV201"/>
-                    <property label="Ga_HET01" name="Ga_HET01"/>
+                    <variable label="Enthalpy" name="enthalpy" type="model"><flux_reconstruction status="off"/></variable>
+                    <variable label="NP_CP01" name="np_coal01" type="model"><flux_reconstruction status="off"/></variable>
+                    <variable label="XCH_CP01" name="x_coal01" type="model"><flux_reconstruction status="off"/></variable>
+                    <variable label="XCK_CP01" name="xck_coal01" type="model"><flux_reconstruction status="off"/></variable>
+                    <variable label="ENT_CP01" name="h2_coal01" type="model"><flux_reconstruction status="off"/></variable>
+                    <variable label="Fr_MV101" name="mv1_fraction_01" type="model"><flux_reconstruction status="off"/></variable>
+                    <variable label="Fr_MV201" name="mv2_fraction_01" type="model"><flux_reconstruction status="off"/></variable>
+                    <variable label="Fr_HET" name="het_fraction" type="model"><flux_reconstruction status="off"/></variable>
+                    <property label="Temp_GAZ" name="t_gas"/>
+                    <property label="ROM_GAZ" name="rho_gas"/>
+                    <property label="YM_CHx1m" name="ym_chx1m"/>
+                    <property label="YM_CHx2m" name="ym_chx2m"/>
+                    <property label="YM_CO" name="ym_co"/>
+                    <property label="YM_O2" name="ym_o2"/>
+                    <property label="YM_CO2" name="ym_co2"/>
+                    <property label="YM_H2O" name="ym_h2o"/>
+                    <property label="YM_N2" name="ym_n2"/>
+                    <property label="XM" name="xm"/>
+                    <property label="Temp_CP01" name="t_coal01"/>
+                    <property label="Frm_CP01" name="w_solid_coal01"/>
+                    <property label="Rho_CP01" name="rho_coal01"/>
+                    <property label="Dia_CK01" name="diameter_coal01"/>
+                    <property label="Ga_DCH01" name="dissapear_rate_coal01"/>
+                    <property label="Ga_DV101" name="m_transfer_v1_coal01"/>
+                    <property label="Ga_DV201" name="m_transfer_v2_coal01"/>
+                    <property label="Ga_HET01" name="het_ts_coal01"/>
                     <property label="ntLuminance_4PI" name="ntLuminance_4PI"/>
                     <reference_temperature>55.5</reference_temperature>
                  </solid_fuels>"""
