@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -46,7 +46,7 @@ from PyQt4.QtGui  import *
 #-------------------------------------------------------------------------------
 
 from Base.Toolbox import GuiParam
-from Base.QtPage import ComboModel
+from Base.QtPage import ComboModel, Py2
 from Base.XMLengine import Case
 from Base.XMLinitialize import XMLinit
 from Pages.SolutionVerifForm import Ui_SolutionVerifForm
@@ -322,8 +322,11 @@ class MeshQualityCriteriaLogDialogView(QDialog, Ui_MeshQualityCriteriaLogDialogF
 
 
     def __saveLog(self):
-        logFile = open(os.path.join(self.exec_dir, 'check_mesh.log'), 'w')
-        logFile.write(self.logText.toPlainText().encode("utf-8"))
+        if Py2:
+            logFile = open(os.path.join(self.exec_dir, 'check_mesh.log'), 'w')
+        else:
+            logFile = open(os.path.join(self.exec_dir, 'check_mesh.log'), 'w', encoding='utf-8')
+        logFile.write(str(self.logText.toPlainText().toAscii()))
         logFile.close()
 
 
@@ -486,14 +489,14 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
         Update command-line options at each modification of
         post processing format
         """
-        list = line.split(',')
+        lst = line.split(',')
         format = self.modelFMTCHR.dicoV2M[str(self.comboBoxFMTCHR.currentText())]
         log.debug("__updateOptionsFormat-> FMTCHR = %s" % format)
         log.debug("__updateOptionsFormat-> OPTCHR = %s" % line)
 
         # update widgets from the options list
 
-        for opt in list:
+        for opt in lst:
 
             if opt == 'binary' or opt == 'text' :
                 self.modelFormat.setItem(str_model=opt)
@@ -508,11 +511,11 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
                 if opt == 'big_endian':
                     self.checkBoxBigEndian.setChecked(True)
 
-        if 'discard_polygons' not in list and 'divide_polygons' not in list:
+        if 'discard_polygons' not in lst and 'divide_polygons' not in lst:
             self.modelPolygon.setItem(str_model="display")
-        if 'discard_polyhedra' not in list and 'divide_polyhedra' not in list:
+        if 'discard_polyhedra' not in lst and 'divide_polyhedra' not in lst:
             self.modelPolyhedra.setItem(str_model="display")
-        if 'big_endian' not in list:
+        if 'big_endian' not in lst:
             self.checkBoxBigEndian.setChecked(False)
 
         # enable and disable options related to the format
