@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -38,10 +38,6 @@ import logging
 #-------------------------------------------------------------------------------
 # Third-party modules
 #-------------------------------------------------------------------------------
-import sys
-if sys.version_info[0] == 2:
-    import sip
-    sip.setapi('QString', 2)
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
@@ -51,13 +47,14 @@ from PyQt4.QtGui  import *
 #-------------------------------------------------------------------------------
 
 from Base.Toolbox import GuiParam
+from Base.QtPage import ComboModel
 from Pages.ThermalScalarForm import Ui_ThermalScalarForm
-import Base.QtPage as QtPage
 from Pages.ThermalScalarModel import ThermalScalarModel
 from Pages.ElectricalModel import ElectricalModel
 from Pages.CoalCombustionModel import CoalCombustionModel
 from Pages.GasCombustionModel import GasCombustionModel
 from Pages.AtmosphericFlowsModel import AtmosphericFlowsModel
+from Pages.CompressibleModel import CompressibleModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -91,7 +88,7 @@ class ThermalScalarView(QWidget, Ui_ThermalScalarForm):
 
         # combo Model
 
-        self.modelThermal = QtPage.ComboModel(self.comboBoxThermal, 4, 1)
+        self.modelThermal = ComboModel(self.comboBoxThermal, 4, 1)
         self.modelThermal.addItem(self.tr("No thermal scalar"), 'off')
         self.modelThermal.addItem(self.tr("Temperature (Celsius)"), 'temperature_celsius')
         self.modelThermal.addItem(self.tr("Temperature (Kelvin)"), 'temperature_kelvin')
@@ -99,6 +96,7 @@ class ThermalScalarView(QWidget, Ui_ThermalScalarForm):
 
         self.modelThermal.addItem(self.tr("Potential temperature"), 'potential_temperature')
         self.modelThermal.addItem(self.tr("Liquid potential temperature"), 'liquid_potential_temperature')
+        self.modelThermal.addItem(self.tr("Total energy (J/kg)"), 'total_energy')
 
         self.connect(self.comboBoxThermal, SIGNAL("activated(const QString&)"), self.slotThermalScalar)
 
@@ -117,6 +115,11 @@ class ThermalScalarView(QWidget, Ui_ThermalScalarForm):
         if GasCombustionModel(self.case).getGasCombustionModel() != 'off':
             self.comboBoxThermal.setEnabled(False)
 
+        if CompressibleModel(self.case).getCompressibleModel() != 'off':
+            self.comboBoxThermal.setEnabled(False)
+        else:
+            self.modelThermal.delItem(6)
+
         if AtmosphericFlowsModel(self.case).getAtmosphericFlowsModel() != 'off':
             self.comboBoxThermal.setEnabled(False)
         else:
