@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -112,9 +112,16 @@ class TimeAveragesModel(Model):
                 if not label:
                     raise ValueError("Node has no label")
 
-                if not (node['support'] and node['support'] == "boundary"):
-                    if name != 'local_time_step':
-                        self.dicoLabel2Name[label] = name
+                dim = node['dimension']
+                if dim and int(dim) > 1:
+                    for ii in range(int(dim)):
+                        label1 = label + "[" + str(ii) + "]"
+                        if not (node['support'] and node['support'] == "boundary"):
+                            self.dicoLabel2Name[label1] = (name, str(ii))
+                else:
+                    if not (node['support'] and node['support'] == "boundary"):
+                        if name != 'local_time_step':
+                            self.dicoLabel2Name[label] = (name, str(0))
 
         return list(self.dicoLabel2Name.keys())
 
@@ -145,7 +152,8 @@ class TimeAveragesModel(Model):
 
         for var in lst:
             self.isInList(var, list(self.dicoLabel2Name.keys()))
-            node.xmlAddChild('var_prop', name=self.dicoLabel2Name[var])
+            (name, comp) = self.dicoLabel2Name[var]
+            node.xmlAddChild('var_prop', name=name, component=comp)
 
         node.xmlSetData('time_step_start', start)
 
@@ -242,7 +250,7 @@ class TimeAveragesModel(Model):
 
         for var in node.xmlGetChildNodeList('var_prop'):
             for label in list(self.dicoLabel2Name.keys()):
-                if self.dicoLabel2Name[label] == var['name']:
+                if self.dicoLabel2Name[label] == (var['name'], var['component']):
                     lst.append(label)
         return node['label'], start, restart, lst
 
@@ -293,8 +301,8 @@ class TimeAveragesTestCase(ModelTest):
 
         doc = '''<time_averages>
                     <time_average id="1" label="moyenne">
-                            <var_prop name="velocity_U"/>
-                            <var_prop name="velocity_V"/>
+                            <var_prop name="velocity" component="0"/>
+                            <var_prop name="velocity" component="1"/>
                             <time_step_start>10</time_step_start>
                     </time_average>
                     <time_average id="2" label="deux">
@@ -317,18 +325,18 @@ class TimeAveragesTestCase(ModelTest):
         mdl.replaceTimeAverage(3, 'trois', 33, 1, ['Pressure', 'VelocitW'])
         doc = '''<time_averages>
                     <time_average id="1" label="moyenne">
-                            <var_prop name="velocity_U"/>
-                            <var_prop name="velocity_V"/>
+                            <var_prop name="velocity" component="0"/>
+                            <var_prop name="velocity" component="1"/>
                             <time_step_start>10</time_step_start>
                     </time_average>
                     <time_average id="2" label="SECOND">
-                            <var_prop name="velocity_W"/>
-                            <var_prop name="velocity_V"/>
+                            <var_prop name="velocity" component="2"/>
+                            <var_prop name="velocity" component="1"/>
                             <time_step_start>12</time_step_start>
                     </time_average>
                     <time_average id="3" label="trois">
                             <var_prop name="pressure"/>
-                            <var_prop name="velocity_W"/>
+                            <var_prop name="velocity" component="2"/>
                             <time_step_start>33</time_step_start>
                     </time_average>
                  </time_averages>'''
@@ -345,13 +353,13 @@ class TimeAveragesTestCase(ModelTest):
         mdl.deleteTimeAverage(2)
         doc = '''<time_averages>
                     <time_average id="1" label="moyenne">
-                            <var_prop name="velocity_U"/>
-                            <var_prop name="velocity_V"/>
+                            <var_prop name="velocity" component="0"/>
+                            <var_prop name="velocity" component="1"/>
                             <time_step_start>10</time_step_start>
                     </time_average>
                     <time_average id="2" label="trois">
-                            <var_prop name="velocity_W"/>
-                            <var_prop name="velocity_U"/>
+                            <var_prop name="velocity" component="2"/>
+                            <var_prop name="velocity" component="0"/>
                             <time_step_start>33</time_step_start>
                     </time_average>
                  </time_averages>'''
