@@ -226,13 +226,17 @@ class Package:
 
     def download(self):
 
-        import urllib
+        if sys.version_info[0] < (3):
+            import urllib2
+            u = urllib2.urlopen(self.url)
+            data = u.read()
+            f = open(self.archive, 'wb')
+            f.write(data)
+            f.close()
 
-        try:
-            urllib.urlretrieve(self.url, self.archive)
-        except:
-            sys.stderr.write("Error while retrieving %s\n" % self.url)
-            sys.exit(1)
+        else:
+            import urllib.request
+            urllib.request.urlretrieve(self.url, self.archive)
 
     #---------------------------------------------------------------------------
 
@@ -387,7 +391,7 @@ class Package:
                                  stderr=subprocess.PIPE)
             output = p.communicate()[0]
             if output.find("--no-as-needed") > -1:
-                ldflags_add = '-Wl,--no-as-needed'
+                ldflags_add = ' -Wl,--no-as-needed\n'
         except Exception:
             pass
 
@@ -412,7 +416,7 @@ class Package:
             line = re.sub(re_intsize64, '', line)
             line = re.sub(re_idxsize64, '-DIDXSIZE64 -DINTSIZE64', line)
             if ldflags_add and line[0:7] == 'LDFLAGS':
-                line += ' ' + ldflags_add
+                line = line[:-1] + ldflags_add
 
             fd.write(line)
 
@@ -597,9 +601,9 @@ class Setup:
             Package(name="HDF5",
                     description="Hierarchical Data Format",
                     package="hdf5",
-                    version="1.8.9",
-                    archive="hdf5-1.8.9.tar.gz",
-                    url="http://www.hdfgroup.org/ftp/HDF5/releases/hdf5-1.8.9/src/%s")
+                    version="1.8.10",
+                    archive="hdf5-1.8.10.tar.gz",
+                    url="http://www.hdfgroup.org/ftp/HDF5/releases/hdf5-1.8.10/src/%s")
 
         p = self.packages['hdf5']
         p.config_opts = "--enable-production"
@@ -610,12 +614,12 @@ class Setup:
             Package(name="CGNS",
                     description="CFD General Notation System",
                     package="cgnslib",
-                    version="3.1.3",
-                    archive="cgnslib_3.1.3-4.tar.gz",
-                    url="http://sourceforge.net/projects/cgns/files/cgnslib_3.1/%s/download")
+                    version="3.2.1",
+                    archive="cgnslib_3.2.1.tar.gz",
+                    url="http://sourceforge.net/projects/cgns/files/cgnslib_3.2/%s/download")
 
         p = self.packages['cgns']
-        p.config_opts = "-D ENABLE_64BIT=ON -D ENABLE_SCOPING=ON"
+        p.config_opts = "-DCGNS_ENABLE_64BIT=ON -DCGNS_ENABLE_SCOPING=ON"
 
         # MED library
 
@@ -623,8 +627,8 @@ class Setup:
             Package(name="MED",
                     description="Model for Exchange of Data",
                     package="med",
-                    version="3.0.6",
-                    archive="med-3.0.6.tar.gz",
+                    version="3.0.7",
+                    archive="med-3.0.7.tar.gz",
                     url="http://files.salome-platform.org/Salome/other/%s")
 
         p = self.packages['med']
@@ -1054,12 +1058,12 @@ Check the setup file and some utilities presence.
         if hdf5.use == 'no':
             config_opts = config_opts + " --without-hdf5"
         else:
-            cgns.config_opts += " -D ENABLE_HDF5=ON"
+            cgns.config_opts += " -DCGNS_ENABLE_HDF5=ON"
             if hdf5.install_dir:
                 config_opts = config_opts + " --with-hdf5=" + hdf5.install_dir
                 med.config_opts += " --with-hdf5=" + hdf5.install_dir
-                cgns.config_opts += " -D HDF5_INCLUDE_PATH=" + hdf5.install_dir + "/include" \
-                    + " -D HDF5_LIBRARY=" + hdf5.install_dir + "/lib/libhdf5.so"
+                cgns.config_opts += " -DHDF5_INCLUDE_PATH=" + hdf5.install_dir + "/include" \
+                    + " -DHDF5_LIBRARY=" + hdf5.install_dir + "/lib/libhdf5.so"
 
         # CGNS
 
@@ -1258,7 +1262,7 @@ disable_frontend  %(disable_frontend)s
 #
 # If Code_Saturne is built with SALOME support,
 # running "code_saturne salome" will launch the
-# associated application, containing thr CFDSTUDY module.
+# associated application, containing the CFDSTUDY module.
 #--------------------------------------------------------
 salome    %(salome)s
 #
@@ -1310,7 +1314,7 @@ salome    %(salome)s
         fc = self.fc
         mpicc = self.mpicc
         cxx = self.cxx
-        mpicxx = self.mpicc
+        mpicxx = self.mpicxx
         python = self.python
         salome = self.salome
 
@@ -1321,7 +1325,7 @@ salome    %(salome)s
         if not fc: fc = 'NEEDS_DEFINITION'
         if not mpicc: mpicc = 'auto'
         if not cxx: cxx = 'auto'
-        if not mpicxx: mpicc = 'auto'
+        if not mpicxx: mpicxx = 'auto'
         if not python: python = 'NEEDS_DEFINITION'
         if not salome: salome = 'no'
 
