@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -40,8 +40,8 @@ import logging
 # Third-party modules
 #-------------------------------------------------------------------------------
 
-from PyQt4.QtGui import QApplication, QCursor, QDialog, QMessageBox, QDockWidget
-from PyQt4.QtCore import Qt, QObject, QVariant, SIGNAL
+from PyQt4.QtGui import QDialog, QMessageBox, QDockWidget
+from PyQt4.QtCore import Qt, QObject, SIGNAL
 
 #-------------------------------------------------------------------------------
 # Salome modules
