@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -38,11 +38,8 @@ import os, logging
 #-------------------------------------------------------------------------------
 
 from PyQt4 import QtGui, QtCore
-from PyQt4.QtGui import QApplication, QCursor, QDialog, QLabel, QGridLayout, \
-                        QCloseEvent, QTextEdit, QTextOption, QDockWidget, QWidget, QFont
-from PyQt4.QtCore import Qt, QObject, QVariant, SIGNAL, QEvent, QProcess, QString
-
-#from PyQt4.QtCore import QProcessEnvironment
+from PyQt4.QtGui import QApplication, QCursor, QDialog, QCloseEvent
+from PyQt4.QtCore import Qt, SIGNAL, QEvent, QProcess, QString
 
 #-------------------------------------------------------------------------------
 # Salome modules
