@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2013 EDF S.A.
+# Copyright (C) 1998-2014 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -40,9 +40,8 @@ import os, re, shutil, logging
 #-------------------------------------------------------------------------------
 
 from PyQt4 import QtCore, QtGui
-from PyQt4.QtGui import QMessageBox, QDialog, QPushButton, QToolTip, QColor, \
-                        QRadioButton, QTableWidget, QTableWidgetItem
-from PyQt4.QtCore import Qt, QStringList, QString, SIGNAL
+from PyQt4.QtGui import QMessageBox, QDialog, QPushButton, QRadioButton
+from PyQt4.QtCore import Qt, QString, SIGNAL
 
 #For Testing
 from PyQt4.QtCore import QTranslator
