@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -92,7 +92,6 @@
 !> \param[in]     iccocg        indicator
 !>                               - 1 re-compute cocg matrix (for iterativ gradients)
 !>                               - 0 otherwise
-!> \param[in]     ipp*          index of the variable for post-processing
 !> \param[in]     iwarnp        verbosity
 !> \param[in]     imucpp        indicator
 !>                               - 0 do not multiply the convectiv term by Cp
@@ -147,7 +146,7 @@
 subroutine bilsca &
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp , idftnp ,                            &
+   iwarnp , imucpp , idftnp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
    flumas , flumab , viscf  , viscb  , viscce , xcpp   ,          &
@@ -170,6 +169,7 @@ use period
 use cplsat
 use mesh
 use cs_f_interfaces
+use cs_c_bindings
 
 !===============================================================================
 
@@ -181,7 +181,7 @@ integer          idtvar
 integer          ivar   , iconvp , idiffp , nswrgp , imligp
 integer          ircflp , ischcp , isstpp
 integer          inc    , imrgra , iccocg
-integer          iwarnp , ipp    , imucpp, idftnp, icvflb
+integer          iwarnp , imucpp, idftnp, icvflb
 
 integer          icvfli(nfabor)
 
@@ -198,14 +198,40 @@ double precision xcpp(ncelet)
 double precision viscce(*)
 
 ! Local variables
+
 integer          idiflc, f_id
 
+type(var_cal_opt) vcopt
+
 !===============================================================================
 
 if (ivar.eq.0) then
   f_id = -1
+  vcopt%iwarni = iwarnp
+  vcopt%iconv  = iconvp
+  vcopt%istat  = -1
+  vcopt%idiff  = idiffp
+  vcopt%idifft = -1
+  vcopt%idften = -1
+  vcopt%iswdyn = -1
+  vcopt%ischcv = ischcp
+  vcopt%isstpc = isstpp
+  vcopt%nswrgr = nswrgp
+  vcopt%nswrsm = -1
+  vcopt%imrgra = imrgra
+  vcopt%imligr = imligp
+  vcopt%ircflu = ircflp
+  vcopt%thetav = thetap
+  vcopt%blencv = blencp
+  vcopt%epsilo = -1.d0
+  vcopt%epsrsm = -1.d0
+  vcopt%epsrgr = epsrgp
+  vcopt%climgr = climgp
+  vcopt%extrag = extrap
+  vcopt%relaxv = relaxp
 else
   f_id = ivarfl(ivar)
+  call field_get_key_struct_var_cal_opt(f_id, vcopt)
 endif
 
 ! Scalar diffusivity
@@ -214,10 +240,9 @@ if (idftnp.eq.1) then
 
     call bilsc2 &
     !==========
-   ( idtvar , f_id   , iconvp , idiffp , nswrgp , imligp , ircflp , &
-     ischcp , isstpp , icvflb , inc    , imrgra , iccocg ,          &
-     ifaccp , iwarnp ,                                              &
-     blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
+   ( idtvar , f_id   , vcopt  ,                                     &
+     icvflb , inc    , iccocg ,                                     &
+     ifaccp ,                                                       &
      pvar   , pvara  ,                                              &
      itypfb , icvfli , coefap , coefbp , cofafp , cofbfp ,          &
      flumas , flumab , viscf  , viscb  ,                            &
@@ -229,11 +254,10 @@ if (idftnp.eq.1) then
 
     call bilsct &
     !==========
-   ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
-     ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-     ipp    , iwarnp ,                                              &
-     blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
-     pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
+   ( idtvar , f_id   , vcopt  ,                                     &
+     inc    , iccocg ,                                              &
+     ifaccp ,                                                       &
+     pvar   , pvara  , itypfb , coefap , coefbp , cofafp , cofbfp , &
      flumas , flumab , viscf  , viscb  , xcpp   ,                   &
      smbrp  )
 
@@ -243,15 +267,15 @@ if (idftnp.eq.1) then
 elseif (idftnp.eq.6) then
 
   idiflc = 0
+  vcopt%idiff  = idiflc
   ! Convective part
   if (imucpp.eq.0.and.iconvp.eq.1) then
 
     call bilsc2 &
     !==========
-   ( idtvar , f_id   , iconvp , idiflc , nswrgp , imligp , ircflp , &
-     ischcp , isstpp , icvflb , inc    , imrgra , iccocg ,          &
-     ifaccp , iwarnp ,                                              &
-     blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
+   ( idtvar , f_id   , vcopt  ,                                     &
+     icvflb , inc    , iccocg ,                                     &
+     ifaccp ,                                                       &
      pvar   , pvara  ,                                              &
      itypfb , icvfli , coefap , coefbp , cofafp , cofbfp ,          &
      flumas , flumab , viscf  , viscb  ,                            &
@@ -263,11 +287,10 @@ elseif (idftnp.eq.6) then
 
     call bilsct &
     !==========
-   ( idtvar , ivar   , iconvp , idiflc , nswrgp , imligp , ircflp , &
-     ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-     ipp    , iwarnp ,                                              &
-     blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
-     pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
+   ( idtvar , f_id   , vcopt  ,                                     &
+     inc    , iccocg ,                                              &
+     ifaccp ,                                                       &
+     pvar   , pvara  , itypfb , coefap , coefbp , cofafp , cofbfp , &
      flumas , flumab , viscf  , viscb  , xcpp   ,                   &
      smbrp  )
 
@@ -278,9 +301,8 @@ elseif (idftnp.eq.6) then
 
     call diften &
     !==========
-   ( idtvar , ivar   , nswrgp , imligp , ircflp ,                   &
-     inc    , imrgra , iccocg , ipp    , iwarnp , epsrgp ,          &
-     climgp , extrap , relaxp , thetap ,                            &
+   ( idtvar , f_id   , vcopt  ,                                     &
+     inc    , iccocg ,                                              &
      pvar   , pvara  , coefap , coefbp , cofafp , cofbfp ,          &
      viscf  , viscb  , viscce ,                                     &
      weighf , weighb ,                                              &
