@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -159,13 +159,14 @@ subroutine bilscv &
 !===============================================================================
 
 use paramx
-use numvar
+use numvar, only: ivarfl
 use pointe
 use entsor
 use parall
 use period
 use cplsat
 use mesh
+use cs_c_bindings
 
 !===============================================================================
 
@@ -194,44 +195,71 @@ double precision secvif(nfac), secvib(nfabor)
 double precision smbr(3,ncelet)
 
 ! Local variables
-integer          idiflc
+
+integer          idiflc, f_id
+
+type(var_cal_opt) vcopt
 
 !===============================================================================
 
+if (ivar.eq.0) then
+  f_id = -1
+  vcopt%iwarni = iwarnp
+  vcopt%iconv  = iconvp
+  vcopt%istat  = -1
+  vcopt%idiff  = idiffp
+  vcopt%idifft = -1
+  vcopt%idften = idftnp
+  vcopt%iswdyn = -1
+  vcopt%ischcv = ischcp
+  vcopt%isstpc = isstpp
+  vcopt%nswrgr = nswrgp
+  vcopt%nswrsm = -1
+  vcopt%imrgra = imrgra
+  vcopt%imligr = imligp
+  vcopt%ircflu = ircflp
+  vcopt%thetav = thetap
+  vcopt%blencv = blencp
+  vcopt%epsilo = -1.d0
+  vcopt%epsrsm = -1.d0
+  vcopt%epsrgr = epsrgp
+  vcopt%climgr = climgp
+  vcopt%extrag = -1.d0
+  vcopt%relaxv = relaxp
+else
+  f_id = ivarfl(ivar)
+  call field_get_key_struct_var_cal_opt(f_id, vcopt)
+endif
+
 ! Scalar diffusivity
 if (idftnp.eq.1) then
 
   call bilsc4 &
   !==========
-   ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
-     ischcp , isstpp , inc    , imrgra , ivisep ,                   &
-     ippu   , iwarnp ,                                              &
-     blencp , epsrgp , climgp , relaxp , thetap ,                   &
+   ( idtvar , f_id   , vcopt  ,                                     &
+     icvflb , inc    , ifaccp , ivisep ,                            &
      pvar   , pvara  ,                                              &
-     coefav , coefbv , cofafv , cofbfv ,                            &
+     itypfb , icvfli , coefav , coefbv , cofafv , cofbfv ,          &
      flumas , flumab , viscf  , viscb  , secvif ,                   &
-     icvflb , icvfli ,                                              &
      smbr   )
 
 ! Symmetric tensor diffusivity
 elseif (idftnp.eq.6) then
 
-  ! Nor diffusive part neither secodary viscosity or transpose of grandient
+  ! Nor diffusive part neither secondary viscosity or transpose of gradient
   idiflc = 0
+  vcopt%idiff  = idiflc
   ! Convective part
   if (iconvp.eq.1) then
 
     call bilsc4 &
     !==========
-     ( idtvar , ivar   , iconvp , idiflc , nswrgp , imligp , ircflp , &
-       ischcp , isstpp , inc    , imrgra , idiflc ,                   &
-       ippu   , iwarnp ,                                              &
-       blencp , epsrgp , climgp , relaxp , thetap ,                   &
-       pvar   , pvara  ,                                              &
-       coefav , coefbv , cofafv , cofbfv ,                            &
-       flumas , flumab , viscf  , viscb  , secvif ,                   &
-       icvflb , icvfli ,                                              &
-       smbr   )
+   ( idtvar , f_id   , vcopt  ,                                     &
+     icvflb , inc    , ifaccp , idiflc ,                            &
+     pvar   , pvara  ,                                              &
+     itypfb , icvfli , coefav , coefbv , cofafv , cofbfv ,          &
+     flumas , flumab , viscf  , viscb  , secvif ,                   &
+     smbr   )
 
   endif
 
@@ -240,12 +268,10 @@ elseif (idftnp.eq.6) then
 
     call diftnv &
     !==========
-   ( idtvar , ivar   , nswrgp , imligp , ircflp ,                   &
-     inc    , imrgra , ivisep ,                                     &
-     ippu   , iwarnp , epsrgp ,                                     &
-     climgp , relaxp , thetap ,                                     &
+   ( idtvar , f_id   , vcopt  ,                                     &
+     inc    , ifaccp , ivisep ,                                     &
      pvar   , pvara  ,                                              &
-     coefav , coefbv , cofafv , cofbfv ,                            &
+     itypfb , coefav , coefbv , cofafv , cofbfv ,                   &
      viscf  , viscb  , secvif ,                                     &
      smbr   )
 
