@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -81,6 +81,7 @@
 #include "cs_mesh.h"
 #include "cs_mesh_quantities.h"
 #include "cs_matrix.h"
+#include "cs_matrix_tuning.h"
 #include "cs_timer.h"
 
 /*----------------------------------------------------------------------------
@@ -268,7 +269,7 @@ _matrix_vector_test(double                 t_measure,
                                   halo,
                                   numbering);
 
-  m = cs_matrix_create_tuned(ms, m_variant);
+  m = cs_matrix_create_by_variant(ms, m_variant);
 
   cs_matrix_set_coefficients(m,
                              sym_coeffs,
@@ -822,7 +823,9 @@ cs_benchmark(int  mpi_trace_mode)
                   "=====================================\n"));
 
   mv = cs_matrix_variant_tuned(t_measure,
+                               0,
                                n_fill_types_nsym,
+                               NULL,
                                fill_types_nsym,
                                fill_weights_nsym,
                                10,       /* min expected SpMV products */
@@ -848,7 +851,9 @@ cs_benchmark(int  mpi_trace_mode)
                   "=============================\n"));
 
   mv = cs_matrix_variant_tuned(t_measure,
+                               0,
                                n_fill_types_sym,
+                               NULL,
                                fill_types_sym,
                                fill_weights_sym,
                                10,  /* min expected SpMV products */
