@@ -9,7 +9,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -462,6 +462,38 @@ cs_grid_set_defaults(int  merge_mean_threshold,
 int
 cs_grid_get_merge_stride(void);
 
+/*----------------------------------------------------------------------------
+ * Set matrix tuning behavior for multigrid coarse meshes.
+ *
+ * The finest mesh (level 0) is handled by the default tuning options,
+ * so only coarser meshes are considered here.
+ *
+ * parameters:
+ *   fill_type <-- associated matrix fill type
+ *   max_level <-- maximum leval for which tuning is active
+ *----------------------------------------------------------------------------*/
+
+void
+cs_grid_set_matrix_tuning(cs_matrix_fill_type_t  fill_type,
+                          int                    max_level);
+
+/*----------------------------------------------------------------------------
+ * Set matrix tuning behavior for multigrid coarse meshes.
+ *
+ * The finest mesh (level 0) is handled by the default tuning options,
+ * so only coarser meshes are considered here.
+ *
+ * parameters:
+ *   fill_type <-- associated matrix fill type
+ *   level     <-- level for which variant is assiged
+ *   mv        <-- matrix variant to assign (NULL to unassign)
+ *----------------------------------------------------------------------------*/
+
+void
+cs_grid_set_matrix_variant(cs_matrix_fill_type_t       fill_type,
+                           int                         level,
+                           const cs_matrix_variant_t  *mv);
+
 /*----------------------------------------------------------------------------
  * Print the default parameters for multigrid coarsening.
  *----------------------------------------------------------------------------*/
