@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -99,13 +99,16 @@ void CS_PROCF(resmgr, RESMGR)
  const char       *cname,     /* <-- variable name */
  const cs_int_t   *lname,     /* <-- variable name length */
  const cs_int_t   *iresds,    /* <-- Descent smoother type:
-                                     0: pcg; 1: Jacobi; 2: cg-stab */
+                                     0: pcg; 1: Jacobi; 2: cg-stab,
+                                     200: pcg_single reduction */
  const cs_int_t   *iresas,    /* <-- Ascent smoother type:
-                                     0: pcg; 1: Jacobi; 2: cg-stab */
+                                     0: pcg; 1: Jacobi; 2: cg-stab,
+                                     200: pcg_single reduction */
  const cs_int_t   *ireslp,    /* <-- Coarse Resolution type:
-                                     0: pcg; 1: Jacobi; 2: cg-stab */
+                                     0: pcg; 1: Jacobi; 2: cg-stab,
+                                     200: pcg_single reduction */
  const cs_int_t   *ipol,      /* <-- Preconditioning polynomial degree
-                                     (0: diagonal) */
+                                     (0: diagonal, -1: none) */
  const cs_int_t   *ncymxp,    /* <-- Max number of cycles */
  const cs_int_t   *nitmds,    /* <-- Max number of iterations for descent */
  const cs_int_t   *nitmas,    /* <-- Max number of iterations for ascent */
