@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -87,6 +87,7 @@ use atincl
 use mesh
 use atchem
 use siream
+use field
 
 !===============================================================================
 
@@ -94,7 +95,7 @@ implicit none
 
 integer          nvar   , nscal
 
-double precision dt(ncelet), rtp(ncelet,*), propce(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), propce(ncelet,*)
 
 ! Local variables
 
@@ -102,10 +103,16 @@ integer          imode, iel
 double precision d2s3
 double precision zent,xuent,xvent,xkent,xeent,tpent,qvent,ncent
 
-integer k,ii
+integer k,ii, isc
 double precision xcent
 
+double precision, dimension(:,:), pointer :: vel
+
 !===============================================================================
+
+! Map field arrays
+call field_get_val_v(ivarfl(iu), vel)
+
 !===============================================================================
 ! 1.  INITIALISATION VARIABLES LOCALES
 !===============================================================================
@@ -181,7 +188,8 @@ if (iaerosol.eq.1) then
   if (init_at_chem.eq.1) then
     do iel = 1, ncel
       do ii = 1, nesp_aer*nbin_aer + nbin_aer
-       rtp(iel,isca(nespg_siream+ii)) = dlconc0(ii)
+        isc = (isca_chem(1) - 1) + nespg_siream + ii
+        rtp(iel,isca(isc)) = dlconc0(ii)
       enddo
     enddo
   endif
@@ -255,9 +263,9 @@ if (isuite.eq.0) then
        (nbmetd, nbmetm,                                               &
         zdmet, tmmet, epmet, zent  , ttcabs, xeent )
 
-        rtp(iel,iu) = xuent
-        rtp(iel,iv) = xvent
-        rtp(iel,iw) = 0.d0
+        vel(1,iel) = xuent
+        vel(2,iel) = xvent
+        vel(3,iel) = 0.d0
 
     !     ITYTUR est un indicateur qui vaut ITURB/10
         if    (itytur.eq.2) then
@@ -339,7 +347,7 @@ endif
 call cs_user_initialization &
 !==========================
 ( nvar   , nscal  ,                                            &
-  dt     , rtp    , propce )
+  dt     )
 
 !----
 ! FORMATS
