@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -109,6 +109,7 @@ use paramx
 use numvar
 use optcal
 use cstphy
+use dimens, only: nvar
 use cstnum, only: pi
 use entsor
 use parall
@@ -119,6 +120,7 @@ use ppincl
 use mesh
 use atincl
 use field
+use spefun
 use field_operator
 
 !===============================================================================
@@ -127,7 +129,7 @@ implicit none
 
 ! Arguments
 
-double precision rtp(ncelet,*), rtpa(ncelet,*)
+double precision rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 
 ! Local variables
@@ -252,7 +254,7 @@ if (ippmod(iatmos).ge.2) then ! humid atmosphere physics
 endif ! (ippmod(iatmos).ge.2)
 
 ! User re-definition:
-call usatph (propce)
+call usatph ()
 
 !===============================================================================
 ! FORMATS
@@ -396,7 +398,7 @@ do iel = 1, ncel
   a_coeff = a_const*rtp(iel, ik )**3/rtp(iel,iep)**2 ! 2 cmu/c2 * k**3 / eps**2
   var_tl= a_coeff*(dtlsd(1,iel)**2 + dtlsd(2,iel)**2 + dtlsd(3,iel)**2)
   var_q = a_coeff*( dqsd(1,iel)**2 + dqsd(2,iel)**2 + dqsd(3,iel)**2)
-  cov_tlq = a_coeff*(  dtlsd(1,iel)*dqsd(iel,1)   &
+  cov_tlq = a_coeff*(  dtlsd(1,iel)*dqsd(1,iel)   &
                      + dtlsd(2,iel)*dqsd(2,iel)   &
                      + dtlsd(3,iel)*dqsd(3,iel))
 
@@ -422,7 +424,7 @@ do iel = 1, ncel
   al = 1.d0/(1.d0 + qsl*clatev**2/(rair*rvsra*cp0*tliq**2))
   qsup = qsl/sig_flu
 
-  nebdia(iel) = 0.5d0*(1.d0 + erf(q1/sqrt(2.d0)))
+  nebdia(iel) = 0.5d0*(1.d0 + ferf(q1/sqrt(2.d0)))
 
   qliq = (sig_flu                                                               &
         /(1.d0 + qsl*clatev**2/(rvap*cp0*tliq**2)))                             &
@@ -480,17 +482,10 @@ end subroutine gaussian
 subroutine grad_thetal(dtlsd)
 double precision dtlsd(3,ncelet)
 
-double precision climgp
-double precision epsrgp
-double precision extrap
-
 integer    iccocg
 integer    iivar
-integer    imligp
 integer    inc
 integer    itpp
-integer    iwarnp
-integer    nswrgp
 
 ! Computation of the gradient of the potential temperature
 
@@ -501,18 +496,11 @@ itpp = isca(iscalt)
 iccocg = 1
 inc = 1
 
-nswrgp = nswrgr(itpp)
-epsrgp = epsrgr(itpp)
-imligp = imligr(itpp)
-iwarnp = iwarni(itpp)
-climgp = climgr(itpp)
-extrap = extrag(itpp)
-
 iivar = itpp
 
 call field_gradient_scalar(ivarfl(iivar), 1, imrgra, inc,           &
-                           iccocg, nswrgp, iwarnp, imligp,          &
-                           epsrgp, extrap, climgp, dtlsd)
+                           iccocg,                                  &
+                           dtlsd)
 
 end subroutine grad_thetal
 
@@ -523,17 +511,10 @@ end subroutine grad_thetal
 subroutine grad_qw(dqsd)
 double precision dqsd(3,ncelet)
 
-double precision climgp
-double precision epsrgp
-double precision extrap
-
 integer    iccocg
 integer    iivar
-integer    imligp
 integer    inc
 integer    iqw
-integer    iwarnp
-integer    nswrgp
 
 ! ----------------------------------------------------------------
 ! now gradient of total humidity
@@ -543,18 +524,12 @@ iccocg = 1
 inc = 1
 
 iqw = isca(itotwt)
-nswrgp = nswrgr(iqw)
-epsrgp = epsrgr(iqw)
-imligp = imligr(iqw)
-iwarnp = iwarni(iqw)
-climgp = climgr(iqw)
-extrap = extrag(iqw)
 
 iivar = iqw
 
 call field_gradient_scalar(ivarfl(iivar), 1, imrgra, inc,           &
-                           iccocg, nswrgp, iwarnp, imligp,          &
-                           epsrgp, extrap, climgp, dqsd)
+                           iccocg,                                  &
+                           dqsd)
 
 end subroutine grad_qw
 end subroutine atphyv
