@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -60,6 +60,7 @@ subroutine atprke &
 !===============================================================================
 
 use paramx
+use dimens, only: nvar
 use numvar
 use entsor
 use cstnum
@@ -82,7 +83,7 @@ implicit none
 ! Arguments
 integer          nscal
 
-double precision rtpa (ncelet,*)
+double precision rtpa (ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision smbrk(ncelet), smbre(ncelet)
 double precision tinstk(ncelet)
@@ -94,13 +95,10 @@ integer         itpp , iqw
 integer         ipcliq
 integer         iccocg, inc
 integer         iivar
-integer         nswrgp, imligp
-integer         iwarnp
 
 double precision gravke, prdtur
 double precision theta_virt
 double precision qldia,qw
-double precision epsrgp, climgp, extrap
 double precision xk, xeps, visct, ttke, rho
 
 double precision dum
@@ -165,21 +163,14 @@ itpp = isca(iscalt)
 iccocg = 1
 inc = 1
 
-nswrgp = nswrgr(itpp)
-epsrgp = epsrgr(itpp)
-imligp = imligr(itpp)
-iwarnp = iwarni(itpp)
-climgp = climgr(itpp)
-extrap = extrag(itpp)
-
 iivar = itpp
 
 ! computes the turbulent production/destruction terms:
 ! dry atmo: (1/sigmas*theta)*(dtheta/dz)*gz
 
 call field_gradient_scalar(ivarfl(iivar), 1, imrgra, inc,           &
-                           iccocg, nswrgp, iwarnp, imligp,          &
-                           epsrgp, extrap, climgp, grad)
+                           iccocg,                                  &
+                           grad)
 
 ! Production and gravity terms
 ! TINSTK=P+G et TINSTE = P + (1-CE3)*G
@@ -262,21 +253,14 @@ enddo
 iccocg = 1
 inc = 1
 
-nswrgp = nswrgr(itpp)
-epsrgp = epsrgr(itpp)
-imligp = imligr(itpp)
-iwarnp = iwarni(itpp)
-climgp = climgr(itpp)
-extrap = extrag(itpp)
-
 iivar = itpp
 
 ! computes the turbulent production/destruction terms:
 ! humid atmo: (1/sigmas*theta_v)*(dtheta_l/dz)*gz
 
 call field_gradient_scalar(ivarfl(iivar), 1, imrgra, inc,           &
-                           iccocg, nswrgp, iwarnp, imligp,          &
-                           epsrgp, extrap, climgp, grad)
+                           iccocg,                                  &
+                           grad)
 
 ! Production and gravity terms
 ! TINSTK = P + G et TINSTE = P + (1-CE3)*G
@@ -303,21 +287,14 @@ endif
 ! now gradient of humidity and it's associated production term
 ! ----------------------------------------------------------------
 
-nswrgp = nswrgr(iqw)
-epsrgp = epsrgr(iqw)
-imligp = imligr(iqw)
-iwarnp = iwarni(iqw)
-climgp = climgr(iqw)
-extrap = extrag(iqw)
-
 iivar = iqw
 
 ! computes the turbulent production/destruction terms:
 ! humid atmo: (1/sigmas*theta_v)*(dtheta_l/dz)*gz
 
 call field_gradient_scalar(ivarfl(iivar), 1, imrgra, inc,           &
-                           iccocg, nswrgp, iwarnp, imligp,          &
-                           epsrgp, extrap, climgp, grad)
+                           iccocg,                                  &
+                           grad)
 
 ! Production and gravity terms
 ! TINSTK = P + G et TINSTE = P + (1-CE3)*G
