@@ -3,7 +3,7 @@
 !     This file is part of the Code_Saturne Kernel, element of the
 !     Code_Saturne CFD tool.
 
-!     Copyright (C) 1998-2013 EDF S.A., France
+!     Copyright (C) 1998-2014 EDF S.A., France
 
 !     contact: saturne-support@edf.fr
 
@@ -84,7 +84,7 @@ integer          ii
 integer          iscdri, icla, iclap
 integer          iflid, iopchr
 integer          nfld, itycat, ityloc, idim1, idim3
-integer          keyccl, keydri, keyvis, keylbl, kdiftn
+integer          keyccl, keydri, kdiftn
 logical          ilved, iprev, inoprv
 integer          f_id
 
@@ -110,12 +110,6 @@ iprev  = .true.    ! variables have previous value
 inoprv = .false.   ! variables have no previous value
 iopchr = 1         ! Postprocessing level for variables
 
-name = 'post_vis'
-call field_get_key_id(name, keyvis)
-
-name = 'label'
-call field_get_key_id(name, keylbl)
-
 ! Key id of the coal scalar class
 call field_get_key_id("scalar_class", keyccl)
 
