@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -74,6 +74,7 @@ use mesh
 use field
 use post
 use atchem
+use atimbr
 use siream
 use ptrglo
 use turbomachinery
@@ -113,8 +114,6 @@ character        ficsui*32
 
 integer, allocatable, dimension(:) :: isostd
 
-double precision, allocatable, dimension(:,:) :: coefa, coefb
-
 double precision, pointer, dimension(:)   :: dt => null()
 double precision, pointer, dimension(:,:) :: rtp => null(), rtpa => null()
 double precision, pointer, dimension(:,:) :: propce => null()
@@ -133,7 +132,7 @@ interface
   ( itrale , nvar   , nscal  ,                                     &
     isostd ,                                                       &
     dt     , rtpa   , rtp    , propce ,                            &
-    coefa  , coefb  , frcxt  , prhyd  )
+    frcxt  , prhyd  )
 
     use dimens, only: ndimfb
     use mesh, only: nfabor
@@ -143,8 +142,6 @@ interface
     integer                                   :: itrale, nvar, nscal
     integer, dimension(nfabor+1)              :: isostd
 
-    double precision, dimension (nfabor, *)   :: coefa, coefb
-
     double precision, pointer, dimension(:)   :: dt
     double precision, pointer, dimension(:,:) :: rtp, rtpa, propce
     double precision, pointer, dimension(:,:) :: frcxt
@@ -244,7 +241,6 @@ if (iihmpr.eq.1) then
 ( iappel ,          &
   ncelet , ncepdc , &
   ivoid  ,          &
-  rvoid  ,          &
   rvoid  )
 endif
 
@@ -253,7 +249,6 @@ call  uskpdc &
 ( nvar   , nscal  ,                                              &
   ncepdc , iappel ,                                              &
   ivoid  , izcpdc ,                                              &
-  rvoid  , rvoid  , rvoid  ,                                     &
   rvoid  ,                                                       &
   rvoid  )
 
@@ -271,6 +266,11 @@ if (ncpdct.gt.0) then
   if (idtten.lt.0) then
     call field_create('dttens', FIELD_INTENSIVE, 1, 6, .true., .false., idtten)
   endif
+else if (iporos.eq.2) then
+  ! Add matching field if not already done
+  if (idtten.lt.0) then
+    call field_create('dttens', FIELD_INTENSIVE, 1, 6, .true., .false., idtten)
+  endif
 endif
 
 ! -----------------
@@ -283,7 +283,6 @@ call ustsma &
   ncetsm , iappel ,                                              &
   ivoid  ,                                                       &
   ivoid  , ivoid  , izctsm ,                                     &
-  rvoid  , rvoid  ,                                              &
   rvoid  ,                                                       &
   ckupdc , rvoid  )
 
@@ -309,7 +308,7 @@ call uspt1d &
    ivoid  , izft1d , ivoid  , ivoid  ,                            &
    rvoid  , rvoid  , rvoid  ,                                     &
    rvoid  , rvoid  , rvoid  ,                                     &
-   rvoid  , rvoid  , rvoid  ,                                     &
+   rvoid  , rvoid  ,                                              &
    rvoid  , rvoid  )
 
 nfpt1t = nfpt1d
@@ -367,11 +366,11 @@ if (nfpt1t.eq.0) deallocate(izft1d)
 
 ! Allocate main arrays
 
-allocate(dt(ncelet), rtp(ncelet,nvar), rtpa(ncelet,nvar))
+allocate(dt(ncelet))
+allocate(rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar))
 allocate(propce(ncelet,nproce))
 
 ! Allocate arrays on boundary faces
-allocate(coefa(nfabor,ncofab), coefb(nfabor,ncofab))
 
 allocate(isostd(nfabor+1))
 if (iphydr.eq.1) then
@@ -389,19 +388,18 @@ endif
 call init_aux_arrays(ncelet, nfabor)
 !===================
 
-! Compute the porosity if needed
-if (iporos.ge.1) then
-  call usporo
-endif
-
-call turbomachinery_init_mapping
-!===============================
+call turbomachinery_init
+!=======================
 
 if (ippmod(iatmos).ge.0) then
 
   call init_meteo
   !==============
 
+  if (imbrication_flag) then
+    call activate_imbrication
+  endif
+
   if (ifilechemistry.ge.1) then
     call init_chemistry
   endif
@@ -466,7 +464,7 @@ endif
 ! Default initializations
 !===============================================================================
 
-call fldtri(nproce, dt, rtpa, rtp, propce, coefa, coefb)
+call fldtri(nproce, dt, rtpa, rtp, propce)
 !==========
 
 call field_allocate_or_map_all
@@ -474,11 +472,18 @@ call field_allocate_or_map_all
 
 call iniva0 &
 !==========
- ( nvar   , nscal  , ncofab ,                                     &
+ ( nvar   , nscal  ,                                              &
    dt     , rtp    , propce ,                                     &
-   coefa  , coefb  ,                                              &
    frcxt  , prhyd  )
 
+! Compute the porosity if needed
+if (iporos.ge.1) then
+  if (iihmpr.eq.1) then
+    call uiporo(ncelet, iporos)
+  endif
+  call usporo
+endif
+
 !===============================================================================
 ! Possible restart
 !===============================================================================
@@ -487,7 +492,7 @@ if (isuite.eq.1) then
 
   call lecamo &
   !==========
- ( ncelet , ncel   , nfabor , nvar   , nscal  ,                   &
+ ( ncelet , ncel   , nfac   , nfabor , nvar   , nscal  ,          &
    dt     , rtp    , propce ,                                     &
    frcxt  , prhyd  )
 
@@ -531,7 +536,7 @@ if (isuite.eq.1) then
       call turbomachinery_update
 
       ! Fields
-      call fldtri(nproce, dt, rtpa, rtp, propce, coefa, coefb)
+      call fldtri(nproce, dt, rtpa, rtp, propce)
 
       ! Other arrays, depending on user options
       if (iilagr.gt.0) &
@@ -606,7 +611,7 @@ if (nfpt1t.gt.0) then
    tppt1d , rgpt1d , eppt1d ,                                     &
    tept1d , hept1d , fept1d ,                                     &
    xlmbt1 , rcpt1d , dtpt1d ,                                     &
-   dt     , rtpa   )
+   dt     )
 
   iappel = 2
   call vert1d &
@@ -667,7 +672,7 @@ endif
 
 if (ippmod(iatmos).ge.2.and.iatsoil.eq.1) then
   call atmsol()
-  !===============
+  !============
 endif
 
 !===============================================================================
@@ -687,7 +692,7 @@ if(ncpdct.gt.0) then
   iappel = 2
 
   if (iihmpr.eq.1) then
-    call uikpdc(iappel, ncelet, ncepdc, icepdc, ckupdc, rtpa)
+    call uikpdc(iappel, ncelet, ncepdc, icepdc, ckupdc)
     !==========
   endif
 
@@ -696,7 +701,7 @@ if(ncpdct.gt.0) then
 ( nvar   , nscal  ,                                              &
   ncepdc , iappel ,                                              &
   icepdc , izcpdc ,                                              &
-  dt     , rtpa   , rtp  , propce ,                              &
+  dt     ,                                                       &
   ckupdc )
 
 endif
@@ -716,7 +721,7 @@ if(nctsmt.gt.0) then
   ncetsm , iappel ,                                              &
   icepdc ,                                                       &
   icetsm , itypsm , izctsm ,                                     &
-  dt     , rtpa   , propce ,                                     &
+  dt     ,                                                       &
   ckupdc , smacel )
 
 endif
@@ -736,7 +741,7 @@ if (ivrtex.eq.1) then
   call usvort &
   !==========
  ( nvar   , nscal  , iappel ,                                     &
-   dt     , rtpa   , propce )
+   dt     )
 
   call vorver (nfabor, iappel)
   !==========
@@ -861,7 +866,6 @@ call tridim                                                       &
    isostd ,                                                       &
    dt     , rtpa   , rtp    ,                                     &
    propce ,                                                       &
-   coefa  , coefb  ,                                              &
    frcxt  , prhyd  )
 
 !===============================================================================
@@ -869,8 +873,7 @@ call tridim                                                       &
 !===============================================================================
 
 if (inpdt0.eq.0 .and. itrale.gt.0) then
-  call calmom(ncel, ncelet, rtp, dt, propce)
-  !==========
+  call time_moment_update_all
 endif
 
 !===============================================================================
@@ -902,13 +905,15 @@ if (itrale.gt.0) then
     !==========
   ( ncelet , ncel,                                                &
     ntmabs, ntcabs, ttcabs, ttmabs, ttpabs,                       &
-    xyzcen, rtp, propce, ipproc)
+    xyzcen)
   endif
 
-  call cs_user_extra_operations                                   &
-  !============================
+  call cs_f_user_extra_operations &
+  !==============================
  ( nvar   , nscal  ,                                              &
-   dt     , rtpa   , rtp    , propce )
+   dt     )
+
+  call cs_user_extra_operations()
 
 endif
 
@@ -1059,8 +1064,7 @@ call pstvar                                                       &
    nvar   , nscal  , nvlsta , nvisbr ,                            &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    itepa  ,                                                       &
-   dt     , rtpa   , rtp    , propce ,                            &
-   statis , stativ , parbor )
+   dt     , rtpa   , rtp    , propce )
 
 !===============================================================================
 ! Probes
@@ -1081,7 +1085,7 @@ if ((nthist.gt.0 .or.frhist.gt.0.d0) .and. itrale.gt.0) then
 
     ttchis = ttcabs
 
-    call ecrhis(nvar, nproce, modhis, rtp)
+    call ecrhis(modhis)
     !==========
 
     if (iilagr.gt.0) then
@@ -1099,7 +1103,7 @@ if ((nthist.gt.0 .or.frhist.gt.0.d0) .and. itrale.gt.0) then
 
 endif
 
-call ushist(nvar, nscal, dt, rtpa, rtp, propce)
+call ushist(nvar, nscal, dt)
 !==========
 
 !===============================================================================
@@ -1125,10 +1129,8 @@ if (modntl.eq.0) then
   if (iilagr.gt.0) then
     call laglis                                                   &
     !==========
- ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
-   ntersl , nvlsta , nvisbr ,                                     &
-   itepa  ,                                                       &
-   ettp   , tepa   , statis , stativ , tslagr , parbor )
+    ( nvlsta , nvisbr ,                                           &
+      statis , stativ , parbor )
   endif
 
 endif
@@ -1176,7 +1178,7 @@ call dmtmps(tecrf1)
 ! Ici on sauve les historiques (si on en a stocke)
 
 modhis = 2
-call ecrhis(nvar, nproce, modhis, rtp)
+call ecrhis(modhis)
 !==========
 
 if (iilagr.gt.0) then
@@ -1200,9 +1202,6 @@ endif
 ! Free main arrays
 deallocate(dt, rtp, rtpa, propce)
 
-! Free other main arrays
-deallocate(coefa, coefb)
-
 deallocate(isostd)
 if (iphydr.eq.1) then
   deallocate(frcxt)
@@ -1236,13 +1235,20 @@ if (iilagr.gt.0) then
 
 endif
 
+call turbomachinery_finalize
+
 call finalize_quadrature
 
 call finalize_aux_arrays
 
 if (ippmod(iatmos).ge.0) then
+
   call finalize_meteo
 
+  if(imbrication_flag)then
+    call finalize_imbrication
+  endif
+
   if (ifilechemistry.ge.1) then
     call finalize_chemistry
   endif
