@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -23,7 +23,7 @@
 subroutine coupbo &
 !================
 
- ( nvar   , ncp    , ncv    , ientha ,                            &
+ ( ncp    , ncv    , ientha ,                                     &
    rtp    ,                                                       &
    cpcst  , cp     , cvcst  , cv     ,                            &
    hbord  , tbord  )
@@ -39,7 +39,6 @@ subroutine coupbo &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! nvar             ! i  ! <-- ! total number of variables                      !
 ! ncp              ! i  ! <-- ! dimension de cp (ncelet ou 1)                  !
 ! ncv              ! i  ! <-- ! dimension de cv (ncelet ou 1)                  !
 ! ientha           ! i  ! <-- ! 1 si tparoi est une enthalpie                  !
@@ -69,6 +68,8 @@ use numvar
 use entsor
 use cstphy
 use mesh
+use dimens, only: nvar
+use field
 
 !===============================================================================
 
@@ -76,12 +77,11 @@ implicit none
 
 ! Arguments
 
-integer          nvar
 integer          ncp    , ncv    , ientha
 
 double precision cpcst  , cvcst
 
-double precision rtp(ncelet,*)
+double precision rtp(ncelet,nflown:nvar)
 double precision cp(ncp), cv(ncv)
 double precision hbord(nfabor),tbord(nfabor)
 
@@ -89,15 +89,18 @@ double precision hbord(nfabor),tbord(nfabor)
 
 integer          nbccou, inbcou, inbcoo, nbfcou, ifac, iloc, iel
 integer          mode, flag
-integer          iccfth, imodif
 integer          iepsel, iepsfa, igamag, ixmasm, ifinwa
 integer          issurf
 double precision enthal, temper, energ, cvt
 
-double precision rvoid(1)
-
 integer, dimension(:), allocatable :: lfcou
 double precision, dimension(:), allocatable :: tfluid, hparoi, wa
+double precision, dimension(:,:), pointer :: vel
+
+!===============================================================================
+
+! Map field arrays
+call field_get_val_v(ivarfl(iu), vel)
 
 !===============================================================================
 
@@ -209,25 +212,22 @@ do inbcou = 1, nbccou
 
       ! Compute e - CvT
 
-      iccfth = 7
-      imodif = 0
+      ! At cell centers
+      call cf_thermo_eps_sup(wa(iepsel), ncel)
+      !=====================
 
-      call cfther                                                    &
-      !==========
-    ( nvar   ,                                                       &
-      iccfth , imodif ,                                              &
-      rtp    ,                                                       &
-      wa(iepsel) , wa(iepsfa) , wa(igamag) ,                         &
-      rvoid  , rvoid )
+      ! At boundary faces centers
+      call cf_thermo_eps_sup(wa(iepsfa), nfabor)
+      !=====================
 
       do iloc = 1, nbfcou
         ifac  = lfcou(iloc)
         iel   = ifabor(ifac)
         energ = tfluid(iloc)
         cvt   = energ                                               &
-                      -(0.5d0*( rtp(iel,iu)**2                      &
-                               +rtp(iel,iv)**2                      &
-                               +rtp(iel,iw)**2)                     &
+                      -(0.5d0*(  vel(1,iel)**2                      &
+                               + vel(2,iel)**2                      &
+                               + vel(3,iel)**2)                     &
                         + wa(iepsel+iel-1)           )
         if (ncv.eq.ncelet) then
           tfluid(iloc) = cvt/cv(iel)
