@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -94,7 +94,6 @@ use cstphy
 use cstnum
 use ppppar
 use ppthch
-use pointe, only: porosi, visten
 use coincl
 use cpincl
 use cs_fuel_incl
@@ -124,7 +123,7 @@ integer          iscal  , itspdv
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision tslagr(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
@@ -173,10 +172,11 @@ double precision, allocatable, dimension(:) :: dpvar
 double precision, allocatable, dimension(:) :: xcpp
 double precision, allocatable, dimension(:) :: srcmas
 
-double precision, dimension(:,:), pointer :: xut
+double precision, dimension(:,:), pointer :: xut, visten
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer :: crom, croma, pcrom
 double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
+double precision, dimension(:), pointer :: porosi
 
 !===============================================================================
 
@@ -247,7 +247,7 @@ endif
 thets  = thetss(iscal)
 thetv  = thetav(ivar )
 
-chaine = nomvar(ippvar)
+call field_get_name(ivarfl(ivar), chaine)
 
 if(iwarni(ivar).ge.1) then
   write(nfecra,1000) chaine(1:16)
@@ -305,10 +305,10 @@ if (iihmpr.eq.1) then
 
   if (iscal.ne.iscalt) then
     call uitssc &
-    ( iscal  , rtp(1,ivar), smbrs  , rovsdt )
+    ( iflid  , rtp(1,ivar), smbrs  , rovsdt )
   else
     call uitsth &
-    ( iscal  , rtp(1,ivar), smbrs  , rovsdt )
+    ( iflid  , rtp(1,ivar), smbrs  , rovsdt )
   endif
 endif
 
@@ -317,7 +317,7 @@ call ustssc &
 ( nvar   , nscal  , ncepdp , ncesmp ,                            &
   iscal  ,                                                       &
   icepdc , icetsm , itypsm ,                                     &
-  dt     , rtpa   , rtp    , propce ,                            &
+  dt     ,                                                       &
   ckupdc , smacel , smbrs  , rovsdt )
 
 ! Atmospheric chemistry
@@ -517,16 +517,10 @@ if (itspdv.eq.1) then
     iprev = 1
     inc = 1
     iccocg = 1
-    nswrgp = nswrgr(iii)
-    imligp = imligr(iii)
-    iwarnp = iwarni(iii)
-    epsrgp = epsrgr(iii)
-    climgp = climgr(iii)
-    extrap = extrag(iii)
 
     call field_gradient_scalar(ivarfl(iii), iprev, imrgra, inc,   &
-                               iccocg, nswrgp, iwarnp, imligp,    &
-                               epsrgp, extrap, climgp, grad)
+                               iccocg,                            &
+                               grad)
 
     ! Traitement de la production
     ! On utilise MAX(PROPCE,ZERO) car en LES dynamique on fait un clipping
@@ -660,8 +654,8 @@ if (isso2t(iscal).gt.0) then
   enddo
 endif
 
-! Low Mach compressible algos (conservative in time)
-if (idilat.gt.1) then
+! Low Mach compressible algos (conservative in time). Same algo for cavitation.
+if (idilat.gt.1 .or. icavit.ge.0) then
   call field_get_val_prev_s(icrom, pcrom)
 
 ! Standard algo
@@ -712,6 +706,8 @@ if (idiff(ivar).ge.1) then
     allocate(weighf(2,nfac))
     allocate(weighb(nfabor))
 
+    call field_get_val_v(ivsten, visten)
+
     if (ipcvsl.eq.0) then
       do iel = 1, ncel
 
@@ -785,6 +781,8 @@ if (iporos.eq.0) then
 ! With porosity
 else
 
+  call field_get_val_s(ipori, porosi)
+
   do iel = 1, ncel
     smbrs(iel) = smbrs(iel)*porosi(iel)
   enddo
@@ -875,7 +873,7 @@ if (ivarsc.gt.0) then
   iii = ivarsc
 else
 ! Valeur bidon
-  iii = 1
+  iii = nflown
 endif
 
 call clpsca(ncelet, ncel, iscal, rtp(1,iii), rtp)
@@ -892,7 +890,7 @@ if (iwarni(ivar).ge.2) then
   endif
   do iel = 1, ncel
     smbrs(iel) = smbrs(iel)                                                 &
-            - istat(ivar)*xcpp(iel)*(crom(iel)/dt(iel))*volume(iel)&
+            - istat(ivar)*xcpp(iel)*(pcrom(iel)/dt(iel))*volume(iel)&
                 *(rtp(iel,ivar)-rtpa(iel,ivar))*ibcl
   enddo
   isqrt = 1
