@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -999,8 +999,18 @@ cs_base_logfile_head(int    argc,
   snprintf(mpi_vendor_lib, 31, "MVAPICH2 %s", MVAPICH2_VERSION);
 #elif defined(MSMPI_VER)
   snprintf(mpi_vendor_lib, 31, "MS-MPI");
-#elif defined(HP_MPI)
-  snprintf(mpi_vendor_lib, 31, "HP-MPI");
+#elif defined(PLATFORM_MPI)
+  {
+    int v, v0, v1, v2, v3;
+    v0 =  PLATFORM_MPI>>24;
+    v =  (PLATFORM_MPI - (v0<<24));
+    v1 =  v>>16;
+    v =  (v - (v1<<16));
+    v2 =  v>>8;
+    v3 =  (v - (v2<<8));
+    snprintf(mpi_vendor_lib, 31, "Platform MPI %x.%x.%x.%x\n",
+             v0, v1, v2, v3);
+  }
 #endif
 
   mpi_vendor_lib[31] = '\0';
@@ -1047,7 +1057,7 @@ cs_base_logfile_head(int    argc,
              "                      Version %s\n\n",
              CS_APP_VERSION);
 
-  bft_printf("\n  Copyright (C) 1998-2013 EDF S.A., France\n\n");
+  bft_printf("\n  Copyright (C) 1998-2014 EDF S.A., France\n\n");
 
 #if defined(CS_REVISION)
   if (strlen(CS_REVISION) > 0)
