@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -312,6 +312,32 @@ void CS_PROCF (csgamma, CSGAMMA)
 #endif
 }
 
+/*----------------------------------------------------------------------------
+ * Compute the erf function of x.
+ *
+ * Fortran interface
+ *
+ * subroutine cserf (x, g)
+ * ******************
+ *
+ * double precision  x     : <-- : input value
+ * double precision  ferf  : --> : output value
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (cserf, CSERF)
+(
+ const cs_real_t  *x,
+ cs_real_t        *ferf
+)
+{
+#if defined(HAVE_ERF)
+  *ferf = erf(*x);
+#else
+  bft_error(__FILE__, __LINE__, 0,
+            _("erf() function (C99) is not available"));
+#endif
+}
+
 /*----------------------------------------------------------------------------
  * Copy a Fortan string buffer to a C string buffer
  *
