@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -94,6 +94,13 @@ BEGIN_C_DECLS
 
   \typedef cs_real_33_t
            \brief 3x3 matrix of floating-point values
+
+  \typedef cs_real_66_t
+           \brief 6x6 matrix of floating-point values
+
+  \typedef cs_real_332_t
+           \brief vector of 2 3x3 matrices of floating-point values
+
 */
 
 /*============================================================================
