@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -107,7 +107,15 @@ typedef struct {
 
   int                     location_id;  /* Id of matching location */
 
-  int                     n_time_vals;  /* Number of time values (1 or 2) */
+  int                     n_time_vals;  /* Number of time values */
+
+  cs_real_t             **vals;         /* For each active location, pointer
+                                           to matching values arrays
+                                           vals[0][:] = val
+                                           vals[1][:] = val_pre
+                                           vals[p][:] = p ith previous field
+                                           p < n_time_vals */
+
 
   cs_real_t              *val;          /* For each active location, pointer
                                            to matching values array */
@@ -119,8 +127,7 @@ typedef struct {
   cs_field_bc_coeffs_t   *bc_coeffs;    /* Boundary condition coefficients,
                                            for variable type fields */
 
-  bool                    is_owner;     /* Ownership flag for values
-                                           and boundary coefficients */
+  bool                    is_owner;     /* Ownership flag for values */
 
 } cs_field_t;
 
@@ -134,6 +141,16 @@ typedef struct {
 typedef void
 (cs_field_log_key_struct_t) (const void  *t);
 
+/*============================================================================
+ * Global variables
+ *============================================================================*/
+
+/* Names for components */
+
+extern const char *cs_glob_field_comp_name_3[];
+extern const char *cs_glob_field_comp_name_6[];
+extern const char *cs_glob_field_comp_name_9[];
+
 /*=============================================================================
  * Public function prototypes
  *============================================================================*/
@@ -172,6 +189,20 @@ cs_field_create(const char   *name,
                 bool          interleaved,
                 bool          has_previous);
 
+/*----------------------------------------------------------------------------
+ * Change the number of time values managed by a field.
+ *
+ * The minimum will never be below 1, as the current time is always handled.
+ *
+ * parameters:
+ *   f           <-> pointer to field structure
+ *   n_time_vals <-- number of time values to maintain
+ *----------------------------------------------------------------------------*/
+
+void
+cs_field_set_n_time_vals(cs_field_t  *f,
+                         int          n_time_vals);
+
 /*----------------------------------------------------------------------------
  * Allocate arrays for field values.
  *
@@ -218,7 +249,7 @@ cs_field_map_values(cs_field_t   *f,
  *   f            <-- pointer to field structure
  *   have_flux_bc <-- if true, flux BC coefficients (af and bf) are added
  *   have_mom_bc  <-- if true, div BC coefficients (ad and bd) are added
- *   have_conv_bc  <-- if true, convection BC coefficients (ac and bc) are added
+ *   have_conv_bc <-- if true, convection BC coefficients (ac and bc) are added
  *----------------------------------------------------------------------------*/
 
 void
@@ -246,61 +277,11 @@ cs_field_allocate_bc_coeffs(cs_field_t  *f,
  * face is dim*dim instead of dim.
  *
  * parameters:
- *   f            <-> pointer to field structure
- *   have_flux_bc <-- if true, flux bc coefficients (af and bf)
- *                    are initialized
- *   have_mom_bc  <-- if true, div BC coefficients (ad and bd)
- *                    are initialized
- *   have_conv_bc <-- if true, convection BC coefficients (ac and bc)
- *                    are initialized
+ *   f <-> pointer to field structure
  *----------------------------------------------------------------------------*/
 
 void
-cs_field_init_bc_coeffs(cs_field_t  *f,
-                        bool         have_flux_bc,
-                        bool         have_mom_bc,
-                        bool         have_conv_bc);
-
-/*----------------------------------------------------------------------------
- * Map existing field boundary condition coefficient arrays.
- *
- * For fields on location CS_MESH_LOCATION_CELLS, boundary conditions
- * are located on CS_MESH_LOCATION_BOUNDARY_FACES.
- *
- * Boundary condition coefficients are not currently supported for other
- * locations (though support could be added by mapping a boundary->location
- * indirection array in the cs_mesh_location_t structure).
- *
- * For multidimensional fields, arrays are assumed to have the same
- * interleaving behavior as the field, unless components are coupled.
- *
- * For multidimensional fields with coupled components, interleaving
- * is the norm, and implicit coefficients arrays are arrays of block matrices,
- * not vectors, so the number of entris for each boundary face is
- * dim*dim instead of dim.
- *
- * parameters:
- *   f  <-> pointer to field structure
- *   a  <-- explicit BC coefficients array
- *   b  <-- implicit BC coefficients array
- *   af <-- explicit flux BC coefficients array, or NULL
- *   bf <-- implicit flux BC coefficients array, or NULL
- *   ad  explicit div BC coefficients array, or NULL
- *   bd  implicit div BC coefficients array, or NULL
- *   ac  explicit convection BC coefficients array, or NULL
- *   bc  implicit convection BC coefficients array, or NULL
- *----------------------------------------------------------------------------*/
-
-void
-cs_field_map_bc_coeffs(cs_field_t  *f,
-                       cs_real_t   *a,
-                       cs_real_t   *b,
-                       cs_real_t   *af,
-                       cs_real_t   *bf,
-                       cs_real_t   *ad,
-                       cs_real_t   *bd,
-                       cs_real_t   *ac,
-                       cs_real_t   *bc);
+cs_field_init_bc_coeffs(cs_field_t  *f);
 
 /*----------------------------------------------------------------------------
  * Copy current field values to previous values if applicable.
@@ -394,6 +375,23 @@ cs_field_by_name_try(const char *name);
 int
 cs_field_id_by_name(const char *name);
 
+/*----------------------------------------------------------------------------
+ * Return the id of a defined field and an associated component
+ * based on a component name.
+ *
+ * If no field with the given name exists, -1 is returned.
+ *
+ * parameters:
+ *   name <-- field or field+component name
+ *   f_id --> field id, or -1 if no match was found
+ *   c_id --> component id, or -1 for all components
+ *----------------------------------------------------------------------------*/
+
+void
+cs_field_component_id_by_name(const char  *name,
+                              int         *f_id,
+                              int         *c_id);
+
 /*----------------------------------------------------------------------------
  * Return an id associated with a given key name.
  *
@@ -809,7 +807,8 @@ cs_field_log_all_key_vals(bool  log_defaults);
  *   "post_vis"     (integer)
  *   "post_probes"  (integer)
  *   "coupled"      (integer, restricted to CS_FIELD_VARIABLE)
- *   "moment_dt"    (integer, restricted to CS_FIELD_PROPERTY);
+ *   "moment_id"    (integer, restricted to
+ *                   CS_FIELD_ACCUMULATOR | CS_FIELD_POSTPROCESS);
  *
  * A recommened practice for different submodules would be to use
  * "cs_<module>_key_init() functions to define keys specific to those modules.
@@ -818,6 +817,22 @@ cs_field_log_all_key_vals(bool  log_defaults);
 void
 cs_field_define_keys_base(void);
 
+/*----------------------------------------------------------------------------
+ * Return a label associated with a field.
+ *
+ * If the "label" key has been set for this field, its associated string
+ * is returned. Otherwise, the field's name is returned.
+ *
+ * parameters:
+ *   f <-- pointer to field structure
+ *
+ * returns:
+ *   pointer to character string associated with label for this field
+ *----------------------------------------------------------------------------*/
+
+const char *
+cs_field_get_label(const cs_field_t  *f);
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
