@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -50,6 +50,8 @@
 #include <ParaMESH.hxx>
 #include <InterpKernelDEC.hxx>
 
+#include <MED_version.h>
+
 #include <MEDCouplingUMesh.hxx>
 #include <MEDCouplingField.hxx>
 #include <MEDCouplingFieldDouble.hxx>
@@ -829,7 +831,12 @@ cs_paramedmem_mesh_id(cs_paramedmem_coupling_t  *coupling,
   assert(coupling != NULL);
 
   for (i = 0; i < coupling->n_meshes; i++) {
+#if (SALOMEMED_VERSION  >= 0x070300)
+    if (   strcmp(mesh_name, coupling->meshes[i]->med_mesh->getName().c_str())
+        == 0)
+#else
     if (strcmp(mesh_name, coupling->meshes[i]->med_mesh->getName()) == 0)
+#endif
       break;
   }
 
@@ -1012,8 +1019,13 @@ cs_paramedmem_field_get_id(cs_paramedmem_coupling_t  *coupling,
   /* Loop on fields to know if field has already been created */
 
   for (int f_id = 0; f_id < coupling->n_fields; f_id++) {
+#if (SALOMEMED_VERSION  >= 0x070300)
+    if (   coupling->fields[f_id]->mesh_id == mesh_id
+        && strcmp(name, coupling->fields[f_id]->f->getName().c_str()) == 0)
+#else
     if (   coupling->fields[f_id]->mesh_id == mesh_id
         && strcmp(name, coupling->fields[f_id]->f->getName()) == 0)
+#endif
       return f_id;
   }
 
