@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -936,16 +936,6 @@ void
 cs_post_renum_faces(const cs_lnum_t  init_i_face_num[],
                     const cs_lnum_t  init_b_face_num[]);
 
-/*----------------------------------------------------------------------------
- * Initialize post-processing of moments
- *
- * Currently, an external cumulative time array is simply mapped to
- * the post-processing API.
- *----------------------------------------------------------------------------*/
-
-void
-cs_post_init_moments(const cs_real_t  *cumulative_time);
-
 /*----------------------------------------------------------------------------
  * Initialize post-processing writers
  *----------------------------------------------------------------------------*/
