@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -291,9 +291,7 @@ _write_additional_vars(void                  *input,
                             &n_cells, &n_i_faces, &n_b_faces,
                             itypps,
                             cell_list, i_face_list, b_face_list,
-                            _input->dt,
-                            _input->rtpa, _input->rtp,
-                            _input->propce);
+                            _input->dt);
 
 }
 
@@ -301,6 +299,23 @@ _write_additional_vars(void                  *input,
  * Public Fortran function definitions
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ * Output post-processing meshes using associated writers.
+ *
+ * Fortran interface:
+ *
+ * subroutine pstgeo
+ * *****************
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (pstgeo, PSTGEO)
+(
+ void
+)
+{
+  cs_post_write_meshes(cs_glob_time_step);
+}
+
 /*----------------------------------------------------------------------------
  * Loop on post-processing meshes to output variables
  *
@@ -398,10 +413,9 @@ void CS_PROCF (pstvar, PSTVAR)
  *
  * subroutine lagpvr
  * *****************
- *                  ( iphyla, ivisv1, ivisv2, ivistp,  ivisdm, iviste,
+ *                  ( ivisv1, ivisv2, ivistp,  ivisdm, iviste,
  *                    ivismp, ivisdk, iviswat, ivisch, ivisck )
  *
- * integer          iphyla      : <-- : type of lagrangian calculation
  * integer          ivisv1      : <-- : display of variable 'fluid velocity'
  * integer          ivisv2      : <-- : display of variable 'particles velocity'
  * integer          ivistp      : <-- : display of variable 'resident time'
@@ -416,7 +430,6 @@ void CS_PROCF (pstvar, PSTVAR)
 
 void CS_PROCF (lagpvr, LAGPVR)
 (
- const cs_int_t  *iphyla,
  const cs_int_t  *ivisv1,
  const cs_int_t  *ivisv2,
  const cs_int_t  *ivistp,
@@ -450,8 +463,9 @@ void CS_PROCF (lagpvr, LAGPVR)
 
   if (*iviste) {
     _default_input.particle_attr[CS_LAGR_TEMPERATURE] = true;
-    if (CS_LAGR_N_LAYERS > 1 && *iphyla == 2)
-      _default_input.particle_multicomponent_export[CS_LAGR_TEMPERATURE] = CS_LAGR_N_LAYERS;
+    if (cs_glob_lagr_params->n_temperature_layers > 1)
+      _default_input.particle_multicomponent_export[CS_LAGR_TEMPERATURE]
+        = cs_glob_lagr_params->n_temperature_layers;
   }
 
   if (*ivismp)
@@ -465,14 +479,16 @@ void CS_PROCF (lagpvr, LAGPVR)
 
   if (*ivisch) {
     _default_input.particle_attr[CS_LAGR_COAL_MASS] = true;
-    if (CS_LAGR_N_LAYERS > 1 && *iphyla == 2)
-      _default_input.particle_multicomponent_export[CS_LAGR_COAL_MASS] = CS_LAGR_N_LAYERS;
+    if (cs_glob_lagr_params->n_temperature_layers > 1)
+      _default_input.particle_multicomponent_export[CS_LAGR_COAL_MASS]
+        = cs_glob_lagr_params->n_temperature_layers;
   }
 
   if (*ivisck) {
     _default_input.particle_attr[CS_LAGR_COKE_MASS] = true;
-    if (CS_LAGR_N_LAYERS > 1 && *iphyla == 2)
-      _default_input.particle_multicomponent_export[CS_LAGR_COKE_MASS] = CS_LAGR_N_LAYERS;
+    if (cs_glob_lagr_params->n_temperature_layers > 1)
+      _default_input.particle_multicomponent_export[CS_LAGR_COKE_MASS]
+        = cs_glob_lagr_params->n_temperature_layers;
   }
 
 }
