@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -57,6 +57,20 @@ BEGIN_C_DECLS
  * Public Fortran function prototypes
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ * Output post-processing meshes using associated writers.
+ *
+ * Fortran interface:
+ *
+ * subroutine pstgeo
+ * *****************
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (pstgeo, PSTGEO)
+(
+ void
+);
+
 /*----------------------------------------------------------------------------
  * Loop on post-processing meshes to output variables
  *
@@ -118,10 +132,9 @@ void CS_PROCF (pstvar, PSTVAR)
  *
  * subroutine lagpvr
  * *****************
- *                  ( iphyla, ivisv1, ivisv2,  ivistp, ivisdm, iviste,
+ *                  ( ivisv1, ivisv2,  ivistp, ivisdm, iviste,
  *                    ivismp, ivisdk, iviswat, ivisch, ivisck )
  *
- * integer          iphyla      : <-- : type of lagrangian calculation
  * integer          ivisv1      : <-- : display of variable 'fluid velocity'
  * integer          ivisv2      : <-- : display of variable 'particles velocity'
  * integer          ivistp      : <-- : display of variable 'resident time'
@@ -136,7 +149,6 @@ void CS_PROCF (pstvar, PSTVAR)
 
 void CS_PROCF (lagpvr, LAGPVR)
 (
- const cs_int_t  *iphyla,
  const cs_int_t  *ivisv1,
  const cs_int_t  *ivisv2,
  const cs_int_t  *ivistp,
