@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -204,10 +204,7 @@ void CS_PROCF (usvpst, USVPST)
  const cs_int_t   lstcel[],  /* <-- list of post-processed cells */
  const cs_int_t   lstfac[],  /* <-- list of post-processed interior faces */
  const cs_int_t   lstfbr[],  /* <-- list of post-processed boundary faces */
- const cs_real_t  dt[],      /* <-- local time step */
- const cs_real_t  rtpa[],    /* <-- cell variables at previous time step */
- const cs_real_t  rtp[],     /* <-- cell variables */
- const cs_real_t  propce[]   /* <-- cell physical properties */
+ const cs_real_t  dt[]       /* <-- local time step */
 );
 
 /*----------------------------------------------------------------------------
@@ -286,6 +283,16 @@ cs_lagr_status(int  *model_flag,
 void
 cs_user_coupling(void);
 
+/*----------------------------------------------------------------------------
+ * This function is called at the end of each time step.
+ *
+ * It and has a very general purpose, although it is recommended to handle
+ * mainly postprocessing or data-extraction type operations.
+ *----------------------------------------------------------------------------*/
+
+void
+cs_user_extra_operations(void);
+
 /*----------------------------------------------------------------------------
  * Define mesh joinings.
  *----------------------------------------------------------------------------*/
@@ -375,6 +382,13 @@ cs_user_parallel_io(void);
 void
 cs_user_partition(void);
 
+/*----------------------------------------------------------------------------
+ * Define sparse matrix tuning options.
+ *----------------------------------------------------------------------------*/
+
+void
+cs_user_matrix_tuning(void);
+
 /*----------------------------------------------------------------------------
  * Define periodic faces.
  *----------------------------------------------------------------------------*/
