@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -50,6 +50,12 @@ BEGIN_C_DECLS
 
 typedef struct {
 
+  int           is_variable;  /* 0 if time step is fixed in time,
+                                 1 if the time step is variable. */
+  int           is_local;     /* 0 if time step is uniform in space,
+                                 1 if it is local in space (in which case
+                                 the time value is only a reference. */
+
   int           nt_prev;      /* absolute time step number reached by previous
                                  computation */
   int           nt_cur;       /* current absolute time step number */
@@ -74,11 +80,31 @@ extern const cs_time_step_t  *cs_glob_time_step;
  * Public function prototypes
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ * Define whether time step is variable or not
+ *
+ * parameters:
+ *   is_variable <-- 0 if time step is variable in time, 1 if it is fixed
+ *----------------------------------------------------------------------------*/
+
+void
+cs_time_step_define_variable(int  is_variable);
+
+/*----------------------------------------------------------------------------
+ * Define whether time step is local in space or not
+ *
+ * parameters:
+ *   is_local <-- 0 if time step is uniform in space, 1 if it is local
+ *----------------------------------------------------------------------------*/
+
+void
+cs_time_step_define_local(int  is_local);
+
 /*----------------------------------------------------------------------------
  * Define maximum time step number
  *
  * parameters:
- *   nt_max  maximum time step number (unlimited if negative)
+ *   nt_max <-- maximum time step number (unlimited if negative)
  *----------------------------------------------------------------------------*/
 
 void
