@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -58,6 +58,7 @@
 
 #include "cs_log.h"
 #include "cs_mesh.h"
+#include "cs_turbulence_model.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -69,6 +70,74 @@
 
 BEGIN_C_DECLS
 
+/*=============================================================================
+ * Additional doxygen documentation
+ *============================================================================*/
+
+/*!
+  \file cs_wall_functions.c
+        Wall functions descriptor and computation.
+*/
+/*----------------------------------------------------------------------------*/
+
+/*! \struct cs_wall_functions_t
+
+  \brief wall functions descriptor.
+
+  Members of this wall functions descriptor are publicly accessible, to allow for concise
+  syntax, as it is expected to be used in many places.
+
+  \var  cs_wall_functions_t::ideuch
+        wall functions
+        - 0: one scale of friction velocities
+        - 1: two scale of friction velocities
+        - 2: scalable wall functions
+  \var  cs_wall_functions_t::iwallt
+        exchange coefficient correlation
+        - 0: not use by default
+        - 1: exchange coefficient computed with a correlation
+  \var  cs_wall_functions_t::ilogpo
+        wall functions with
+        - 0: a power lay (deprecated)
+        - 1: a log lay
+  \var  cs_wall_functions_t::ypluli
+        limit value of \f$y^+\f$ for the viscous sublayer
+
+        \ref ypluli depends on the chosen wall function: it is initialised to
+        10.88 for the scalable wall function (\ref ideuch=2), otherwise it is
+        initialised to \f$1/\kappa\approx 2,38\f$. In LES, \ref ypluli is taken
+        by default to be 10.88. Always useful.
+*/
+/*----------------------------------------------------------------------------*/
+
+/*! \cond DOXYGEN_SHOULD_SKIP_THIS */
+
+/*============================================================================
+ * Static global variables
+ *============================================================================*/
+
+/* wall functions structure and associated pointer */
+
+static cs_wall_functions_t  _wall_functions =
+  {-999, 0, 1, -1e13};
+
+const cs_wall_functions_t  *cs_glob_wall_functions = &_wall_functions;
+
+/*============================================================================
+ * Prototypes for functions intended for use only by Fortran wrappers.
+ * (descriptions follow, with function bodies).
+ *============================================================================*/
+
+void
+cs_f_wall_functions_get_pointers(int     **ideuch,
+                                 int     **iwallt,
+                                 int     **ilogpo);
+
+void
+cs_f_wall_reference_values(double  **ypluli);
+
+/*! \endcond (end ignore by Doxygen) */
+
 /*============================================================================
  * Private function definitions
  *============================================================================*/
@@ -77,10 +146,6 @@ BEGIN_C_DECLS
  * Power law: Werner & Wengle
  *
  * parameters:
- *   ypluli   <-- y+ limit
- *   apow     <-- Coef of the Wener law
- *   bpow     <-- Coef of the Wener law
- *   dpow     <-- Coef of the Wener law
  *   l_visc   <-- kinematic viscosity
  *   vel      <-- wall projected cell center velocity
  *   y        <-- wall distance
@@ -95,22 +160,20 @@ BEGIN_C_DECLS
  *----------------------------------------------------------------------------*/
 
 static void
-_1scale_power_law(cs_real_t   ypluli,
-                  cs_real_t   apow,
-                  cs_real_t   bpow,
-                  cs_real_t   dpow,
-                  cs_real_t   l_visc,
+_1scale_power_law(cs_real_t   l_visc,
                   cs_real_t   vel,
                   cs_real_t   y,
-                  cs_int_t   *iuntur,
-                  cs_int_t   *nsubla,
-                  cs_int_t   *nlogla,
+                  int        *iuntur,
+                  cs_lnum_t  *nsubla,
+                  cs_lnum_t  *nlogla,
                   cs_real_t  *ustar,
                   cs_real_t  *uk,
                   cs_real_t  *yplus,
                   cs_real_t  *ypup,
                   cs_real_t  *cofimp)
 {
+  const double ypluli = cs_glob_wall_functions->ypluli;
+
   const double ydvisc =  y / l_visc;
 
   /* Compute the friction velocity ustar */
@@ -150,12 +213,6 @@ _1scale_power_law(cs_real_t   ypluli,
  *
  * parameters:
  *   ifac   <-- face number
- *   xkappa <-- Von Karman constant
- *   cstlog <-- Log law constant
- *   ypluli <-- y+ limit
- *   apow   <-- Coef of the Wener law
- *   bpow   <-- Coef of the Wener law
- *   dpow   <-- Coef of the Wener law
  *   l_visc <-- kinematic viscosity
  *   vel    <-- wall projected cell center velocity
  *   y      <-- wall distance
@@ -170,25 +227,21 @@ _1scale_power_law(cs_real_t   ypluli,
  *----------------------------------------------------------------------------*/
 
 static void
-_1scale_log_law(cs_int_t     ifac,
-                cs_real_t    xkappa,
-                cs_real_t    cstlog,
-                cs_real_t    ypluli,
-                cs_real_t    apow,
-                cs_real_t    bpow,
-                cs_real_t    dpow,
+_1scale_log_law(cs_lnum_t    ifac,
                 cs_real_t    l_visc,
                 cs_real_t    vel,
                 cs_real_t    y,
-                cs_int_t    *iuntur,
-                cs_int_t    *nsubla,
-                cs_int_t    *nlogla,
+                int         *iuntur,
+                cs_lnum_t   *nsubla,
+                cs_lnum_t   *nlogla,
                 cs_real_t   *ustar,
                 cs_real_t   *uk,
                 cs_real_t   *yplus,
                 cs_real_t   *ypup,
                 cs_real_t   *cofimp)
 {
+  const double ypluli = cs_glob_wall_functions->ypluli;
+
   double ustarwer, ustarmin, ustaro, ydvisc;
   double eps = 0.001;
   int niter_max = 100;
@@ -259,10 +312,6 @@ _1scale_log_law(cs_int_t     ifac,
  * friction and the TKE.
  *
  * parameters:
- *   xkappa     <-- Von Karman constant
- *   cstlog     <-- Log law constant
- *   cmu025     <-- C_mu^1/4
- *   ypluli     <-- y+ limit
  *   l_visc     <-- kinematic viscosity
  *   t_visc     <-- turbulent kinematic viscosity
  *   vel        <-- wall projected cell center velocity
@@ -279,24 +328,22 @@ _1scale_log_law(cs_int_t     ifac,
  *----------------------------------------------------------------------------*/
 
 static void
-_2scales_log_law(cs_real_t   xkappa,
-                 cs_real_t   cstlog,
-                 cs_real_t   cmu025,
-                 cs_real_t   ypluli,
-                 cs_real_t   l_visc,
+_2scales_log_law(cs_real_t   l_visc,
                  cs_real_t   t_visc,
                  cs_real_t   vel,
                  cs_real_t   y,
                  cs_real_t   kinetic_en,
-                 cs_int_t   *iuntur,
-                 cs_int_t   *nsubla,
-                 cs_int_t   *nlogla,
+                 int        *iuntur,
+                 cs_lnum_t  *nsubla,
+                 cs_lnum_t  *nlogla,
                  cs_real_t  *ustar,
                  cs_real_t  *uk,
                  cs_real_t  *yplus,
                  cs_real_t  *ypup,
                  cs_real_t  *cofimp)
 {
+  const double ypluli = cs_glob_wall_functions->ypluli;
+
   double rcprod, ml_visc, Re, g;
 
   /* Compute the friction velocity ustar */
@@ -344,10 +391,6 @@ _2scales_log_law(cs_real_t   xkappa,
  * Scalable wall function: shift the wall if "y+ < y+lim".
  *
  * parameters:
- *   xkappa     <-- Von Karman constant
- *   cstlog     <-- Log law constant
- *   cmu025     <-- C_mu^1/4
- *   ypluli     <-- y+ limit
  *   l_visc     <-- kinematic viscosity
  *   t_visc     <-- turbulent kinematic viscosity
  *   vel        <-- wall projected cell center velocity
@@ -365,18 +408,14 @@ _2scales_log_law(cs_real_t   xkappa,
  *----------------------------------------------------------------------------*/
 
 static void
-_2scales_scalable_wallfunction(cs_real_t   xkappa,
-                               cs_real_t   cstlog,
-                               cs_real_t   cmu025,
-                               cs_real_t   ypluli,
-                               cs_real_t   l_visc,
+_2scales_scalable_wallfunction(cs_real_t   l_visc,
                                cs_real_t   t_visc,
                                cs_real_t   vel,
                                cs_real_t   y,
                                cs_real_t   kinetic_en,
-                               cs_int_t   *iuntur,
-                               cs_int_t   *nsubla,
-                               cs_int_t   *nlogla,
+                               int        *iuntur,
+                               cs_lnum_t  *nsubla,
+                               cs_lnum_t  *nlogla,
                                cs_real_t  *ustar,
                                cs_real_t  *uk,
                                cs_real_t  *yplus,
@@ -385,6 +424,8 @@ _2scales_scalable_wallfunction(cs_real_t   xkappa,
                                cs_real_t  *cofimp
 )
 {
+  const double ypluli = cs_glob_wall_functions->ypluli;
+
   double rcprod, ml_visc, Re, g;
   /* Compute the friction velocity ustar */
 
@@ -432,7 +473,6 @@ _2scales_scalable_wallfunction(cs_real_t   xkappa,
  * No wall fucntions
  *
  * parameters:
- *   ypluli     <-- y+ limit
  *   l_visc     <-- kinematic viscosity
  *   t_visc     <-- turbulent kinematic viscosity
  *   vel        <-- wall projected cell center velocity
@@ -449,14 +489,13 @@ _2scales_scalable_wallfunction(cs_real_t   xkappa,
  *----------------------------------------------------------------------------*/
 
 static void
-_no_wallfunction(cs_real_t   ypluli,
-                 cs_real_t   l_visc,
+_no_wallfunction(cs_real_t   l_visc,
                  cs_real_t   t_visc,
                  cs_real_t   vel,
                  cs_real_t   y,
-                 cs_int_t   *iuntur,
-                 cs_int_t   *nsubla,
-                 cs_int_t   *nlogla,
+                 int        *iuntur,
+                 cs_lnum_t  *nsubla,
+                 cs_lnum_t  *nlogla,
                  cs_real_t  *ustar,
                  cs_real_t  *uk,
                  cs_real_t  *yplus,
@@ -464,6 +503,8 @@ _no_wallfunction(cs_real_t   ypluli,
                  cs_real_t  *ypup,
                  cs_real_t  *cofimp)
 {
+  const double ypluli = cs_glob_wall_functions->ypluli;
+
   /* Compute the friction velocity ustar */
 
   *ustar = sqrt(vel * l_visc / y);
@@ -486,45 +527,175 @@ _no_wallfunction(cs_real_t   ypluli,
   }
 }
 
+/*============================================================================
+ * Fortran wrapper function definitions
+ *============================================================================*/
+
+/*! \cond DOXYGEN_SHOULD_SKIP_THIS */
+
+/*----------------------------------------------------------------------------
+ * Get pointers to members of the wall functions structure.
+ *
+ * This function is intended for use by Fortran wrappers, and
+ * enables mapping to Fortran global pointers.
+ *
+ * parameters:
+ *   ideuch --> pointer to cs_glob_wall_functions->ideuch
+ *   iwallt --> pointer to cs_glob_wall_functions->iwallt
+ *   ilogpo --> pointer to cs_glob_wall_functions->ilogpo
+ *----------------------------------------------------------------------------*/
+
+void
+cs_f_wall_functions_get_pointers(int     **ideuch,
+                                 int     **iwallt,
+                                 int     **ilogpo)
+{
+  *ideuch = &(_wall_functions.ideuch);
+  *iwallt = &(_wall_functions.iwallt);
+  *ilogpo = &(_wall_functions.ilogpo);
+}
+
+/*----------------------------------------------------------------------------
+ * Get pointers to members of the wall functions structure.
+ *
+ * This function is intended for use by Fortran wrappers, and
+ * enables mapping to Fortran global pointers.
+ *
+ * parameters:
+ *   ypluli --> pointer to cs_glob_wall_functions->ypluli
+ *----------------------------------------------------------------------------*/
+
+void
+cs_f_wall_reference_values(double  **ypluli)
+{
+  *ypluli = &(_wall_functions.ypluli);
+}
+
+/*! \endcond (end ignore by Doxygen) */
+
 /*============================================================================
  * Public function definitions for Fortran API
  *============================================================================*/
 
 /*----------------------------------------------------------------------------
- * Compute the friction velocity and y+/u+
+ * Wrapper to cs_wall_functions_velocity
  *----------------------------------------------------------------------------*/
 
 void CS_PROCF (wallfunctions, WALLFUNCTIONS)
 (
- const cs_int_t   *const iwallf,      /* <-- wall function type               */
- const cs_int_t   *const ifac,        /* <-- face number                      */
- const cs_real_t  *const xkappa,      /* <-- Von Karman constant              */
- const cs_real_t  *const cstlog,      /* <-- Log law constant                 */
- const cs_real_t  *const cmu025,      /* <-- C_mu^1/4                         */
- const cs_real_t  *const ypluli,      /* <-- y+ limit                         */
- const cs_real_t  *const apow,        /* <-- Coef of the Wener law            */
- const cs_real_t  *const bpow,        /* <-- Coef of the Wener law            */
- const cs_real_t  *const dpow,        /* <-- Coef of the Wener law            */
- const cs_real_t  *const l_visc,      /* <-- kinematic viscosity              */
- const cs_real_t  *const t_visc,      /* <-- turbulent kinematic viscosity    */
- const cs_real_t  *const vel,         /* <-- wall projected
-                                             cell center velocity             */
- const cs_real_t  *const y,           /* <-- wall distance                    */
- const cs_real_t  *const kinetic_en,  /* <-- turbulente kinetic energy        */
-       cs_int_t         *iuntur,      /* <-- indicator:
-                                              0 in the viscous sublayer       */
-       cs_int_t         *nsubla,      /* <-- counter of cell in the viscous
-                                             sublayer                         */
-       cs_int_t         *nlogla,      /* <-- counter of cell in the log-layer */
-       cs_real_t        *ustar,       /* --> friction velocity                */
-       cs_real_t        *uk,          /* --> friction velocity                */
-       cs_real_t        *yplus,       /* --> non-dimension wall distance      */
-       cs_real_t        *ypup,        /* --> yplus projected vel ratio        */
-       cs_real_t        *cofimp,      /* --> |U_F|/|U_I^p| to ensure a good
-                                             turbulence production            */
-       cs_real_t        *dplus        /* --> dimensionless shift to the wall
-                                             for scalable wall functions      */
+ const cs_int_t   *const iwallf,
+ const cs_lnum_t  *const ifac,
+ const cs_real_t  *const l_visc,
+ const cs_real_t  *const t_visc,
+ const cs_real_t  *const vel,
+ const cs_real_t  *const y,
+ const cs_real_t  *const kinetic_en,
+       cs_int_t         *iuntur,
+       cs_lnum_t        *nsubla,
+       cs_lnum_t        *nlogla,
+       cs_real_t        *ustar,
+       cs_real_t        *uk,
+       cs_real_t        *yplus,
+       cs_real_t        *ypup,
+       cs_real_t        *cofimp,
+       cs_real_t        *dplus
 )
+{
+  cs_wall_functions_velocity(*iwallf,
+                             *ifac,
+                             *l_visc,
+                             *t_visc,
+                             *vel,
+                             *y,
+                             *kinetic_en,
+                             iuntur,
+                             nsubla,
+                             nlogla,
+                             ustar,
+                             uk,
+                             yplus,
+                             ypup,
+                             cofimp,
+                             dplus);
+}
+
+/*----------------------------------------------------------------------------
+ * Wrapper to cs_wall_functions_scalar
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (hturbp, HTURBP)
+(
+ const cs_real_t  *const prl,
+ const cs_real_t  *const prt,
+ const cs_real_t  *const ckarm,
+ const cs_real_t  *const yplus,
+ const cs_real_t  *const dplus,
+       cs_real_t        *htur,
+       cs_real_t        *yplim
+)
+{
+  cs_wall_functions_scalar(*prl,
+                           *prt,
+                           *ckarm,
+                           *yplus,
+                           *dplus,
+                           htur,
+                           yplim);
+}
+
+/*=============================================================================
+ * Public function definitions
+ *============================================================================*/
+
+/*----------------------------------------------------------------------------*/
+
+/*! \brief  Compute the friction velocity and \f$y^+\f$ / \f$u^+\f$.
+
+*/
+/*------------------------------------------------------------------------------
+  Arguments
+ ______________________________________________________________________________.
+   mode           name          role                                           !
+ _____________________________________________________________________________*/
+/*!
+ * \param[in]     iwallf        wall function type
+ * \param[in]     ifac          face number
+ * \param[in]     l_visc        kinematic viscosity
+ * \param[in]     t_visc        turbulent kinematic viscosity
+ * \param[in]     vel           wall projected cell center velocity
+ * \param[in]     y             wall distance
+ * \param[in]     kinetic_en    turbulente kinetic energy
+ * \param[in]     iuntur        indicator: 0 in the viscous sublayer
+ * \param[in]     nsubla        counter of cell in the viscous sublayer
+ * \param[in]     nlogla        counter of cell in the log-layer
+ * \param[out]    ustar         friction velocity
+ * \param[out]    uk            friction velocity
+ * \param[out]    yplus         non-dimension wall distance
+ * \param[out]    ypup          yplus projected vel ratio
+ * \param[out]    cofimp        \f$\frac{|U_F|}{|U_I^p|}\f$ to ensure a good
+ *                              turbulence production
+ * \param[out]    dplus         dimensionless shift to the wall for scalable
+ *                              wall functions
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_wall_functions_velocity(int          iwallf,
+                           cs_lnum_t    ifac,
+                           cs_real_t    l_visc,
+                           cs_real_t    t_visc,
+                           cs_real_t    vel,
+                           cs_real_t    y,
+                           cs_real_t    kinetic_en,
+                           int         *iuntur,
+                           cs_lnum_t   *nsubla,
+                           cs_lnum_t   *nlogla,
+                           cs_real_t   *ustar,
+                           cs_real_t   *uk,
+                           cs_real_t   *yplus,
+                           cs_real_t   *ypup,
+                           cs_real_t   *cofimp,
+                           cs_real_t   *dplus)
 {
   /* Pseudo shift of the wall, 0 by default */
   *dplus = 0.;
@@ -532,15 +703,11 @@ void CS_PROCF (wallfunctions, WALLFUNCTIONS)
   /* Activation of wall function by default */
   *iuntur = 1;
 
-  if (*iwallf == 3) {
+  if (iwallf == 3) {
 
-    _1scale_power_law(*ypluli,
-                      *apow,
-                      *bpow,
-                      *dpow,
-                      *l_visc,
-                      *vel,
-                      *y,
+    _1scale_power_law(l_visc,
+                      vel,
+                      y,
                       iuntur,
                       nsubla,
                       nlogla,
@@ -550,18 +717,28 @@ void CS_PROCF (wallfunctions, WALLFUNCTIONS)
                       ypup,
                       cofimp);
 
-  } else if (*iwallf == 0) {
+  } else if (iwallf == 0) {
 
-    _1scale_log_law(*ifac,
-                    *xkappa,
-                    *cstlog,
-                    *ypluli,
-                    *apow,
-                    *bpow,
-                    *dpow,
-                    *l_visc,
-                    *vel,
-                    *y,
+    _1scale_log_law(ifac,
+                    l_visc,
+                    vel,
+                    y,
+                    iuntur,
+                    nsubla,
+                    nlogla,
+                    ustar,
+                    uk,
+                    yplus,
+                    ypup,
+                    cofimp);
+
+  } else if (iwallf == 1) {
+
+    _2scales_log_law(l_visc,
+                     t_visc,
+                     vel,
+                     y,
+                     kinetic_en,
                      iuntur,
                      nsubla,
                      nlogla,
@@ -571,63 +748,157 @@ void CS_PROCF (wallfunctions, WALLFUNCTIONS)
                      ypup,
                      cofimp);
 
-  } else if (*iwallf == 1) {
+  } else if (iwallf == 2) {
 
-    _2scales_log_law(*xkappa,
-                     *cstlog,
-                     *cmu025,
-                     *ypluli,
-                     *l_visc,
-                     *t_visc,
-                     *vel,
-                     *y,
-                     *kinetic_en,
-                      iuntur,
-                      nsubla,
-                      nlogla,
-                      ustar,
-                      uk,
-                      yplus,
-                      ypup,
-                      cofimp);
+    _2scales_scalable_wallfunction(l_visc,
+                                   t_visc,
+                                   vel,
+                                   y,
+                                   kinetic_en,
+                                   iuntur,
+                                   nsubla,
+                                   nlogla,
+                                   ustar,
+                                   uk,
+                                   yplus,
+                                   dplus,
+                                   ypup,
+                                   cofimp);
 
-  } else if (*iwallf == 2) {
+  } else if (iwallf == 4) {
 
-    _2scales_scalable_wallfunction(*xkappa,
-                                   *cstlog,
-                                   *cmu025,
-                                   *ypluli,
-                                   *l_visc,
-                                   *t_visc,
-                                   *vel,
-                                   *y,
-                                   *kinetic_en,
-                                    iuntur,
-                                    nsubla,
-                                    nlogla,
-                                    ustar,
-                                    uk,
-                                    yplus,
-                                    dplus,
-                                    ypup,
-                                    cofimp);
-
-  } else if (*iwallf == 4) {
-
-    _no_wallfunction(*ypluli,
-                     *l_visc,
-                     *t_visc,
-                     *vel,
-                     *y,
-                      iuntur,
-                      nsubla,
-                      nlogla,
-                      ustar,
-                      uk,
-                      yplus,
-                      dplus,
-                      ypup,
-                      cofimp);
+    _no_wallfunction(l_visc,
+                     t_visc,
+                     vel,
+                     y,
+                     iuntur,
+                     nsubla,
+                     nlogla,
+                     ustar,
+                     uk,
+                     yplus,
+                     dplus,
+                     ypup,
+                     cofimp);
   }
 
 }
+
+/*----------------------------------------------------------------------------*/
+
+/*! \brief Compute the correction of the exchange coefficient between the fluid
+  and the wall for a turbulent flow.
+
+  This is function of the dimensionless
+  distance to the wall \f$ y^+ = \dfrac{\centip \centf u_\star}{\nu}\f$.
+
+  Then the return coefficient reads:
+  \f[
+  h_{tur} = Pr \dfrac{y^+}{T^+}
+  \f]
+
+  This coefficient is computed thanks to a similarity model between
+  dynamic viscous sub-layer and themal sub-layer.
+
+  \f$ T^+ \f$ is computed as follows:
+
+  - For a laminar Prandtl number smaller than 0.1 (such as liquid metals),
+    the standard model with two sub-layers (Prandtl-Taylor) is used.
+
+  - For a laminar Prandtl number larger than 0.1 (such as liquids and gaz),
+    a model with three sub-layers (Arpaci-Larsen) is used.
+
+  The final exchange coefficient is:
+  \f[
+  h = \dfrac{K}{\centip \centf} h_{tur}
+  \f]
+
+*/
+/*-----------------------------------------------------------------------------
+  Arguments
+ ______________________________________________________________________________.
+   mode           name          role                                           !
+ _____________________________________________________________________________*/
+/*!
+ * \param[in]     prl           laminar Prandtl number
+ * \param[in]     prt           turbulent Prandtl number
+ * \param[in]     ckarm         Von Karman constant
+ * \param[in]     yplus         dimensionless distance to the wall
+ * \param[in]     dplus         dimensionless distance for scalable
+ *                              wall functions
+ * \param[out]    htur          corrected exchange coefficient
+ * \param[out]    yplim         value of the limit for \f$ y^+ \f$
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_wall_functions_scalar(double  prl,
+                         double  prt,
+                         double  ckarm,
+                         double  yplus,
+                         double  dplus,
+                         double  *htur,
+                         double  *yplim)
+{
+
+  /* Local variables */
+
+  double tplus;
+  double beta2,a2;
+  double yp2;
+  double prlm1;
+
+  const double epzero = 1.e-12;
+
+  /*==========================================================================*/
+
+  /*==========================================================================
+    1. Initializations
+    ==========================================================================*/
+
+  /*==========================================================================*/
+
+  (*htur) = CS_MAX(yplus-dplus,epzero)/CS_MAX(yplus,epzero);
+
+  prlm1 = 0.1;
+
+  /*==========================================================================
+    2. Compute htur for small Prandtl numbers
+    ==========================================================================*/
+
+  if (prl <= prlm1) {
+    (*yplim)   = prt/(prl*ckarm);
+    if (yplus > (*yplim)) {
+      tplus = prl*(*yplim) + prt/ckarm * log(yplus/(*yplim));
+      (*htur) = prl*(yplus-dplus)/tplus;
+    }
+
+    /*========================================================================
+      3. Compute htur for the model with three sub-layers
+      ========================================================================*/
+
+  } else {
+    yp2   = ckarm*1000./prt;
+    yp2   = sqrt(yp2);
+    (*yplim)   = pow(1000./prl,1./3.);
+
+    a2 = 15.*pow(prl,2./3.);
+    beta2 = a2 - 500./ pow(yp2,2);
+
+    if (yplus >= (*yplim) && yplus < yp2) {
+      tplus = a2 - 500./(yplus*yplus);
+      (*htur) = prl*(yplus-dplus)/tplus;
+    }
+
+    if (yplus >= yp2) {
+      tplus = beta2 + prt/ckarm*log(yplus/yp2);
+      (*htur) = prl*(yplus-dplus)/tplus;
+    }
+
+  }
+
+}
+
+/*----------------------------------------------------------------------------*/
+
+END_C_DECLS
