@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,8 @@ module cstphy
 
   !=============================================================================
 
+  use, intrinsic :: iso_c_binding
+
   use paramx
 
   implicit none
@@ -60,19 +62,19 @@ module cstphy
   parameter(rair = 287.d0)
 
   !> Gravity
-  double precision, save :: gx, gy, gz
+  real(c_double), pointer, save :: gx, gy, gz
 
-  integer, save :: icorio
+  integer(c_int), pointer, save :: icorio
 
   !> Rotation vector
-  double precision, save :: omegax, omegay, omegaz
+  real(c_double), pointer, save :: omegax, omegay, omegaz
 
   ! TODO
   double precision, save :: irot(3,3), prot(3,3), qrot(3,3), rrot(3,3)
 
   !> Constantes physiques du fluide
   !> filling \ref xyzp0 indicator
-  integer, save ::          ixyzp0
+  integer(c_int), pointer, save ::          ixyzp0
 
   !> reference density.
   !> Negative value: not initialised.
@@ -83,7 +85,7 @@ module cstphy
   !> it is therefore better to specify its value.
   !>
   !> Always useful otherwise, even if a law defining the density is given by
-  !> the user subroutine \ref usphyv or \ref uselph.
+  !> the user subroutines \ref usphyv or \ref uselph.
   !> indeed, except with the
   !> compressible module, CS  does not use
   !> the total pressure \f$P\f$ when solving the Navier-Stokes equation, but a
@@ -99,14 +101,14 @@ module cstphy
   !> both \f$P\f$ and \f$P^*\f$ appear in the listing and the post-processing outputs..
   !> with the compressible module, the calculation is made directly on the total
   !> pressure
-  double precision, save :: ro0
+  real(c_double), pointer, save :: ro0
 
   !> reference molecular dynamic viscosity.
   !> Negative value: not initialised.
   !>
   !> Always useful, it is the used value unless the user specifies the
   !> viscosity in the subroutine \ref usphyv
-  double precision, save :: viscl0
+  real(c_double), pointer, save :: viscl0
 
   !> reference pressure for the total pressure.
   !> except with the compressible module, the total pressure \f$P\f$ is evaluated
@@ -115,7 +117,7 @@ module cstphy
   !> (given by \ref xyzp0).
   !> with the compressible module, the total pressure is solved directly.
   !> always Useful
-  double precision, save :: p0
+  real(c_double), pointer, save :: p0
 
   !> reference value for the reduced pressure \f$P^*\f$ (see \ref ro0).
   !> It is especially used to initialise the reduced pressure and as a reference
@@ -126,7 +128,7 @@ module cstphy
   !> equations directly represents the total pressure.
   !> It is therefore initialised to \ref p0 and not \ref pred0 (see \ref ro0).
   !> Always useful, except with the compressible module
-  double precision, save :: pred0
+  real(c_double), pointer, save :: pred0
 
   !> coordinates of the reference point \f$\vect{x}_0\f$ for the total pressure.
   !>  - When there are no Dirichlet conditions for the pressure (closed domain),
@@ -153,7 +155,7 @@ module cstphy
   !> \ref xyzp0 is therefore not used..
   !>
   !> Always useful, except with the compressible module.
-  double precision, save :: xyzp0(3)
+  real(c_double), pointer, save :: xyzp0(:)
 
   !> reference temperature.
   !>
@@ -161,7 +163,7 @@ module cstphy
   !> of the density), for the electricity modules to initialise the domain
   !> temperature and for the compressible module (initialisations).
   !> It must be given in Kelvin.
-  double precision, save :: t0
+  real(c_double), pointer, save :: t0
 
   !> reference specific heat.
   !>
@@ -175,19 +177,23 @@ module cstphy
   !> calculate the diffusivity of the thermal scalars,
   !> based on their conductivity; it is therefore needed, unless the
   !> diffusivity is also specified in \ref usphyv.
-  double precision, save :: cp0
+  real(c_double), pointer, save :: cp0
 
   !> molar mass of the perfect gas in \f$ kg/mol \f$ (if \ref ieos=1)
   !>
   !> Always useful
-  double precision, save :: xmasmr
+  real(c_double), pointer, save :: xmasmr
 
   !> Uniform thermodynamic pressure for the low-Mach algorithm
   !> Thermodynamic pressure for the current time step
-  double precision, save :: pther
+  real(c_double), pointer, save :: pther
 
   !> Thermodynamic pressure for the previous time step
-  double precision, save :: pthera
+  real(c_double), pointer, save :: pthera
+
+  !>   pthermax: Thermodynamic maximum pressure for user clipping,
+  !>             used to model a venting effect
+  real(c_double), pointer, save :: pthermax
 
   !> \defgroup csttur Module for turbulence constants
 
@@ -219,7 +225,7 @@ module cstphy
   !> In LES, \ref ypluli is taken by default to be 10.88.
   !>
   !> Always useful
-  double precision, save :: ypluli
+  real(c_double), pointer, save :: ypluli
 
   !> Werner and Wengle coefficient
   double precision, save :: apow
@@ -266,7 +272,7 @@ module cstphy
   double precision, save :: ce4
 
   !> Prandtl number for \f$k\f$ with \f$k-\varepsilon\f$ and v2f models.
-  !> nUseful if and only if \ref iturb=20, 21 or 50
+  !> Useful if and only if \ref iturb=20, 21 or 50
   !> (\f$k-\varepsilon\f$ or v2f)
   double precision, save :: sigmak
 
@@ -511,7 +517,7 @@ module cstphy
   !> the domain volume).
   !>
   !> Useful if and only if \ref turb = 20, 21, 30, 31, 50 or 60 (RANS models)
-  double precision, save :: almax
+  real(c_double), pointer, save :: almax
 
   !> the characteristic flow velocity,
   !> used for the initialisation of the turbulence.
@@ -520,12 +526,12 @@ module cstphy
   !> Useful if and only if \ref iturb= 20, 21, 30, 31, 50 or 60 (RANS model)
   !> and the turbulence is not initialised somewhere
   !> else (restart file or subroutine \ref cs\_user\_initialization)
-  double precision, save :: uref
+  real(c_double), pointer, save :: uref
 
   !> mixing length for the mixing length model
   !>
   !> Useful if and only if \ref iturb= 10 (mixing length)
-  double precision, save :: xlomlg
+  real(c_double), pointer, save :: xlomlg
 
   !> constant used in the definition of LES filtering diameter:
   !> \f$ \delta = \text{xlesfl} . (\text{ales} . volume)^{\text{bles}} \f$
@@ -657,4 +663,179 @@ module cstphy
 
   !=============================================================================
 
+  interface
+
+    !---------------------------------------------------------------------------
+
+    !> \cond DOXYGEN_SHOULD_SKIP_THIS
+
+    !---------------------------------------------------------------------------
+
+    ! Interface to C function retrieving pointers to members of the
+    ! global physical constants structure
+
+    subroutine cs_f_physical_constants_get_pointers(gx, gy, gz, icorio,     &
+                                                    omegax, omegay, omegaz) &
+      bind(C, name='cs_f_physical_constants_get_pointers')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: gx, gy, gz, icorio, omegax, omegay, omegaz
+    end subroutine cs_f_physical_constants_get_pointers
+
+    ! Interface to C function retrieving pointers to members of the
+    ! global fluid properties structure
+
+    subroutine cs_f_fluid_properties_get_pointers(ixyzp0, ro0, viscl0, p0, &
+                                                  pred0, xyzp0, t0, cp0,   &
+                                                  xmasmr, pther, pthera,   &
+                                                  pthermax)                &
+      bind(C, name='cs_f_fluid_properties_get_pointers')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: ixyzp0, ro0, viscl0, p0, pred0, xyzp0, t0, cp0
+      type(c_ptr), intent(out) :: xmasmr, pther, pthera, pthermax
+    end subroutine cs_f_fluid_properties_get_pointers
+
+    ! Interface to C function retrieving pointers to members of the
+    ! RANS turbulence model structure
+
+    subroutine cs_f_turb_reference_values(almax, uref, xlomlg) &
+      bind(C, name='cs_f_turb_reference_values')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: almax , uref  , xlomlg
+    end subroutine cs_f_turb_reference_values
+
+    ! Interface to C function retrieving pointers to members of the
+    ! global wall functions structure
+
+    subroutine cs_f_wall_reference_values(ypluli) &
+      bind(C, name='cs_f_wall_reference_values')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: ypluli
+    end subroutine cs_f_wall_reference_values
+
+    !---------------------------------------------------------------------------
+
+    ! Interface to C function completing the constants of the
+    ! turbulence model
+
+    subroutine cs_f_turb_complete_constants() &
+      bind(C, name='cs_f_turb_complete_constants')
+      use, intrinsic :: iso_c_binding
+    end subroutine cs_f_turb_complete_constants
+
+    !---------------------------------------------------------------------------
+
+    !> \endcond DOXYGEN_SHOULD_SKIP_THIS
+
+    !---------------------------------------------------------------------------
+
+  end interface
+
+  !=============================================================================
+
+contains
+
+  !=============================================================================
+
+  !> \brief Initialize Fortran time step API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine physical_constants_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_gx, c_gy, c_gz, c_icorio, c_omegax, c_omegay, c_omegaz
+
+    call cs_f_physical_constants_get_pointers(c_gx, c_gy, c_gz, c_icorio, &
+                                              c_omegax, c_omegay, c_omegaz)
+
+    call c_f_pointer(c_gx, gx)
+    call c_f_pointer(c_gy, gy)
+    call c_f_pointer(c_gz, gz)
+    call c_f_pointer(c_icorio, icorio)
+    call c_f_pointer(c_omegax, omegax)
+    call c_f_pointer(c_omegay, omegay)
+    call c_f_pointer(c_omegaz, omegaz)
+
+  end subroutine physical_constants_init
+
+  !> \brief Initialize Fortran time step API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine fluid_properties_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_ixyzp0, c_ro0, c_viscl0, c_p0, c_pred0, c_xyzp0, c_t0
+    type(c_ptr) :: c_cp0, c_xmasmr, c_pther, c_pthera, c_pthermax
+
+    call cs_f_fluid_properties_get_pointers(c_ixyzp0, c_ro0, c_viscl0, c_p0, &
+                                            c_pred0, c_xyzp0, c_t0, c_cp0,   &
+                                            c_xmasmr, c_pther, c_pthera,     &
+                                            c_pthermax)
+
+    call c_f_pointer(c_ixyzp0, ixyzp0)
+    call c_f_pointer(c_ro0, ro0)
+    call c_f_pointer(c_viscl0, viscl0)
+    call c_f_pointer(c_p0, p0)
+    call c_f_pointer(c_pred0, pred0)
+    call c_f_pointer(c_xyzp0, xyzp0, [3])
+    call c_f_pointer(c_t0, t0)
+    call c_f_pointer(c_cp0, cp0)
+    call c_f_pointer(c_xmasmr, xmasmr)
+    call c_f_pointer(c_pther, pther)
+    call c_f_pointer(c_pthera, pthera)
+    call c_f_pointer(c_pthermax, pthermax)
+
+  end subroutine fluid_properties_init
+
+  !> \brief Initialize Fortran RANS turbulence model API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine turb_reference_values_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_almax , c_uref  , c_xlomlg
+
+    call cs_f_turb_reference_values( c_almax, c_uref, c_xlomlg)
+
+    call c_f_pointer(c_almax , almax )
+    call c_f_pointer(c_uref  , uref  )
+    call c_f_pointer(c_xlomlg, xlomlg)
+
+  end subroutine turb_reference_values_init
+
+  !> \brief Initialize Fortran wall functions API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine wall_reference_values_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_ypluli
+
+    call cs_f_wall_reference_values( c_ypluli)
+
+    call c_f_pointer(c_ypluli , ypluli )
+
+  end subroutine wall_reference_values_init
+
+  !=============================================================================
+
 end module cstphy
