@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -57,13 +57,13 @@ implicit none
   !> Number of scalars with variable diffusivity
   integer, save :: nvisls
 
-  !> number of boundary coefficient for the boundary conditions
-  integer, save :: ncofab
-
   !> number of properties defined at the cells.
   !> They will be stored in the array \ref propce
   integer, save :: nproce
 
+  !> number of displayed variables (for probes).
+  integer, save :: nvpp
+
   !> fake dimension for arrays coefa and coefb
   !> where \ref nfabor = 0 (to avoid issues with array bounds when
   !> multidimensional arrays have size nfabor in one dimension)
