@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -96,8 +96,7 @@ double precision rvoid(1)
 double precision, allocatable, dimension(:) :: viscf, viscb
 double precision, allocatable, dimension(:) :: coefad, coefbd
 double precision, allocatable, dimension(:) :: cofafd, cofbfd
-double precision, allocatable, dimension(:) :: dam
-double precision, allocatable, dimension(:,:) :: xam
+double precision, allocatable, dimension(:) :: dam, xam
 double precision, allocatable, dimension(:) :: rtpdp, smbdp, rovsdp
 double precision, allocatable, dimension(:,:) :: grad
 double precision, allocatable, dimension(:) :: w1, w2, w3
@@ -114,7 +113,7 @@ double precision, allocatable, dimension(:) :: w7, w8, w9
 allocate(viscf(nfac), viscb(nfabor))
 allocate(coefad(nfabor), coefbd(nfabor))
 allocate(cofafd(nfabor), cofbfd(nfabor))
-allocate(dam(ncelet), xam(nfac,2))
+allocate(dam(ncelet), xam(nfac))
 allocate(rtpdp(ncelet), smbdp(ncelet), rovsdp(ncelet))
 
 ! Allocate work arrays
@@ -203,11 +202,8 @@ imucpp = 0
 
 call matrix &
 !==========
- ( ncelet , ncel   , nfac   , nfabor ,                            &
-   iconvp , idiffp , ndircp ,                                     &
-   isym   , nfecra ,                                              &
+ ( iconvp , idiffp , ndircp , isym   ,                            &
    thetap , imucpp ,                                              &
-   ifacel , ifabor ,                                              &
    coefbd , cofbfd , rovsdp ,                                     &
    viscf  , viscb  , viscf  , viscb  ,                            &
    rvoid  , dam    , xam    )
@@ -217,7 +213,7 @@ call matrix &
 !===============================================================================
 
 ipp = 1
-nomvar(ipp) = 'DisParoi'
+nomva0 = 'DisParoi'
 ipol   = 0
 ireslp = 0
 ! No multigrid (NCYMXP,NITMFP arbitrary)
@@ -252,7 +248,7 @@ do isweep = 0, nswrsl
 
   call prodsc(ncel,isqrt,smbdp,smbdp,rnorm)
   if (iwarny.ge.2) then
-     write(nfecra,5000) nomvar(ipp),isweep,rnorm
+     write(nfecra,5000) nomva0,isweep,rnorm
   endif
   if (isweep.le.1) rnoini = rnorm
   ! Convergence test
@@ -264,7 +260,7 @@ do isweep = 0, nswrsl
 
   call invers &
   !==========
- ( nomvar(ipp)     , isym   , ibsize , iesize ,                   &
+ ( nomva0 , isym   , ibsize , iesize ,                            &
    ipol   , ireslp , nitmay , imgrpy ,                            &
    ncymxp , nitmfp ,                                              &
    iwarny , niterf , icycle , iinvpe ,                            &
@@ -299,7 +295,7 @@ do isweep = 0, nswrsl
     !==========
  ( idtva0 , ivar   , iconvp , idiffp , nswrgy , imligy , ircfly , &
    ischcy , isstpy , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarny , imucpp , idftnp ,                            &
+   iwarny , imucpp , idftnp ,                                     &
    blency , epsrgy , climgy , extray , relaxp , thetap ,          &
    rtpdp  , rtpdp  , coefad , coefbd , coefad , cofbfd ,          &
    viscf  , viscb  , viscf  , viscb  , rvoid  , rvoid  ,          &
