@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -59,7 +59,7 @@ subroutine driflu &
 !===============================================================================
 
 use paramx
-use dimens, only: ndimfb
+use dimens, only: ndimfb, nvar
 use numvar
 use entsor
 use optcal
@@ -81,7 +81,7 @@ implicit none
 
 integer          iflid
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision imasfl(nfac), bmasfl(ndimfb)
 double precision rovsdt(ncelet), smbrs(ncelet)
@@ -97,7 +97,7 @@ integer          iconvp, idiffp
 integer          ircflp, ischcp, isstpp
 integer          ippu  , ippv  , ippw
 integer          isou  , jsou
-integer          f_id
+integer          f_id  , f_id0
 integer          iflmb0, idftnp, iphydp, ivisep, itypfl
 integer          keysca, iscal, keydri, iscdri, icvflb
 integer          ivoid(1)
@@ -118,7 +118,7 @@ double precision, dimension(:), allocatable :: coefap, coefbp
 double precision, dimension(:), allocatable :: cofafp, cofbfp
 double precision, dimension(:,:), allocatable :: coefa1
 double precision, dimension(:,:,:), allocatable :: coefb1
-double precision, dimension(:,:), allocatable :: drift, vel, dudt
+double precision, dimension(:,:), allocatable :: drift, dudt
 double precision, dimension(:), allocatable :: viscf, viscb
 double precision, dimension(:), allocatable :: flumas, flumab
 
@@ -128,6 +128,7 @@ double precision, dimension(:,:), pointer :: coefav, cofafv
 double precision, dimension(:,:,:), pointer :: coefbv, cofbfv
 double precision, dimension(:), pointer :: imasfl_mix, bmasfl_mix
 double precision, dimension(:), pointer :: brom, crom
+double precision, dimension(:,:), pointer :: vel, vela
 
 !===============================================================================
 
@@ -149,6 +150,10 @@ call field_get_key_int(ivarfl(iu), kbmasf, iflmab)
 call field_get_val_s(iflmas, imasfl_mix)
 call field_get_val_s(iflmab, bmasfl_mix)
 
+! Map field arrays
+call field_get_val_v(ivarfl(iu), vel)
+call field_get_val_prev_v(ivarfl(iu), vela)
+
 !===============================================================================
 ! 1. Initialization
 !===============================================================================
@@ -182,7 +187,6 @@ endif
 
 ! Vector containing all the additional convective terms
 allocate(drift(3, ncelet))
-allocate(vel(3, ncelet))
 allocate(dudt(3, ncelet))
 allocate(w1(ncelet), viscce(ncelet))
 allocate(coefap(ndimfb), coefbp(ndimfb))
@@ -315,7 +319,7 @@ if (btest(iscdri, DRIFT_SCALAR_TURBOPHORESIS).or.    &
   call itrmas &
   !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydp , &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp , extrap ,                                     &
    rvoid  ,                                                       &
    viscce ,                                                       &
@@ -335,15 +339,12 @@ endif
 if (btest(iscdri, DRIFT_SCALAR_CENTRIFUGALFORCE)) then
 
   do iel = 1, ncel
-    vel(1, iel) = rtp(iel, iu)
-    vel(2, iel) = rtp(iel, iv)
-    vel(3, iel) = rtp(iel, iw)
 
     rhovdt = crom(iel)*volume(iel)/dt(iel)
 
-    dudt(1,iel) = -rhovdt*(rtp(iel,iu)-rtpa(iel,iu))
-    dudt(2,iel) = -rhovdt*(rtp(iel,iv)-rtpa(iel,iv))
-    dudt(3,iel) = -rhovdt*(rtp(iel,iw)-rtpa(iel,iw))
+    dudt(1,iel) = -rhovdt*(vel(1,iel)-vela(1,iel))
+    dudt(2,iel) = -rhovdt*(vel(2,iel)-vela(2,iel))
+    dudt(3,iel) = -rhovdt*(vel(3,iel)-vela(3,iel))
   enddo
 
   iconvp = 1
@@ -426,6 +427,7 @@ do ifac = 1, nfabor
 
 enddo
 
+f_id0  = -1
 init   = 0
 inc    = 1
 iflmb0 = 0
@@ -439,9 +441,9 @@ extrap = extrag(ivar)
 
 call inimav &
 !==========
- ( ivar   , itypfl ,                                              &
+ ( f_id0  , itypfl ,                                              &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp ,                                              &
    crom   , brom   ,                                              &
    drift  ,                                                       &
@@ -464,11 +466,7 @@ init = 1
 iconvp = iconv(ivar)
 thetap = thetav(ivar)
 
-call divmas &
- ( ncelet , ncel   , nfac   , nfabor , init   , nfecra ,    &
-   ifacel , ifabor ,                                        &
-   flumas , flumab ,                                        &
-   w1     )
+call divmas(init, flumas, flumab, w1)
 
 ! NB: if the porosity module is swiched on, the the porosity is already
 ! taken into account in w1
@@ -482,7 +480,6 @@ enddo
 ! Free memory
 deallocate(viscce)
 deallocate(drift)
-deallocate(vel)
 deallocate(dudt)
 deallocate(w1)
 deallocate(viscf, viscb)
