@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -95,7 +95,7 @@ integer          ncelps , nfbrps
 
 integer          lstcel(ncelps), lstfbr(nfbrps)
 
-double precision rtp(ncelet,*)
+double precision rtp(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision tracel(ncelps*3)
 double precision trafbr(nfbrps*3)
@@ -111,7 +111,7 @@ integer          ipp   , idimt , kk   , ll, iel
 integer          ivarl , ivar0
 integer          iii, ivarl1 , ivarlm , iflu   , ilpd1  , icla
 integer          fldid, fldprv, keycpl, iflcpl
-integer          ipcsii, keyvis, iflpst, itplus
+integer          ipcsii, iflpst, itplus, iprev
 
 double precision epsrgp, climgp, extrap
 double precision pcentr
@@ -124,8 +124,8 @@ double precision, dimension(:), pointer :: tplusp
 double precision, dimension(:), pointer :: valsp, coefap, coefbp
 double precision, dimension(:,:), pointer :: valvp, cofavp, cofbvp
 double precision, dimension(:,:,:), pointer :: cofbtp
-double precision, dimension(:), pointer :: crom
-double precision, dimension(:), pointer :: f_val
+double precision, dimension(:), pointer :: crom, yplbr
+double precision, dimension(:,:), pointer :: vel
 
 !===============================================================================
 
@@ -139,6 +139,9 @@ ipp = 0
 
 if (numtyp .eq. -1) then
 
+  ! Map field arrays
+  call field_get_val_v(ivarfl(iu), vel)
+
   !  1.1.2 Automatic additional variables
   !  ------------------------------------
 
@@ -205,13 +208,13 @@ if (numtyp .eq. -1) then
 
       iel = lstcel(iloc)
 
-      tracel(1 + (iloc-1)*idimt) = rtp(iel,iu) &
+      tracel(1 + (iloc-1)*idimt) = vel(1,iel) &
           + (omegay*xyzcen(3,iel) - omegaz*xyzcen(2,iel))
 
-      tracel(2 + (iloc-1)*idimt) = rtp(iel,iv) &
+      tracel(2 + (iloc-1)*idimt) = vel(2,iel) &
           + (omegaz*xyzcen(1,iel) - omegax*xyzcen(3,iel))
 
-      tracel(3 + (iloc-1)*idimt) = rtp(iel,iw) &
+      tracel(3 + (iloc-1)*idimt) = vel(3,iel) &
           + (omegax*xyzcen(2,iel) - omegay*xyzcen(1,iel))
 
     enddo
@@ -223,56 +226,7 @@ if (numtyp .eq. -1) then
 
   ! Vitesse et pression relatives en cas de calcul en repre fixe
 
-  if (imobil.eq.1) then
-
-    call field_get_val_s(icrom, crom)
-
-    idimt = 1
-    ientla = .true.
-    ivarpr = .false.
-
-    do iloc = 1, ncelps
-
-      iel = lstcel(iloc)
-
-      pcentr =   0.5d0*((omegay*xyzcen(3,iel) - omegaz*xyzcen(2,iel))**2 &
-                      + (omegaz*xyzcen(1,iel) - omegax*xyzcen(3,iel))**2 &
-                      + (omegax*xyzcen(2,iel) - omegay*xyzcen(1,iel))**2)
-
-      tracel(iloc) = rtp(iel,ipr) - crom(iel)*pcentr
-
-    enddo
-
-    call post_write_var(nummai, 'Rel Pressure', idimt, ientla, ivarpr,  &
-                        ntcabs, ttcabs, tracel, rbid, rbid)
-
-    idimt = 3
-    ientla = .true.
-    ivarpr = .false.
-
-    do iloc = 1, ncelps
-
-      iel = lstcel(iloc)
-
-      tracel(1 + (iloc-1)*idimt) = rtp(iel,iu) &
-          - (omegay*xyzcen(3,iel) - omegaz*xyzcen(2,iel))
-
-      tracel(2 + (iloc-1)*idimt) = rtp(iel,iv) &
-          - (omegaz*xyzcen(1,iel) - omegax*xyzcen(3,iel))
-
-      tracel(3 + (iloc-1)*idimt) = rtp(iel,iw) &
-          - (omegax*xyzcen(2,iel) - omegay*xyzcen(1,iel))
-
-    enddo
-
-    call post_write_var(nummai, 'Rel Velocity', idimt, ientla, ivarpr,  &
-                        ntcabs, ttcabs, tracel, rbid, rbid)
-
-  endif
-
-  ! Vitesse et pression relatives en cas de calcul en repre fixe
-
-  if (iturbo.eq.1 .or. iturbo.eq.2) then
+  if (imobil.eq.1 .or. iturbo.eq.1 .or. iturbo.eq.2) then
 
     call field_get_val_s(icrom, crom)
 
@@ -309,19 +263,19 @@ if (numtyp .eq. -1) then
 
       if (irotce(iel).ne.0) then
 
-        tracel(1 + (iloc-1)*idimt) = rtp(iel,iu) &
+        tracel(1 + (iloc-1)*idimt) = vel(1,iel) &
             - (rotax(2)*xyzcen(3,iel) - rotax(3)*xyzcen(2,iel))
 
-        tracel(2 + (iloc-1)*idimt) = rtp(iel,iv) &
+        tracel(2 + (iloc-1)*idimt) = vel(2,iel) &
             - (rotax(3)*xyzcen(1,iel) - rotax(1)*xyzcen(3,iel))
 
-        tracel(3 + (iloc-1)*idimt) = rtp(iel,iw) &
+        tracel(3 + (iloc-1)*idimt) = vel(3,iel) &
             - (rotax(1)*xyzcen(2,iel) - rotax(2)*xyzcen(1,iel))
 
       else
-        tracel(1 + (iloc-1)*idimt) = rtp(iel,iu)
-        tracel(2 + (iloc-1)*idimt) = rtp(iel,iv)
-        tracel(3 + (iloc-1)*idimt) = rtp(iel,iw)
+        tracel(1 + (iloc-1)*idimt) = vel(1,iel)
+        tracel(2 + (iloc-1)*idimt) = vel(2,iel)
+        tracel(3 + (iloc-1)*idimt) = vel(3,iel)
       endif
 
     enddo
@@ -341,7 +295,6 @@ else if (numtyp .eq. -2) then
   !  Projection of variables at boundary with no reconstruction
   !  ----------------------------------------------------------
 
-  call field_get_key_id('post_vis', keyvis)
   call field_get_key_id('coupled', keycpl)
 
   fldprv = -1
@@ -494,6 +447,7 @@ else if (numtyp .eq. -2) then
   if (ipstdv(ipstyp).ne.0) then
 
     idimt = 1  ! variable dimension
+    call field_get_val_s(iyplbr, yplbr)
 
     ! Compute variable on boundary faces
 
@@ -778,12 +732,8 @@ if (numtyp.eq.-2) then
 
         do iloc = 1, nfbrps
           ifac = lstfbr(iloc)
-          if (parbor(ifac,inbr).gt.seuilf) then
-            trafbr(iloc) = parbor(ifac,ivarl) / tstatp
-          else
-            trafbr(iloc) = 0.d0
-          endif
-        enddo
+          trafbr(iloc) = parbor(ifac,ivarl) / tstatp
+       enddo
 
       else
 
@@ -831,45 +781,6 @@ if (numtyp.eq.-2) then
 
   if (iirayo.gt.0) then
 
-    do ivarl = 1, nbrayf
-
-      if (irayvf(ivarl).eq.1) then
-
-        if (ivarl .eq. itparp)      then
-          ipp =  itparo
-        else if (ivarl .eq. iqincp) then
-          ipp = iqinci
-        else if (ivarl .eq. ixlamp)  then
-          ipp = ixlam
-        else if (ivarl .eq. iepap)   then
-          ipp = iepa
-        else if (ivarl .eq. iepsp)   then
-          ipp = ieps
-        else if (ivarl .eq. ifnetp)  then
-          ipp = ifnet
-        else if (ivarl .eq. ifconp) then
-          ipp = ifconv
-        else if (ivarl .eq. ihconp) then
-          ipp = ihconv
-        endif
-
-        call field_get_val_s(ipp, f_val)
-
-        do iloc = 1, nfbrps
-          ifac = lstfbr(iloc)
-          trafbr(iloc) = f_val(ifac)
-        enddo
-
-        idimt  = 1
-        ientla = .true.
-        ivarpr = .false.
-
-        call post_write_var(nummai, trim(nbrvaf(ivarl)), idimt,              &
-                            ientla, ivarpr, ntcabs, ttcabs, rbid, rbid, trafbr)
-
-      endif
-    enddo
-
     do iloc = 1, nfbrps
       ifac = lstfbr(iloc)
       trafbr(iloc) = izfrad(ifac)
