@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -71,44 +71,95 @@ use parall
 use ppppar
 use ppthch
 use ppincl
+use field
 
 !===============================================================================
 
 implicit none
 
 integer          nvar, ncelet, ncel
-double precision rtpa(ncelet,nvar), rtp(ncelet,nvar)
+double precision rtpa(ncelet,nflown:nvar), rtp(ncelet,nflown:nvar)
 double precision dt(ncelet), volume(ncelet)
 
 ! Local variables
 
-integer          ic, icel, ivar, ipp
+integer          ic, icel, ivar, ipp, f_id, f_id_prv, c_id, f_dim
+integer          ippf, kval
+logical          interleaved
 character*200    chain, chainc
 
-!==================================================================
-! 1. DERIVE POUR LES VARIABLES TRANSPORTEES (sauf pression)
-!==================================================================
+double precision, dimension(:), pointer :: field_s_v, field_s_vp
+double precision, dimension(:,:), pointer :: field_v_v, field_v_vp
+
+integer, save :: keypp = -1
+
+!===============================================================================
+
+if (keypp.lt.0) then
+  call field_get_key_id("post_id", keypp)
+endif
+
+f_id = -1
+c_id = 1
 
 do ivar = 1, nvar
-  if (ivar.eq.ipr) cycle
-  ipp = ipprtp(ivar)
-  if (ilisvr(ipp).gt.0) then
-    dervar(ipp) = 0
-    do icel = 1, ncel
-      dervar(ipp) = dervar(ipp)                                 &
-              + (rtp(icel,ivar)-rtpa(icel,ivar))**2             &
-              *  volume(icel)/dt(icel)
-    enddo
-    if (irangp.ge.0) call parsom (dervar(ipp))
-    dervar(ipp) = dervar(ipp) / voltot
+  if (ivar.eq.ipr.and.ippmod(icompf).lt.0) cycle
+
+  f_id_prv = f_id
+  f_id = ivarfl(ivar)
+  if (f_id.eq.f_id_prv) then
+    c_id = c_id + 1
+  else
+    c_id = 1
+  endif
+  call field_get_key_int(f_id, keypp, ippf)
+  if (ippf.le.1) cycle
+
+  call field_get_dim(f_id, f_dim, interleaved)
+  if (f_dim.gt.1) then
+    call field_get_val_v(f_id, field_v_v)
+    call field_get_val_prev_v(f_id, field_v_vp)
+  else if (f_dim.eq.1) then
+    call field_get_val_s(f_id, field_s_v)
+    call field_get_val_prev_s(f_id, field_s_vp)
+  endif
+
+  if (f_dim.gt.1) then
+    call field_get_key_int(f_id, keylog, kval)
+    if (kval.gt.0) then
+      call field_get_key_int(f_id, keypp, ipp)
+      dervar(ipp) = 0.d0
+      do icel = 1, ncel
+        dervar(ipp) = dervar(ipp)                                            &
+                + (field_v_v(c_id,icel) - field_v_vp(c_id,icel))**2          &
+                *  volume(icel)/dt(icel)
+      enddo
+      if (irangp.ge.0) call parsom (dervar(ipp))
+      dervar(ipp) = dervar(ipp) / voltot
+    endif
+  else if (f_dim.eq.1) then
+    call field_get_key_int(f_id, keylog, kval)
+    if (kval.gt.0) then
+      call field_get_key_int(f_id, keypp, ipp)
+      dervar(ipp) = 0.d0
+      do icel = 1, ncel
+        dervar(ipp) = dervar(ipp)                                            &
+                + (field_s_v(icel) - field_s_vp(icel))**2                    &
+                *  volume(icel)/dt(icel)
+      enddo
+      if (irangp.ge.0) call parsom (dervar(ipp))
+      dervar(ipp) = dervar(ipp) / voltot
+    endif
   endif
 enddo
 
-ipp = ipprtp(ipr)
-if (dervar(ipp).lt.epzero) then
-  dervar(ipp) = -1.d0
+if (ippmod(icompf).lt.0) then
+  ipp = ipprtp(ipr)
+  if (dervar(ipp).lt.epzero) then
+    dervar(ipp) = -1.d0
+  endif
+  dervar(ipp) = rnsmbr(ipp) / dervar(ipp)
 endif
-dervar(ipp) = rnsmbr(ipp) / dervar(ipp)
 
 !===============================================================================
 ! 2. ECRITURE DES CRITERES DE CONVERGENCE
@@ -119,13 +170,37 @@ write(nfecra,1010)
 write(nfecra,1011)
 write(nfecra,1010)
 
+f_id = -1
+c_id = 1
+
 do ivar = 1, nvar
+
   ipp = ipprtp(ivar)
-  if (ilisvr(ipp).gt.0) then
+
+  f_id_prv = f_id
+  f_id = ivarfl(ivar)
+  if (f_id.eq.f_id_prv) then
+    c_id = c_id + 1
+  else
+    c_id = 1
+  endif
+
+  call field_get_key_int(ivarfl(ivar), keylog, kval)
+  if (kval.gt.0) then
     chainc = 'c'
     chain = ' '
     ic = 4
-    chain = nomvar(ipp)
+    call field_get_dim (f_id, f_dim, interleaved)
+    call field_get_label(f_id, chain)
+    if (f_dim.gt.1) then
+      if (c_id.eq.1) then
+        chain = trim(chain) // 'X'
+      else if (c_id.eq.2) then
+        chain = trim(chain) // 'Y'
+      else if (c_id.eq.3) then
+        chain = trim(chain) // 'Z'
+      endif
+    endif
     chainc(ic:ic+12) = chain(1:12)
     ic=ic+12
     chain = ' '
@@ -146,6 +221,7 @@ do ivar = 1, nvar
     ic=ic+12
     write(nfecra,'(a)') chainc(1:ic)
   endif
+
 enddo
 
 write(nfecra,1010)
