@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -77,20 +77,15 @@ module entsor
   !>   - \>0: period
   integer, save :: ntsuit
 
-  !> in post post processing output nth variable if ichrvr(n)=1
-  !> for each quantity defined at the cell centres (physical or numerical
-  !> variable), indicator of whether it should be post-processed or not
-  !>   * -999: not initialised. By default, the post-processed
-  !> quantities are the unknowns (pressure, velocity, \f$k\f$, \f$\varepsilon\f$,
-  !> \f$R_{ij}\f$, \f$\omega\f$, \f$\varphi\f$, \f$\overline{f}\f$, scalars),
-  !> density,turbulent viscosity and the time step if is not uniform.
-  !>   * 0: not post-processed.
-  !>   * 1: post-processed.
-  !>
-  !> Useful if and only if the variable is defined at the cell centers:
-  !> calculation variable, physical property (time step, density,
-  !> viscosity, specific heat) or turbulent viscosity if \ref iturb >= 10
-  integer, save :: ichrvr(nvppmx)
+  !> field key for output label
+  integer, save :: keylbl = -1
+
+  !> field keys for logging and postprocessing output
+  integer, save :: keylog = -1
+  integer, save :: keyvis = -1
+
+  !> field key for start position in global postprocessing (ipp index) arrays
+  integer, save :: keyipp = -1
 
   !> \defgroup userfile Additional user files
 
@@ -135,7 +130,7 @@ module entsor
   !> - it is recommended to keep the default value and, if necessary, to modify
   !> the launch script to copy the files in the alternate destination directory
   !> - useful if and only if chronological record files are generated
-  !> (i.e. there is \ref n for which \ref ihisvr(n, 1) \f$\ne\f$ 0)
+  !> (i.e. there is \ref n for which \ref ihisvr "ihisvr(n, 1)" \f$\ne\f$ 0)
   character*80, save :: emphis
 
   !> prefix of history files
@@ -213,11 +208,11 @@ module entsor
   !> \ref ihisvr(n, 1) \f$\ne\f$ 0)
   integer, save :: nthsav
 
-  !> number \ref ihisvr(n, 1) and index-numbers \ref ihisvr(n, j>1) of the
-  !> record probes to be used for each variable, em i.e. calculation variable
+  !> number \ref ihisvr "ihisvr(n, 1)" and index-numbers \ref ihisvr "ihisvr(n, j>1)"
+  !> of the record probes to be used for each variable, em i.e. calculation variable
   !> or physical property defined at the cell centers.
-  !> With \ref ihisvr(n, 1)=-999 or -1, \ref ihisvr(n, j>1) is useless.
-  !>  - \ref ihisvr(n, 1): number of record probes to use
+  !> With \ref ihisvr "ihisvr(n, 1)"=-999 or -1, \ref ihisvr(n, j>1) is useless.
+  !>  - \ref ihisvr "ihisvr(n, 1)": number of record probes to use
   !> for the variable N.
   !>     * = -999: by default: chronogical records are generated on
   !> all the probes if N is one of the main variables (pressure, velocity,
@@ -225,20 +220,20 @@ module entsor
   !> viscosity. For the other quantities, no chronological record is generated.
   !>     * = -1: chronological records are produced on all the probes.
   !>     * = 0: no chronological record on any probe.
-  !>     * > 0: chronological record on \ref ihisvr(n, 1) probes to be
-  !> specified with  \ref ihisvr(n, j>1).
+  !>     * > 0: chronological record on \ref ihisvr "ihisvr(n, 1)" probes to be
+  !> specified with  \ref ihisvr "ihisvr(n, j>1)".
   !> always useful, must be inferior or equal to \ref ncapt.
-  !>  - \ref ihisvr(n, j>1): index-numbers of the probes
+  !>  - \ref ihisvr "ihisvr(n, j>1)": index-numbers of the probes
   !> used for the variable n.
-  !> (with j <= \ref ihisvr(n,1)+1).
-  !>     * = -999: by default: if \ref ihisvr(n, 1) \f$\ne\f$ -999
+  !> (with j <= \ref ihisvr "ihisvr(n,1)+1").
+  !>     * = -999: by default: if \ref ihisvr "ihisvr(n, 1)" \f$\ne\f$ -999
   !> the  code stops. Otherwise, refer to the description of the case
-  !> \ref ihisvr(n, 1)=-999.
+  !> \ref ihisvr "ihisvr(n, 1)"=-999.
   !>
-  !> Useful if and only if \ref ihisvr(n, 1) > 0 .
+  !> Useful if and only if \ref ihisvr "ihisvr(n, 1)" > 0 .
   !>
-  !> The condition \ref ihisvr(n, j) <= \ref ncapt must be respected.
-  !> For an easier use, it is recommended to simply specify \ref ihisvr(n,1)=-1 for
+  !> The condition \ref ihisvr "ihisvr(n, j)" <= \ref ncapt must be respected.
+  !> For an easier use, it is recommended to simply specify \ref ihisvr "ihisvr(n,1)"=-1 for
   !> all the interesting variables.
   integer, save :: ihisvr(nvppmx,ncaptm+1)
 
@@ -331,42 +326,23 @@ module entsor
   !> \addtogroup listing
   !> \{
 
-  !> name of the variables (unknowns, physical properties ...): used in the
-  !> execution listing, in the post-processing files, etc.
-  !> If not initialised,  the code chooses the manes by default.
-  !> It is recommended not to define variable names of more than 16
-  !> characters, to get a clear execution listing (some advanced writing
-  !> levels take into account only the first 16 characters).
-  !> always useful}
-  character*80, save :: nomvar(nvppmx)
+  !> temporary variable name for some algebraic operations
 
-  !> locator pointer vor variables output
+  character*80, save :: nomva0
+
+  !> locator pointer for variables output
   integer, save :: ipprtp(nvarmx)
-  !> locator pointer vor variables output
+  !> locator pointer for variables output
   integer, save :: ipppro(npromx)
-  !> locator pointer vor variables output
+  !> locator pointer for variables output
   integer, save :: ippdt
-  !> locator pointer vor variables output
+  !> locator pointer for variables output
   integer, save :: ipptx
-  !> locator pointer vor variables output
+  !> locator pointer for variables output
   integer, save :: ippty
-  !> locator pointer vor variables output
+  !> locator pointer for variables output
   integer, save :: ipptz
 
-  !> for every quantity (variable, physical or numerical property ...),
-  !> indicator concerning the writing in the execution report file
-  !> default value (-999) is automatically converted into 1 if the concerned
-  !> quantity is one of the main variables (pressure, velocity, turbulence,
-  !> scalar), the density, the time step if \ref idtvar > 0 or the turbulent
-  !> viscosity. Otherwise converted into 0.
-  !> = 1: writing in the execution listing.
-  !> = 0: no writing.
-  integer, save :: ilisvr(nvppmx)
-  !> index of a variable if ipp corresponds to a determined variable
-  !> (p,u,k...)
-  !> 0 si ipp corresponds to an annex variable (cp, mut...) or to nothing.
-  integer, save :: itrsvr(nvppmx)
-
   !> writing period in the execution report file.
   !>   - -1: no writing
   !>   - \> 0: period (every \ref ntlist time step). The value of
