@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -210,6 +210,30 @@ module field
 
     !---------------------------------------------------------------------------
 
+    ! Interface to C function returning a given field's ownership info
+
+    subroutine cs_f_field_get_ownership(f_id, f_is_owner)  &
+      bind(C, name='cs_f_field_get_ownership')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      integer(c_int), value :: f_id
+      logical(c_bool), intent(out) :: f_is_owner
+    end subroutine cs_f_field_get_ownership
+
+    !---------------------------------------------------------------------------
+
+    ! Interface to C function returning a given field's type info
+
+    subroutine cs_f_field_get_type(f_id, f_type)  &
+      bind(C, name='cs_f_field_get_type')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      integer(c_int), value :: f_id
+      integer(c_int), intent(out) :: f_type
+    end subroutine cs_f_field_get_type
+
+    !---------------------------------------------------------------------------
+
     ! Interface to C function indicating if a field maintains a previous time
 
     function cs_f_field_have_previous(f_id) result(have_previous)  &
@@ -222,6 +246,17 @@ module field
 
     !---------------------------------------------------------------------------
 
+    ! Interface to C function changing a fields handling of previous values
+
+    subroutine cs_f_field_set_n_previous(f_id, n_previous)  &
+      bind(C, name='cs_f_field_set_n_previous')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      integer(c_int), value :: f_id, n_previous
+    end subroutine cs_f_field_set_n_previous
+
+    !---------------------------------------------------------------------------
+
     ! Interface to C function allocating field values
 
     subroutine cs_field_allocate_values(f)  &
@@ -262,30 +297,13 @@ module field
 
     ! Interface to C function initializing boundary condition coefficients
 
-    subroutine cs_field_init_bc_coeffs(f, have_flux_bc, have_mom_bc,      &
-                                       have_conv_bc)                      &
+    subroutine cs_field_init_bc_coeffs(f)                      &
       bind(C, name='cs_field_init_bc_coeffs')
       use, intrinsic :: iso_c_binding
       implicit none
       type(c_ptr), value           :: f
-      logical(c_bool), value       :: have_flux_bc
-      logical(c_bool), value       :: have_mom_bc
-      logical(c_bool), value       :: have_conv_bc
     end subroutine cs_field_init_bc_coeffs
 
-
-    !---------------------------------------------------------------------------
-
-    ! Interface to C function mapping boundary condition coefficients
-
-    subroutine cs_field_map_bc_coeffs(f, a, b, af, bf, ad, bd, ac, bc)  &
-      bind(C, name='cs_field_map_bc_coeffs')
-      use, intrinsic :: iso_c_binding
-      implicit none
-      type(c_ptr), value :: f
-      real(kind=c_double), dimension(*) :: a, b, af, bf, ad, bd, ac, bc
-    end subroutine cs_field_map_bc_coeffs
-
     !---------------------------------------------------------------------------
 
     ! Interface to C function copying current to previous values
@@ -438,6 +456,19 @@ module field
 
     !---------------------------------------------------------------------------
 
+    ! Interface to C function returning a label associated with a field.
+
+    subroutine cs_f_field_get_label(f_id, str_max, str, str_len) &
+      bind(C, name='cs_f_field_get_label')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      integer(c_int), value       :: f_id, str_max
+      type(c_ptr), intent(out)    :: str
+      integer(c_int), intent(out) :: str_len
+    end subroutine cs_f_field_get_label
+
+    !---------------------------------------------------------------------------
+
     !> \endcond DOXYGEN_SHOULD_SKIP_THIS
 
     !---------------------------------------------------------------------------
@@ -639,7 +670,7 @@ contains
   !> \param[out]  f_dim        number of field components (dimension)
   !> \param[out]  interleaved  true if field is interleaved, false otherwise
 
-  subroutine field_get_dim (f_id, f_dim, interleaved)
+  subroutine field_get_dim(f_id, f_dim, interleaved)
 
     use, intrinsic :: iso_c_binding
     implicit none
@@ -672,7 +703,71 @@ contains
 
   !=============================================================================
 
-  !> \brief Return a given field's dimension.
+  !> \brief Return the field ownership flag.
+
+  !> \param[in]   f_id         field id
+  !> \param[out]  f_is_owner  true if field is owner, false otherwise
+
+  subroutine field_get_ownership(f_id, f_is_owner)
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Arguments
+
+    integer, intent(in)  :: f_id
+    logical, intent(out) :: f_is_owner
+
+    ! Local variables
+
+    integer(c_int) :: c_f_id
+    logical(c_bool) :: c_is_owner
+
+    c_f_id = f_id
+
+    call cs_f_field_get_ownership(c_f_id, c_is_owner)
+
+    f_is_owner = c_is_owner
+
+    return
+
+  end subroutine field_get_ownership
+
+  !=============================================================================
+
+  !> \brief Return a given field's type.
+
+  !> \param[in]   f_id         field id
+  !> \param[out]  f_type       field type flag
+
+  subroutine field_get_type(f_id, f_type)
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Arguments
+
+    integer, intent(in)  :: f_id
+    integer, intent(out) :: f_type
+
+    ! Local variables
+
+    integer(c_int) :: c_f_id
+    integer(c_int) :: c_type
+
+    c_f_id = f_id
+
+    call cs_f_field_get_type(c_f_id, c_type)
+
+    f_type = c_type
+
+    return
+
+  end subroutine field_get_type
+
+  !=============================================================================
+
+  !> \brief Indicate if a field maintains values at the previous time step
 
   !> \param[in]   f_id           field id
   !> \param[out]  have_previous  true if previous values are maintained
@@ -707,6 +802,35 @@ contains
 
   !=============================================================================
 
+  !> \brief Modify a field's handling of values at the previous time step
+
+  !> \param[in]   f_id        field id
+  !> \param[out]  n_previous  number of previous values (0 or 1)
+
+  subroutine field_set_n_previous(f_id, n_previous)
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Arguments
+
+    integer, intent(in)  :: f_id, n_previous
+
+    ! Local variables
+
+    integer(c_int) :: c_f_id, c_n_previous
+
+    c_f_id = f_id
+    c_n_previous = n_previous
+
+    call cs_f_field_set_n_previous(c_f_id, c_n_previous)
+
+    return
+
+  end subroutine field_set_n_previous
+
+  !=============================================================================
+
   !> \brief Allocate field's value arrays.
 
   !> \param[in]  id  field id
@@ -816,14 +940,8 @@ contains
   !> \brief Initialize boundary condition coefficient arrays if applicable.
 
   !> \param[in]  id            field id
-  !> \param[in]  have_flux_bc  if .true., flux BC coefficients
-  !>                           (coefaf and coefbf) are initialize
-  !> \param[in]  have_mom_bc   if .true., BC coefficients used in divergence
-  !>                           term (coefad and coefbd) are initialized
-  !> \param[in]  have_conv_bc   if .true., BC coefficients used in convection
-  !>                           term (coefac and coefbc) are initialized
 
-  subroutine field_init_bc_coeffs(id, have_flux_bc, have_mom_bc, have_conv_bc)
+  subroutine field_init_bc_coeffs(id)
 
     use, intrinsic :: iso_c_binding
     implicit none
@@ -831,54 +949,6 @@ contains
     ! Arguments
 
     integer, intent(in) :: id
-    logical, intent(in) :: have_flux_bc
-    logical, intent(in) :: have_mom_bc
-    logical, intent(in) :: have_conv_bc
-
-    ! Local variables
-
-    integer(c_int) :: c_id
-    logical(c_bool) :: c_have_flux_bc
-    logical(c_bool) :: c_have_mom_bc
-    logical(c_bool) :: c_have_conv_bc
-    type(c_ptr)     :: f
-
-    c_id = id
-
-    f = cs_field_by_id(c_id)
-    c_have_flux_bc = have_flux_bc
-    c_have_mom_bc = have_mom_bc
-    c_have_conv_bc = have_conv_bc
-    call cs_field_init_bc_coeffs(f, c_have_flux_bc, c_have_mom_bc, c_have_conv_bc)
-
-    return
-
-  end subroutine field_init_bc_coeffs
-
-
-  !=============================================================================
-
-  !> \brief  Map existing field boundary condition coefficient arrays.
-
-  !> \param[in]  id  field id
-  !> \param[in]  a   explicit BC coefficients array
-  !> \param[in]  b   implicit BC coefficients array
-  !> \param[in]  af  explicit flux BC coefficients array, if present
-  !> \param[in]  bf  implicit flux BC coefficients array, if present
-  !> \param[in]  ad  explicit div BC coefficients array, if present
-  !> \param[in]  bd  implicit div BC coefficients array, if present
-  !> \param[in]  ac  explicit conv BC coefficients array, if present
-  !> \param[in]  bc  implicit conv BC coefficients array, if present
-
-  subroutine field_map_bc_coeffs(id, a, b, af, bf, ad, bd, ac, bc)
-
-    use, intrinsic :: iso_c_binding
-    implicit none
-
-    ! Arguments
-
-    integer, intent(in)                        :: id
-    double precision, intent(in), dimension(*) :: a, b, af, bf, ad, bd, ac, bc
 
     ! Local variables
 
@@ -888,11 +958,11 @@ contains
     c_id = id
 
     f = cs_field_by_id(c_id)
-    call cs_field_map_bc_coeffs(f, a, b, af, bf, ad, bd, ac, bc)
+    call cs_field_init_bc_coeffs(f)
 
     return
 
-  end subroutine field_map_bc_coeffs
+  end subroutine field_init_bc_coeffs
 
   !=============================================================================
 
@@ -1275,6 +1345,50 @@ contains
 
   !=============================================================================
 
+  !> \brief Return a label associated with a field.
+
+  !> If the "label" key has been set for this field, its associated string
+  !> is returned. Otherwise, the field's name is returned.
+
+  !> \param[in]   f_id  field id
+  !> \param[out]  str   string associated with key
+
+  subroutine field_get_label (f_id, str)
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Arguments
+
+    integer, intent(in)           :: f_id
+    character(len=*), intent(out) :: str
+
+    ! Local variables
+
+    integer :: i
+    integer(c_int) :: c_f_id, c_str_max, c_str_len
+    type(c_ptr) :: c_str_p
+    character(kind=c_char, len=1), dimension(:), pointer :: c_str
+
+    c_f_id = f_id
+    c_str_max = len(str)
+
+    call cs_f_field_get_label(c_f_id, c_str_max, c_str_p, c_str_len)
+    call c_f_pointer(c_str_p, c_str, [c_str_len])
+
+    do i = 1, c_str_len
+      str(i:i) = c_str(i)
+    enddo
+    do i = c_str_len + 1, c_str_max
+      str(i:i) = ' '
+    enddo
+
+    return
+
+  end subroutine field_get_label
+
+  !=============================================================================
+
   !> \brief Return pointer to the values array of a given scalar field
 
   !> \param[in]     field_id  id of given field (which must be scalar)
