@@ -3,7 +3,7 @@
 !     This file is part of the Code_Saturne Kernel, element of the
 !     Code_Saturne CFD tool.
 
-!     Copyright (C) 1998-2013 EDF S.A., France
+!     Copyright (C) 1998-2014 EDF S.A., France
 
 !     contact: saturne-support@edf.fr
 
@@ -29,8 +29,7 @@ subroutine fldtri &
 !================
 
  ( nproce ,                                                            &
-   dt     , rtpa   , rtp    , propce ,                                 &
-   coefa  , coefb  )
+   dt     , rtpa   , rtp    , propce )
 
 !===============================================================================
 ! Purpose:
@@ -48,8 +47,6 @@ subroutine fldtri &
 ! rtp, rtpa        ! ra ! <-- ! calculated variables at cell centers           !
 !  (ncelet, *)     !    !     !  (at current and previous time steps)          !
 ! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
-! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
-!  (nfabor, *)     !    !     !                                                !
 !__________________.____._____.________________________________________________.
 
 !     Type: i (integer), r (real), s (string), a (array), l (logical),
@@ -62,10 +59,10 @@ subroutine fldtri &
 !===============================================================================
 
 use paramx
-use dimens, only: ndimfb
 use optcal
 use cstphy
 use numvar
+use dimens, only: nvar
 use entsor
 use pointe
 use albase
@@ -90,16 +87,15 @@ implicit none
 ! Arguments
 
 integer          nproce, nscal
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
-double precision coefa(ndimfb,*), coefb(ndimfb,*)
 
 ! Local variables
 
 logical          lprev
 integer          ii, ivar, iprop
 integer          iflid, nfld
-integer          icondl, icondf, icondd, icondc, ipcrom, ipcroa
+integer          ipcrom, ipcroa
 integer          f_id
 
 integer          ifvar(nvppmx)
@@ -127,44 +123,37 @@ ipass = ipass + 1
 !----------------------
 
 ivar = ipr
-icondl = iclrtp(ivar, icoef)
-icondf = iclrtp(ivar, icoeff)
-icondd = icondl
-icondc = icondl
 
 call field_map_values(ivarfl(ivar), rtp(1,ivar), rtpa(1,ivar))
 if (ipass .eq. 1) then
-  if (nfabor .gt. 0) then
-    call field_map_bc_coeffs(ivarfl(ivar),                           &
-                             coefa(1, icondl), coefb(1, icondl),     &
-                             coefa(1, icondf), coefb(1, icondf),     &
-                             coefa(1, icondd), coefb(1, icondd),     &
-                             coefa(1, icondc), coefb(1, icondc))
-  else
-    call field_allocate_bc_coeffs(ivarfl(ivar), .true., .false., .false.)
-  endif
+  call field_allocate_bc_coeffs(ivarfl(ivar), .true., .false., .false.)
+  call field_init_bc_coeffs(ivarfl(ivar))
 endif
 
 ivar = iu
-call field_map_values(ivarfl(ivar), rtp(1,ivar), rtpa(1,ivar))
+
+if (ibdtso.gt.1) then
+  call field_set_n_previous(ivarfl(ivar), ibdtso)
+endif
 
 if (ipass.eq.1) then
-  if (nfabor .gt. 0) then
-    if (ippmod(icompf).ge.0) then
-      call field_map_bc_coeffs(ivarfl(ivar),                         &
-                               coefau(1, 1), coefbu(1, 1, 1),        &
-                               cofafu(1, 1), cofbfu(1, 1, 1),        &
-                               coefau(1, 1), coefbu(1, 1, 1),        &
-                               cofacu(1, 1), cofbcu(1, 1, 1))
-    else
-      call field_map_bc_coeffs(ivarfl(ivar),                         &
-                               coefau(1, 1), coefbu(1, 1, 1),        &
-                               cofafu(1, 1), cofbfu(1, 1, 1),        &
-                               coefau(1, 1), coefbu(1, 1, 1),        &
-                               coefau(1, 1), coefbu(1, 1, 1))
-    endif
-  else
+  if (ippmod(icompf).ge.0) then
     call field_allocate_bc_coeffs(ivarfl(ivar), .true., .false., .true.)
+  else
+    call field_allocate_bc_coeffs(ivarfl(ivar), .true., .false., .false.)
+  endif
+  call field_init_bc_coeffs(ivarfl(ivar))
+endif
+
+! Void fraction for cavitation
+!-----------------------------
+
+if (icavit.ge.0) then
+  ivar = ivoidf
+  call field_map_values(ivarfl(ivar), rtp(1,ivar), rtpa(1,ivar))
+  if (ipass .eq. 1) then
+    call field_allocate_bc_coeffs(ivarfl(ivar), .true., .false., .false.)
+    call field_init_bc_coeffs(ivarfl(ivar))
   endif
 endif
 
@@ -223,26 +212,14 @@ endif
 
 do ii = 1, nfld
   ivar = ifvar(ii)
-  icondl = iclrtp(ivar, icoef)
-  icondf = iclrtp(ivar, icoeff)
-  icondd = icondl
-  if (itytur.eq.3) then
-    if (ivar.ge.ir11 .and. ivar.le.ir23) then
-      icondd = iclrtp(ivar, icoefr)
-    endif
-  endif
-  icondc = icondl
   call field_map_values(ivarfl(ivar), rtp(1,ivar), rtpa(1,ivar))
   if (ipass .eq. 1) then
-    if (nfabor .gt. 0) then
-      call field_map_bc_coeffs(ivarfl(ivar),                         &
-                               coefa(1, icondl), coefb(1, icondl),   &
-                               coefa(1, icondf), coefb(1, icondf),   &
-                               coefa(1, icondd), coefb(1, icondd),   &
-                               coefa(1, icondc), coefb(1, icondc))
+    if (itytur.eq.3 .and. ivar.ge.ir11 .and. ivar.le.ir23) then
+      call field_allocate_bc_coeffs(ivarfl(ivar), .true., .true., .false.)
     else
       call field_allocate_bc_coeffs(ivarfl(ivar), .true., .false., .false.)
     endif
+    call field_init_bc_coeffs(ivarfl(ivar))
   endif
 enddo
 
@@ -255,15 +232,8 @@ if (iale.eq.1) then
   ivar = iuma
   call field_map_values(ivarfl(ivar), rtp(1,ivar), rtpa(1,ivar))
   if (ipass .eq. 1) then
-    if (nfabor .gt. 0) then
-      call field_map_bc_coeffs(ivarfl(ivar),                       &
-                               claale(1, 1), clbale(1, 1, 1),      &
-                               cfaale(1, 1), cfbale(1, 1, 1),      &
-                               claale(1, 1), clbale(1, 1, 1),      &
-                               claale(1, 1), clbale(1, 1, 1))
-    else
-      call field_allocate_bc_coeffs(ivarfl(ivar), .true., .false., .false.)
-    endif
+    call field_allocate_bc_coeffs(ivarfl(ivar), .true., .false., .false.)
+    call field_init_bc_coeffs(ivarfl(ivar))
   endif
 endif
 
@@ -275,32 +245,22 @@ nscal = nscaus + nscapp
 do ii = 1, nscal
   if (isca(ii) .gt. 0) then
     ivar = isca(ii)
-    icondl = iclrtp(ivar, icoef)
-    icondf = iclrtp(ivar, icoeff)
-    icondd = icondl
-    icondc = icondl
     call field_map_values(ivarfl(ivar), rtp(1,ivar), rtpa(1,ivar))
     if (ipass .eq. 1) then
-      if (nfabor .gt. 0) then
-        if (ippmod(icompf).ge.0 .and. ii.eq.ienerg) then
-          icondc = iclrtp(ivar, icoefc)
-        endif
-        call field_map_bc_coeffs(ivarfl(ivar),                       &
-                                 coefa(1, icondl), coefb(1, icondl), &
-                                 coefa(1, icondf), coefb(1, icondf), &
-                                 coefa(1, icondd), coefb(1, icondd), &
-                                 coefa(1, icondc), coefb(1, icondc))
-        ! Boundary conditions of the turbulent fluxes T'u'
-        if (ityturt(ii).eq.3) then
-          call field_get_name(ivarfl(ivar), fname)
-          ! Index of the corresponding turbulent flux
-          call field_get_id(trim(fname)//'_turbulent_flux', f_id)
-          call field_allocate_bc_coeffs(f_id, .true., .true., .false.)
-          call field_init_bc_coeffs(f_id, .true., .true., .false.)
-        endif
+      if (ippmod(icompf).ge.0 .and. ii.eq.ienerg) then
+        call field_allocate_bc_coeffs(ivarfl(ivar), .true., .false., .true.)
       else
         call field_allocate_bc_coeffs(ivarfl(ivar), .true., .false., .false.)
       endif
+      call field_init_bc_coeffs(ivarfl(ivar))
+      ! Boundary conditions of the turbulent fluxes T'u'
+      if (ityturt(ii).eq.3) then
+        call field_get_name(ivarfl(ivar), fname)
+        ! Index of the corresponding turbulent flux
+        call field_get_id(trim(fname)//'_turbulent_flux', f_id)
+        call field_allocate_bc_coeffs(f_id, .true., .true., .false.)
+        call field_init_bc_coeffs(f_id)
+      endif
     endif
   endif
 enddo
@@ -320,9 +280,13 @@ endif
 ! The choice made in VARPOS specifies that we will only be interested in
 ! properties at cell centers (no mass flux, nor density at the boundary).
 
+f_id = -1
 do iprop = 1, nproce
   if (iprop.eq.ipcrom .or. iprop.eq.ipcroa) cycle
-  call field_map_values(iprpfl(iprop), propce(1, iprop), propce(1, iprop))
+  if (iprpfl(iprop).ne.f_id) then
+    f_id = iprpfl(iprop)
+    call field_map_values(iprpfl(iprop), propce(1, iprop), propce(1, iprop))
+  endif
 enddo
 
 ! Reserved fields whose ids are not saved (may be queried by name)
