@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -50,6 +50,7 @@ use cplsat
 use ppincl
 use mesh
 use field
+use cavitation
 
 !===============================================================================
 
@@ -57,7 +58,7 @@ implicit none
 
 ! Local variables
 
-integer          ii, jj, ivar, iscal, iprop, iest, imom
+integer          ii, jj, iscal, iprop, iest, imom
 integer          istr
 
 !===============================================================================
@@ -102,17 +103,39 @@ write(nfecra, 900)
 ! 0. Global field keys
 !===============================================================================
 
+call field_get_key_id("label", keylbl)
+call field_get_key_id('log', keylog)
+call field_get_key_id('post_vis', keyvis)
+call field_get_key_id("post_id", keyipp)
+
 call field_get_key_id("inner_mass_flux_id", kimasf)
 call field_get_key_id("boundary_mass_flux_id", kbmasf)
 
+call field_get_key_id("scalar_diffusivity_id", kivisl)
+
 icrom = -1
 ibrom = -1
 
+ipori = -1
+iporf = -1
+
 !===============================================================================
 ! 1. Map Fortran pointers to C global data
 !===============================================================================
 
 call time_step_init
+call thermal_model_init
+call turb_model_init
+call turb_rans_model_init
+call turb_les_model_init
+call wall_functions_init
+call stokes_options_init
+call physical_constants_init
+call fluid_properties_init
+call space_disc_options_init
+call piso_options_init
+call wall_reference_values_init
+call turb_reference_values_init
 
 !===============================================================================
 ! 2. ENTREES SORTIES entsor.f90
@@ -155,14 +178,6 @@ implal = 80
 ficlal = 'listla'
 ntlal  = 1
 
-!    Post traitement
-!       ICHRVR  : Variables a sortir
-!         (1 oui, 0 non, sinon : non initialise)
-
-do ii = 1, nvppmx
-  ichrvr(ii )   = -999
-enddo
-
 ! ---> Fichier thermochinie
 !        FPP : utilisateur
 !        JNF : Janaf
@@ -293,7 +308,6 @@ enddo
 !              1 pointe sur une case poubelle et constitue donc une
 !              bonne initialisation
 !     NOMVAR : Nom des variables
-!     ILISVR : on suit la variable (1) ou non (0) ou non initialise
 !     ITRSVR : numero de variable si IPP correspond a une variable resolue (p,u,k...)
 !              0 si IPP correspond a une variable annexe (cp, mut...)ou a rien
 !     NTLIST : periode d'ecriture
@@ -310,12 +324,6 @@ ipptx        = 1
 ippty        = 1
 ipptz        = 1
 
-do ii = 1, nvppmx
-  nomvar(ii)    = ' '
-  ilisvr(ii)    = -999
-  itrsvr(ii)    = 0
-enddo
-
 ntlist = 1
 
 !   PARAMETRES DE CONVERGENCE, NORME DU SECOND MEMBRE, NOMBRE ITERATIONS
@@ -383,22 +391,15 @@ call tstjpe(iperio, iperot)
 !===============================================================================
 
 ! --- Nombre de scalaires, de scalaires a diffusivite
-!            variable, de variables
+!            variable, de variables, de proprietes
 
 nscal  = 0
 nscaus = 0
 nscapp = 0
 nscasp = 0
 nvar   = 0
-
-! --- Nombre de proprietes physiques (utile ?)
-
 nproce = 0
-
-! --- Nombre de tableaux NFABOR de type COEFA (ou COEFB)
-
-ncofab = 0
-
+nvpp   = 1
 
 !===============================================================================
 ! 5. POSITION DES VARIABLES DE numvar.f90
@@ -449,7 +450,7 @@ call ppinii
 ! --- Proprietes physiques au sens large
 
 do iprop  = 1, npromx
-  ipproc(iprop) = 0
+  ipproc(iprop) = iprop
 enddo
 
 irom   = 0
@@ -461,26 +462,12 @@ ifour  = 0
 icp    = 0
 iprtot = 0
 
+ibeta  = 0
+
 do iscal = 1, nscamx
   ivisls(iscal) = -1
 enddo
 
-! --- Conditions aux limites (COEFA, COEFB)
-
-icoef  = 1
-icoeff = 2
-! Special treatment of divRij in the momentum equation
-icoefr = 3
-! Replacement of the convection flux
-icoefc = 4
-
-do ivar = 1, nvarmx
-  iclrtp(ivar,icoef ) = 0
-  iclrtp(ivar,icoeff) = 0
-  iclrtp(ivar,icoefr) = 0
-  iclrtp(ivar,icoefc) = 0
-enddo
-
 ! --- Ici tout numvar est initialise.
 
 !===============================================================================
@@ -571,7 +558,10 @@ thetsn =-999.d0
 !     Noter cpdt que le TS d'acc. masse n'est pas regi par I..EXT
 !       (il suit bilsc2)
 isto2t = -999
-thetst =-999.d0
+thetst = -999.d0
+
+! Backward differential time scheme order
+ibdtso = -999
 
 !    -- Proprietes physiques
 !     I..EXT definit l'extrapolation -theta ancien + (1+theta) nouveau
@@ -842,6 +832,10 @@ idries =-1
 irccor = 0
 itycor = -999
 
+! --- Turbulent diffusion model for second moment closure
+!     Set to 1 (Daly and Harlow model) by default
+idirsm = 1
+
 ! --- Viscosite secondaire
 
 ivisse = 1
@@ -870,10 +864,14 @@ ipucou = 0
 !     ----------
 !      - the dilatable steady algorithm is used (idilat= 1)
 !      - the thermodynamic pressure (pther) is initialized with p0 = p_atmos
+!      - the maximum thermodynamic pressure (pthermax) is initialized with -1
+!        (no maximum by default, this term is used to model a venting effect when
+!         a positive value is given by the user)
 !      - the parameter (epsdp) for diagonal pressure strengthening is equal to 1e-12
 
 idilat = 1
 pther  = 1.013d5
+pthermax= -1.d0
 epsdp  = 1.0d-12
 
 ! --- Take into account the balance or imbalance between the pressure
@@ -892,6 +890,12 @@ epsdp  = 1.0d-12
 iphydr = 0
 icalhy = -1
 
+! --- Cavitation module (not activated by default)
+!       -1: module not activated
+!        0: no vaporization/condensation model
+!        1: Merkle's model
+icavit = -1
+
 ! --- No Bernoulli free entrance faces
 iifren = 0
 
@@ -997,18 +1001,19 @@ nfpt1t = 0
 
 
 do imom = 1, nbmomx
-!       Pas de temps de depart (-1 : jamais)
+  ! Pas de temps de depart (-1 : jamais)
   ntdmom(imom) = -1
   ! start time
   ttdmom(imom) = 0.d0
-!       Ancien moment a relire ou -1 pour (re)initialisation
+  !Ancien moment a relire ou -1 pour (re)initialisation
   imoold(imom) = -2
 enddo
 
 !     Variables composant les moments
 do ii = 1, ndgmox
   do imom = 1, nbmomx
-    idfmom(ii,imom) = 0
+    idfmom(1,ii,imom) = -1
+    idfmom(2,ii,imom) = -1
   enddo
 enddo
 
@@ -1016,16 +1021,10 @@ enddo
 
 !       Nombre de moments
 nbmomt = 0
-!       Nombre de tableaux ncel pourle temps cumule
-nbdtcm = 0
 
 do imom = 1, nbmomx
   ! Pointeur sur les moments
   icmome(imom) = 0
-  ! Pointeur sur le pas de temps cumule
-  idtmom(imom) = 0
-  ! Degre
-  idgmom(imom) = 0
 enddo
 
 ! --- Calcul de la distance a la paroi
@@ -1268,8 +1267,6 @@ do iscal = 1, nscamx
   iscacp(iscal) =-10
   iclvfl(iscal) = -1
   iscavr(iscal) = 0
-  scamin(iscal) =-grand
-  scamax(iscal) =+grand
   visls0(iscal) =-grand*10.d0
   sigmas(iscal) = 1.0d0
   wmolsp(iscal) = 0.0d0
@@ -1406,13 +1403,20 @@ ettp => rvoid2
 ettpa => rvoid2
 tepa => rvoid2
 statis => rvoid2
-stativ => rvoid2
+nullify(stativ)
 parbor => rvoid2
 tslagr => rvoid2
-dlgeo => rvoid2
+nullify(dlgeo)
 
 !===============================================================================
-! 14. SORTIE
+! 14. INITIALISATION DES PARAMETRES DU MODULE DE CAVITATION
+!===============================================================================
+
+call init_cavitation
+!===================
+
+!===============================================================================
+! 15. SORTIE
 !===============================================================================
 
 return
