@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -222,12 +222,5 @@ endif
 call impini
 !==========
 
-!===============================================================================
-! 7. Other initializations
-!===============================================================================
-
-call cs_log_init_moments(dtcmom)   ! Map dtcmom to C logging API
-call cs_post_init_moments(dtcmom)  ! Map dtcmom to C post-processing API
-
 return
 end subroutine
