@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -35,20 +35,17 @@
 !------------------------------------------------------------------------------
 !> \param[in]     nvar          total number of variables
 !> \param[in]     nscal         total number of scalars
-!> \param[in]     ncofab        total number of couples coefa/b for bound cond
 !> \param[out]    dt            time step value
 !> \param[out]    rtp           calculation variables at cells center
 !> \param[out]    propce        physical properties at cell centers
-!> \param[out]    coefa         boundary conditions for boundary faces
-!> \param[out]    coefb         boundary conditions for boundary faces
 !> \param[out]    frcxt         external stress generating hydrostatic pressure
 !> \param[out]    prhyd         hydrostatic pressure predicted
 !______________________________________________________________________________
 
 subroutine iniva0 &
- ( nvar   , nscal  , ncofab ,                                     &
+ ( nvar   , nscal  ,                                              &
    dt     , rtp    , propce ,                                     &
-   coefa  , coefb  , frcxt  , prhyd)
+   frcxt  , prhyd)
 
 !===============================================================================
 ! Module files
@@ -70,6 +67,7 @@ use ppincl
 use cplsat
 use field
 use mesh
+use cavitation
 
 !===============================================================================
 
@@ -77,16 +75,15 @@ implicit none
 
 ! Arguments
 
-integer          nvar   , nscal  , ncofab
+integer          nvar   , nscal
 
-double precision dt(ncelet), rtp(ncelet,*), propce(ncelet,*)
-double precision coefa(nfabor,ncofab), coefb(nfabor,ncofab)
 double precision frcxt(3,ncelet), prhyd(ncelet)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), propce(ncelet,*)
 
 ! Local variables
 
 integer          iis   , ivar  , iscal , imom
-integer          iel   , ifac  , isou  , jsou
+integer          iel   , ifac  , isou
 integer          iclip , ii    , jj    , idim
 integer          iivisl, iivist, iivisa, iivism
 integer          iicp  , iicpa
@@ -94,11 +91,21 @@ integer          iiviss, iiptot
 integer          iptsna, iptsta, iptsca
 integer          nn
 integer          iflid, nfld, ifmaip, bfmaip, iflmas, iflmab
+integer          f_id, f_id_prv, f_dim
+integer          kscmin, kscmax
+
+logical          interleaved
 
 double precision xxk, xcmu, trii
 
 double precision rvoid(1)
-double precision, dimension(:), pointer :: brom, crom
+
+double precision, dimension(:), pointer :: brom, crom, crom_prev2
+double precision, dimension(:), pointer :: cofbcp
+double precision, dimension(:), pointer :: porosi
+double precision, dimension(:,:), pointer :: porosf
+double precision, dimension(:), pointer :: field_s_v
+double precision, dimension(:,:), pointer :: field_v_v
 
 !===============================================================================
 
@@ -140,18 +147,25 @@ enddo
 call field_get_val_s(icrom, crom)
 call field_get_val_s(ibrom, brom)
 
-!     Masse volumique aux cellules (et au pdt precedent si ordre2 ou icalhy)
+!     Masse volumique aux cellules (et au pdt precedent si ordre2 ou icalhy
+!     ou cavitation)
 do iel = 1, ncel
   crom(iel)  = ro0
 enddo
-if (iroext.gt.0.or.icalhy.eq.1.or.idilat.gt.1) then
+if (iroext.gt.0.or.icalhy.eq.1.or.idilat.gt.1.or.icavit.ge.0) then
   call field_current_to_previous(icrom)
 endif
+if (icavit.ge.0) then
+  call field_get_val_s(icroaa, crom_prev2)
+  do iel = 1, ncelet
+    crom_prev2(iel) = crom(iel)
+  enddo
+endif
 !     Masse volumique aux faces de bord (et au pdt precedent si ordre2)
 do ifac = 1, nfabor
   brom(ifac) = ro0
 enddo
-if (iroext.gt.0) then
+if (iroext.gt.0.or.icavit.ge.0) then
   call field_current_to_previous(ibrom)
 endif
 
@@ -252,23 +266,85 @@ if (iale.eq.1) then
   enddo
 endif
 
+! Porosity
+if (iporos.ge.1) then
+  call field_get_val_s(ipori, porosi)
+  do iel = 1, ncelet
+    porosi(iel) = 1.d0
+  enddo
+
+  ! Tensorial porosity
+  if (iporos.eq.2) then
+    call field_get_val_v(iporf, porosf)
+    do iel = 1, ncelet
+      porosf(1, iel) = 1.d0
+      porosf(2, iel) = 1.d0
+      porosf(3, iel) = 1.d0
+      porosf(4, iel) = 0.d0
+      porosf(5, iel) = 0.d0
+      porosf(6, iel) = 0.d0
+    enddo
+  endif
+endif
+
 !===============================================================================
 ! 4. INITIALISATION STANDARD DES VARIABLES DE CALCUL
 !     On complete ensuite pour les variables turbulentes et les scalaires
 !===============================================================================
 
-!     Toutes les variables a 0
-do ivar = 1, nvar
-  do iel = 1, ncel
-    rtp(iel,ivar) = 0.d0
-  enddo
-enddo
-
 !     On met la pression P* a PRED0
+!$omp parallel do
 do iel = 1, ncel
   rtp(iel,ipr) = pred0
 enddo
 
+!     Toutes les variables a 0
+f_id = -1
+
+do ivar = 1, nvar
+  f_id_prv = f_id
+  f_id = ivarfl(ivar)
+  if (f_id.eq.f_id_prv) cycle
+
+  call field_get_dim(f_id, f_dim, interleaved)
+
+  if (f_dim.gt.1) then
+    call field_get_val_v(f_id, field_v_v)
+  else if (f_dim.eq.1) then
+    call field_get_val_s(f_id, field_s_v)
+  endif
+
+  if (f_dim.gt.1) then
+    !$omp parallel do private(isou)
+    do iel = 1, ncel
+      do isou = 1, f_dim
+        field_v_v(isou,iel) = 0.d0
+      enddo
+    enddo
+  else
+    !$omp parallel do
+    do iel = 1, ncel
+      field_s_v(iel) = 0.d0
+    enddo
+  endif
+enddo
+
+! On definit les clipping du taux de vide et on initialize au clipping inf.
+if (icavit.ge.0) then
+
+  call field_get_key_id("min_scalar_clipping", kscmin)
+  call field_get_key_id("max_scalar_clipping", kscmax)
+
+  call field_set_key_double(ivarfl(ivoidf), kscmin, clvfmn)
+  call field_set_key_double(ivarfl(ivoidf), kscmax, clvfmx)
+
+  call field_get_val_s(ivarfl(ivoidf), field_s_v)
+  do iel = 1, ncel
+    field_s_v(iel) = clvfmn
+  enddo
+
+endif
+
 !===============================================================================
 ! 5. INITIALISATION DE K, RIJ ET EPS
 !===============================================================================
@@ -442,46 +518,15 @@ endif
 !===============================================================================
 
 ! Conditions aux limites
-do ii = 1, ncofab
-  do ifac = 1, nfabor
-    coefa(ifac,ii) = 0.d0
-    coefb(ifac,ii) = 1.d0
-  enddo
-enddo
 
 if (ienerg.gt.0) then
+  call field_get_coefbc_s(ivarfl(isca(ienerg)), cofbcp)
   do ifac = 1, nfabor
-    coefb(ifac,iclrtp(isca(ienerg),icoefc)) = 0.d0
+    cofbcp(ifac) = 0.d0
   enddo
 endif
 
-! Boundary conditions for the velocity if coupling of the components
-do ifac = 1, nfabor
-  do isou = 1, 3
-    coefau(isou,ifac) = 0.d0
-    cofafu(isou,ifac) = 0.d0
-    do jsou = 1, 3
-      if (jsou.eq.isou) then
-        coefbu(isou,jsou,ifac) = 1.d0
-        cofbfu(isou,jsou,ifac) = 0.d0
-      else
-        coefbu(isou,jsou,ifac) = 0.d0
-        cofbfu(isou,jsou,ifac) = 0.d0
-      endif
-    enddo
-  enddo
-enddo
-
-if (ippmod(icompf).ge.0) then
-  do ifac = 1, nfabor
-    do isou = 1, 3
-      cofacu(isou,ifac) = 0.d0
-      do jsou = 1, 3
-          cofbcu(isou,jsou,ifac) = 0.d0
-      enddo
-    enddo
-  enddo
-endif
+! Boundary conditions
 
 do ifac = 1, nfabor
   itypfb(ifac) = 0
@@ -537,6 +582,11 @@ if(isno2t.gt.0) then
       propce(iel,iptsna+ii-1) = 0.d0
     enddo
   enddo
+  if (icavit.ge.0) then
+    do iel = 1, ncel
+      propce(iel,iptsna+3) = 0.d0
+    enddo
+  endif
 endif
 
 !     les termes sources turbulents
@@ -575,14 +625,6 @@ do imom = 1, nbmomt
     propce(iel,ipproc(icmome(imom))) = 0.d0
   enddo
 enddo
-do ii = 1,  nbdtcm
-  do iel = 1, ncel
-    propce(iel,ipproc(icdtmo(ii))) = 0.d0
-  enddo
-enddo
-do ii = 1,  nbmomx
-  dtcmom(ii) = 0.d0
-enddo
 
 !===============================================================================
 ! 10.  INITIALISATION CONSTANTE DE SMAGORINSKY EN MODELE DYNAMIQUE
