@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -34,6 +34,7 @@ subroutine modini
 use paramx
 use cstnum
 use dimens
+use field
 use numvar
 use optcal
 use cstphy
@@ -53,9 +54,11 @@ implicit none
 
 ! Local variables
 
-integer          ii, jj, ivar, iok, iest, imom, ikw
-integer          icompt, ipp, nbccou, nn
+integer          n_fields
+integer          ii, jj, ivar, iok, imom, ikw
+integer          icompt, ipp, nbccou, keyvar
 integer          nscacp, iscal
+integer          imrgrp
 double precision relxsp
 double precision omgnrm, cosdto, sindto
 double precision ux, uy, uz
@@ -65,6 +68,12 @@ double precision ux, uy, uz
 ! Indicateur erreur (0 : pas d'erreur)
 iok = 0
 
+call field_get_n_fields(n_fields)
+
+call field_get_key_id("variable_id", keyvar)
+
+call cs_f_turb_complete_constants
+
 !===============================================================================
 ! 1. ENTREES SORTIES entsor
 !===============================================================================
@@ -77,74 +86,21 @@ do ii = 1, nvarmx
   endif
 enddo
 
-!---> Variables de calcul ITRSVR = ivar. Sinon 0 (valeur d'initialisation).
-
-do ivar = 1, nvar
-  itrsvr(ipprtp(ivar)) = ivar
-enddo
-
 !---> sorties chrono?
 !     Sauf mention contraire de l'utilisateur, on sort a la fin les
 !        variables de calcul, la viscosite, rho, le pas de temps s'il
 !        est variable, les estimateurs s'ils sont actives, les moments
 !        s'il y en a et la viscosite de maillage en ALE.
 
-do ii = 2, nvppmx
-  if (itrsvr(ii).ge.1.and.ichrvr(ii).eq.-999) then
-    ichrvr(ii) = 1
-  endif
-enddo
-ipp = ipppro(ipproc(irom))
-if (ichrvr(ipp).eq.-999) ichrvr(ipp) = 1
-ipp = ipppro(ipproc(ivisct))
-if ((iturb.eq.10 .or. itytur.eq.2                 &
-     .or. itytur.eq.5 .or. iturb.eq.60            &
-     .or. iturb.eq.70)                            &
-     .and.ichrvr(ipp).eq.-999) ichrvr(ipp) = 1
 if (idtvar.lt.0) then
-  ichrvr(ipppro(ipproc(icour))) = 0
-  ichrvr(ipppro(ipproc(ifour))) = 0
-endif
-do iest = 1, nestmx
-  if (iescal(iest).gt.0) then
-    ipp = ipppro(ipproc(iestim(iest)))
-    if (ichrvr(ipp).eq.-999) ichrvr(ipp) = 1
-  endif
-enddo
-if (idtvar.eq.2.and.ichrvr(ippdt).eq.-999) ichrvr(ippdt) = 1
-if (ipucou.ne.1) then
-  ichrvr(ipptx) = 0
-  ichrvr(ippty) = 0
-  ichrvr(ipptz) = 0
+  call hide_property(icour)
+  call hide_property(ifour)
 endif
 
-if (nbmomt.gt.0) then
-  do imom = 1, nbmomt
-    ipp = ipppro(ipproc(icmome(imom)))
-    if (ichrvr(ipp).eq.-999) ichrvr(ipp) = 1
-  enddo
-endif
 if (iale.eq.1) then
   call cs_post_set_deformable
-  nn = 1
-  if (iortvm.eq.1) nn = 3
-  do ii = 1, nn
-    ipp = ipppro(ipproc(ivisma(ii)))
-    if (ichrvr(ipp).eq.-999) ichrvr(ipp) = 1
-  enddo
 endif
 
-do ii = 1, nvppmx
-  if (ichrvr(ii).eq.-999) then
-    ichrvr(ii) = 0
-  endif
-enddo
-
-icompt = 0
-do ii = 2, nvppmx
-  if (ichrvr(ii).eq.1) icompt = icompt+1
-enddo
-
 !---> sorties historiques ?
 !      Si une valeur non modifiee par l'utilisateur (=-999)
 !        on la met a sa valeur par defaut
@@ -157,9 +113,13 @@ enddo
 !      NTHSAV =  0 : periode par defaut (voir caltri)
 !             > 0  : periode
 
-do ii = 2, nvppmx
-  if (itrsvr(ii).ge.1.and.ihisvr(ii,1).eq.-999) then
-    ihisvr(ii,1) = -1
+do ii = 0, n_fields-1
+  call field_get_key_int(ii, keyvar, ivar)
+  if (ivar.ge.1) then
+    call field_get_key_int(ii, keyipp, ipp)
+    if (ihisvr(ipp,1).eq.-999) then
+      ihisvr(ipp,1) = -1
+    endif
   endif
 enddo
 if (ihisvr(ippdt, 1).eq.-999) ihisvr(ippdt, 1) = -1
@@ -212,303 +172,23 @@ else
   endif
 endif
 
-! ---> Nom des variables
+! Variable labels
 
-if (nomvar(ipprtp(ipr)) .eq.' ') then
-  nomvar(ipprtp(ipr)) = 'Pressure'
-  if (icorio.eq.1) then
-    nomvar(ipprtp(ipr)) = 'Rel Pressure'
-  endif
-endif
-if (nomvar(ipprtp(iu)) .eq.' ') then
-  nomvar(ipprtp(iu))   = 'VelocityX'
-  if (icorio.eq.1) then
-    nomvar(ipprtp(iu)) = 'Rel VelocityX'
-  endif
-endif
-if (nomvar(ipprtp(iv)) .eq.' ') then
-  nomvar(ipprtp(iv))   = 'VelocityY'
-  if (icorio.eq.1) then
-    nomvar(ipprtp(iv)) = 'Rel VelocityY'
-  endif
-endif
-if (nomvar(ipprtp(iw)) .eq.' ') then
-  nomvar(ipprtp(iw))   = 'VelocityZ'
-  if (icorio.eq.1) then
-    nomvar(ipprtp(iw)) = 'Rel VelocityZ'
-  endif
-endif
-if (itytur.eq.2) then
-  if (nomvar(ipprtp(ik)) .eq.' ') then
-    nomvar(ipprtp(ik)) = 'Turb Kinetic Energy'
-  endif
-  if (nomvar(ipprtp(iep)) .eq.' ') then
-    nomvar(ipprtp(iep)) = 'Turb Dissipation'
-  endif
-elseif (itytur.eq.3) then
-  if (nomvar(ipprtp(ir11)) .eq.' ') then
-    nomvar(ipprtp(ir11)) =  'R11'
-  endif
-  if (nomvar(ipprtp(ir22)) .eq.' ') then
-    nomvar(ipprtp(ir22)) = 'R22'
-  endif
-  if (nomvar(ipprtp(ir33)) .eq.' ') then
-    nomvar(ipprtp(ir33)) = 'R33'
-  endif
-  if (nomvar(ipprtp(ir12)) .eq.' ') then
-    nomvar(ipprtp(ir12)) = 'R12'
-  endif
-  if (nomvar(ipprtp(ir13)) .eq.' ') then
-    nomvar(ipprtp(ir13)) = 'R13'
-  endif
-  if (nomvar(ipprtp(ir23)) .eq.' ') then
-    nomvar(ipprtp(ir23)) = 'R23'
-  endif
-  if (nomvar(ipprtp(iep)) .eq.' ') then
-    nomvar(ipprtp(iep)) = 'Turb Dissipation'
-  endif
-  if (iturb.eq.32) then
-    if (nomvar(ipprtp(ial)) .eq.' ') then
-      nomvar(ipprtp(ial)) = 'Alphap'
-    endif
-  endif
-elseif (itytur.eq.5) then
-  if (nomvar(ipprtp(ik)) .eq.' ') then
-    nomvar(ipprtp(ik)) = 'Turb Kinetic Energy'
-  endif
-  if (nomvar(ipprtp(iep)) .eq.' ') then
-    nomvar(ipprtp(iep)) = 'Turb Dissipation'
-  endif
-  if (nomvar(ipprtp(iphi)) .eq.' ') then
-    nomvar(ipprtp(iphi)) = 'Phi'
-  endif
-  if (iturb.eq.50) then
-    if (nomvar(ipprtp(ifb)) .eq.' ') then
-      nomvar(ipprtp(ifb)) = 'f_bar'
-    endif
-  elseif (iturb.eq.51) then
-    if (nomvar(ipprtp(ial)) .eq.' ') then
-      nomvar(ipprtp(ial)) = 'Alpha'
-    endif
-  endif
-elseif (iturb.eq.60) then
-  if (nomvar(ipprtp(ik)) .eq.' ') then
-    nomvar(ipprtp(ik)) = 'Turb Kinetic Energy'
-  endif
-  if (nomvar(ipprtp(iomg)) .eq.' ') then
-    nomvar(ipprtp(iomg)) = 'Omega'
-  endif
-elseif (iturb.eq.70) then
-  if (nomvar(ipprtp(inusa)) .eq.' ') then
-    nomvar(ipprtp(inusa)) = 'NuTilda'
-  endif
+if (icorio.eq.1) then
+  call field_set_key_str(ivarfl(ipr), keylbl, 'Rel Pressure')
+  call field_set_key_str(ivarfl(iu), keylbl, 'Rel Velocity')
 endif
 
-if (nomvar(ipppro(ipproc(irom))) .eq.' ') then
-  nomvar(ipppro(ipproc(irom))) = 'Density'
-endif
-if (nomvar(ipppro(ipproc(ivisct))) .eq.' ') then
-  nomvar(ipppro(ipproc(ivisct))) = 'Turb Viscosity'
-endif
-if (nomvar(ipppro(ipproc(iviscl))) .eq.' ') then
-  nomvar(ipppro(ipproc(iviscl))) = 'Laminar Viscosity'
-endif
-if (ismago.gt.0) then
-  if (nomvar(ipppro(ipproc(ismago))) .eq.' ') then
-    nomvar(ipppro(ipproc(ismago))) = 'Csdyn2'
-  endif
-endif
-if (icp.gt.0) then
-  if (nomvar(ipppro(ipproc(icp))) .eq.' ') then
-    nomvar(ipppro(ipproc(icp))) = 'Specific Heat'
-  endif
-endif
-if (iescal(iespre).gt.0) then
-  ipp = ipppro(ipproc(iestim(iespre)))
-  if (nomvar(ipp) .eq.' ') then
-    write(nomvar(ipp),'(a5,i1)') 'EsPre',iescal(iespre)
-  endif
-endif
-if (iescal(iesder).gt.0) then
-  ipp = ipppro(ipproc(iestim(iesder)))
-  if (nomvar(ipp) .eq.' ') then
-    write(nomvar(ipp),'(a5,i1)') 'EsDer',iescal(iesder)
-  endif
-endif
-if (iescal(iescor).gt.0) then
-  ipp = ipppro(ipproc(iestim(iescor)))
-  if (nomvar(ipp) .eq.' ') then
-    write(nomvar(ipp),'(a5,i1)') 'EsCor',iescal(iescor)
-  endif
-endif
-if (iescal(iestot).gt.0) then
-  ipp = ipppro(ipproc(iestim(iestot)))
-  if (nomvar(ipp) .eq.' ') then
-    write(nomvar(ipp),'(a5,i1)') 'EsTot',iescal(iestot)
-  endif
+! Logging and postprocessing output
+
+if (itytur.eq.4) then
+  call hide_property(ivisct)
 endif
 
-if (iscalt.gt.0.and.iscalt.le.nscal) then
-  if (nomvar(ipprtp(isca(iscalt))) .eq.' ') then
-    if (itherm.eq.1) then
-      nomvar(ipprtp(isca(iscalt))) = 'Temperature'
-    else if (itherm.eq.2) then
-      nomvar(ipprtp(isca(iscalt))) = 'Enthalpy'
-    else if (itherm.eq.3) then
-      nomvar(ipprtp(isca(iscalt))) = 'Total Energy'
-    endif
-  endif
-endif
-
-do jj = 1, nscaus
-  ii = jj
-  if (nomvar(ipprtp(isca(ii))) .eq.' ') then
-    write(nomvar(ipprtp(isca(ii))),'(a5,i3.3)') 'Scaus', ii
-  endif
-enddo
-do jj = 1, nscapp
-  ii = iscapp(jj)
-  if (nomvar(ipprtp(isca(ii))) .eq.' ') then
-    write(nomvar(ipprtp(isca(ii))), '(a5,i3.3)') 'Scapp', ii
-  endif
-enddo
-
-if (nbmomt.gt.0) then
-  do imom = 1, nbmomt
-    ipp = ipppro(ipproc(icmome(imom)))
-    if (nomvar(ipp) .eq.' ') then
-      write(nomvar(ipp), '(a6,i2.2)') 'MoyTps', imom
-    endif
-  enddo
-endif
-
-! total pressure (not defined in compressible case)
-if (ippmod(icompf).lt.0) then
-  ipp = ipppro(ipproc(iprtot))
-  if (nomvar(ipp) .eq.' ') then
-    nomvar(ipp)   = 'Total Pressure'
-  endif
-endif
-
-ipp = ipppro(ipproc(icour))
-if (nomvar(ipp) .eq.' ') then
-  nomvar(ipp) = 'CFL'
-endif
-
-ipp = ipppro(ipproc(ifour))
-if (nomvar(ipp) .eq.' ') then
-  nomvar(ipp) = 'Fourier Number'
-endif
-
-if (nomvar(ippdt) .eq.' ') then
-  nomvar(ippdt) = 'Local Time Step'
-endif
-
-if (nomvar(ipptx) .eq.' ') then
-  nomvar(ipptx) = 'Tx'
-endif
-if (nomvar(ippty) .eq.' ') then
-  nomvar(ippty) = 'Ty'
-endif
-if (nomvar(ipptz) .eq.' ') then
-  nomvar(ipptz) = 'Tz'
-endif
-
-if (iale.eq.1) then
-  if (nomvar(ipprtp(iuma)) .eq.' ') then
-    nomvar(ipprtp(iuma)) = 'Mesh VelocityX'
-  endif
-  if (nomvar(ipprtp(ivma)) .eq.' ') then
-    nomvar(ipprtp(ivma)) = 'Mesh VelocityY'
-  endif
-  if (nomvar(ipprtp(iwma)) .eq.' ') then
-    nomvar(ipprtp(iwma)) = 'Mesh VelocityZ'
-  endif
-  if (iortvm.eq.0) then
-    if (nomvar(ipppro(ipproc(ivisma(1)))) .eq.' ') then
-      nomvar(ipppro(ipproc(ivisma(1)))) = 'Mesh ViscX'
-    endif
-  else
-    if (nomvar(ipppro(ipproc(ivisma(1)))) .eq.' ') then
-      nomvar(ipppro(ipproc(ivisma(1)))) = 'Mesh ViscX'
-    endif
-    if (nomvar(ipppro(ipproc(ivisma(2)))) .eq.' ') then
-      nomvar(ipppro(ipproc(ivisma(2)))) = 'Mesh ViscY'
-    endif
-    if (nomvar(ipppro(ipproc(ivisma(3)))) .eq.' ') then
-      nomvar(ipppro(ipproc(ivisma(3)))) = 'Mesh ViscZ'
-    endif
-  endif
-endif
-
-! ---> Sorties listing
-
-ipp = ipppro(ipproc(irom))
-if (irovar.eq.1.and.ilisvr(ipp).eq.-999) ilisvr(ipp) = 1
-ipp = ipppro(ipproc(ivisct))
-if ((iturb.eq.10 .or. itytur.eq.2                 &
-     .or. itytur.eq.5 .or. iturb.eq.60            &
-     .or. iturb.eq.70)                            &
-     .and.ilisvr(ipp).eq.-999) ilisvr(ipp) = 1
-if (inusa .gt. 0) then
-  ipp = ipppro(ipproc(inusa))
-  if (iturb.eq.70.and.ilisvr(ipp).eq.-999) ilisvr(ipp) = 1
-endif
-ipp = ipppro(ipproc(icour))
 if (idtvar.lt.0) then
-  ilisvr(ipp) = 0
-else if (ilisvr(ipp).eq.-999) then
-  ilisvr(ipp) = 1
+  call hide_property(icour)
+  call hide_property(ifour)
 endif
-ipp = ipppro(ipproc(ifour))
-if (idtvar.lt.0) then
-  ilisvr(ipp) = 0
-else if (ilisvr(ipp).eq.-999) then
-  ilisvr(ipp) = 1
-endif
-if (iescal(iespre).gt.0) then
-  ipp = ipppro(ipproc(iestim(iespre)))
-  if (ilisvr(ipp).eq.-999) ilisvr(ipp) = 1
-endif
-if (iescal(iesder).gt.0) then
-  ipp = ipppro(ipproc(iestim(iesder)))
-  if (ilisvr(ipp).eq.-999) ilisvr(ipp) = 1
-endif
-if (iescal(iescor).gt.0) then
-  ipp = ipppro(ipproc(iestim(iescor)))
-  if (ilisvr(ipp).eq.-999) ilisvr(ipp) = 1
-endif
-if (iescal(iestot).gt.0) then
-  ipp = ipppro(ipproc(iestim(iestot)))
-  if (ilisvr(ipp).eq.-999) ilisvr(ipp) = 1
-endif
-
-if (nbmomt.gt.0) then
-  do imom = 1, nbmomt
-    ipp = ipppro(ipproc(icmome(imom)))
-    if (ilisvr(ipp).eq.-999) ilisvr(ipp) = 1
-  enddo
-endif
-
-if (ilisvr(ippdt).eq.-999) ilisvr(ippdt)  = 1
-if (ipucou.ne.1 .or. idtvar.lt.0) then
-  ilisvr(ipptx) = 0
-  ilisvr(ippty) = 0
-  ilisvr(ipptz) = 0
-endif
-
-do ii = 2, nvppmx
-  if (itrsvr(ii).ge.1.and.ilisvr(ii).eq.-999) then
-    ilisvr(ii) = 1
-  endif
-enddo
-do ii = 1, nvppmx
-  if (ilisvr(ii).eq.-999) then
-    ilisvr(ii) = 0
-  endif
-enddo
-
-
 
 !===============================================================================
 ! 2. POSITION DES VARIABLES DE numvar
@@ -644,6 +324,18 @@ elseif (ischtp.eq.2) then
   thetav(ipr) = 1.d0
 endif
 
+!     Taux de vide en diphasique homogene
+if (icavit.ge.0) then
+  if (abs(thetav(ivoidf)+999.d0).gt.epzero) then
+    write(nfecra,1031) 'TAUX DE VIDE','THETAV'
+    iok = iok + 1
+  elseif (ischtp.eq.1) then
+    thetav(ivoidf) = 1.d0
+  elseif (ischtp.eq.2) then
+    thetav(ivoidf) = 0.5d0
+  endif
+endif
+
 !     Turbulence (en k-eps : ordre 1)
 if (itytur.eq.2) then
   if (abs(thetav(ik )+999.d0).gt.epzero.or.               &
@@ -685,14 +377,29 @@ elseif (itytur.eq.3) then
     thetav(ir23) = 0.5d0
     thetav(iep ) = 0.5d0
   endif
-  ! Daly Harlow (GGDH) on Rij and epsilon by Default
-  idften(ir11) = 6
-  idften(ir22) = 6
-  idften(ir33) = 6
-  idften(ir12) = 6
-  idften(ir23) = 6
-  idften(ir13) = 6
-  idften(iep)  = 6
+
+  ! Diffusivity model:
+
+  ! Daly Harlow (GGDH) on Rij and epsilon by default
+  if (idirsm.ne.0) then
+    idften(ir11) = 6
+    idften(ir22) = 6
+    idften(ir33) = 6
+    idften(ir12) = 6
+    idften(ir23) = 6
+    idften(ir13) = 6
+    idften(iep)  = 6
+
+  ! Scalar diffusivity (Shir model) elswhere (idirsm = 0)
+  else
+    idften(ir11) = 1
+    idften(ir22) = 1
+    idften(ir33) = 1
+    idften(ir12) = 1
+    idften(ir23) = 1
+    idften(ir13) = 1
+    idften(iep)  = 1
+  endif
 
   if (iturb.eq.32) then
     if (abs(thetav(ial)+999.d0).gt.epzero) then
@@ -826,22 +533,41 @@ enddo
 
 ! ---> BLENCV
 !        Si l'utilisateur n'a rien specifie pour le schema convectif
-!                  1 (ie centre) pour les vitesses et
-!                                      les scalaires utilisateurs
+!                  1 (ie centre) pour les vitesses
+!                                     les scalaires utilisateurs
+!                                     le scalaire thermique
 !                  0 (ie upwind pur) pour le reste
 !   (en particulier, en L.E.S. toutes les variables sont donc en centre)
 
+!  Pour le modele de cavitation on force dans tous les cas le taux de vide en
+!  upwind et on affiche un message si l'utilisateur avait specifie autre chose
+
 ii = iu
 if (abs(blencv(ii)+999.d0).lt.epzero) blencv(ii) = 1.d0
 ii = iv
 if (abs(blencv(ii)+999.d0).lt.epzero) blencv(ii) = 1.d0
 ii = iw
 if (abs(blencv(ii)+999.d0).lt.epzero) blencv(ii) = 1.d0
+
+if (icavit.ge.0) then
+  ii = ivoidf
+  if (abs(blencv(ii)).gt.epzero) then
+    if (abs(blencv(ii)+999.d0).gt.epzero) &
+         write(nfecra,3000) 0.d0, blencv(ii)
+    blencv(ii) = 0.d0
+  endif
+endif
+
 do jj = 1, nscaus
   ii = isca(jj)
   if (abs(blencv(ii)+999.d0).lt.epzero) blencv(ii) = 1.d0
 enddo
 
+if (iscalt.gt.0) then
+  ii = isca(iscalt)
+  if (abs(blencv(ii)+999.d0).lt.epzero) blencv(ii) = 1.d0
+endif
+
 do ii = 1, nvarmx
   if (abs(blencv(ii)+999.d0).lt.epzero) then
     blencv(ii) = 0.d0
@@ -911,8 +637,10 @@ endif
 !          gradients (=-999),
 !        On impose -1 avec gradrc (pas de limitation)
 !               et  1 avec gradmc (limitation)
+imrgrp = abs(imrgra)
+if (imrgrp.ge.10) imrgrp = imrgrp - 10
 
-if (imrgra.eq.0.or.imrgra.ge.4.or.imrgra.le.-4) then
+if (imrgrp.eq.0.or.imrgrp.ge.4) then
   do ii = 1, nvarmx
     if (imligr(ii).eq.-999) then
       imligr(ii) = -1
@@ -1094,7 +822,9 @@ endif
 if (nscal.gt.0) then
   do ii = 1, nscal
     if (iscacp(ii).eq.-10)then
-      if (ii.ne.iscalt) then
+      if (ii.eq.iscalt .and. itherm.eq.1) then
+        iscacp(ii) = 1
+      else
         iscacp(ii) = 0
       endif
     endif
@@ -1114,18 +844,6 @@ if (icalhy.ne.-1.and.icalhy.ne.0.and.icalhy.ne.1) then
 endif
 
 
-! ---> IDGMOM
-!      Calcul du degre des moments
-
-do imom = 1, nbmomx
-  idgmom(imom) = 0
-enddo
-do imom = 1, nbmomt
-  do ii = 1, ndgmox
-    if (idfmom(ii,imom).ne.0) idgmom(imom) = idgmom(imom) + 1
-  enddo
-enddo
-
 ! ---> ICDPAR
 !      Calcul de la distance a la paroi. En standard, on met ICDPAR a -1, au cas
 !      ou les faces de bord auraient change de type d'un calcul a l'autre. En k-omega,
@@ -1152,7 +870,7 @@ if ((iturb.eq.30.and.irijec.eq.1).or.              &
   ineedy = 1
 endif
 
-if (imrgra.eq.0 .or. imrgra.ge.4 .or. imrgra.le.-4) then
+if (imrgrp.eq.0 .or. imrgrp.ge.4) then
   if (imligy.eq.-999) then
     imligy = -1
   endif
@@ -1270,10 +988,14 @@ else
   sigmae = 1.30d0
 endif
 
-if (iturb.eq.32) then
-  csrij = 0.21d0
+if (idirsm.eq.0) then
+  csrij = 0.11d0
 else
-  csrij = 0.22d0
+  if (iturb.eq.32) then
+    csrij = 0.21d0
+  else
+    csrij = 0.22d0
+  endif
 endif
 
 ! ---> ICLVFL
@@ -1300,6 +1022,16 @@ enddo
 ! Elles sont prises egales aux valeurs correspondantes pour le
 ! scalaire associe.
 
+if (iscalt.gt.0) then
+  if (visls0(iscalt).lt.-grand) then
+    if (itherm .eq. 1) then
+      visls0(iscalt) = viscl0
+    else if (itherm .eq. 2) then
+      visls0(iscalt) = viscl0 / cp0
+    endif
+  endif
+endif
+
 if (nscaus.gt.0) then
   do jj = 1, nscaus
     if (iscavr(jj).le.0 .and. visls0(jj).lt.-grand) then
@@ -1340,11 +1072,8 @@ enddo
 ! Turbulent fluxes constant for GGDH, AFM and DFM
 if (nscal.gt.0) then
   do iscal = 1, nscal
-    if (iturt(iscal).eq.0) then
-      idften(isca(iscal)) = 1
-
     ! AFM and GGDH on the scalar
-    elseif (ityturt(iscal).eq.1.or.ityturt(iscal).eq.2) then
+    if (ityturt(iscal).eq.1.or.ityturt(iscal).eq.2) then
       idften(isca(iscal)) = 6
       ctheta(iscal) = cthafm
 
@@ -1362,6 +1091,8 @@ if (nscal.gt.0) then
           ctheta(ii) = csrij
         endif
       enddo
+    else
+      ctheta(iscal) = csrij
     endif
   enddo
 endif
@@ -1666,6 +1397,23 @@ endif
 '@  Le calcul sera execute.',                                   /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /)
+ 3000 format(                                                     &
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /,&
+'@ @@ ATTENTION :       A L''ENTREE DES DONNEES',               /,&
+'@    =========',                                               /,&
+'@',                                                            /,&
+'@  Le modele de cavitation necessite un schema upwind pour la',/,&
+'@    convection du taux de vide (BLENCV(IVOIDF)=',e14.5,').',  /,&
+'@  L''utilisateur a choisi BLENCV(IVOIDF)=',e14.5,             /,&
+'@',                                                            /,&
+'@  Le schema upwind pour le taux de vide est force.',          /,&
+'@',                                                            /,&
+'@  Le calcul sera execute.',                                   /,&
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
 
 #else
@@ -1840,6 +1588,23 @@ endif
 '@  The calculation will be run.',                              /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /)
+ 3000 format(                                                     &
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@',                                                            /,&
+'@ @@ WARNING:       IN THE DATA SPECIFICATION',                /,&
+'@    ========',                                                /,&
+'@',                                                            /,&
+'@  The cavitation model requires an upwind convection scheme' ,/,&
+'@    for the void fraction (BLENCV(IVOIDF)=',e14.5,').',       /,&
+'@  The user has set BLENCV(IVOIDF)=',e14.5,                    /,&
+'@',                                                            /,&
+'@  The upwind scheme for the void fraction is forced.',        /,&
+'@',                                                            /,&
+'@  The calculation will be run.',                              /,&
+'@',                                                            /,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
 
 #endif
