@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -48,78 +48,107 @@ module numvar
   !> \addtogroup main_variables
   !> \{
 
+  !> \anchor ipr
   !> pressure
   integer, save :: ipr
 
+  !> \anchor iu
   !> velocity component \f$ u_x \f$
   integer, save :: iu
 
+  !> \anchor iv
   !> velocity component \f$ u_y \f$
   integer, save :: iv
 
+  !> \anchor iw
   !> velocity component \f$ u_z \f$
   integer, save :: iw
 
+  !> \anchor ivoidf
+  !> void fraction for cavitation modelling
+  integer, save :: ivoidf
+
+  !> \anchor ik
   !> turbulent kinetic energy \f$ k \f$
   integer, save :: ik
 
+  !> \anchor iep
   !> turbulent dissipation \f$ \varepsilon \f$
   integer, save :: iep
 
+  !> \anchor ir11
   !> Reynolds stress component \f$ R_{xx} \f$
   integer, save :: ir11
 
+  !> \anchor ir22
   !> Reynolds stress component \f$ R_{yy} \f$
   integer, save :: ir22
 
+  !> \anchor ir33
   !> Reynolds stress component \f$ R_{zz} \f$
   integer, save :: ir33
 
+  !> \anchor ir12
   !> Reynolds stress component \f$ R_{xy} \f$
   integer, save :: ir12
 
+  !> \anchor ir23
   !> Reynolds stress component \f$ R_{yz} \f$
   integer, save :: ir23
 
+  !> \anchor ir13
   !> Reynolds stress component \f$ R_{zz} \f$
   integer, save :: ir13
 
+  !> \anchor iphi
   !> variable \f$ \phi \f$ of the \f$ \phi-f_b \f$ model
   integer, save :: iphi
 
+  !> \anchor ifb
   !> variable \f$ f_b \f$ of the \f$ \phi-f_b \f$ model
   integer, save :: ifb
 
+  !> \anchor ial
   !> variable \f$ \alpha \f$ of the \f$ Bl-v^2-k \f$ model
   integer, save :: ial
 
+  !> \anchor iomg
   !> variable \f$ \omega \f$ of the \f$ k-\omega \f$ SST
   integer, save :: iomg
 
+  !> \anchor inusa
   !> variable \f$ \widetilde{\nu}_T \f$ of the Spalart Allmaras
   integer, save :: inusa
 
+  !> \anchor isca
   !> isca(i) is the index of the scalar i
   integer, save :: isca(nscamx)
 
+  !> \anchor iscapp
   !> iscapp(i) is the index of the specific physics scalar i
   integer, save :: iscapp(nscamx)
 
+  !> \anchor nscaus
   !> number of user scalars
   integer, save :: nscaus
 
+  !> \anchor nscapp
   !> number of specific physics scalars
   integer, save :: nscapp
 
+  !> \anchor nscasp
   !> number of species scalars
   integer, save :: nscasp
 
+  !> \anchor iuma
   !> mesh velocity component \f$ w_x \f$
   integer, save :: iuma
 
+  !> \anchor ivma
   !> mesh velocity component \f$ w_y \f$
   integer, save :: ivma
 
+  !> \anchor iwma
   !> mesh velocity component \f$ w_z \f$
   integer, save :: iwma
 
@@ -145,6 +174,9 @@ module numvar
   !> Density at the previous time step
   integer, save :: iroma
 
+  !> Density at the second previous time
+  integer, save :: iromaa
+
   !> dynamic molecular viscosity (in kg/(m.s))
   integer, save :: iviscl
 
@@ -178,15 +210,27 @@ module numvar
   !> interior and boundary convective mass flux key ids of the variables
   integer, save :: kimasf, kbmasf
 
+  !> variable diffusivity field id key for scalars
+  integer, save :: kivisl
+
   !> convective mass flux of the variables at the previous time-step
   integer, save :: ifluaa(nvarmx)
 
-  !> cell and boundary density key ids of the variables
+  !> cell and boundary density field ids of the variables
   integer, save :: icrom, ibrom
 
+  !> cell density at the second previous time step key id of the variables
+  integer, save :: icroaa
+
+  !> field ids of the cell porosity
+  integer, save :: ipori, iporf
+
   !> dynamic constant of Smagorinsky
   integer, save :: ismago
 
+  !> field id of the anisotropic turbulent viscosity
+  integer, save :: ivsten
+
   !> Courant number
   integer, save :: icour
 
@@ -210,34 +254,11 @@ module numvar
   !> pointer for thermal expansion coefficient
   integer, save :: ibeta
 
-  !> \}
+  !> field id of the stresses at boundary  (if post-processed)
+  integer, save :: iforbr
 
-  !----------------------------------------------------------------------------
-  ! Boundary conditions coefficients
-  !----------------------------------------------------------------------------
-
-  !>\defgroup bc_coeffs Boundary conditions coefficients
-  !> \brief Boundary condition coefficient are stored in coefa and coefb.
-  !> See \ref condli and the theory guide for more information.
-
-  !> \addtogroup bc_coeffs
-  !> \{
-
-  !> Coefficients used for gradient terms and convective terms
-  integer, save :: icoef
-
-  !> Coefficients used for diffusive terms
-  integer, save :: icoeff
-
-  !> Coefficients used for divergence terms
-  !> (for example \f$ \tens{R}_{ij} \f$ in the momentum equation)
-  integer, save :: icoefr
-
-  !> Coefficients used for convection terms
-  integer, save :: icoefc
-
-  !> pointer to coefa and coefb arrays
-  integer, save :: iclrtp(nvarmx,4)
+  !>  field id of \f$y^+\f$ at boundary (if post-processed)
+  integer, save :: iyplbr
 
   !> \}
 
