@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -109,7 +109,7 @@ module optcal
 
   !> number of interations on the pressure-velocity coupling on Navier-Stokes
   !> (for the PISO algorithm)
-  integer, save ::          nterup
+  integer(c_int), pointer, save ::          nterup
 
   !> extrapolation of source terms in the Navier-Stokes equations
   !>    - 1: true
@@ -155,6 +155,11 @@ module optcal
   !> initcp : =1 si  chaleur specifique relue dans un suite
   integer, save ::          initcp
 
+  !> ibdtso : backward differential scheme in time order
+  ! TODO: only for velocity prediction step at the moment, ibdtso should be
+  ! updated to array of size nscamx.
+  integer, save ::          ibdtso
+
   !> initvs : =1 si  diffusivite scalaire relue dans un suite
   integer, save ::          initvs(nscamx)
 
@@ -214,14 +219,14 @@ module optcal
 
   !> relative precision for the convergence test of the iterative process on
   !> pressure-velocity coupling (PISO)
-  double precision, save :: epsup
+  real(c_double), pointer, save :: epsup
 
   !> norm  of the increment \f$ \vect{u}^{k+1} - \vect{u}^k \f$
   !> of the iterative process on pressure-velocity coupling (PISO)
-  double precision, save :: xnrmu
+  real(c_double), pointer, save :: xnrmu
 
   !> norm of \f$ \vect{u}^0 \f$ (used by PISO algorithm)
-  double precision, save :: xnrmu0
+  real(c_double), pointer, save :: xnrmu0
 
   !> \}
 
@@ -256,7 +261,7 @@ module optcal
   !> method to compute interior mass flux due to ALE mesh velocity
   !>    - 1: based on cell center mesh velocity
   !>    - 0: based on nodes displacement
-  integer, save ::          iflxmw
+  integer(c_int), pointer, save :: iflxmw
 
   !> \}
 
@@ -266,16 +271,16 @@ module optcal
 
   !> type of gradient reconstruction
   !>    - 0: iterative process
-  !>    - 1: standard least suqare methode
-  !>    - 2: least suqare methode with extended neighbourhood
-  !>    - 3: least suqare methode with reduced extended neighbourhood
-  !>    - 4: iterative precess initialized by the least square methode
-  integer, save ::          imrgra
+  !>    - 1: standard least square method
+  !>    - 2: least square method with extended neighbourhood
+  !>    - 3: least square method with reduced extended neighbourhood
+  !>    - 4: iterative precess initialized by the least square method
+  integer(c_int), pointer, save :: imrgra
 
   !> anomax : angle de non orthogonalite des faces en radian au dela duquel
   !> on retient dans le support etendu des cellules voisines
   !> de la face les cellules dont un noeud est sur la face
-  double precision, save :: anomax
+  real(c_double), pointer, save :: anomax
 
   !> max number of iterations for the iterative gradient
   integer, save ::          nswrgr(nvarmx)
@@ -311,7 +316,7 @@ module optcal
   !> face viscosity field interpolation
   !>    - 1: harmonic
   !>    - 0: arithmetic (default)
-  integer, save :: imvisf
+  integer(c_int), pointer, save :: imvisf
 
   !> \}
 
@@ -505,17 +510,17 @@ module optcal
   !>    - 1: temperature
   !>    - 2: enthalpy
   !>    - 3: total energy (only for compressible module)
-  integer, save :: itherm
+  integer(c_int), pointer, save :: itherm
 
   !> temperature scale
   !>    - 0: none
   !>    - 1: Kelvin
   !>    - 2: Celsius
-  integer, save :: itpscl
+  integer(c_int), pointer, save :: itpscl
 
   !> index of the thermal scalar (temperature, energy of enthalpy),
   !> the index of the corresponding variable is isca(iscalt)
-  integer, save :: iscalt
+  integer(c_int), pointer, save :: iscalt
 
   !> \}
 
@@ -528,6 +533,7 @@ module optcal
   !> \addtogroup turbulence
   !> \{
 
+  !> \anchor iturb
   !> turbulence model
   !>    - 0: no turbulence model (laminar flow)
   !>    - 10: mixing length model
@@ -543,103 +549,108 @@ module optcal
   !>    - 51: v2f \f$ BL-v^2-k \f$
   !>    - 60: \f$ k-\omega \f$ SST
   !>    - 70: Spalart-Allmaras model
-  integer, save :: iturb
+  integer(c_int), pointer, save :: iturb
 
   !> Class of turbulence model (integer value iturb/10)
-  integer, save :: itytur
+  integer(c_int), pointer, save :: itytur
 
   !> Activation of rotation/curvature correction for an eddy viscosity turbulence models
   !>    - 0: false
   !>    - 1: true
-  integer, save :: irccor
+  integer(c_int), pointer, save :: irccor
 
   !> Type of rotation/curvature correction for an eddy viscosity turbulence models
   !>    - 1 Cazalbou correction (default when irccor=1 and itytur=2 or 5)
   !>    - 2 Spalart-Shur correction (default when irccor=1 and iturb=60 or 70)
-  integer, save :: itycor
+  integer(c_int), pointer, save :: itycor
+
+  !> Turbulent diffusion model for second moment closure
+  !>    - 0: scalar diffusivity (Shir model)
+  !>    - 1: tensorial diffusivity (Daly and Harlow model, default model)
+  integer(c_int), pointer, save :: idirsm
 
   !>  Wall functions
   !>    - 0: one scale of friction velocities
   !>    - 1: two scale of friction velocities
   !>    - 2: scalable wall functions
-  integer, save :: ideuch
+  integer(c_int), pointer, save :: ideuch
 
   !> exchange coefficient correlation
   !>    - 0: not use by default
   !>    - 1: exchange coefficient computed with a correlation
-  integer, save :: iwallt
+  integer(c_int), pointer, save :: iwallt
 
   !> wall function with
   !>    - 0 a power lay (deprecated)
   !>    - 1 a log lay
-  integer, save :: ilogpo
+  integer(c_int), pointer, save :: ilogpo
 
   !> clipping of k and epsilon
   !>    - 0 absolute value clipping
   !>    - 1 coupled clipping based on physical relationships
-  integer, save :: iclkep
+  integer(c_int), pointer, save :: iclkep
 
   !> take \f$ 2/3 \rho \grad k \f$ in the momentum equation
   !>    - 1: true
   !>    - 0: false (default)
-  integer, save :: igrhok
+  integer(c_int), pointer, save :: igrhok
 
   !> buoyant term in \f$ k- \varepsilon \f$
   !>    - 1: true (default if \f$ \rho \f$ is variable)
   !>    - 0: false
-  integer, save :: igrake
+  integer(c_int), pointer, save :: igrake
 
   !> buoyant term in \f$ R_{ij}- \varepsilon \f$
   !>    - 1: true (default if \f$ \rho \f$ is variable)
   !>    - 0: false
-  integer, save :: igrari
+  integer(c_int), pointer, save :: igrari
 
   !> partially coupled version of \f$ k-\varepsilon \f$ (only for iturb=20)
   !>    - 1: true (default)
   !>    - 0: false
-  integer, save :: ikecou
+  integer(c_int), pointer, save :: ikecou
 
   !> pseudo eddy viscosity in the matrix of momentum equation to partially
   !> implicit \f$ \divv \left( \rho \tens{R} \right) \f$
   !>    - 1: true
   !>    - 0: false (default)
-  integer, save :: irijnu
+  integer(c_int), pointer, save :: irijnu
 
   !> accurate treatment of \f$ \tens{R} \f$ at the boundary (see \ref condli)
   !>    - 1: true
   !>    - 0: false (default)
-  integer, save :: irijrb
+  integer(c_int), pointer, save :: irijrb
 
   !> wall echo term of \f$ \tens{R} \f$
   !>    - 1: true
   !>    - 0: false (default)
-  integer, save :: irijec
+  integer(c_int), pointer, save :: irijec
 
   !> whole treatment of the diagonal part of the dissusion tensor of
   !> \f$ \tens{R} \f$ and \f$ \varepsilon \f$
   !>    - 1: true (default)
   !>    - 0: simplified treatment
-  integer, save :: idifre
+  integer(c_int), pointer, save :: idifre
 
   !> partial implicitation of symmetry BCs of \f$ \tens{R} \f$
   !>    - 1: true (default)
   !>    - 0: false
-  integer, save :: iclsyr
+  integer(c_int), pointer, save :: iclsyr
 
   !> partial implicitation of wall BCs of \f$ \tens{R} \f$
   !>    - 1: true
   !>    - 0: false (default)
-  integer, save :: iclptr
+  integer(c_int), pointer, save :: iclptr
 
   !> Van Driest smoothing at the wall (only for itytur=4)
   !>    - 1: true
   !>    - 0: false
-  integer, save :: idries
+  integer(c_int), pointer, save :: idries
 
   !> vortex method (in LES)
   !>    - 1: true
   !>    - 0: false (default)
-  integer, save :: ivrtex
+  integer(c_int), pointer, save :: ivrtex
 
   !> turbulent flux model for \f$ \overline{\varia^\prime \vect{u}^\prime} \f$
   !> for any scalar \f$ \varia \f$, iturt(isca)
@@ -659,8 +670,8 @@ module optcal
   integer, save :: ifltur(nscamx)
 
   !> number of variable plus number of turbulent fluxes
-  !> (used by the Boundary Conditions)
-  integer, save :: nvarcl
+  !> (used by the boundary conditions)
+  integer(c_int), pointer, save :: nvarcl
 
   !> \}
 
@@ -677,37 +688,38 @@ module optcal
   !> into account in the momentum equation
   !>    - 1: true (default)
   !>    - 0: false
-  integer, save :: ivisse
+  integer(c_int), pointer, save :: ivisse
 
   !> Reconstruction of the velocity field with the updated pressure option
   !>    - 0: default
-  integer, save ::          irevmc
+  integer(c_int), pointer, save ::          irevmc
 
   !> Compute the pressure step thanks to the continuity equation
   !>    - 1: true (default)
   !>    - 0: false
-  integer, save ::          iprco
+  integer(c_int), pointer, save ::          iprco
 
   !> Compute the normed residual for the pressure step in the prediction step
   !>    - 1: true (default)
   !>    - 0: false
-  integer, save ::          irnpnw
+  integer(c_int), pointer, save ::          irnpnw
 
   !> normed residual for the pressure step
-  double precision, save :: rnormp
+  real(c_double), pointer, save :: rnormp
 
   !> Arakawa multiplicator for the Rhie and Chow filter (1 by default)
-  double precision, save :: arak
+  real(c_double), pointer, save :: arak
 
   !> Pseudo coupled pressure-velocity solver
   !>    - 1: true
   !>    - 0: false (default)
-  integer, save :: ipucou
+  integer(c_int), pointer, save :: ipucou
 
+  !> \anchor iccvfg
   !> calculation with a fixed velocity field
   !>    - 1: true
   !>    - 0: false (default)
-  integer, save :: iccvfg
+  integer(c_int), pointer, save :: iccvfg
 
   !> Algorithm to take into account the density variation in time
   !>    - 1: dilatable steady algorithm (default)
@@ -715,10 +727,10 @@ module optcal
   !>    - 3: low-Mach algorithm
   !>    - 4: algorithm for fire
   !    - 0: boussinesq algorithm with constant density
-  integer, save :: idilat
+  integer(c_int), pointer, save :: idilat
 
   !> parameter of diagonal pressure strengthening
-  double precision, save :: epsdp
+  real(c_double), pointer, save :: epsdp
 
   !TODO doxygen
   ! Type des conditions limites et index min et max
@@ -728,8 +740,8 @@ module optcal
   !> accurate treatment of the wall temperature
   !>    - 1: true
   !>    - 0: false (default)
-  !> (see \ref condli, usefull in case of coupling with syrthes)
-  integer, save :: itbrrb
+  !> (see \ref condli, useful in case of coupling with syrthes)
+  integer(c_int), pointer, save :: itbrrb
 
   !> indicates if the scalar isca is coupled with syrthes
   !>    - 1: coupled with syrthes
@@ -743,26 +755,26 @@ module optcal
   !>    - 1: impose the equilibrium of the hydrostaic part of the pressure with any external force, even head losses
   !>    - 2: compute an hydrostatic pressure due to buoyancy forces before the prediction step
   !>    - 0: no treatment (default)
-  integer, save :: iphydr
+  integer(c_int), pointer, save :: iphydr
 
 
   !> indicates the presence of a Bernoulli boundary face (automatically computed)
   !>    - 0: no face
   !>    - 1: at least one face
-  integer, save :: iifren
+  integer(c_int), pointer, save :: iifren
 
   !> compute the hydrostatic pressure in order to compute the Dirichlet
   !> conditions on the pressure at outlets
   !>    - 1: true
   !>    - 0: false (default)
-  integer, save :: icalhy
+  integer(c_int), pointer, save :: icalhy
 
   !TODO doxygen
   ! icond: Handling condensation source terms
   !        1: condensation source terms activated
   !        2: condensation source terms with metal structures activated
   !        0: by default (without condensation source terms)
-  integer, save :: icond
+  integer(c_int), pointer, save :: icond
 
   !> compute error estimators
   !>    - 1: true
@@ -771,6 +783,23 @@ module optcal
 
   !> \}
 
+  !----------------------------------------------------------------------------
+  ! Homogeneous mixture modelling
+  !----------------------------------------------------------------------------
+
+  !> \defgroup homegeneous_mixture Homogeneous mixture modelling
+
+  !> \addtogroup homegeneous_mixture
+  !> \{
+
+  !> cavitation module
+  !>    - -1: module not activated
+  !>    -  0: no vaporization/condensation model
+  !>    -  1: Merkle's model
+  integer, save :: icavit
+
+  !> \}
+
   !----------------------------------------------------------------------------
   ! Temporal mean and moments calculation
   !----------------------------------------------------------------------------
@@ -783,9 +812,6 @@ module optcal
   !> number of moments
   integer, save ::          nbmomt
 
-  !> nombre de tableaux ncel pour le temps cumule
-  integer, save ::          nbdtcm
-
   !> index of the initial time step for computing the moment
   integer, save ::          ntdmom(nbmomx)
 
@@ -796,25 +822,8 @@ module optcal
   !>           s'utilise ainsi propce(iel,ipproc(icmome(imom)))
   integer, save ::          icmome(nbmomx)
 
-  !> numero du temps cumule associe aux moments
-  !> ce numero va de 1 a n pour les temps cumules non uniformes
-  !> et de -1 a -p pour les temps cumules uniformes
-  !> s'utilise ainsi
-  !>    - si idtmom(imom) > 0 propce(iel,ipropc(icdtmo(idtmom(imom))))
-  !>    - si idtmom(imom) < 0 dtcmom(-idtmom(imom))
-  integer, save ::          idtmom(nbmomx)
-
-  !> numero des variables composant le moment idfmom(jj,imom)
-  integer, save ::          idfmom(ndgmox,nbmomx)
-
-  !> moment degree
-  integer, save ::          idgmom(nbmomx)
-
-  !> numero de propriete du temps cumule (voir idtmom)
-  integer, save ::          icdtmo(nbmomx)
-
-  !> valeur du pas de temps cumule quand il est uniforme (see \ref idtmom).
-  double precision, save :: dtcmom(nbmomx)
+  !> numero des champs composant le moment idfmom(ic,jj,imom)
+  integer, save ::          idfmom(2,ndgmox,nbmomx)
 
   !> initial time for computing the moment
   double precision, save :: ttdmom(nbmomx)
@@ -985,10 +994,6 @@ module optcal
   !>          1 : le scalaire associe est une espece
   integer, save ::          iscasp(nscamx)
 
-  !> scamin, scamax : min et max pour clipping des scalaires
-  !>                  on ne clippe que si scamin < scamax
-  double precision, save :: scamin(nscamx), scamax(nscamx)
-
   !> visls0 : viscosite des scalaires si constante
   double precision, save :: visls0(nscamx)
 
@@ -1044,6 +1049,26 @@ module optcal
 
     !---------------------------------------------------------------------------
 
+    ! Interface to C function defining whether time step is variable in
+    ! time or not
+
+    subroutine time_step_define_variable(is_variable)  &
+      bind(C, name='cs_time_step_define_variable')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      integer(c_int), value :: is_variable
+    end subroutine time_step_define_variable
+
+    ! Interface to C function defining whether time step is local in
+    ! space or not
+
+    subroutine time_step_define_local(is_local)  &
+      bind(C, name='cs_time_step_define_local')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      integer(c_int), value :: is_local
+    end subroutine time_step_define_local
+
     ! Interface to C function retrieving pointers to members of the
     ! global time step structure
 
@@ -1056,6 +1081,97 @@ module optcal
       type(c_ptr), intent(out) :: t_prev, t_cur, t_max
     end subroutine cs_f_time_step_get_pointers
 
+    ! Interface to C function retrieving pointers to members of the
+    ! global thermal model structure
+
+    subroutine cs_f_thermal_model_get_pointers(itherm, itpscl, iscalt) &
+      bind(C, name='cs_f_thermal_model_get_pointers')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: itherm, itpscl, iscalt
+    end subroutine cs_f_thermal_model_get_pointers
+
+    ! Interface to C function retrieving pointers to members of the
+    ! global turbulence model structure
+
+    subroutine cs_f_turb_model_get_pointers(iturb, itytur, nvarcl) &
+      bind(C, name='cs_f_turb_model_get_pointers')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: iturb, itytur, nvarcl
+    end subroutine cs_f_turb_model_get_pointers
+
+    ! Interface to C function retrieving pointers to members of the
+    ! global wall functions structure
+
+    subroutine cs_f_wall_functions_get_pointers(ideuch, iwallt, ilogpo) &
+      bind(C, name='cs_f_wall_functions_get_pointers')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: ideuch, iwallt, ilogpo
+    end subroutine cs_f_wall_functions_get_pointers
+
+    ! Interface to C function retrieving pointers to members of the
+    ! RANS turbulence model structure
+
+    subroutine cs_f_turb_rans_model_get_pointers(irccor, itycor, idirsm, &
+                                                 iclkep, igrhok, igrake, &
+                                                 igrari, ikecou, irijnu, &
+                                                 irijrb, irijec, idifre, &
+                                                 iclsyr, iclptr)         &
+      bind(C, name='cs_f_turb_rans_model_get_pointers')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: irccor, itycor, idirsm, iclkep, igrhok
+      type(c_ptr), intent(out) :: igrake, igrari, ikecou, irijnu, irijrb
+      type(c_ptr), intent(out) :: irijec, idifre, iclsyr, iclptr
+    end subroutine cs_f_turb_rans_model_get_pointers
+
+    ! Interface to C function retrieving pointers to members of the
+    ! LES turbulence model structure
+
+    subroutine cs_f_turb_les_model_get_pointers(idries, ivrtex) &
+      bind(C, name='cs_f_turb_les_model_get_pointers')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: idries, ivrtex
+    end subroutine cs_f_turb_les_model_get_pointers
+
+    ! Interface to C function retrieving pointers to members of the
+    ! Stokes options structure
+
+    subroutine cs_f_stokes_options_get_pointers(ivisse, irevmc, iprco, irnpnw, &
+                                                rnormp, arak  ,ipucou, iccvfg, &
+                                                idilat, epsdp ,itbrrb, iphydr, &
+                                                iifren, icalhy, icond )        &
+      bind(C, name='cs_f_stokes_options_get_pointers')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: ivisse, irevmc, iprco, irnpnw, rnormp, arak
+      type(c_ptr), intent(out) :: ipucou, iccvfg, idilat, epsdp, itbrrb, iphydr
+      type(c_ptr), intent(out) :: iifren, icalhy, icond
+    end subroutine cs_f_stokes_options_get_pointers
+
+    ! Interface to C function retrieving pointers to members of the
+    ! global spatial discretisation options structure
+
+    subroutine cs_f_space_disc_get_pointers(imvisf, imrgra, anomax, iflxmw) &
+      bind(C, name='cs_f_space_disc_get_pointers')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: imvisf, imrgra, anomax, iflxmw
+    end subroutine cs_f_space_disc_get_pointers
+
+    ! Interface to C function retrieving pointers to members of the
+    ! global PISO options structure
+
+    subroutine cs_f_piso_get_pointers(nterup, epsup, xnrmu, xnrmu0) &
+      bind(C, name='cs_f_piso_get_pointers')
+      use, intrinsic :: iso_c_binding
+      implicit none
+      type(c_ptr), intent(out) :: nterup, epsup, xnrmu, xnrmu0
+    end subroutine cs_f_piso_get_pointers
+
     !---------------------------------------------------------------------------
 
     !> \endcond DOXYGEN_SHOULD_SKIP_THIS
@@ -1096,6 +1212,202 @@ contains
 
   end subroutine time_step_init
 
+  !> \brief Initialize Fortran thermal model API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine thermal_model_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_itherm, c_itpscl, c_iscalt
+
+    call cs_f_thermal_model_get_pointers(c_itherm, c_itpscl, c_iscalt)
+
+    call c_f_pointer(c_itherm, itherm)
+    call c_f_pointer(c_itpscl, itpscl)
+    call c_f_pointer(c_iscalt, iscalt)
+
+  end subroutine thermal_model_init
+
+  !> \brief Initialize Fortran turbulence model API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine turb_model_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_iturb, c_itytur, c_nvarcl
+
+    call cs_f_turb_model_get_pointers(c_iturb, c_itytur, c_nvarcl)
+
+    call c_f_pointer(c_iturb, iturb)
+    call c_f_pointer(c_itytur, itytur)
+    call c_f_pointer(c_nvarcl, nvarcl)
+
+  end subroutine turb_model_init
+
+  !> \brief Initialize Fortran wall functions API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine wall_functions_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_ideuch, c_iwallt, c_ilogpo
+
+    call cs_f_wall_functions_get_pointers( c_ideuch, c_iwallt, c_ilogpo)
+
+    call c_f_pointer(c_ideuch, ideuch)
+    call c_f_pointer(c_iwallt, iwallt)
+    call c_f_pointer(c_ilogpo, ilogpo)
+
+  end subroutine wall_functions_init
+
+  !> \brief Initialize Fortran RANS turbulence model API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine turb_rans_model_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_irccor, c_itycor, c_idirsm, c_iclkep, c_igrhok, c_igrake
+    type(c_ptr) :: c_igrari, c_ikecou, c_irijnu, c_irijrb, c_irijec, c_idifre
+    type(c_ptr) :: c_iclsyr, c_iclptr
+
+    call cs_f_turb_rans_model_get_pointers( c_irccor, c_itycor, c_idirsm, &
+                                            c_iclkep, c_igrhok, c_igrake, &
+                                            c_igrari, c_ikecou, c_irijnu, &
+                                            c_irijrb, c_irijec, c_idifre, &
+                                            c_iclsyr, c_iclptr)
+
+    call c_f_pointer(c_irccor, irccor)
+    call c_f_pointer(c_itycor, itycor)
+    call c_f_pointer(c_idirsm, idirsm)
+    call c_f_pointer(c_iclkep, iclkep)
+    call c_f_pointer(c_igrhok, igrhok)
+    call c_f_pointer(c_igrake, igrake)
+    call c_f_pointer(c_igrari, igrari)
+    call c_f_pointer(c_ikecou, ikecou)
+    call c_f_pointer(c_irijnu, irijnu)
+    call c_f_pointer(c_irijrb, irijrb)
+    call c_f_pointer(c_irijec, irijec)
+    call c_f_pointer(c_idifre, idifre)
+    call c_f_pointer(c_iclsyr, iclsyr)
+    call c_f_pointer(c_iclptr, iclptr)
+
+  end subroutine turb_rans_model_init
+
+  !> \brief Initialize Fortran LES turbulence model API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine turb_les_model_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_idries, c_ivrtex
+
+    call cs_f_turb_les_model_get_pointers( c_idries, c_ivrtex)
+
+    call c_f_pointer(c_idries, idries)
+    call c_f_pointer(c_ivrtex, ivrtex)
+
+  end subroutine turb_les_model_init
+
+  !> \brief Initialize Fortran Stokes options API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine stokes_options_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_ivisse, c_irevmc, c_iprco, c_irnpnw, c_rnormp, c_arak
+    type(c_ptr) :: c_ipucou, c_iccvfg, c_idilat, c_epsdp, c_itbrrb, c_iphydr
+    type(c_ptr) :: c_iifren, c_icalhy, c_icond
+
+    call cs_f_stokes_options_get_pointers(c_ivisse, c_irevmc, c_iprco ,  &
+                                          c_irnpnw, c_rnormp, c_arak  , c_ipucou, c_iccvfg, &
+                                          c_idilat, c_epsdp , c_itbrrb, c_iphydr, &
+                                          c_iifren, c_icalhy, c_icond)
+
+    call c_f_pointer(c_ivisse, ivisse)
+    call c_f_pointer(c_irevmc, irevmc)
+    call c_f_pointer(c_iprco , iprco )
+    call c_f_pointer(c_irnpnw, irnpnw)
+    call c_f_pointer(c_rnormp, rnormp)
+    call c_f_pointer(c_arak  , arak  )
+    call c_f_pointer(c_ipucou, ipucou)
+    call c_f_pointer(c_iccvfg, iccvfg)
+    call c_f_pointer(c_idilat, idilat)
+    call c_f_pointer(c_epsdp , epsdp )
+    call c_f_pointer(c_itbrrb, itbrrb)
+    call c_f_pointer(c_iphydr, iphydr)
+    call c_f_pointer(c_iifren, iifren)
+    call c_f_pointer(c_icalhy, icalhy)
+    call c_f_pointer(c_icond , icond )
+
+  end subroutine stokes_options_init
+
+  !> \brief Initialize Fortran space discretisation options API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine space_disc_options_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_imvisf, c_imrgra, c_anomax, c_iflxmw
+
+    call cs_f_space_disc_get_pointers(c_imvisf, c_imrgra, c_anomax, &
+                                      c_iflxmw)
+
+    call c_f_pointer(c_imvisf, imvisf)
+    call c_f_pointer(c_imrgra, imrgra)
+    call c_f_pointer(c_anomax, anomax)
+    call c_f_pointer(c_iflxmw, iflxmw)
+
+  end subroutine space_disc_options_init
+
+  !> \brief Initialize Fortran PISO options API.
+  !> This maps Fortran pointers to global C structure members.
+
+  subroutine piso_options_init
+
+    use, intrinsic :: iso_c_binding
+    implicit none
+
+    ! Local variables
+
+    type(c_ptr) :: c_nterup, c_epsup, c_xnrmu, c_xnrmu0
+
+    call cs_f_piso_get_pointers(c_nterup, c_epsup, c_xnrmu, c_xnrmu0)
+
+    call c_f_pointer(c_nterup, nterup)
+    call c_f_pointer(c_epsup, epsup)
+    call c_f_pointer(c_xnrmu, xnrmu)
+    call c_f_pointer(c_xnrmu0, xnrmu0)
+
+  end subroutine piso_options_init
+
   !=============================================================================
 
 end module optcal
