@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -74,6 +74,8 @@ use ppthch
 use ppincl
 use mesh
 use field
+use cavitation
+
 !===============================================================================
 
 implicit none
@@ -82,27 +84,26 @@ implicit none
 
 integer          nvar   , nscal
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 
 ! Local variables
 
 character*80     chaine
 integer          ivar  , iel   , ifac  , iscal
-integer          ii    , iok   , iok1  , iok2  , iisct
+integer          ii    , iok   , iok1  , iok2  , iisct, idfm
 integer          nn
 integer          mbrom , ipcvst
 integer          ipccp , ipcvis, ipcvma
-integer          ivarh
 integer          iclipc
 Double precision xk, xe, xnu, xrom, vismax(nscamx), vismin(nscamx)
 double precision nusa, xi3, fv1, cv13
-double precision varmn(4), varmx(4), tt, ttmin, ttke, viscto, xrtp
+double precision varmn(4), varmx(4), tt, ttmin, ttke, viscto
 double precision xttkmg, xttdrb
-double precision alpha, ym, yk
 double precision trrij,rottke
 double precision, dimension(:), pointer :: brom, crom
 double precision, dimension(:), pointer :: sval
+double precision, dimension(:,:), pointer :: visten
 integer          ipass
 data             ipass /0/
 save             ipass
@@ -153,19 +154,16 @@ mbrom = 0
 if (iihmpr.eq.1) then
   call uiphyv &
   !===========
-( ncel, ncelet, nscaus, itherm,                                 &
-  iviscl, icp,    ivisls, irovar, ivivar,                       &
-  isca, iscalt, iscavr, ipproc, iviscv, itempk,                 &
-  p0  , t0    , ro0   , cp0   , viscl0, visls0, viscv0,         &
-  rtp, propce)
+( ncel   , ncelet , itherm , icp    , ivisls , irovar , ivivar ,          &
+  iscalt , iscavr , iviscv , itempk ,                                     &
+  p0     , t0     , ro0    , cp0    , viscl0 , visls0 , viscv0 )
 endif
 
 call usphyv &
 !==========
 ( nvar   , nscal  ,                                              &
   mbrom  ,                                                       &
-  dt     , rtp    , rtpa   ,                                     &
-  propce )
+  dt     )
 
 if (ippmod(iphpar).ge.1) then
   call ppphyv &
@@ -176,88 +174,6 @@ if (ippmod(iphpar).ge.1) then
 
 endif
 
-!===============================================================================
-! 5. Density defined by a perfect gas equation of state
-!    for the low-Mach algorithm
-!===============================================================================
-
-if (idilat.eq.3) then
-
-  ! Works only with enthalpy
-  if (iscalt.le.0) call csexit(1)
-  if (itherm.ne.2) call csexit(1)
-  ivarh  = isca(iscalt)
-  call field_get_val_s(icrom, crom)
-
-  ! Count the number of species
-  nscasp = 0
-  do ii = 1, nscamx
-    nscasp = nscasp + iscasp(ii)
-  enddo
-
-  do iel = 1, ncel
-
-    ! Enthalpy over Cp, with Cp specific heat variable or constant
-    if (icp.gt.0) then
-      ipccp  = ipproc(icp)
-      xrtp =  rtp(iel,ivarh)/propce(iel,ipccp)
-    else
-      xrtp =  rtp(iel,ivarh)/cp0
-    endif
-
-    alpha = 0.d0
-
-    if (nscasp.ge.2) then
-      ! Deduced species
-      ym = 1.d0
-
-      do ii = 1, nscaus
-        if (iscasp(ii).eq.1) then
-          yk = rtp(iel, isca(ii))
-
-          ! Clipping of the fraction yk
-          yk = max(yk, 0.d0)
-          yk = min(yk, 1.d0)
-
-          alpha = alpha + yk/wmolsp(ii)
-
-          ym = ym - yk
-        endif
-      enddo
-
-      ! Clipping of remaining species
-      ym = max(ym, 0.d0)
-
-      ! Add to alpha the value due to the deduced fraction
-      alpha = alpha + ym/wmolsp(0)
-
-      ! Check if the values are correct
-      if (alpha.lt.epzero .or. rair.lt.epzero .or.   &
-           xrtp.lt.epzero .or. pther.lt.epzero) then
-        write(nfecra,9004)
-        call csexit(1)
-      endif
-
-      crom(iel) = pther/(alpha*rair*xrtp)
-
-      ! Monospecies: density defined with the perfect state law
-    else
-
-      ! Check if the values are correct
-      if (rair.lt.epzero .or.                       &
-          xrtp.lt.epzero .or. pther.lt.epzero) then
-        write(nfecra,9004)
-        call csexit(1)
-      endif
-
-      crom(iel) = pther/(rair*xrtp)
-
-    endif
-
-  enddo
-
-endif
-
 !  ROMB SUR LES BORDS : VALEUR PAR DEFAUT (CELLE DE LA CELLULE VOISINE)
 
 if (mbrom.eq.0) then
@@ -322,12 +238,12 @@ if (ntcabs.eq.ntpabs+1) then
 endif
 
 !===============================================================================
-! 6. Compute the eddy viscosity
+! 5. Compute the eddy viscosity
 !===============================================================================
 
 if     (iturb.eq. 0) then
 
-! 6.1 Laminar
+! 5.1 Laminar
 ! ===========
 
   ipcvst = ipproc(ivisct)
@@ -338,14 +254,14 @@ if     (iturb.eq. 0) then
 
 elseif (iturb.eq.10) then
 
-! 6.2 Mixing length model
+! 5.2 Mixing length model
 ! =======================
 
   call vislmg(rtpa, propce)
 
 elseif (itytur.eq.2) then
 
-! 6.3 k-epsilon
+! 5.3 k-epsilon
 ! =============
 
   ipcvst = ipproc(ivisct)
@@ -359,7 +275,7 @@ elseif (itytur.eq.2) then
 
 elseif (itytur.eq.3) then
 
-! 6.4 Rij-epsilon
+! 5.4 Rij-epsilon
 ! ===============
 
   ipcvst = ipproc(ivisct)
@@ -373,7 +289,7 @@ elseif (itytur.eq.3) then
 
 elseif (iturb.eq.40) then
 
-! 6.5 LES Smagorinsky
+! 5.5 LES Smagorinsky
 ! ===================
 
   call vissma(rtpa, propce)
@@ -381,7 +297,7 @@ elseif (iturb.eq.40) then
 
 elseif (iturb.eq.41) then
 
-! 6.6 LES dynamic
+! 5.6 LES dynamic
 ! ===============
 
   call visdyn &
@@ -395,7 +311,7 @@ elseif (iturb.eq.41) then
 
 elseif (iturb.eq.42) then
 
-! 6.7 LES WALE
+! 5.7 LES WALE
 ! ============
 
   call viswal(rtpa, propce)
@@ -403,7 +319,7 @@ elseif (iturb.eq.42) then
 
 elseif (itytur.eq.5) then
 
-! 6.8 v2f (phi-model and BL-v2/k)
+! 5.8 v2f (phi-model and BL-v2/k)
 ! ===============================
 
   if (iturb.eq.50) then
@@ -432,7 +348,7 @@ elseif (itytur.eq.5) then
 
 elseif (iturb.eq.60) then
 
-! 6.9 k-omega SST
+! 5.9 k-omega SST
 ! ===============
 
   call vissst(rtpa, propce)
@@ -440,7 +356,7 @@ elseif (iturb.eq.60) then
 
 elseif (iturb.eq.70) then
 
-! 6.10 Spalart-Allmaras
+! 5.10 Spalart-Allmaras
 ! =====================
 
   cv13 = csav1**3
@@ -460,20 +376,18 @@ elseif (iturb.eq.70) then
 endif
 
 !===============================================================================
-! 7. Symmetric tensor diffusivity
+! 6. Anisotropic turbulent viscosity (symmetric)
 !===============================================================================
-iok = 0
-do ivar = 1, nvar
-  if (ivar.ne.ipr) then
-    if (idften(ivar).eq.6) iok = 1
-  endif
-enddo
+idfm = 0
 
 do iscal = 1, nscal
-  if (ityturt(iscal).eq.3) iok = 1
+  if (ityturt(iscal).eq.3) idfm = 1
 enddo
 
-if (iok.eq.1) then
+if (idfm.eq.1 .or. itytur.eq.3 .and. idirsm.eq.1) then
+
+  call field_get_val_v(ivsten, visten)
+
   if (itytur.eq.3) then
 
     call field_get_val_s(icrom, crom)
@@ -494,8 +408,8 @@ if (iok.eq.1) then
         visten(2,iel) = rottke*rtp(iel,ir22)
         visten(3,iel) = rottke*rtp(iel,ir33)
         visten(4,iel) = rottke*rtp(iel,ir12)
-        visten(5,iel) = rottke*rtp(iel,ir13)
-        visten(6,iel) = rottke*rtp(iel,ir23)
+        visten(5,iel) = rottke*rtp(iel,ir23)
+        visten(6,iel) = rottke*rtp(iel,ir13)
       enddo
 
     ! LRR or SSG
@@ -508,8 +422,8 @@ if (iok.eq.1) then
         visten(2,iel) = rottke*rtp(iel,ir22)
         visten(3,iel) = rottke*rtp(iel,ir33)
         visten(4,iel) = rottke*rtp(iel,ir12)
-        visten(5,iel) = rottke*rtp(iel,ir13)
-        visten(6,iel) = rottke*rtp(iel,ir23)
+        visten(5,iel) = rottke*rtp(iel,ir23)
+        visten(6,iel) = rottke*rtp(iel,ir13)
       enddo
     endif
 
@@ -527,6 +441,22 @@ if (iok.eq.1) then
   endif
 endif
 
+!===============================================================================
+! 7. Eddy viscosity correction for cavitating flows
+!===============================================================================
+
+if (icavit.ge.0 .and. icvevm.eq.1) then
+  if (itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60 .or. iturb.eq.70) then
+
+    ipcvst = ipproc(ivisct)
+    call field_get_val_s(icrom, crom)
+
+    call cavitation_correct_visc_turb (crom, rtp(:,ivoidf), propce(:,ipcvst))
+    !================================
+
+  endif
+endif
+
 !===============================================================================
 ! 8. User modification of the turbulent viscosity and symmetric tensor
 !    diffusivity
@@ -537,7 +467,7 @@ call usvist &
 ( nvar   , nscal  ,                                              &
   ncepdc , ncetsm ,                                              &
   icepdc , icetsm , itypsm ,                                     &
-  dt     , rtp    , rtpa   , propce ,                            &
+  dt     ,                                                       &
   ckupdc , smacel )
 
 !===============================================================================
@@ -592,7 +522,7 @@ if (iale.eq.1.and.ntcabs.eq.0) then
   call usvima &
   !==========
  ( nvar   , nscal  ,                                              &
-   dt     , rtp    , rtpa   , propce ,                            &
+   dt     ,                                                       &
    propce(1,ipproc(ivisma(1))) ,                                  &
    propce(1,ipproc(ivisma(2))) , propce(1,ipproc(ivisma(3))) )
 
@@ -669,10 +599,10 @@ endif
 ! Writings
 iok1 = 0
 do ii = 1, nn
-  if (ii.eq.1) call field_get_name (icrom, chaine)
-  if (ii.eq.2) chaine = nomvar(ipppro(ipproc(iviscl)))
-  if (ii.eq.3) chaine = nomvar(ipppro(ipproc(ivisct)))
-  if (ii.eq.4) chaine = nomvar(ipppro(ipproc(icp   )))
+  if (ii.eq.1) call field_get_name(icrom, chaine)
+  if (ii.eq.2) call field_get_name(iprpfl(iviscl), chaine)
+  if (ii.eq.3) call field_get_name(iprpfl(ivisct), chaine)
+  if (ii.eq.4) call field_get_name(iprpfl(icp), chaine)
   if (iwarni(iu).ge.1.or.ipass.eq.1.or.varmn(ii).lt.0.d0) then
     if (iok1.eq.0) then
       write(nfecra,3010)
@@ -688,7 +618,7 @@ if (iok1.eq.1) write(nfecra,3012)
 
 ! Masse volumique definie
 ii = 1
-call field_get_name (icrom, chaine)
+call field_get_name(icrom, chaine)
 if (varmn(ii).lt.0.d0) then
   write(nfecra,9011)chaine(1:16),varmn(ii)
   iok = iok + 1
@@ -696,7 +626,7 @@ endif
 
 ! Viscosite moleculaire definie
 ii = 2
-chaine = nomvar(ipppro(ipproc(iviscl)))
+call field_get_name(iprpfl(iviscl), chaine)
 if (varmn(ii).lt.0.d0) then
   write(nfecra,9011)chaine(1:16),varmn(ii)
   iok = iok + 1
@@ -706,7 +636,7 @@ endif
 ! on ne clippe pas mu_t en modele LES dynamique, car on a fait
 ! un clipping sur la viscosite totale
 ii = 3
-chaine = nomvar(ipppro(ipproc(ivisct)))
+call field_get_name(iprpfl(ivisct), chaine)
 if (varmn(ii).lt.0.d0.and.iturb.ne.41) then
   write(nfecra,9012)varmn(ii)
   iok = iok + 1
@@ -715,7 +645,7 @@ endif
 ! Chaleur specifique definie
 if (icp.gt.0) then
   ii = 4
-  chaine = nomvar(ipppro(ipproc(icp   )))
+  call field_get_name(iprpfl(icp), chaine)
   if (varmn(ii).lt.0.d0) then
     iisct = 0
     if (itherm.ne.0) iisct = 1
@@ -762,7 +692,7 @@ if (nscal.ge.1) then
 
     ivar = isca(iscal)
     if (iwarni(ivar).ge.1.or.ipass.eq.1.or.vismin(iscal).le.0.d0) then
-      chaine = nomvar(ipprtp(ivar))
+      call field_get_label(ivarfl(ivar), chaine)
       if (iok1.eq.0) then
         write(nfecra,3110)
         iok1 = 1
@@ -782,7 +712,7 @@ if (nscal.ge.1) then
     ivar = isca(iscal)
 
     if (vismin(iscal).lt.0.d0) then
-      chaine = nomvar(ipprtp(ivar))
+      call field_get_label(ivarfl(ivar), chaine)
       write(nfecra,9111)chaine(1:16),iscal,vismin(iscal)
       iok = iok + 1
     endif
@@ -821,7 +751,7 @@ if (iale.eq.1.and.ntcabs.eq.0) then
     endif
 
     ! Writings
-    chaine = nomvar(ipppro(ipcvma))
+    call field_get_name(iprpfl(ipcvma), chaine)
     if (iwarni(iuma).ge.1.or.ipass.eq.1.or.varmn(1).lt.0.d0) then
       if (iok1.eq.0) then
         write(nfecra,3210)
@@ -833,7 +763,7 @@ if (iale.eq.1.and.ntcabs.eq.0) then
     ! Verifications de valeur physique
 
     ! Viscosite de maillage definie
-    chaine = nomvar(ipppro(ipcvma))
+    call field_get_name(iprpfl(ipcvma), chaine)
     if (varmn(1).le.0.d0) then
       write(nfecra,9211) varmn(1)
       iok = iok + 1
@@ -956,21 +886,6 @@ endif
 '@  Verifier uscfx2 et uscfpv.',                                /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@',                                                            /)
-9004  format( &
-'@',                                                            /,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@',                                                            /,&
-'@ @@ ATTENTION : ARRET LORS DU CALCUL DES GRANDEURS PHYSIQUES',/,&
-'@    =========',                                               /,&
-'@    OPTION IDILAT 3',                                         /,&
-'@    LE CALCUL ENGENDRE UN RHO NEGATIF',                       /,&
-'@',                                                            /,&
-'@  Le calcul ne sera pas execute.',                            /,&
-'@',                                                            /,&
-'@  Verifier uscfx1 et uscfpv.',                                /,&
-'@',                                                            /,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
  9011  format(                                                    &
 '@',                                                            /,&
@@ -978,7 +893,7 @@ endif
 '@',                                                            /,&
 '@ @@ ATTENTION : ARRET LORS DU CALCUL DES GRANDEURS PHYSIQUES',/,&
 '@    =========',                                               /,&
-'@    LA PROPRIETE PHYSIQUE', a16  ,' N A PAS ETE',             /,&
+'@    LA PROPRIETE PHYSIQUE ', a16  ,' N A PAS ETE',            /,&
 '@                                       CORRECTEMENT DEFINIE.',/,&
 '@',                                                            /,&
 '@  Le calcul ne sera pas execute.',                            /,&
@@ -1034,7 +949,7 @@ endif
 '@',                                                            /,&
 '@ @@ ATTENTION : ARRET LORS DU CALCUL DES GRANDEURS PHYSIQUES',/,&
 '@    =========',                                               /,&
-'@    LA DIFFUSIVITE DU SCALAIRE', a16                         ,/,&
+'@    LA DIFFUSIVITE DU SCALAIRE ', a16                        ,/,&
 '@       (SCALAIRE NUMERO', i10   ,') N A PAS ETE',             /,&
 '@                                       CORRECTEMENT DEFINIE.',/,&
 '@',                                                            /,&
@@ -1171,19 +1086,6 @@ endif
 '@  Verify uscfx2 and uscfpv.',                                 /,&
 '@',                                                            /,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@',                                                            /)
- 9004  format( &
-'@',                                                            /,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@',                                                            /,&
-'@ @@ WARNING: ABORT IN THE PHYSICAL QUANTITIES COMPUTATION',   /,&
-'@    ========',                                                /,&
-'@    OPTION IDILAT 3',                                         /,&
-'@    THE COMPUTATION MAKE RHO NEGATIVE',                       /,&
-'@',                                                            /,&
-'@  The calculation will not be run.',                          /,&
-'@',                                                            /,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@',                                                            /)
  9011  format(                                                    &
 '@',                                                            /,&
@@ -1191,7 +1093,7 @@ endif
 '@',                                                            /,&
 '@ @@ WARNING: ABORT IN THE PHYSICAL QUANTITIES COMPUTATION',   /,&
 '@    ========',                                                /,&
-'@    THE PHYSICAL PROPERTY', a16  ,' HAS NOT BEEN',            /,&
+'@    THE PHYSICAL PROPERTY ', a16  ,' HAS NOT BEEN',           /,&
 '@                                          CORRECTLY DEFINED.',/,&
 '@',                                                            /,&
 '@  The calculation will not be run.',                          /,&
@@ -1246,7 +1148,7 @@ endif
 '@',                                                            /,&
 '@ @@ WARNING: ABORT IN THE PHYSICAL QUANTITIES COMPUTATION',   /,&
 '@    ========',                                                /,&
-'@    THE DIFFUSIVITY OF THE SCALAR', a16                      ,/,&
+'@    THE DIFFUSIVITY OF THE SCALAR ', a16                     ,/,&
 '@       (SCALAR NUMBER', i10   ,') HAS NOT BEEN',              /,&
 '@                                          CORRECTLY DEFINED.',/,&
 '@',                                                            /,&
