@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -57,7 +57,6 @@ module pointe
     double precision, dimension(:),  pointer :: p !< rank 1 array pointer
   end type pmapper_double_r1
 
-
   !> container for rank 2 double precision array pointer.
   type pmapper_double_r2
     double precision, dimension(:,:),  pointer :: p !< rank 2 array pointer
@@ -109,16 +108,10 @@ module pointe
   !> and the closest wall is therefore \c yplpar(iel1)
   double precision, allocatable, dimension(:)   :: yplpar
 
-  !> \f$y^+\f$ at boundary, if post-processed
-  double precision, allocatable, dimension(:)   :: yplbr
-
   !> friction velocity at the wall, in the case of a LES calculation
   !> with van Driest-wall damping
   double precision, allocatable, dimension(:)   :: uetbor
 
-  !> stresses at boundary (if post-processed)
-  double precision, allocatable, dimension(:,:) :: forbr
-
   !> \}
 
   !=============================================================================
@@ -128,46 +121,7 @@ module pointe
   !> \addtogroup coupled_case
   !> \{
 
-  !> boundary conditions for the velocity vector with
-  !> the coupled velocity components algorithm (\c ivelco=1): see \ref note_2
-  double precision, dimension(:,:),   allocatable :: coefau
-
-  !> boundary conditions for the velocity diffusion flux with
-  !> the coupled velocity components algorithm (\c ivelco=1): see \ref note_2
-  double precision, dimension(:,:),   allocatable :: cofafu
-
-  !> boundary conditions for the velocity convective flux (only for
-  !> compressible flows).
-  double precision, dimension(:,:),   allocatable :: cofacu
-
-  !> boundary conditions for the velocity vector with
-  !> the coupled velocity components algorithm (\c ivelco=1): see \ref note_2
-  double precision, dimension(:,:,:), allocatable :: coefbu
-
-  !> boundary conditions for the velocity diffusion flux with
-  !> the coupled velocity components algorithm (\c ivelco=1): see \ref note_2
-  double precision, dimension(:,:,:), allocatable :: cofbfu
-
-  !> boundary conditions for the velocity convective flux (only for
-  !> compressible flows).
-  double precision, dimension(:,:,:), allocatable :: cofbcu
-
-  !> explicit Boundary conditions for the mesh velocity.
-  !> dim = (3,nfabor)
-  double precision, dimension(:,:), allocatable ::   cfaale
-
-  !> explicit Boundary conditions for the mesh velocity.
-  !> dim = (3,nfabor)
-  double precision, dimension(:,:), allocatable ::   claale
-
-  !> implicit Boundary conditions for the mesh velocity.
-  !> dim = (3,3,nfabor)
-  double precision, dimension(:,:,:), allocatable :: cfbale
-
-  !> implicit Boundary conditions for the mesh velocity.
-  !> dim = (3,3,nfabor)
-  double precision, dimension(:,:,:), allocatable :: clbale
-
+  !> \anchor itypfb
   !> boundary condition type at the boundary face \c ifac
   !> (see user subroutine \ref cs\_user\_boundary\_conditions)
   integer, allocatable, dimension(:) :: itypfb
@@ -345,14 +299,9 @@ module pointe
   !> See the user subroutine \ref ustsma
   double precision, allocatable, dimension(:,:) :: smacel
 
-  !> value of the porosity
-  double precision, allocatable, dimension(:) :: porosi
-
-  !> value of the porosity (for convection and diffusion only)
-  double precision, allocatable, dimension(:,:) :: porosf
-
-  !> symmetric tensor cell visco
-  double precision, allocatable, dimension(:,:) :: visten
+  !> liquid-vapour mass transfer term for cavitating flows
+  !> and its derivative with respect to pressure
+  double precision, allocatable, dimension(:) :: gamcav, dgdpca
 
   !> \}
 
@@ -369,12 +318,19 @@ module pointe
   integer, allocatable, dimension(:) :: icocel, itycel
   integer, allocatable, dimension(:) :: ifrlag
 
-  double precision, pointer, dimension(:,:) :: ettp => null(), ettpa => null()
+  !> \anchor ettp
+  double precision, pointer, dimension(:,:) :: ettp => null()
+  !> \anchor ettpa
+  double precision, pointer, dimension(:,:) :: ettpa => null()
+  !> \anchor tepa
   double precision, pointer, dimension(:,:) :: tepa => null()
-  double precision, pointer, dimension(:,:) :: statis => null(), stativ => null()
+  !> \anchor statis
+  double precision, pointer, dimension(:,:) :: statis => null()
+  !> \anchor parbor
   double precision, pointer, dimension(:,:) :: parbor => null()
+  !> \anchor tslagr
   double precision, pointer, dimension(:,:) :: tslagr => null()
-  double precision, pointer, dimension(:,:) :: dlgeo => null()
+  double precision, pointer, dimension(:,:) :: stativ, dlgeo
 
   !> \}
 
@@ -410,7 +366,7 @@ contains
     integer, intent(in) :: ncelet, nfabor
 
     ! Local variables
-    integer                iok, ivar, iscal, iel, ifac
+    integer                ivar, iscal, ifac
     integer                kdiftn
 
     ! Key id for diffusivity tensor
@@ -436,59 +392,13 @@ contains
 
     if (iale.eq.1) then
       allocate(idfstr(nfabor))
-      allocate(cfaale(3,nfabor), claale(3,nfabor))
-      allocate(cfbale(3,3,nfabor), clbale(3,3,nfabor))
     endif
 
-    ! Boundary condition for the velocity when components are coupled
-
-    allocate(coefau(3,nfabor),cofafu(3,nfabor))
-    allocate(coefbu(3,3,nfabor),cofbfu(3,3,nfabor))
-    if (ippmod(icompf).ge.0) then
-      allocate(cofacu(3,nfabor))
-      allocate(cofbcu(3,3,nfabor))
-    endif
-
-    ! Porosity array when needed
-
-    if (iporos.ge.1) then
-      allocate(porosi(ncelet))
-      do iel = 1, ncelet
-        porosi(iel) = 1.d0
-      enddo
-    endif
-    if (iporos.eq.2) then
-      allocate(porosf(6, ncelet))
-      do iel = 1, ncelet
-        porosf(1, iel) = 1.d0
-        porosf(2, iel) = 1.d0
-        porosf(3, iel) = 1.d0
-        porosf(4, iel) = 0.d0
-        porosf(5, iel) = 0.d0
-        porosf(6, iel) = 0.d0
-      enddo
-    endif
-
-    ! Symmetric cell diffusivity when needed
-    iok = 0
-    do ivar = 1, nvarmx
-      if (idften(ivar).eq.6) iok = 1
-    enddo
-
-    do iscal = 1, nscamx
-      if (ityturt(iscal).eq.3) iok = 1
-    enddo
-
     ! Also tensorial diffusion for the velocity in case of tensorial porosity
     if (iporos.eq.2) then
       idften(iu) = 6
       ! Key word: tensorial diffusivity
       call field_set_key_int(ivarfl(iu), kdiftn, idften(iu))
-      iok = 1
-    endif
-
-    if (iok.eq.1) then
-      allocate(visten(6,ncelet))
     endif
 
     ! Diagonal cell tensor for the pressure solving when needed
@@ -509,12 +419,6 @@ contains
       allocate(ifapat(ncelet))
     endif
 
-    ! Forces on boundary faces
-
-    if (ineedf.eq.1) then
-      allocate(forbr(3,nfabor))
-    endif
-
     ! Friction velocity on boundary faces
 
     if (     (itytur.eq.4 .and. idries.eq.1) &
@@ -522,12 +426,6 @@ contains
       allocate(uetbor(nfabor))
     endif
 
-    ! Non-dimensional distance to the wall (for post-processing)
-
-    if (ipstdv(ipstyp).ne.0) then
-      allocate(yplbr(nfabor))
-    endif
-
     ! Temporary storage arrays for k-omega model
 
     if (iturb.eq.60) then
@@ -543,6 +441,12 @@ contains
       endif
     endif
 
+    ! liquid-vapour mass transfer term for cavitating flows
+    ! and its part implicit in pressure
+    if (icavit.ge.0) then
+      allocate(gamcav(ncelet), dgdpca(ncelet))
+    endif
+
     return
 
   end subroutine init_aux_arrays
@@ -569,40 +473,6 @@ contains
 
     allocate(buffer(ncelet))
 
-    ! Porosity array when needed
-
-    if (allocated(porosi)) then
-      do iel = 1, ncel
-        buffer(iel) = porosi(iel)
-      enddo
-      deallocate(porosi)
-      call synsca (buffer)
-      allocate(porosi(ncelet))
-      do iel = 1, ncelet
-        porosi(iel) = buffer(iel)
-      enddo
-    endif
-
-    ! Symmetric cell diffusivity when needed
-
-    if (allocated(visten)) then
-      allocate(buff2(6,ncel))
-      do iel = 1, ncel
-        do isou = 1, 6
-          buff2(isou,iel) = visten(isou,iel)
-        enddo
-      enddo
-      deallocate(visten)
-      allocate(visten(6,ncelet))
-      do iel = 1, ncel
-        do isou = 1, 6
-          visten(isou,iel) = buff2(isou,iel)
-        enddo
-      enddo
-      deallocate(buff2)
-      call syntin(visten)
-    endif
-
     ! Wall-distance calculation
 
     if (allocated(dispar)) then
@@ -707,21 +577,14 @@ contains
     if (allocated(izcpdc)) deallocate(izcpdc)
     if (allocated(izctsm)) deallocate(izctsm)
     if (allocated(izft1d)) deallocate(izft1d)
-    if (allocated(coefau)) deallocate(coefau, cofafu,                   &
-                                      coefbu, cofbfu)
-    if (allocated(cofacu)) deallocate(cofacu, cofbcu)
-    if (allocated(porosi)) deallocate(porosi)
-    if (allocated(visten)) deallocate(visten)
-    if (allocated(cfaale)) deallocate(cfaale, cfbale, claale, clbale)
     if (allocated(dispar)) deallocate(dispar)
     if (allocated(yplpar)) deallocate(yplpar)
     if (allocated(ifapat)) deallocate(ifapat)
-    if (allocated(forbr)) deallocate(forbr)
     if (allocated(uetbor)) deallocate(uetbor)
-    if (allocated(yplbr)) deallocate(yplbr)
     if (allocated(s2kw)) deallocate(s2kw, divukw)
     if (allocated(straio))  deallocate(straio)
     if (allocated(b_head_loss)) deallocate(b_head_loss)
+    if (allocated(gamcav)) deallocate(gamcav, dgdpca)
 
     return
 
