@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -456,6 +456,10 @@ do ifac = 1, nfabor
           rcodcl(ifac,ik,1)   = xkent
           rcodcl(ifac,iomg,1) = xeent/cmu/xkent
 
+        elseif (iturb.eq.70) then
+
+          rcodcl(ifac,inusa,1) = cmu*xkent**2/xeent
+
         endif
 
       endif
