@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -89,7 +89,7 @@ implicit none
 integer          itrale , italim , itrfin
 integer          nvar
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision flmalf(nfac), flmalb(nfabor), xprale(ncelet)
 double precision cofale(nfabor,11)
 
@@ -104,6 +104,9 @@ double precision delta
 
 double precision, allocatable, dimension(:,:) :: forast
 double precision, dimension(:), pointer :: imasfl, bmasfl
+double precision, dimension(:,:), pointer :: forbr
+double precision, dimension(:,:), pointer :: coefau
+double precision, dimension(:,:,:), pointer :: coefbu
 double precision, dimension(:), pointer :: coefap, coefbp
 
 !===============================================================================
@@ -117,6 +120,11 @@ call field_get_key_int(ivarfl(iu), kbmasf, iflmab)
 call field_get_val_s(iflmas, imasfl)
 call field_get_val_s(iflmab, bmasfl)
 
+call field_get_val_v(iforbr, forbr)
+
+call field_get_coefa_v(ivarfl(iu), coefau)
+call field_get_coefb_v(ivarfl(iu), coefbu)
+
 call field_get_coefa_s(ivarfl(ipr), coefap)
 call field_get_coefb_s(ivarfl(ipr), coefbp)
 
