@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -69,6 +69,7 @@ use paramx
 use optcal
 use numvar
 use pointe
+use dimens, only: nvar
 use albase, only: nalimx
 use alstru
 use alaste
@@ -88,7 +89,7 @@ integer          itrale , italim , ineefl
 
 integer          impale(nnod)
 
-double precision rtpa(ncelet,*)
+double precision rtpa(ncelet,nflown:nvar)
 double precision flmalf(nfac), flmalb(nfabor), xprale(ncelet)
 double precision cofale(nfabor,11)
 double precision depale(3,nnod)
@@ -100,6 +101,8 @@ integer          iflmas, iflmab
 
 integer, allocatable, dimension(:) :: lstfac
 double precision, dimension(:), pointer :: imasfl, bmasfl
+double precision, dimension(:,:), pointer :: coefau
+double precision, dimension(:,:,:), pointer :: coefbu
 double precision, dimension(:), pointer :: coefap, coefbp
 
 !===============================================================================
@@ -114,6 +117,9 @@ call field_get_key_int(ivarfl(iu), kbmasf, iflmab)
 call field_get_val_s(iflmas, imasfl)
 call field_get_val_s(iflmab, bmasfl)
 
+call field_get_coefa_v(ivarfl(iu), coefau)
+call field_get_coefb_v(ivarfl(iu), coefbu)
+
 call field_get_coefa_s(ivarfl(ipr), coefap)
 call field_get_coefb_s(ivarfl(ipr), coefbp)
 
