@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -92,7 +92,6 @@ use ppincl
 use cfpoin
 use mesh
 use field
-use pointe, only: coefau, coefbu
 
 !===============================================================================
 
@@ -107,7 +106,7 @@ integer          iscal
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision viscf(nfac), viscb(nfabor)
@@ -131,7 +130,6 @@ double precision sclnor, thetap, epsrsp, relaxp
 
 integer          inc    , iccocg , imucpp , idftnp , iswdyp
 integer          ivar0  , ii , jj
-integer          iccfth , imodif
 integer          iel1  , iel2
 integer          iterns
 
@@ -147,13 +145,20 @@ double precision, allocatable, dimension(:,:) :: grad
 double precision, allocatable, dimension(:) :: w1
 double precision, allocatable, dimension(:) :: w4, w5, w6
 double precision, allocatable, dimension(:) :: w7, w8, w9
+
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer :: brom, crom, cromo
+double precision, dimension(:,:), pointer :: coefau
+double precision, dimension(:,:,:), pointer :: coefbu
 double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
 double precision, dimension(:), pointer :: coefa_p, coefb_p
+double precision, dimension(:,:), pointer :: vel
 
 !===============================================================================
 
+! Map field arrays
+call field_get_val_v(ivarfl(iu), vel)
+
 !===============================================================================
 ! 1. INITIALIZATION
 !===============================================================================
@@ -191,7 +196,7 @@ else
 endif
 
 ! Prints
-chaine = nomvar(ippvar)
+call field_get_label(ivarfl(ivar), chaine)
 
 if(iwarni(ivar).ge.1) then
   write(nfecra,1000) chaine(1:8)
@@ -216,12 +221,12 @@ enddo
 ! HEAT VOLUMIC SOURCE TERM: RHO * PHI *VOLUME
 ! =================================
 
-call ustssc                                                                     &
+call ustssc                                                                    &
 !==========
-( nvar   , nscal  , ncepdp , ncesmp ,                                           &
-  iscal  ,                                                                      &
-  icepdc , icetsm , itypsm ,                                                    &
-  dt     , rtpa   , rtp    , propce ,                                           &
+( nvar   , nscal  , ncepdp , ncesmp ,                                          &
+  iscal  ,                                                                     &
+  icepdc , icetsm , itypsm ,                                                   &
+  dt     ,                                                                     &
   ckupdc , smacel , smbrs  , rovsdt )
 
 do iel = 1, ncel
@@ -241,10 +246,10 @@ enddo
 !                                     inj
 if (ncesmp.gt.0) then
   iterns = 1
-  call catsma ( ncelet , ncel , ncesmp , iterns ,                               &
-                isno2t, thetav(ivar),                                           &
-                icetsm , itypsm(1,ivar) ,                                       &
-                volume , rtpa(1,ivar) , smacel(1,ivar) ,                        &
+  call catsma ( ncelet , ncel , ncesmp , iterns ,                              &
+                isno2t, thetav(ivar),                                          &
+                icetsm , itypsm(1,ivar) ,                                      &
+                volume , rtpa(1,ivar) , smacel(1,ivar) ,                       &
                 smacel(1,ipr) , smbrs , rovsdt , w1    )
 endif
 
@@ -254,7 +259,7 @@ endif
 ! ======================       DT
 
 do iel = 1, ncel
-  rovsdt(iel) = rovsdt(iel)                                                     &
+  rovsdt(iel) = rovsdt(iel)                                                    &
                 + istat(ivar)*(cromo(iel)/dt(iel))*volume(iel)
 enddo
 
@@ -266,7 +271,7 @@ if (idiff(iu).ge. 1) then
   call cfdivs                                                     &
   !==========
  ( rtpa   , propce ,                                              &
-   smbrs  , rtp(1,iu), rtp(1,iv), rtp(1,iw) )
+   smbrs  , vel )
 endif
 
 !                              __   P        n+1
@@ -362,8 +367,8 @@ endif
 do ifac = 1, nfac
   iel1 = ifacel(1,ifac)
   iel2 = ifacel(2,ifac)
-  viscf(ifac) =                                                                 &
-     - rtp(iel1,ipr)/w9(iel1) * 0.5d0*(imasfl(ifac) +abs(imasfl(ifac)))         &
+  viscf(ifac) =                                                                &
+     - rtp(iel1,ipr)/w9(iel1) * 0.5d0*(imasfl(ifac) +abs(imasfl(ifac)))        &
      - rtp(iel2,ipr)/w9(iel2) * 0.5d0*(imasfl(ifac) -abs(imasfl(ifac)))
 enddo
 
@@ -376,8 +381,8 @@ call field_get_coefb_s(ivarfl(ipr), coefb_p)
 do ifac = 1, nfabor
   if (icvfli(ifac).eq.0) then
     iel = ifabor(ifac)
-    viscb(ifac) = - bmasfl(ifac)                                                &
-                    * (coefa_p(ifac) + coefb_p(ifac)*rtp(iel,ipr))              &
+    viscb(ifac) = - bmasfl(ifac)                                               &
+                    * (coefa_p(ifac) + coefb_p(ifac)*rtp(iel,ipr))             &
                     / brom(ifac)
   else
     viscb(ifac) = 0.d0
@@ -386,18 +391,17 @@ enddo
 
 !     Divergence
 init = 0
-call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                                &
-            ifacel,ifabor,viscf,viscb,smbrs)
+call divmas(init, viscf, viscb, smbrs)
 
 
 ! GRAVITATION FORCE TERM : RHO*g.U *VOLUME
 ! ======================
 
 do iel = 1, ncel
-  smbrs(iel) = smbrs(iel) + w9(iel)*volume(iel)                                 &
-                           *( gx*rtp(iel,iu)                                    &
-                            + gy*rtp(iel,iv)                                    &
-                            + gz*rtp(iel,iw) )
+  smbrs(iel) = smbrs(iel) + w9(iel)*volume(iel)                                &
+                           *( gx*vel(1,iel)                                    &
+                            + gy*vel(2,iel)                                    &
+                            + gz*vel(3,iel) )
 enddo
 
 !                                  Kij*Sij           LAMBDA   Cp   MUT
@@ -454,14 +458,16 @@ if( idiff(ivar).ge. 1 ) then
 !                                                    2
 
 ! Complementary term at cell centers
-  iccfth = 7
-  imodif = 0
-  call cfther                                                                   &
-  !==========
- ( nvar   ,                                                                     &
-   iccfth , imodif ,                                                            &
-   rtp    ,                                                                     &
-   w9     , wb     , w8     , rvoid  , rvoid )
+
+  ! Compute e - CvT
+
+  ! At cell centers
+  call cf_thermo_eps_sup(w9, ncel)
+  !=====================
+
+  ! At boundary faces centers
+  call cf_thermo_eps_sup(wb, nfabor)
+  !=====================
 
 ! Divergence computation with reconstruction
 
@@ -469,9 +475,9 @@ if( idiff(ivar).ge. 1 ) then
 ! Computation of the gradient of (0.5*u*u+EPSILONsup)
 
   do iel = 1, ncel
-    w7(iel) =0.5d0*( rtp(iel,iu)**2                                             &
-                    +rtp(iel,iv)**2                                             &
-                    +rtp(iel,iw)**2 ) + w9(iel)
+    w7(iel) = 0.5d0*( vel(1,iel)**2                                            &
+                     +vel(2,iel)**2                                            &
+                     +vel(3,iel)**2 ) + w9(iel)
   enddo
 
 ! Note : by default, since the parameters are unknowns, the velocity parameters
@@ -547,6 +553,9 @@ if( idiff(ivar).ge. 1 ) then
   ! Hence the contribution of the terms in u2 and e-CvT shouldn't be taken into
   ! account when ifbet(ifac).ne.0
 
+  call field_get_coefa_v(ivarfl(iu), coefau)
+  call field_get_coefb_v(ivarfl(iu), coefbu)
+
   do ifac = 1, nfabor
 
     if (ifbet(ifac).eq.0) then
@@ -555,20 +564,20 @@ if( idiff(ivar).ge. 1 ) then
 
       flux = viscb(ifac)*(w1(iel)/distb(ifac))*                  &
             ( w9(iel) - wb(ifac)                                 &
-            + 0.5d0*( rtp(iel,iu)**2 -                           &
-              ( coefau(1, ifac) + coefbu(1, 1, ifac)*rtp(iel,iu) &
-                                + coefbu(1, 2, ifac)*rtp(iel,iv) &
-                                + coefbu(1, 3, ifac)*rtp(iel,iw) &
+            + 0.5d0*( vel(1,iel)**2 -                            &
+              ( coefau(1, ifac) + coefbu(1, 1, ifac)*vel(1,iel)  &
+                                + coefbu(1, 2, ifac)*vel(2,iel)  &
+                                + coefbu(1, 3, ifac)*vel(3,iel)  &
               )**2                                               &
-                   + rtp(iel,iv)**2 -                            &
-              ( coefau(2, ifac) + coefbu(2, 1, ifac)*rtp(iel,iu) &
-                                + coefbu(2, 2, ifac)*rtp(iel,iv) &
-                                + coefbu(2, 3, ifac)*rtp(iel,iw) &
+                   + vel(2,iel)**2 -                             &
+              ( coefau(2, ifac) + coefbu(2, 1, ifac)*vel(1,iel)  &
+                                + coefbu(2, 2, ifac)*vel(2,iel)  &
+                                + coefbu(2, 3, ifac)*vel(3,iel)  &
               )**2                                               &
-                   + rtp(iel,iw)**2 -                            &
-              ( coefau(3, ifac) + coefbu(3, 1, ifac)*rtp(iel,iu) &
-                                + coefbu(3, 2, ifac)*rtp(iel,iv) &
-                                + coefbu(3, 3, ifac)*rtp(iel,iw) &
+                   + vel(3,iel)**2 -                             &
+              ( coefau(3, ifac) + coefbu(3, 1, ifac)*vel(1,iel)  &
+                                + coefbu(3, 2, ifac)*vel(2,iel)  &
+                                + coefbu(3, 3, ifac)*vel(3,iel)  &
               )**2                                               &
             ))
 
@@ -655,30 +664,23 @@ call codits                                                      &
 !===============================================================================
 
 ! dummy value
-iii = 1
+iii = nflown
 
 call clpsca(ncelet, ncel, iscal, rtp(1,iii), rtp)
 !==========
 
 ! --- Traitement utilisateur pour gestion plus fine des bornes
 !       et actions correctives ventuelles.
-  iccfth = -4
-  imodif = 0
-  call cfther                                                     &
-  !==========
- ( nvar   ,                                                       &
-   iccfth , imodif ,                                              &
-   rtp    ,                                                       &
-   w6     , w7     , w8     , rvoid  , rvoid )
-
+call cf_check_internal_energy(rtp(1,isca(ienerg)), ncel,       &
+                              vel)
 
 ! Explicit balance (see codits : the increment is removed)
 
 if (iwarni(ivar).ge.2) then
   do iel = 1, ncel
-    smbrs(iel) = smbrs(iel)                                                     &
-            - istat(ivar)*(crom(iel)/dt(iel))*volume(iel)              &
-                *(rtp(iel,ivar)-rtpa(iel,ivar))                                 &
+    smbrs(iel) = smbrs(iel)                                                    &
+            - istat(ivar)*(crom(iel)/dt(iel))*volume(iel)                      &
+                *(rtp(iel,ivar)-rtpa(iel,ivar))                                &
                 * max(0,min(nswrsm(ivar)-2,1))
   enddo
   isqrt = 1
@@ -693,15 +695,9 @@ endif
 ! The state equation is used P   =P(RHO   ,H   )
 
 ! Computation of P and T at cell centers
-iccfth = 24
-imodif = 0
-call cfther                                                                     &
-!==========
-( nvar   ,                                                                      &
-  iccfth , imodif ,                                                             &
-  rtp    ,                                                                      &
-  rtp(1,ipr) , rtp(1,isca(itempk)) , w8     ,                                   &
-  rvoid  , rvoid )
+call cf_thermo_pt_from_de(crom, rtp(1,isca(ienerg)), rtp(1,ipr),         &
+                          rtp(1,isca(itempk)),                           &
+                          vel, ncel)
 
 !===============================================================================
 ! 7. COMMUNICATION OF PRESSURE, ENERGY AND TEMPERATURE
@@ -738,4 +734,4 @@ deallocate(w7, w8, w9)
 
 return
 
-end subroutine
+end subroutine cfener
