@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -85,6 +85,7 @@ use ppppar
 use ppthch
 use ppincl
 use mesh
+use pointe, only: itypfb
 use field
 
 !===============================================================================
@@ -99,7 +100,7 @@ integer          ncepdp , ncesmp
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision vela  (3  ,ncelet)
@@ -121,7 +122,6 @@ double precision epsrgp, climgp, extrap, blencp, epsilp
 double precision epsrsp
 double precision sclnor
 
-integer          iccfth, imodif
 integer          imucpp, idftnp, iswdyp
 integer          imvis1
 
@@ -176,7 +176,7 @@ call field_get_val_s(iflmab, bmasfl)
 call field_get_val_s(icrom, crom)
 call field_get_val_prev_s(icrom, rhopre)
 
-chaine = nomvar(ippvar)
+call field_get_label(ivarfl(ivar), chaine)
 
 if(iwarni(ivar).ge.1) then
   write(nfecra,1000) chaine(1:8)
@@ -185,9 +185,10 @@ endif
 call field_get_coefaf_s(ivarfl(ipr), coefaf_p)
 call field_get_coefbf_s(ivarfl(ipr), coefbf_p)
 
-! Coefficients for the reconstruction of the pressure gradient
-! computed from the diffusion coefficient coefaf, coefbf
-! (A Neumann BC has been stored in coefaf, coefbf)
+! Computation of the boundary coefficients for the pressure gradient
+! recontruction in accordance with the diffusion boundary coefficients (coefaf_p,
+! coefbf_p). Always a homogeneous Neumann except at walls where the hydrostatic
+! pressure is taken into account (icfgrp option).
 do ifac = 1, nfabor
   iel = ifabor(ifac)
   hint = dt(iel) / distb(ifac)
@@ -223,19 +224,14 @@ endif
 !     UNSTEADY TERM
 !     =============
 
-! --- Calculation of the square of sound velocity c2
+! --- Calculation of the square of sound velocity c2.
 !     Pressure is an unsteady variable in this algorithm
-!     Varpos has been modified for that
+!     Varpos has been modified for that.
 
 allocate(c2(ncelet))
-iccfth = 126
-imodif = 0
-call cfther                                                       &
-!==========
- ( nvar   ,                                                       &
-   iccfth , imodif ,                                              &
-   rtp    ,                                                       &
-   c2     , w7     , w8     , rvoid  , rvoid )
+
+call cf_thermo_c_square( rtp(1,ipr), crom, c2, ncel)
+!======================
 
 do iel = 1, ncel
   rovsdt(iel) = rovsdt(iel) + istat(ivar)*(volume(iel)/(dt(iel)*c2(iel)))
@@ -245,8 +241,9 @@ enddo
 ! 3. "MASS FLUX" AND FACE "VISCOSITY" CALCULATION
 !===============================================================================
 
-!     Here VISCF et VISCB are both work arrays.
-!     WFLMAS et WFLMAB are calculated
+! Computation of the "convective flux" for the density:
+! (u + dt f) is computed at internal faces and stored in wflmas,
+! the values at boundary faces in wflmab won't be taken into account.
 
 call cfmsfp                                                                     &
 !==========
@@ -256,6 +253,7 @@ call cfmsfp
   ckupdc , smacel ,                                                             &
   wflmas , wflmab )
 
+! Mass flux at internal faces (upwind scheme for the density).
 do ifac = 1, nfac
   ii = ifacel(1,ifac)
   jj = ifacel(2,ifac)
@@ -264,14 +262,30 @@ do ifac = 1, nfac
                  + crom(jj)*(wflmas(ifac)-abs(wflmas(ifac))))
 enddo
 
-do ifac = 1, nfabor
-  iel = ifabor(ifac)
-  wflmab(ifac) = -bmasfl(ifac)
-enddo
+! Mass flux at boundary faces.
+if (icfgrp.eq.1) then
+  ! The hydrostatic pressure gradient contribution has to be added to the mass
+  ! flux if it has been taken into account in the pressure B.C. at walls.
+  do ifac = 1, nfabor
+    iel = ifabor(ifac)
+    if (itypfb(ifac).eq.iparoi) then
+      wflmab(ifac) = -bmasfl(ifac)                                              &
+                     -dt(iel)*crom(iel)*(  gx*surfbo(1,ifac)                    &
+                                         + gy*surfbo(2,ifac)                    &
+                                         + gz*surfbo(3,ifac))
+    else
+      wflmab(ifac) = -bmasfl(ifac)
+    endif
+  enddo
+else
+  do ifac = 1, nfabor
+    iel = ifabor(ifac)
+    wflmab(ifac) = -bmasfl(ifac)
+  enddo
+endif
 
 init = 0
-call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                                &
-            ifacel,ifabor,wflmas,wflmab,smbrs)
+call divmas(init,wflmas,wflmab,smbrs)
 
 ! (Delta t)_ij is calculated as the "viscocity" associated to the pressure
 imvis1 = 1
@@ -342,16 +356,8 @@ call codits
 ! --- User intervention for a finer management of the bounds and possible
 !       corrective treatement.
 
-iccfth = -2
-imodif = 0
-
-call cfther                                                                     &
-!==========
-( nvar   ,                                                                      &
-  iccfth , imodif  ,                                                            &
-  rtp    ,                                                                      &
-  w7     , w8     , w9     , rvoid  , rvoid )
-
+call cf_check_pressure(rtp(1,ipr), ncel)
+!=====================
 
 ! --- Explicit balance (see codits : the increment is withdrawn)
 
@@ -394,7 +400,7 @@ iphydp = 0
 call itrmas                                                                     &
 !==========
 ( init   , inc    , imrgra , iccocg , nswrgp , imligp ,                         &
-  iphydp , iwarnp , nfecra ,                                                    &
+  iphydp , iwarnp ,                                                             &
   epsrgp , climgp , extrap ,                                                    &
   rvoid  ,                                                                      &
   rtp(1,ivar)     ,                                                             &
@@ -404,9 +410,9 @@ call itrmas
   dt     , dt     , dt     ,                                                    &
   imasfl, bmasfl)
 
-! incrementation of the flux with [rho (u + dt f)].n = wflmas
-! (added with a negative sign since WFLMAS,WFLMAB was used above
-!  in the right hand side).
+! Incrementation of the flux with [rho (u + dt f)].n = wflmas
+! (added with a negative sign since wflmas,wflmab was used above
+! in the right hand side).
 do ifac = 1, nfac
   imasfl(ifac) = imasfl(ifac) - wflmas(ifac)
 enddo
