@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -88,6 +88,7 @@ use coincl
 use cpincl
 use ppincl
 use mesh
+use field
 
 !===============================================================================
 
@@ -95,7 +96,7 @@ implicit none
 
 integer          nvar   , nscal
 
-double precision dt(ncelet), rtp(ncelet,*), propce(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), propce(ncelet,*)
 
 ! Local variables
 
@@ -283,7 +284,7 @@ if ( isuite.eq.0 ) then
     call cs_user_initialization &
     !==========================
   ( nvar   , nscal  ,                                            &
-    dt     , rtp    , propce )
+    dt     )
 
 ! ----- En periodique et en parallele,
 !       il faut echanger ces initialisations (qui sont en fait dans RTPA)
@@ -315,7 +316,7 @@ if ( isuite.eq.0 ) then
         valmax = max(valmax,rtp(iel,ivar))
         valmin = min(valmin,rtp(iel,ivar))
       enddo
-      chaine = nomvar(ipprtp(ivar))
+      call field_get_label(ivarfl(ivar), chaine)
       if (irangp.ge.0) then
         call parmin(valmin)
         !==========
