@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -78,6 +78,7 @@ use paramx
 use numvar
 use entsor
 use optcal
+use dimens, only: nvar
 use cstphy
 use cstnum
 use parall
@@ -89,6 +90,7 @@ use cpincl
 use ppincl
 use mesh
 use field
+
 !===============================================================================
 
 implicit none
@@ -97,7 +99,7 @@ implicit none
 
 integer          iscal
 
-double precision rtp(ncelet,*), rtpa(ncelet,*)
+double precision rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision smbrs(ncelet), rovsdt(ncelet)
 
@@ -121,7 +123,7 @@ double precision, dimension(:), pointer ::  crom
 !===============================================================================
 
 ivar = isca(iscal)
-chaine = nomvar(ipprtp(ivar))
+call field_get_label(ivarfl(ivar), chaine)
 call field_get_val_s(icrom, crom)
 
 !===============================================================================
