@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -80,6 +80,7 @@ subroutine cplini &
 use paramx
 use numvar
 use optcal
+use dimens, only: nvar
 use cstphy
 use cstnum
 use entsor
@@ -95,7 +96,7 @@ use mesh
 
 implicit none
 
-double precision rtp(ncelet,*)
+double precision rtp(ncelet,nflown:nvar)
 
 ! Local variables
 
