@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -98,6 +98,7 @@ use paramx
 use numvar
 use entsor
 use optcal
+use dimens, only: nvar
 use cstphy
 use cstnum
 use parall
@@ -110,6 +111,7 @@ use ppincl
 use lagpar
 use lagran
 use mesh
+use field
 
 !===============================================================================
 
@@ -121,7 +123,7 @@ integer          iscal
 
 integer          itypfb(nfabor)
 
-double precision rtp(ncelet,*), rtpa(ncelet,*)
+double precision rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision smbrs(ncelet), rovsdt(ncelet)
 double precision tslagr(ncelet,*)
@@ -144,7 +146,7 @@ integer          iscala , icha
 ivar = isca(iscal)
 
 ! --- Nom de la variable associee au scalaire a traiter ISCAL
-chaine = nomvar(ipprtp(ivar))
+call field_get_label(ivarfl(ivar), chaine)
 
 !===============================================================================
 ! 2. PRISE EN COMPTE DES TERMES SOURCES
