@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -107,6 +107,7 @@ subroutine cplym1 &
 use paramx
 use numvar
 use optcal
+use dimens, only: nvar
 use cstphy
 use cstnum
 use entsor
@@ -130,7 +131,7 @@ integer          nitbmc , nrtbmc
 integer          itbmc(ncelet,nitbmc)
 integer          indpdf(ncelet) , ipi7i8(ncelet)
 
-double precision rtp(ncelet,*)
+double precision rtp(ncelet,nflown:nvar)
 double precision f1m(ncelet)  , f2m(ncelet)
 double precision f3m(ncelet)  , f4m(ncelet)
 double precision dsi7(ncelet) , dsi8(ncelet) , sdeb(ncelet)
