@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -53,6 +53,7 @@ subroutine cs_coal_masstransfer &
 use paramx
 use numvar
 use optcal
+use dimens, only: nvar
 use cstphy
 use cstnum
 use entsor
@@ -73,7 +74,7 @@ implicit none
 
 integer          ncelet , ncel
 
-double precision rtpa(ncelet,*), propce(ncelet,*)
+double precision rtpa(ncelet,nflown:nvar), propce(ncelet,*)
 double precision volume(ncelet)
 
 ! Local variables
