@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -68,6 +68,7 @@ subroutine cs_coal_thfieldconv1 &
 use paramx
 use numvar
 use optcal
+use dimens, only: nvar
 use cstphy
 use cstnum
 use entsor
@@ -86,7 +87,7 @@ implicit none
 
 integer          ncelet , ncel
 
-double precision eh(ncelet)   , x2(ncelet)   , rtp(ncelet,*)
+double precision eh(ncelet)   , x2(ncelet)   , rtp(ncelet,nflown:nvar)
 double precision fuel1(ncelet), fuel2(ncelet), fuel3(ncelet)
 double precision fuel4(ncelet), fuel5(ncelet), fuel6(ncelet) , fuel7(ncelet)
 double precision oxyd(ncelet), xiner(ncelet)
