@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -64,7 +64,7 @@ implicit none
 
 ! Local variables
 
-integer ii, jj, isc, ipp
+integer jj, isc
 double precision cpa,cpe,cpv,hv0,rhoe,visc,conduc
 
 !===============================================================================
@@ -73,12 +73,6 @@ double precision cpa,cpe,cpv,hv0,rhoe,visc,conduc
 ! 1. Transported variables
 !===============================================================================
 
-itherm = 1
-iscacp(itemp4) = 1
-iscacp(ihumid) = 0
-
-iscalt = itemp4
-
 irovar = 1
 ivivar = 0
 
@@ -96,18 +90,6 @@ do isc = 1, nscapp
 
 enddo
 
-ipp = ipprtp(isca(itemp4))
-nomvar(ipp)  = 'Temperature'
-ichrvr(ipp)  = 1
-ilisvr(ipp)  = 1
-ihisvr(ipp,1)= -1
-
-ipp = ipprtp(isca(ihumid))
-nomvar(ipp)  = 'Humidity'
-ichrvr(ipp)  = 1
-ilisvr(ipp)  = 1
-ihisvr(ipp,1)= -1
-
 ! Postprocessing output
 
 ichrze = 1
