@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -91,7 +91,7 @@ implicit none
 
 integer          nvar   , nscal
 
-double precision dt(ncelet), rtp(ncelet,*), propce(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), propce(ncelet,*)
 
 ! Local variables
 
@@ -114,7 +114,7 @@ double precision dt(ncelet), rtp(ncelet,*), propce(ncelet,*)
 call cs_user_initialization &
 !==========================
 ( nvar   , nscal  ,                                            &
-  dt     , rtp    , propce )
+  dt     )
 
 
 !----
