@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -58,6 +58,7 @@ use paramx
 use numvar
 use entsor
 use optcal
+use dimens, only: nvar
 use cstphy
 use cstnum
 use period
@@ -66,6 +67,7 @@ use ppthch
 use ppincl
 use ctincl
 use mesh
+use field
 
 !===============================================================================
 
@@ -75,7 +77,7 @@ implicit none
 
 integer          iscal
 
-double precision rtp(ncelet,*)
+double precision rtp(ncelet,nflown:nvar)
 double precision smbrs(ncelet), rovsdt(ncelet)
 
 ! Local variables
@@ -96,8 +98,7 @@ integer          ivar
 ivar = isca(iscal)
 
 ! --- Nom de la variable associee au scalaire a traiter ISCAL
-chaine = nomvar(ipprtp(ivar))
-
+call field_get_label(ivarfl(ivar), chaine)
 
 !===============================================================================
 ! 2. PRISE EN COMPTE DES TERMES SOURCES ET VARIABLES STANDARDS
