@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -69,35 +69,38 @@ implicit none
 integer        isc
 
 !===============================================================================
-!===============================================================================
-! 1. DEFINITION DES POINTEURS
-!===============================================================================
-
-! ---- Temperature
-itemp4 = iscapp(1)
-
-! ---- Humidite
-ihumid = iscapp(2)
-
 
 !===============================================================================
-! 2. PROPRIETES PHYSIQUES
-!    A RENSEIGNER OBLIGATOIREMENT (sinon pb dans varpos)
-!      IVISLS, ICP
+! 1. Definition of fields
+!===============================================================================
+
+! Thermal model
+
+itherm = 1
+itpscl = 2
+
+call add_model_scalar_field('temperature', 'Temperature', itemp4)
+iscalt = itemp4
+
+iscacp(itemp4) = 1
+
+call add_model_scalar_field('humidity', 'Humidity', ihumid)
+
+!===============================================================================
+! 2. Physical properties
 !===============================================================================
 
 do isc = 1, nscapp
 
-  if ( iscavr(iscapp(isc)).le.0 ) then
-
-! ---- Viscosite dynamique moleculaire variable pour les
-!                                              scalaires ISCAPP(ISC)
+  if (iscavr(iscapp(isc)).le.0) then
+    ! Reference dynamic viscosity relative to this scalar
     ivisls(iscapp(isc)) = 0
-
   endif
 
 enddo
 
+! Cp is variable
+
 icp = 1
 
 return
