@@ -6,7 +6,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -503,7 +503,7 @@ _add_catalyst_field(fvm_to_catalyst_t         *writer,
                     const double               time_value)
 {
   int f_id = writer->n_fields;
-  
+
   BFT_REALLOC(writer->fields,
               writer->n_fields+ 1,
               fvm_catalyst_field_t *);
@@ -511,6 +511,8 @@ _add_catalyst_field(fvm_to_catalyst_t         *writer,
   vtkUnstructuredGrid *f =  NULL;
   vtkDoubleArray *tmp = NULL;
 
+  const int dest_dim = (dim == 6) ? 9 : dim;
+
   if (writer->mb->GetMetaData(mesh_id) != NULL) {
 
     f = vtkUnstructuredGrid::SafeDownCast(vtkDataSet::SafeDownCast
@@ -519,7 +521,7 @@ _add_catalyst_field(fvm_to_catalyst_t         *writer,
     tmp = vtkDoubleArray::New();
     tmp->SetName(fieldname);
 
-    tmp->SetNumberOfComponents(dim);
+    tmp->SetNumberOfComponents(dest_dim);
 
     if (location == FVM_WRITER_PER_NODE) {
       f->GetPointData()->AllocateArrays(f->GetNumberOfPoints());
@@ -548,7 +550,7 @@ _add_catalyst_field(fvm_to_catalyst_t         *writer,
   writer->fields[f_id]->f = f;
 
   writer->n_fields++;
-  
+
   return f_id;
 }
 
@@ -569,8 +571,6 @@ _export_vertex_coords(const fvm_nodal_t        *mesh,
 
   double point[3];
 
-  double  *block_coords = NULL;
-
   const double  *vertex_coords = mesh->vertex_coords;
   const cs_lnum_t  n_vertices = mesh->n_vertices;
 
@@ -651,7 +651,7 @@ _write_connect_block(fvm_element_t         type,
   int vertex_order[8];
   cs_lnum_t  i;
   int  j;
-  
+
   vtkIdType *vtx_ids = new vtkIdType[8];
 
   const int  stride = fvm_nodal_n_vertices_element[type];
@@ -825,8 +825,8 @@ _export_nodal_polyhedra(cs_lnum_t                   n_vertices,
  *----------------------------------------------------------------------------*/
 
 static void
-_export_field_values_n(const fvm_nodal_t     *mesh,
-                       const char            *fieldname,
+_export_field_values_n(const fvm_nodal_t    *mesh,
+                       const char           *fieldname,
                        int                   dim,
                        cs_interlace_t        interlace,
                        int                   n_parent_lists,
@@ -837,16 +837,19 @@ _export_field_values_n(const fvm_nodal_t     *mesh,
 {
   assert(f != NULL);
 
-  void *values;
+  double *values = NULL;
+
+  const int dest_dim = (dim == 6) ? 9 : dim;
+
   values = vtkDoubleArray::SafeDownCast
     (f->GetPointData()->GetArray(fieldname))
     ->WritePointer(0, f->GetNumberOfPoints());
 
   fvm_convert_array(dim,
                     0,
-                    dim, 
-                    0, 
-                    mesh->n_vertices, 
+                    dest_dim,
+                    0,
+                    mesh->n_vertices,
                     interlace,
                     datatype,
                     CS_DOUBLE,
@@ -855,6 +858,21 @@ _export_field_values_n(const fvm_nodal_t     *mesh,
                     mesh->parent_vertex_num,
                     field_values,
                     values);
+
+  /* Special case for symmetric tensors */
+
+  if (dim == 6) {
+    for (cs_lnum_t i = 0; i < mesh->n_vertices; i++) {
+      values[9*i + 8] = values[9*i + 2];
+      values[9*i + 7] = values[9*i + 4];
+      values[9*i + 6] = values[9*i + 5];
+      values[9*i + 4] = values[9*i + 1];
+      values[9*i + 2] = values[9*i + 5];
+      values[9*i + 1] = values[9*i + 3];
+      values[9*i + 5] = values[9*i + 7];
+    }
+  }
+
 }
 
 /*----------------------------------------------------------------------------
@@ -892,6 +910,8 @@ _export_field_values_e(const fvm_nodal_t         *mesh,
   int  section_id;
   double  *values = NULL;
 
+  const int dest_dim = (dim == 6) ? 9 : dim;
+
   values = vtkDoubleArray::SafeDownCast
     (f->GetCellData()->GetArray(fieldname))
     ->WritePointer(0, dim*f->GetNumberOfCells());
@@ -928,7 +948,21 @@ _export_field_values_e(const fvm_nodal_t         *mesh,
                       field_values,
                       values + start_id);
 
-    start_id += section->n_elements*dim;
+    /* Special case for symmetric tensors */
+
+    if (dim == 6) {
+      for (cs_lnum_t i = 0; i < mesh->n_vertices; i++) {
+        values[9*i + 8] = values[9*i + 2];
+        values[9*i + 7] = values[9*i + 4];
+        values[9*i + 6] = values[9*i + 5];
+        values[9*i + 4] = values[9*i + 1];
+        values[9*i + 2] = values[9*i + 5];
+        values[9*i + 1] = values[9*i + 3];
+        values[9*i + 5] = values[9*i + 7];
+      }
+    }
+
+    start_id += section->n_elements*dest_dim;
     if (n_parent_lists == 0)
       src_shift += section->n_elements;
 
@@ -1059,7 +1093,7 @@ fvm_to_catalyst_init_writer(const char             *name,
   w->processor->Initialize();
 
   vtkCPPythonScriptPipeline  *pipeline = vtkCPPythonScriptPipeline::New();
- 
+
   /* read the coprocessing Python file */
 
   char *script_path = NULL;
@@ -1080,11 +1114,11 @@ fvm_to_catalyst_init_writer(const char             *name,
     if (pipeline->Initialize(script_path) == 0)
       bft_error(__FILE__, __LINE__, 0,
                 _("Error initializing pipeline from \"%s\":\n\n"), script_path);
- 
+
     /* pipeline->SetGhostLevel(1); */
     w->processor->AddPipeline(pipeline);
     pipeline->Delete();
- 
+
   }
   else
     bft_error(__FILE__, __LINE__, 0,
