@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -132,6 +132,17 @@ void CS_PROCF (csvvva, CSVVVA) (int *const iviscv);
 
 void CS_PROCF (csnsca, CSNSCA) (int *const nscaus);
 
+/*----------------------------------------------------------------------------
+ * User scalars labels
+ *
+ * Fortran Interface:
+ *
+ * SUBROUTINE UISCAU
+ * *****************
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (uiscau, UISCAU) (void);
+
 /*----------------------------------------------------------------------------
  * User thermal scalar.
  *
@@ -157,9 +168,8 @@ void CS_PROCF (uithsc, UITHSC) (int *const iscalt);
  * integer          itherm     <--  type of thermal model
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF (csisca, CSISCA) (      int *const iscavr,
-                                      int *const itherm,
-                                const int *const iscapp);
+void CS_PROCF (csisca, CSISCA) (int        *iscavr,
+                                const int  *itherm);
 
 /*----------------------------------------------------------------------------
  * Constant or variable indicator for the user scalar laminar viscosity.
@@ -236,39 +246,6 @@ void CS_PROCF (csiphy, CSIPHY) (int *const iphydr);
 
 void CS_PROCF (cscfgp, CSCFGP) (int *const icfgrp);
 
-/*----------------------------------------------------------------------------
- *
- * SUBROUTINE CSVNUM()
- * *****************
- *----------------------------------------------------------------------------*/
-
-void CS_PROCF (csvnum, CSVNUM) (const int *const nvar,
-                                const int *const iu,
-                                const int *const iv,
-                                const int *const iw,
-                                const int *const ipr,
-                                const int *const iturb,
-                                const int *const ik,
-                                const int *const iep,
-                                const int *const ir11,
-                                const int *const ir22,
-                                const int *const ir33,
-                                const int *const ir12,
-                                const int *const ir13,
-                                const int *const ir23,
-                                const int *const iomg,
-                                const int *const iphi,
-                                const int *const ifb,
-                                const int *const ial,
-                                const int *const inusa,
-                                const int *const iale,
-                                const int *const iuma,
-                                const int *const ivma,
-                                const int *const iwma,
-                                const int *const isca,
-                                const int *const iscapp,
-                                const int *const itherm);
-
 /*----------------------------------------------------------------------------
  * Restart parameters.
  *
@@ -329,18 +306,16 @@ void CS_PROCF (cstime, CSTIME) (int    *const inpdt0,
  *
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF (uinum1, UINUM1) (const    int *const isca,
-                                const    int *const iscapp,
-                                      double *const blencv,
-                                         int *const ischcv,
-                                         int *const isstpc,
-                                         int *const ircflu,
-                                      double *const cdtvar,
-                                         int *const nitmax,
-                                      double *const epsilo,
-                                         int *const iresol,
-                                         int *const imgrpr,
-                                         int *const nswrsm);
+void CS_PROCF (uinum1, UINUM1) (double *const blencv,
+                                   int *const ischcv,
+                                   int *const isstpc,
+                                   int *const ircflu,
+                                double *const cdtvar,
+                                   int *const nitmax,
+                                double *const epsilo,
+                                   int *const iresol,
+                                   int *const imgrpr,
+                                   int *const nswrsm);
 
 /*----------------------------------------------------------------------------
  * Global numerical parameters.
@@ -383,65 +358,40 @@ void CS_PROCF (csphys, CSPHYS) (const    int *const nmodpp,
                                       double *const t0,
                                       double *const p0,
                                       double *const xmasmr,
-                                         int *const itempk);
+                                         int *const itempk,
+                                         int *const itherm,
+                                         int *const itpscl);
 
 /*----------------------------------------------------------------------------
  * User scalar min and max values for clipping.
  *
  * Fortran Interface:
  *
- * subroutine cssca2 (iscalt, iscavr, scamin, scamax)
+ * subroutine cssca2
  * *****************
  *
- * integer          iscalt  <--   index of the thermal scalar
- * integer          iscavr  <--   number of the related variance if any
- * double precision scamin  -->   user scalar min array
- * double precision scamax  -->   user scalar max array
+ * integer          iscavr   <--  number of the related variance if any
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF (cssca2, CSSCA2) (const    int *const iscalt,
-                                const    int *const iscavr,
-                                      double *const scamin,
-                                      double *const scamax);
-
-/*----------------------------------------------------------------------------
- * Read reference dynamic and user scalar viscosity
- *----------------------------------------------------------------------------*/
+void CS_PROCF (cssca2, CSSCA2) (const    int *const iscavr);
 
 void CS_PROCF (cssca3, CSSCA3) (const    int *const itherm,
                                 const    int *const iscalt,
                                 const    int *const iscavr,
                                 double *const visls0,
                                 double *const t0,
-                                double *const p0);
+                                double *const p0,
+                                double *const cp0);
 
 /*----------------------------------------------------------------------------
  * Array of properties used in the calculation
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF (uiprop, UIPROP) (const int *const irom,
-                                const int *const iviscl,
-                                const int *const ivisct,
-                                const int *const ivisls,
-                                const int *const icour,
-                                const int *const ifour,
+void CS_PROCF (uiprop, UIPROP) (const int *const ivisls,
                                 const int *const ismago,
                                 const int *const iale,
                                 const int *const icp,
-                                const int *const iscalt,
-                                const int *const iscavr,
-                                const int *const iprtot,
-                                const int *const ipppro,
-                                const int *const ipproc,
-                                const int *const icmome,
-                                const int *const ipptx,
-                                const int *const ippty,
-                                const int *const ipptz,
-                                const int *const ippdt,
-                                const int *const ivisma,
-                                const int *const idtvar,
-                                const int *const ipucou,
-                                const int *const iappel);
+                                const int *const iscavr);
 
 /*----------------------------------------------------------------------------
  * Temporal averaging treatment
@@ -467,23 +417,32 @@ void CS_PROCF (uimoyt, UIMOYT) (const int *const ndgmox,
 void CS_PROCF (cstini, CSTINI) (double *const uref,
                                 double *const almax);
 
-void CS_PROCF(fcnmva, FCNMVA)
-(
- const char      *const fstr,    /* Fortran string */
- int             *const len,     /* String Length  */
- int             *const var_id   /* Variable Id (1 to n) */
- CS_ARGF_SUPP_CHAINE
-);
+/*----------------------------------------------------------------------------
+ * Solver taking a scalar porosity into account
+ *
+ * Fortran Interface:
+ *
+ * SUBROUTINE UIIPSU
+ * *****************
+ *
+ * INTEGER          IPOROS     -->   porosity
+ *----------------------------------------------------------------------------*/
 
-void CS_PROCF(cfnmva, CFNMVA)
-(
- char          *const fstr,    /* Fortran string */
- int           *const len,     /* String Length  */
- int           *const var_id   /* Variable Id (1 to n) */
- CS_ARGF_SUPP_CHAINE
-);
+void CS_PROCF (uiipsu, UIIPSU) (int *iporos);
 
-void CS_PROCF(nvamem, NVAMEM) (void);
+/*----------------------------------------------------------------------------
+ * Define porosity.
+ *
+ * Fortran Interface:
+ *
+ * SUBROUTINE UIPORO
+ * *****************
+ *
+ * INTEGER          IPOROS     <--   porosity
+ *----------------------------------------------------------------------------*/
+
+void CS_PROCF (uiporo, UIPORO) (const int *ncelet,
+                                const int *iporos);
 
 /*----------------------------------------------------------------------------
  * User momentum source terms.
@@ -509,16 +468,16 @@ void CS_PROCF(uitsnv, UITSNV)(const cs_real_3_t *restrict vel,
  *
  * Fortran Interface:
  *
- * subroutine uitssc (iscal, pvar, tsexp, tsimp)
+ * subroutine uitssc (f_id, pvar, tsexp, tsimp)
  * *****************
  *
- * integer          iscal    <-- index of the corresponding scalar
+ * integer          f_id     <--  field id
  * double precision pvar     <--  scalar
  * double precision tsexp    -->  explicit source terms
  * double precision tsimp    -->  implicit source terms
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF(uitssc, UITSSC)(const int                  *iscal,
+void CS_PROCF(uitssc, UITSSC)(const int                  *f_id,
                               const cs_real_t   *restrict pvar,
                               cs_real_t         *restrict tsexp,
                               cs_real_t         *restrict tsimp);
@@ -529,16 +488,16 @@ void CS_PROCF(uitssc, UITSSC)(const int                  *iscal,
  *
  * Fortran Interface:
  *
- * subroutine uitsth (iscal, pvar, tsexp, tsimp)
+ * subroutine uitsth (f_id, pvar, tsexp, tsimp)
  * *****************
  *
- * integer          iscal    <-- index of the corresponding scalar
+ * integer          f_id     <--  field id
  * double precision pvar     <--  scalar
  * double precision tsexp    -->  explicit source terms
  * double precision tsimp    -->  implicit source terms
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF(uitsth, UITSTH)(const int                  *iscal,
+void CS_PROCF(uitsth, UITSTH)(const int                  *f_id,
                               const cs_real_t   *restrict pvar,
                               cs_real_t         *restrict tsexp,
                               cs_real_t         *restrict tsimp);
@@ -553,38 +512,24 @@ void CS_PROCF(uitsth, UITSTH)(const int                  *iscal,
  *
  * integer          ncelet   <--  number of cells with halo
  * integer          isuite   <--  restart indicator
- * integer          isca     <--  indirection array for scalar number
- * integer          iscold   <--  scalar number for restart
  * integer          iccfth   <--  type of initialisation(compressible model)
- * integer          ipr      <--  rtp index for pressure
- * integer          iscalt   <--  index of the thermal scalar
- * integer          itempk   <--  rtp index for temperature (in K)
- * integer          ienerg   <--  rtp index for energy total
  * double precision ro0      <--  value of density if IROVAR=0
  * double precision cp0      <--  value of specific heat if ICP=0
  * double precision viscl0   <--  value of viscosity if IVIVAR=0
  * double precision uref     <--  value of reference velocity
  * double precision almax    <--  value of reference length
  * double precision xyzcen   <--  cell's gravity center
- * double precision rtp      -->  variables and scalars array
  *----------------------------------------------------------------------------*/
 
 void CS_PROCF(uiiniv, UIINIV)(const int          *ncelet,
                               const int          *isuite,
-                              const int          *isca,
-                              const int          *iscold,
                                     int          *iccfth,
-                              const int *const    ipr,
-                              const int *const    iscalt,
-                              const int *const    itempk,
-                              const int *const    ienerg,
                               const cs_real_t    *ro0,
                               const cs_real_t    *cp0,
                               const cs_real_t    *viscl0,
                               const cs_real_t    *uref,
                               const cs_real_t    *almax,
-                              const double *const xyzcen,
-                                    double        rtp[]);
+                              const double *const xyzcen);
 
 /*----------------------------------------------------------------------------
  * User law for material Properties
@@ -596,16 +541,12 @@ void CS_PROCF(uiiniv, UIINIV)(const int          *ncelet,
  *
  * INTEGER          NCEL     <--  number of cells whithout halo
  * INTEGER          NCELET   <--  number of cells whith halo
- * INTEGER          NSCAUS   <--  number of user scalar including thermal scalar
- * INTEGER          IVISCL   <--  pointer for mulecular viscosity mu
  * INTEGER          ICP      <--  pointer for predifined heat Cp
  * INTEGER          IVISLS   <--  pointer for Lambda/Cp
  * INTEGER          IROVAR   <--  =1 if rho variable, =0 if rho constant
  * INTEGER          IVIVAR   <--  =1 if mu variable, =0 if mu constant
- * INTEGER          ISCA     <--  indirection array for scalar number
  * INTEGER          ISCALT   <--  pointer for the thermal scalar in ISCA
  * INTEGER          ISCAVR   <--  scalars that are variance
- * INTEGER          IPPROC   <--  indirection array for cell properties
  * INTEGER          IVISCV   <--  pointer for volumic viscosity viscv
  * INTEGER          ITEMPK   <--  pointer for temperature (in K)
  * DOUBLE PRECISION P0       <--  pressure reference value
@@ -615,33 +556,26 @@ void CS_PROCF(uiiniv, UIINIV)(const int          *ncelet,
  * DOUBLE PRECISION VISCL0   <--  dynamic viscosity reference value
  * DOUBLE PRECISION VISLS0   <--  diffusion coefficient of the scalars
  * DOUBLE PRECISION VISCV0   <--  volumic viscosity
- * DOUBLE PRECISION RTP      <--  variables and scalars array
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF(uiphyv, UIPHYV)(const cs_int_t  *const ncel,
-                              const cs_int_t  *const ncelet,
-                              const cs_int_t  *const nscaus,
-                              const cs_int_t  *const itherm,
-                              const cs_int_t         iviscl[],
-                              const cs_int_t         icp[],
-                              const cs_int_t         ivisls[],
-                              const cs_int_t         irovar[],
-                              const cs_int_t         ivivar[],
-                              const cs_int_t         isca[],
-                              const cs_int_t         iscalt[],
-                              const cs_int_t         iscavr[],
-                              const cs_int_t         ipproc[],
-                              const cs_int_t         iviscv[],
-                              const cs_int_t         itempk[],
-                              const cs_real_t        p0[],
-                              const cs_real_t        t0[],
-                              const cs_real_t        ro0[],
-                              const cs_real_t        cp0[],
-                              const cs_real_t        viscl0[],
-                              const cs_real_t        visls0[],
-                              const cs_real_t        viscv0[],
-                              const cs_real_t        rtp[],
-                                    double           propce[]);
+void CS_PROCF(uiphyv, UIPHYV)(const cs_int_t  *ncel,
+                              const cs_int_t  *ncelet,
+                              const cs_int_t  *itherm,
+                              const cs_int_t  *icp,
+                              const cs_int_t   ivisls[],
+                              const cs_int_t  *irovar,
+                              const cs_int_t  *ivivar,
+                              const cs_int_t  *iscalt,
+                              const cs_int_t   iscavr[],
+                              const cs_int_t  *iviscv,
+                              const cs_int_t  *itempk,
+                              const cs_real_t *p0,
+                              const cs_real_t *t0,
+                              const cs_real_t *ro0,
+                              const cs_real_t *cp0,
+                              const cs_real_t *viscl0,
+                              const cs_real_t *visls0,
+                              const cs_real_t *viscv0);
 
 /*----------------------------------------------------------------------------
  * Head losses definition
@@ -656,15 +590,13 @@ void CS_PROCF(uiphyv, UIPHYV)(const cs_int_t  *const ncel,
  * integer          ncepdp  -->   number of cells with head losses
  * integer          icepdc  -->   ncepdp cells number with head losses
  * double precision ckupdc  -->   head losses matrix
- * double precision rtpa     <--  variables array at previous time step
  *----------------------------------------------------------------------------*/
 
 void CS_PROCF(uikpdc, UIKPDC)(const int*   iappel,
                               const int*   ncelet,
                                     int*   ncepdp,
                                     int    icepdc[],
-                                    double ckupdc[],
-                              const double rtpa[] );
+                                    double ckupdc[]);
 
 /*----------------------------------------------------------------------------
  * 1D profile postprocessing
@@ -682,9 +614,6 @@ void CS_PROCF(uikpdc, UIKPDC)(const int*   iappel,
  * DOUBLE PRECISION TTMABS   <--  max physical time
  * DOUBLE PRECISION TTPABS   <--  physical time at calculation beginning
  * DOUBLE PRECISION XYZCEN   <--  cell's gravity center
- * DOUBLE PRECISION RTP      <--  variables and scalars array
- * DOUBLE PRECISION PROPCE   <--  property array
- * INTEGER          IPPROC   <--  indirection array for cell properties
  *----------------------------------------------------------------------------*/
 
 void CS_PROCF (uiprof, UIPROF)(const int    *const ncelet,
@@ -694,10 +623,7 @@ void CS_PROCF (uiprof, UIPROF)(const int    *const ncelet,
                                const double *const ttcabs,
                                const double *const ttmabs,
                                const double *const ttpabs,
-                               const double *const xyzcen,
-                               const double *const rtp,
-                               const double *const propce,
-                               const int    *const ipproc);
+                               const double *const xyzcen);
 
 /*----------------------------------------------------------------------------
  * Free memory: clean global private variables and libxml2 variables.
@@ -716,6 +642,16 @@ void CS_PROCF (memui1, MEMUI1) (const int *const ncharb);
  * Public function prototypes
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ * Get thermal scalar model.
+ *
+ * return:
+ *   value of itherm
+ *----------------------------------------------------------------------------*/
+
+int
+gui_thermal_model(void);
+
 /*-----------------------------------------------------------------------------
  * Get initial value from property markup.
  *
