@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -72,8 +72,6 @@ void CS_PROCF (csenso, CSENSO) (const cs_int_t  *nvppmx,
                                 cs_int_t        *ntlist,
                                 cs_int_t        *iecaux,
                                 cs_int_t        *ipstdv,
-                                cs_int_t        *ichrvr,
-                                cs_int_t        *ilisvr,
                                 cs_int_t        *ihisvr,
                                 cs_int_t        *tplfmt,
                                 const cs_int_t  *isca,
