@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -25,7 +25,6 @@ subroutine lagcou &
 
  ( nbpmax ,                                                       &
    ntersl ,                                                       &
-   indep  , ibord  ,                                              &
    rtp    , propce ,                                              &
    taup   , tempct , tsfext ,                                     &
    cpgd1  , cpgd2  , cpght  ,                                     &
@@ -62,10 +61,8 @@ subroutine lagcou &
 !__________________!____!_____!________________________________________________!
 ! nbpmax           ! e  ! <-- ! nombre max de particulies autorise             !
 ! ntersl           ! e  ! <-- ! nbr termes sources de couplage retour          !
-! indep            ! te ! <-- ! pour chaque particule :                        !
-!  (nbpmax)        !    !     !    numero de la cellule de depart              !
-! ibord            ! te ! <-- ! contient le numero de la                       !
-!   (nbpmax)       !    !     !   face d'interaction part/frontiere            !
+! itepa            ! te ! --> ! info particulaires (entiers)                   !
+! (nbpmax,nivep)   !    !     !   (cellule de la particule,...)                !
 ! rtp              ! tr ! <-- ! variables de calcul au centre des              !
 ! (ncelet,*)       !    !     !    cellules                                    !
 ! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
@@ -99,6 +96,7 @@ use paramx
 use cstnum
 use numvar
 use optcal
+use dimens, only: nvar
 use entsor
 use cstphy
 use pointe
@@ -121,9 +119,8 @@ implicit none
 
 integer          nbpmax
 integer          ntersl
-integer          indep(nbpmax), ibord(nbpmax)
 
-double precision propce(ncelet,*) , rtp(ncelet,*)
+double precision propce(ncelet,*) , rtp(ncelet,nflown:nvar)
 double precision taup(nbpmax) , tempct(nbpmax,2)
 double precision tsfext(nbpmax)
 double precision cpgd1(nbpmax) , cpgd2(nbpmax) , cpght(nbpmax)
@@ -138,9 +135,13 @@ double precision tvmax , tauv , taum , aux1
 double precision uuf , vvf , wwf , mf
 
 double precision, dimension(:), pointer ::  crom
+double precision, dimension(:,:), pointer :: vel
 
 !===============================================================================
 
+! Map field arrays
+call field_get_val_v(ivarfl(iu), vel)
+
 !===============================================================================
 ! 1. INITIALISATION
 !===============================================================================
@@ -178,7 +179,7 @@ enddo
 
 do npt = 1,nbpart
   aux1 = dtp/taup(npt)
-  if (nordre.eq.1 .or. ibord(npt).gt.0) then
+  if (nordre.eq.1 .or. itepa(npt,jord1).gt.0) then
     tsfext(npt)= (1.d0-exp(-aux1)) *ettp(npt,jmp) *taup(npt)
   else
     tsfext(npt) = tsfext(npt)                                     &
@@ -210,7 +211,7 @@ if (ltsdyn.eq.1) then
 
   do npt = 1,nbpart
 
-    iel = indep(npt)
+    iel = itepa(npt,jisora)
 
 ! Volume et masse des particules dans la maille
 
@@ -242,7 +243,7 @@ if (ltsdyn.eq.1) then
 
     do npt = 1,nbpart
 
-      iel = indep(npt)
+      iel = itepa(npt,jisora)
 
       uuf = 0.5d0 * ( ettpa(npt,juf) + ettp(npt,juf) )
       vvf = 0.5d0 * ( ettpa(npt,jvf) + ettp(npt,jvf) )
@@ -258,9 +259,9 @@ if (ltsdyn.eq.1) then
     do iel = 1,ncel
 
       tslag(iel,itske) = tslag(iel,itske)                       &
-                       - rtp(iel,iu) * tslag(iel,itsvx)         &
-                       - rtp(iel,iv) * tslag(iel,itsvy)         &
-                       - rtp(iel,iw) * tslag(iel,itsvz)
+                       - vel(1,iel) * tslag(iel,itsvx)         &
+                       - vel(2,iel) * tslag(iel,itsvy)         &
+                       - vel(3,iel) * tslag(iel,itsvz)
 
     enddo
 
@@ -268,7 +269,7 @@ if (ltsdyn.eq.1) then
 
     do npt = 1,nbpart
 
-      iel = indep(npt)
+      iel = itepa(npt,jisora)
 
       uuf = 0.5d0 * ( ettpa(npt,juf) + ettp(npt,juf) )
       vvf = 0.5d0 * ( ettpa(npt,jvf) + ettp(npt,jvf) )
@@ -300,25 +301,25 @@ if (ltsdyn.eq.1) then
     do iel = 1,ncel
 
       tslag(iel,itsr11) = tslag(iel,itsr11)                       &
-                 - 2.d0 * rtp(iel,iu) * tslag(iel,itsvx)
+                 - 2.d0 * vel(1,iel) * tslag(iel,itsvx)
 
       tslag(iel,itsr12) = tslag(iel,itsr12)                       &
-                        - rtp(iel,iu) * tslag(iel,itsvy)   &
-                        - rtp(iel,iv) * tslag(iel,itsvx)
+                        - vel(1,iel) * tslag(iel,itsvy)   &
+                        - vel(2,iel) * tslag(iel,itsvx)
 
       tslag(iel,itsr13) = tslag(iel,itsr13)                       &
-                        - rtp(iel,iu) * tslag(iel,itsvz)   &
-                        - rtp(iel,iw) * tslag(iel,itsvx)
+                        - vel(1,iel) * tslag(iel,itsvz)   &
+                        - vel(3,iel) * tslag(iel,itsvx)
 
       tslag(iel,itsr22) = tslag(iel,itsr22)                       &
-                 - 2.d0 * rtp(iel,iv) * tslag(iel,itsvy)
+                 - 2.d0 * vel(2,iel) * tslag(iel,itsvy)
 
       tslag(iel,itsr23) = tslag(iel,itsr23)                       &
-                        - rtp(iel,iv) * tslag(iel,itsvz)   &
-                        - rtp(iel,iw) * tslag(iel,itsvy)
+                        - vel(2,iel) * tslag(iel,itsvz)   &
+                        - vel(3,iel) * tslag(iel,itsvy)
 
       tslag(iel,itsr33) = tslag(iel,itsr33)                       &
-                 - 2.d0 * rtp(iel,iw) * tslag(iel,itsvz)
+                 - 2.d0 * vel(3,iel) * tslag(iel,itsvz)
 
     enddo
 
@@ -336,7 +337,7 @@ if ( ltsmas.eq.1 .and. (impvar.eq.1 .or. idpvar.eq.1) ) then
 
 ! Dans saturne TSmasse > 0 ===> Apport de masse sur le fluide
 
-    iel = indep(npt)
+    iel = itepa(npt,jisora)
 
     tslag(iel,itsmas) = tslag(iel,itsmas) - tepa(npt,jrpoi)       &
      * ( ettp(npt,jmp) - ettpa(npt,jmp) ) /dtp
@@ -355,7 +356,7 @@ if (ltsthe.eq.1) then
 
     do npt = 1,nbpart
 
-      iel = indep(npt)
+      iel = itepa(npt,jisora)
 
       tslag(iel,itste) = tslag(iel,itste)                         &
      -( ettp(npt,jmp)  *ettp(npt,jtp) *ettp(npt,jcp)              &
@@ -371,7 +372,7 @@ if (ltsthe.eq.1) then
 
       do npt = 1,nbpart
 
-        iel = indep(npt)
+        iel = itepa(npt,jisora)
 
         aux1 = pi *ettp(npt,jdp) *ettp(npt,jdp) *tepa(npt,jreps)  &
                 *(propce(iel,ipproc(ilumin))                      &
@@ -396,7 +397,7 @@ if (ltsthe.eq.1) then
 
       do npt = 1,nbpart
 
-        iel = indep(npt)
+        iel = itepa(npt,jisora)
         icha = itepa(npt,jinch)
 
         tslag(iel,itste) = tslag(iel,itste)                         &
@@ -481,4 +482,4 @@ endif
 ! FIN
 !----
 
-end subroutine
+end subroutine lagcou
