@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,9 @@ subroutine lages2 &
 !================
 
  ( nbpmax , nvp    , nvep   , nivep  ,                            &
-   itepa  , ibord  ,                                              &
-   rtpa   , rtp    , propce ,                            &
-   ettp   , ettpa  , tepa   , statis , taup   , tlag   , piil   , &
+   itepa  ,                                                       &
+   rtpa   , rtp    , propce ,                                     &
+   ettp   , ettpa  , tepa   , taup   , tlag   , piil   ,          &
    tsuf   , tsup   , bx     , tsfext ,                            &
    vagaus , auxl   , gradpr ,                                     &
    romp   , brgaus , terbru , fextla )
@@ -57,8 +57,6 @@ subroutine lages2 &
 ! ntersl           ! e  ! <-- ! nbr termes sources de couplage retour          !
 ! itepa            ! te ! <-- ! info particulaires (entiers)                   !
 ! (nbpmax,nivep    !    !     !   (cellule de la particule,...)                !
-! ibord            ! te ! --> ! si nordre=2, contient le numero de la          !
-!   (nbpmax)       !    !     !   face d'interaction part/frontiere            !
 ! rtp, rtpa        ! tr ! <-- ! variables de calcul au centre des              !
 ! (ncelet,*)       !    !     !    cellules (instant courant et prec)          !
 ! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
@@ -103,6 +101,7 @@ use numvar
 use cstphy
 use cstnum
 use optcal
+use dimens, only: nvar
 use entsor
 use lagpar
 use lagran
@@ -119,12 +118,12 @@ implicit none
 ! Arguments
 
 integer          nbpmax , nvp    , nvep  , nivep
-integer          itepa(nbpmax,nivep) , ibord(nbpmax)
+integer          itepa(nbpmax,nivep)
 
-double precision rtp(ncelet,*) , rtpa(ncelet,*)
+double precision rtp(ncelet,nflown:nvar) , rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision ettp(nbpmax,nvp) , ettpa(nbpmax,nvp)
-double precision tepa(nbpmax,nvep) , statis(ncelet,*)
+double precision tepa(nbpmax,nvep)
 double precision taup(nbpmax) , tlag(nbpmax,3)
 double precision piil(nbpmax,3) , bx(nbpmax,3,2)
 double precision tsuf(nbpmax,3) , tsup(nbpmax,3)
@@ -151,9 +150,14 @@ double precision grav(3) , rom , vitf
 double precision tbriu
 
 double precision, dimension(:), pointer :: cromf
+double precision, dimension(:,:), pointer :: vel, vela
 
 !===============================================================================
 
+! Map field arrays
+call field_get_val_v(ivarfl(iu), vel)
+call field_get_val_prev_v(ivarfl(iu), vela)
+
 !===============================================================================
 ! 1. INITIALISATIONS
 !===============================================================================
@@ -200,13 +204,13 @@ do id = 1,3
          +grav(id)+fextla(ip,id)       ) * taup(ip)
 
       if (nor.eq.1) then
-        if (id.eq.1) vitf = rtpa(iel,iu)
-        if (id.eq.2) vitf = rtpa(iel,iv)
-        if (id.eq.3) vitf = rtpa(iel,iw)
+        if (id.eq.1) vitf = vela(1,iel)
+        if (id.eq.2) vitf = vela(2,iel)
+        if (id.eq.3) vitf = vela(3,iel)
       else
-        if (id.eq.1) vitf = rtp(iel,iu)
-        if (id.eq.2) vitf = rtp(iel,iv)
-        if (id.eq.3) vitf = rtp(iel,iw)
+        if (id.eq.1) vitf = vel(1,iel)
+        if (id.eq.2) vitf = vel(2,iel)
+        if (id.eq.3) vitf = vel(3,iel)
       endif
       auxl(ip,id+3) = piil(ip,id) * tlag(ip,id) + vitf
 
@@ -321,7 +325,7 @@ else
 
     do ip = 1,nbpart
 
-      if (itepa(ip,jisor).gt.0 .and. ibord(ip).eq.0) then
+      if (itepa(ip,jisor).gt.0 .and. itepa(ip,jord1).eq.0) then
 
         aux0 = -dtp / taup(ip)
         aux1 = -dtp / tlag(ip,id)
@@ -449,4 +453,5 @@ endif
 ! FIN
 !----
 
-end subroutine
+return
+end subroutine lages2
