@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -24,7 +24,7 @@ subroutine lagich &
 !================
 
  ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                &
-   itepa  , ibord  , propce , ettp   , ettpa  ,                &
+   itepa  , propce , ettp   , ettpa  ,                         &
    tepa   , tempct , tsvar  , cpgd1  , cpgd2  ,                &
    cpght                                         )
 
@@ -56,8 +56,6 @@ subroutine lagich &
 ! nivep            ! e  ! <-- ! nombre info particulaires (entiers)            !
 ! itepa            ! te ! <-- ! info particulaires (entiers)                   !
 ! (nbpmax,nivep    !    !     !   (cellule de la particule,...)                !
-! ibord            ! te ! <-- ! contient le numero de la                       !
-!   (nbpmax)       !    !     !   face d'interaction part/frontiere            !
 ! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
 ! ettp             ! tr ! --> ! tableaux des variables liees                   !
 !  (nbpmax,nvp)    !    !     !   aux particules etape courante                !
@@ -109,7 +107,7 @@ implicit none
 
 integer          nbpmax , nvp , nvp1 , nvep , nivep
 
-integer          itepa(nbpmax,nivep) , ibord(nbpmax)
+integer          itepa(nbpmax,nivep)
 
 double precision propce(ncelet,*)
 double precision ettp(nbpmax,nvp) , ettpa(nbpmax,nvp)
