@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -24,8 +24,8 @@ subroutine lagidp &
 !================
 
  ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
-   itepa  , ibord  ,                                              &
-   ettp   , ettpa  ,  tepa   , taup   , tlag   , tempct ,         &
+   itepa  ,                                                       &
+   ettp   , ettpa  , tepa   ,                                     &
    tsvar  , auxl1  , auxl2  )
 
 !===============================================================================
@@ -49,18 +49,12 @@ subroutine lagidp &
 ! nivep            ! e  ! <-- ! nombre info particulaires (entiers)            !
 ! itepa            ! te ! <-- ! info particulaires (entiers)                   !
 ! (nbpmax,nivep    !    !     !   (cellule de la particule,...)                !
-! ibord            ! te ! <-- ! contient le numero de la                       !
-!   (nbpmax)       !    !     !   face d'interaction part/frontiere            !
 ! ettp             ! tr ! --> ! tableaux des variables liees                   !
 !  (nbpmax,nvp)    !    !     !   aux particules etape courante                !
 ! ettpa            ! tr ! <-- ! tableaux des variables liees                   !
 !  (nbpmax,nvp)    !    !     !   aux particules etape precedente              !
 ! tepa             ! tr ! <-- ! info particulaires (reels)                     !
 ! (nbpmax,nvep)    !    !     !   (poids statistiques,...)                     !
-! taup(nbpmax)     ! tr ! <-- ! temps caracteristique dynamique                !
-! tlag(nbpmax)     ! tr ! <-- ! temps caracteristique fluide                   !
-! tempct           ! tr ! <-- ! temps caracteristique thermique                !
-!  (nbpmax,2)      !    !     !                                                !
 ! tsvar            ! tr ! <-- ! prediction 1er sous-pas pour la                !
 ! (nbpmax,nvp1)    !    !     !   variable ivar, utilise pour la               !
 !                  !    !     !   correction au 2eme sous-pas                  !
@@ -96,11 +90,10 @@ implicit none
 
 integer          nbpmax , nvp , nvp1 , nvep , nivep
 
-integer          itepa(nbpmax,nivep) , ibord(nbpmax)
+integer          itepa(nbpmax,nivep)
 
 double precision ettp(nbpmax,nvp) , ettpa(nbpmax,nvp)
 double precision tepa(nbpmax,nvep)
-double precision taup(nbpmax) , tlag(nbpmax,3) , tempct(nbpmax,2)
 double precision tsvar(nbpmax,nvp1)
 double precision auxl1(nbpmax) , auxl2(nbpmax)
 
@@ -124,9 +117,9 @@ enddo
 
 call lagitg                                                       &
 !==========
- ( nbpmax , nvp    , nvp1   ,                                     &
+ ( nbpmax , nvp    , nvp1   , nivep ,                             &
    jdp    ,                                                       &
-   itepa(1,jisor)  , ibord  ,                                     &
+   itepa  ,                                                       &
    ettp   , ettpa  , auxl1  , auxl2  , tsvar  )
 
 !===============================================================================
