@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -24,9 +24,9 @@ subroutine lagitp &
 !================
 
  ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
-   itepa  , ibord  ,                                              &
+   itepa  ,                                                       &
    propce ,                                                       &
-   ettp   , ettpa  , tepa   , taup   , tlag   , tempct ,          &
+   ettp   , ettpa  , tepa   , tempct ,                            &
    tsvar  , auxl1  , auxl2  )
 
 !===============================================================================
@@ -50,8 +50,6 @@ subroutine lagitp &
 ! nivep            ! e  ! <-- ! nombre info particulaires (entiers)            !
 ! itepa            ! te ! <-- ! info particulaires (entiers)                   !
 ! (nbpmax,nivep    !    !     !   (cellule de la particule,...)                !
-! ibord            ! te ! <-- ! contient le numero de la                       !
-!   (nbpmax)       !    !     !   face d'interaction part/frontiere            !
 ! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
 ! ettp             ! tr ! --> ! tableaux des variables liees                   !
 !  (nbpmax,nvp)    !    !     !   aux particules etape courante                !
@@ -59,8 +57,6 @@ subroutine lagitp &
 !  (nbpmax,nvp)    !    !     !   aux particules etape precedente              !
 ! tepa             ! tr ! <-- ! info particulaires (reels)                     !
 ! (nbpmax,nvep)    !    !     !   (poids statistiques,...)                     !
-! taup(nbpmax)     ! tr ! <-- ! temps caracteristique dynamique                !
-! tlag(nbpmax)     ! tr ! <-- ! temps caracteristique fluide                   !
 ! tempct           ! tr ! <-- ! temps caracteristique thermique                !
 !  (nbpmax,2)      !    !     !                                                !
 ! tsvar            ! tr ! <-- ! prediction 1er sous-pas pour la                !
@@ -100,12 +96,12 @@ implicit none
 
 integer          nbpmax , nvp , nvp1 , nvep , nivep
 
-integer          itepa(nbpmax,nivep) , ibord(nbpmax)
+integer          itepa(nbpmax,nivep)
 
 double precision propce(ncelet,*)
 double precision ettp(nbpmax,nvp) , ettpa(nbpmax,nvp)
 double precision tepa(nbpmax,nvep)
-double precision taup(nbpmax) , tlag(nbpmax,3) , tempct(nbpmax,2)
+double precision tempct(nbpmax,2)
 double precision tsvar(nbpmax,nvp1)
 double precision auxl1(nbpmax) , auxl2(nbpmax)
 
@@ -177,9 +173,9 @@ endif
 
 call lagitg                                                       &
 !==========
- ( nbpmax , nvp    , nvp1   ,                                     &
+ ( nbpmax , nvp    , nvp1   , nivep  ,                            &
    jtp    ,                                                       &
-   itepa(1,jisor)  , ibord  ,                                     &
+   itepa  ,                                                       &
    ettp   , ettpa  , auxl1  , auxl2  , tsvar  )
 
 !===============================================================================
