@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -98,6 +98,7 @@ use cstnum
 use cstphy
 use numvar
 use optcal
+use dimens, only: nvar
 use entsor
 use parall
 use period
@@ -120,7 +121,7 @@ integer          nbpmax , nvp    , nvep  , nivep
 integer          ntersl , nvlsta , nvisbr
 integer          itepa(nbpmax,nivep)
 
-double precision rtpa(ncelet,*) , propce(ncelet,*)
+double precision rtpa(ncelet,nflown:nvar) , propce(ncelet,*)
 double precision ettp(nbpmax,nvp) , tepa(nbpmax,nvep)
 double precision statis(ncelet,nvlsta)
 double precision stativ(ncelet,nvlsta-1)
@@ -437,6 +438,8 @@ endif
 
 nberro = 0
 
+nomite(jord1) = 'order_1'
+
 if (nbclst.gt.0) then
   nomite(jclst) = 'numero_groupe_statistiques'
 endif
