@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -271,6 +271,7 @@ enddo
 ! Caracteristiques et infos particulaires (ENTIERS)
 
 nomite(jisor) = 'indicateur_'
+nomite(jord1) = 'order_1'
 
 if (iphyla.eq.2) then
   nomite(jinch) = 'numero_charbon'
@@ -298,7 +299,7 @@ nbval  = 1
 irtyp  = 1
 
 do ii = 1, nivep
-  if (ii .ne. jisor) then
+  if (ii .ne. jisor .and. ii .ne. jisora .and. ii .ne.jirka) then
     rubriq = nomite(ii)
     if (ii.eq.jdfac) then
       idbase = 1
