@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -25,7 +25,7 @@ subroutine lagphy &
 
  ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
-   itepa  , ibord  ,                                              &
+   itepa  ,                                                       &
    dt     , rtp    , propce ,                                     &
    ettp   , ettpa  , tepa   , taup   , tlag   ,                   &
    tempct , tsvar  , auxl   ,                                     &
@@ -53,8 +53,6 @@ subroutine lagphy &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! nvar             ! i  ! <-- ! total number of variables                      !
-! nscal            ! i  ! <-- ! total number of scalars                        !
 ! nbpmax           ! e  ! <-- ! nombre max de particulies autorise             !
 ! nvp              ! e  ! <-- ! nombre de variables particulaires              !
 ! nvp1             ! e  ! <-- ! nvp sans position, vfluide, vpart              !
@@ -65,8 +63,6 @@ subroutine lagphy &
 ! nvisbr           ! e  ! <-- ! nombre de statistiques aux frontieres          !
 ! itepa            ! te ! <-- ! info particulaires (entiers)                   !
 ! (nbpmax,nivep    !    !     !   (cellule de la particule,...)                !
-! ibord            ! te ! <-- ! contient le numero de la                       !
-!   (nbpmax)       !    !     !   face d'interaction part/frontiere            !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
 ! rtp              ! tr ! <-- ! variables de calcul au centre des              !
 ! (ncelet,*)       !    !     !    cellules (instant courant ou prec)          !
@@ -105,6 +101,7 @@ use numvar
 use cstphy
 use cstnum
 use optcal
+use dimens, only: nvar
 use entsor
 use lagpar
 use lagran
@@ -116,13 +113,12 @@ implicit none
 
 ! Arguments
 
-integer          nvar   , nscal
 integer          nbpmax , nvp    , nvp1   , nvep  , nivep
 integer          ntersl , nvlsta , nvisbr
 
-integer          itepa(nbpmax,nivep) , ibord(nbpmax)
+integer          itepa(nbpmax,nivep)
 
-double precision dt(ncelet) , rtp(ncelet,*)
+double precision dt(ncelet) , rtp(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision ettp(nbpmax,nvp) , ettpa(nbpmax,nvp)
 double precision tepa(nbpmax,nvep)
@@ -153,10 +149,10 @@ if ( iphyla.eq.2 .or. (iphyla.eq.1 .and. itpvar.eq.1) ) then
   call lagitf                                                     &
   !==========
   ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                  &
-    itepa  , ibord  ,                                             &
+    itepa  ,                                                      &
     rtp    , propce ,                                             &
-    ettp   , ettpa  , tepa   , taup   , tlag   , tempct ,         &
-    tsvar  , auxl(1,1) )
+    ettp   , ettpa  , tepa   , tsvar  ,                           &
+    auxl(1,1) )
 
 endif
 
@@ -169,9 +165,9 @@ if ( iphyla.eq.1 .and. itpvar.eq.1 ) then
   call lagitp                                                     &
   !==========
   ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                  &
-    itepa  , ibord  ,                                             &
+    itepa  ,                                                      &
     propce ,                                                      &
-    ettp   , ettpa  , tepa   , taup   , tlag   , tempct ,         &
+    ettp   , ettpa  , tepa   , tempct ,                           &
     tsvar  , auxl(1,1) , auxl(1,2)  )
 
 endif
@@ -185,8 +181,8 @@ if ( iphyla.eq.1 .and. idpvar.eq.1 ) then
   call lagidp                                                     &
   !==========
   ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                  &
-    itepa  , ibord  ,                                             &
-    ettp   , ettpa  , tepa   , taup   , tlag   , tempct ,         &
+    itepa  ,                                                      &
+    ettp   , ettpa  , tepa   ,                                    &
     tsvar  , auxl(1,1) , auxl(1,2)  )
 
 endif
@@ -200,8 +196,8 @@ if (iphyla.eq.1 .and. impvar.eq.1) then
   call lagimp                                                     &
   !==========
   ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                  &
-    itepa  , ibord  ,                                             &
-    ettp   , ettpa  , tepa   , taup   , tlag   , tempct ,         &
+    itepa  ,                                                      &
+    ettp   , ettpa  , tepa   ,                                    &
     tsvar  , auxl(1,1) , auxl(1,2)  )
 
 endif
@@ -215,7 +211,7 @@ if (iphyla.eq.2) then
   call lagich                                                     &
   !==========
   ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                  &
-    itepa  , ibord  , propce , ettp   , ettpa  ,                  &
+    itepa  , propce , ettp   , ettpa  ,                           &
     tepa   , tempct , tsvar  , cpgd1  , cpgd2  ,                  &
     cpght  )
 
@@ -229,11 +225,10 @@ if (nvls.ge.1) then
 
   call uslaed                                                     &
   !==========
-    ( nvar   , nscal  ,                                           &
-      nbpmax , nvp    , nvp1   , nvep   , nivep  ,                &
+    ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                &
       ntersl , nvlsta , nvisbr ,                                  &
-      itepa  , ibord  ,                                           &
-      dt     , rtp    , propce ,                                  &
+      itepa  ,                                                    &
+      dt     ,                                                    &
       ettp   , ettpa  , tepa   , taup   , tlag   ,                &
       tempct , tsvar  ,                                           &
       auxl(1,1) ,  auxl(1,2) ,  auxl(1,3) )
