@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -48,6 +48,7 @@ module lagran
   !> \addtogroup base
   !> \{
 
+  !> \anchor iilagr
   !> activates (>0) or deactivates (=0) the Lagrangian module
   !> the different values correspond to the following modellings:
   !> - = 1 Lagrangian two-phase flow in one-way coupling (no influence of
@@ -67,6 +68,7 @@ module lagran
   !> the global calculation must also be a restart calculation
   integer, save ::           isuila
 
+  !> \anchor isttio
   !> indicates the steady (=1) or unsteady (=0) state of the
   !> continuous phase flow
   !> in particular, \ref isttio = 1 is needed in order to:
@@ -242,6 +244,8 @@ module lagran
   integer, save ::   jryplu
   !> Additional pointer in the ITEPA array (contains the particule state)
   integer, save ::   jrinpf
+  !> Additional pointer in the ITEPA array (contains the particule state)
+  integer, save ::   jord1
 
   !> \}
 
@@ -256,6 +260,10 @@ module lagran
   !> - 1: resuspension model
   integer, save ::   ireent
 
+  !> - 0: no DLVO conditions with roughness surface
+  !> - 1: DLVO conditions with roughness surface
+  integer, save ::     irough
+
   !> Additional pointer in ITEPA and TEPA arrays (contains particule state)
   integer, save ::   jroll
   !> Additional pointer in ITEPA and TEPA arrays (contains particule state)
@@ -417,6 +425,12 @@ module lagran
   !> for \ref itepa array; this
   !> number is re-actualised during the trajectography step
   integer, save :: jisor
+  !> pointer to number of the previous cell containing the particle
+  !> for \ref itepa array
+  integer, save :: jisora
+  !> pointer to number of the previous rank containing the particle
+  !> for \ref itepa array
+  integer, save :: jirka
   !> pointer to number of the coal particle for \ref itepa array
   integer, save :: jinch
   !> pointer to class of the particle for \ref itepa array
@@ -682,6 +696,7 @@ module lagran
   !> the statistics represent the significant results on the particle cloud
   integer, save ::  istala
 
+  !> \anchor isuist
   !> during a Lagrangian calculation restart, indicates whether the particle
   !> statistics (volume and boundary) and two-way coupling terms are to be read
   !> from a restart file (=1) or reinitialised (=0).
@@ -701,7 +716,7 @@ module lagran
   !> Useful if \ref istala = 1
   integer, save ::  idstnt
 
-  !>
+  !> \anchor nstist
   !> absolute Lagrangian iteration number (includings the restarts) after
   !> which the volume statistics are cumulated over time (they are then said
   !> to be stationary).
@@ -860,6 +875,7 @@ module lagran
   !> Variance of the air scalar
   integer, save ::  itsfp4
 
+  !> \anchor nstits
   !> number of absolute Lagrangian iterations (including the restarts)
   !> after which a time-average of the two-way coupling source terms is
   !> calculated.
@@ -1058,6 +1074,7 @@ module lagran
   !> Useful if \ref iensi3=1
   integer, save ::  nusbor
 
+  !> \anchor nstbor
   !> number of absolute Lagrangian iterations (including the restarts)
   !> after which the statistics at the boundaries are considered stationary
   !> are veraged (over time or over the number of interactions).
@@ -1131,6 +1148,12 @@ module lagran
   !> \ref ivit: mean interaction velocity with the boundary faces
   integer, save ::  ivit
 
+  !> number of resuspended particles
+  integer, save ::  ires
+
+  !> \ref iflres: mass flow of resuspended particles at the boundary faces
+  integer, save ::  iflres
+
   ! TODO
   integer, save ::  iencnb
   ! TODO
@@ -1209,6 +1232,7 @@ module lagran
   !> \addtogroup visualization
   !> \{
 
+  !> \anchor iensi3
   !> activation (=1) or not (=0) of the recording of the particle/boundary
   !> interactions in  \ref parbor, and of the calculation of the
   !> statistics at the corresponding boundaries, for post-processing
@@ -1351,8 +1375,8 @@ contains
 
     ! Arguments
 
-    integer, dimension(ndlaim)          :: i_cz_params
-    double precision, dimension(ndlagm) :: r_cz_params
+    integer(c_int), dimension(ndlaim) :: i_cz_params
+    real(c_double), dimension(ndlagm) :: r_cz_params
 
     ! Local variables
 
@@ -1418,10 +1442,10 @@ contains
 
     ! Arguments
 
-    integer, value                      :: class_id
-    integer, value                      :: zone_id
-    integer, dimension(ndlaim)          :: i_cz_params
-    double precision, dimension(ndlagm) :: r_cz_params
+    integer(c_int), value             :: class_id
+    integer(c_int), value             :: zone_id
+    integer(c_int), dimension(ndlaim) :: i_cz_params
+    real(c_double), dimension(ndlagm) :: r_cz_params
 
     ! Local variables
 
