@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -100,13 +100,13 @@ integer          nvar   , nscal
 integer          nbpmax , nvp    , nvp1   , nvep  , nivep
 integer          ntersl , nvlsta , nvisbr
 
-double precision dt(ncelet) , rtp(ncelet,*) , rtpa(ncelet,*)
+double precision dt(ncelet) , rtp(ncelet,nflown:nvar) , rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 
 ! Local variables
 
 integer          ip     , npt    , iok
-integer          iel    , ivf
+integer          iel    , ivf    , ivar, ifld
 integer          npar1  , npar2
 integer          modntl
 
@@ -115,8 +115,6 @@ integer          ifac
 double precision visccf, romf
 double precision ustarmoy, surftot, surfb
 
-integer, allocatable, dimension(:) :: indep, ibord
-
 double precision, allocatable, dimension(:) :: taup
 double precision, allocatable, dimension(:,:) :: tlag, piil
 double precision, allocatable, dimension(:,:) :: vagaus
@@ -159,7 +157,6 @@ save             ipass
 !===============================================================================
 
 ! Allocate temporary arrays
-allocate(indep(nbpmax), ibord(nbpmax))
 allocate(auxl(nbpmax,3))
 allocate(taup(nbpmax))
 allocate(tlag(nbpmax,3))
@@ -200,7 +197,7 @@ endif
 if (idlvo.eq.1) then
 
   allocate(energt(nfabor))
-  if (iclogst.eq.1) then
+  if (iclogst.eq.1 .or.  irough .eq.1) then
      allocate(tempp(nfabor))
   endif
 endif
@@ -247,10 +244,12 @@ dnbres = 0.d0
 !         mais la presence de cs_user_extra_operations incite a la prudence...
 
 if (iilagr.eq.3) then
-  do ivf = 1,nvar
-    do iel = 1,ncel
-      rtpa(iel,ivf) = rtp(iel,ivf)
-    enddo
+  ifld = -1
+  do ivar = 1,nvar
+    if (ivarfl(ivar) .ne. ifld) then
+      ifld = ivarfl(ivar)
+      call field_current_to_previous(ifld)
+    endif
   enddo
 endif
 
@@ -262,16 +261,17 @@ if (iplar.eq.1) then
 
   call lagbeg                                                     &
   !==========
- ( nbpmax , nlayer , iphyla , idepst , ireent , iclogst  ,        &
+ ( nbpmax , nlayer , iphyla , idepst , irough , ireent , iclogst, &
    nvls   , nbclst , icocel , itycel ,                            &
-   jisor  , jrval  , jrpoi  , jrtsp  , jdp    , jmp    ,          &
+   jisor  , jisora , jirka  , jord1  ,                            &
+   jrval  , jrpoi  , jrtsp  , jdp    , jmp    ,                   &
    jxp    , jyp    , jzp    , jup    , jvp    , jwp    ,          &
    juf    , jvf    , jwf    , jtaux  , jryplu ,                   &
    jrinpf , jdfac  , jimark ,                                     &
    jtp    , jhp    , jtf    , jmwat  , jmch   , jmck   ,          &
    jcp    , jrdck  , jrd0p  , jinch  , jrhock ,                   &
    jreps  , jdepo  , jnbasg , jnbasp , jfadh  , jmfadh ,          &
-   jndisp)
+   jndisp , jclst  , jvls   )
 
 ! --> if the deposition model is activated
 
@@ -360,6 +360,39 @@ if ( iclogst.eq.1 ) then
 
 endif
 
+!===============================================================================
+! 1.ter  Initialization for the roughness surface model
+!===============================================================================
+
+if ( irough .eq. 1 ) then
+
+ do ifac = 1,nfabor
+      iel = ifabor(ifac)
+
+      if (iscalt.gt.0) then
+
+         if (itherm.eq.1 .and. itpscl.eq.2) then
+            tempp(ifac) = rtp(iel,isca(iscalt)) + tkelvi
+         else if (itherm.eq.1 .and. itpscl.eq.2) then
+            tempp(ifac) = rtp(iel,isca(iscalt))
+         else if (itherm.eq.2) then
+            call usthht(1,rtp(iel,isca(iscalt)),tempp(ifac))
+         endif
+
+      else
+         tempp(ifac) = t0
+      endif
+
+   enddo
+
+   call roughness_init                                &
+   !===========
+   ( cstfar, epsvid, epseau, fion, tempp,             &
+     phi1  , phi2  , cstham, dcutof, lambwl, kboltz , &
+     espasg , denasp , rayasp , rayasg)
+
+endif
+
 !===============================================================================
 ! 2.  MISE A JOUR DES NOUVELLES PARTICULES ENTREES DANS LE DOMAINE
 !===============================================================================
@@ -406,7 +439,7 @@ if (iroule.ge.1) then
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
    itypfb , itrifb , itepa ,                                      &
-   dt     , rtpa   , propce ,                                     &
+   dt     ,                                                       &
    ettp   , tepa   , vagaus , croule , auxl ,                     &
    dispar , yplpar )
 
@@ -442,13 +475,14 @@ if ( irangp .ge. 0 ) then
   call parcpt(nbpartall)
 endif
 
-!
 if (nbpartall.eq.0) goto 20
 
-!-->On enregistre l'element de depart de la particule
+! Record particle's starting cell and rank, and reset order 1 switch
 
 do ip = 1,nbpart
-  indep(ip) = itepa(ip,jisor)
+  itepa(ip,jisora) = itepa(ip,jisor)
+  itepa(ip,jirka) = irangp
+  itepa(ip,jord1) = 0
 enddo
 
 !===============================================================================
@@ -574,8 +608,7 @@ call lagesp                                                       &
    ( nvar   , nscal  ,                                            &
      nbpmax , nvp    , nvp1   , nvep   , nivep  ,                 &
      ntersl , nvlsta , nvisbr ,                                   &
-     itepa  , ibord  ,                                            &
-     dlgeo  ,                                                     &
+     itepa  ,                                                     &
      dt     , rtpa   , rtp    , propce ,                          &
      ettp   , ettpa  , tepa   ,                                   &
      statis , stativ , taup   , tlag   , piil   ,                 &
@@ -593,7 +626,7 @@ if (iphyla.eq.1 .or. iphyla.eq.2) then
     !==========
     ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                &
       ntersl , nvlsta , nvisbr ,                                  &
-      itepa  , ibord  ,                                           &
+      itepa  ,                                                    &
       dt     , rtpa   , propce ,                                  &
       ettp   , ettpa  , tepa   , taup   , tlag   , tempct ,       &
       tsvar  , auxl   , cpgd1  , cpgd2  , cpght  )
@@ -602,7 +635,7 @@ if (iphyla.eq.1 .or. iphyla.eq.2) then
     !==========
     ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                &
       ntersl , nvlsta , nvisbr ,                                  &
-      itepa  , ibord  ,                                           &
+      itepa  ,                                                    &
       dt     , rtp    , propce ,                                  &
       ettp   , ettpa  , tepa   , taup   , tlag   , tempct ,       &
       tsvar  , auxl   , cpgd1  , cpgd2  , cpght  )
@@ -623,7 +656,6 @@ if (iilagr.eq.2 .and. nor.eq.nordre) then
   !==========
    ( nbpmax ,                                                     &
      ntersl ,                                                     &
-     indep  , ibord  ,                                            &
      rtp    , propce ,                                            &
      taup   , tempct , tsfext ,                                   &
      cpgd1  , cpgd2  , cpght  ,                                   &
@@ -677,32 +709,29 @@ if (nor.eq.1) then
   call getbdy                                                     &
   !==========
  ( nflagm , nfrlag , injcon , ilflag , iusncl ,                   &
-   iusclb , iusmoy , deblag , ifrlag )
+   iusclb , deblag , ifrlag )
 
 
   call prtget                                                     &
   !==========
  ( nbpmax , nbpart ,                                              &
-   ettp   , ettpa  , itepa  , tepa   ,                            &
-   ibord  , indep  )
+   ettp   , ettpa  , itepa  , tepa   )
 
   call dplprt                                                     &
   !==========
- ( nbpart   , dnbpar   , nordre   , parbor   , iensi3   ,         &
+ ( nbpart   , nordre   , parbor   , iensi3   ,                    &
    inbr     , inbrbd   , iflm     , iflmbd   , iang     ,         &
    iangbd   , ivit     , ivitbd   , iencnb   , iencma   ,         &
    iencdi   , iencck   , iencnbbd , iencmabd , iencdibd ,         &
    iencckbd , inclg    , iscovc   ,                               &
-   nusbor   , iusb     , vislen   , dlgeo,                        &
-   rtp      , iu       , iv       , iw       , energt   ,         &
+   nusbor   , iusb     , vislen   , dlgeo    , energt   ,         &
    tprenc   , visref   , enc1     , enc2     , tkelvi)
 
   call prtput                                                     &
   !==========
  ( nbpmax , nbpart , dnbpar , nbpout , dnbpou , nbperr , dnbper,  &
    nbpdep , dnbdep , npencr , dnpenc ,                            &
-   ettp   , ettpa  , itepa  , tepa   ,                            &
-   ibord  )
+   ettp   , ettpa  , itepa  , tepa   )
 
 
   if (ierr.eq.1) then
@@ -738,7 +767,7 @@ if (ireent.gt.0) then
   !==========
  ( nbpmax , nvp    , nvep   , nivep  ,                            &
    itepa  ,                                                       &
-   ettp   , ettpa  , tepa )
+   ettp   , ettpa  , tepa   , rtp , parbor, nvisbr)
 
 endif
 
@@ -776,7 +805,7 @@ if ( nor.eq.nordre .and. iroule.ge.1 ) then
   !==========
    ( ncelet , ncel   ,                                            &
      nbpmax , nvp    , nvp1   , nvep   , nivep  ,                 &
-     itepa  , indep  ,                                            &
+     itepa  ,                                                     &
      ettp   , ettpa  , tepa   , croule )
 
   if (npclon.gt.0) then
@@ -807,7 +836,7 @@ call uslast                                                       &
  ( nvar   , nscal  ,                                              &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
-   dt     , rtpa   , rtp    , propce ,                            &
+   dt     ,                                                       &
    taup   , tlag   , tempct )
 
 !===============================================================================
@@ -820,7 +849,7 @@ call ucdprt                                                        &
 !==========
  ( nbpmax , nbpart , dnbpar , nbpout , dnbpou , nbperr ,           &
    dnbper , nbpdep , dnbdep , npencr , dnpenc ,                    &
-   ettp   , ettpa  , itepa  , tepa   , ibord  , indep  )
+   ettp   , ettpa  , itepa  , tepa   )
 
 !===============================================================================
 ! 17. NOMBRE DE PARITICULES PERDUES (SUITES COMPRISES)
@@ -858,7 +887,6 @@ endif
 
 ! Free memory
 
-deallocate(indep, ibord)
 deallocate(auxl)
 deallocate(taup)
 deallocate(tlag)
@@ -900,7 +928,7 @@ if ((idepst.eq.1).and.(ntcabs.eq.ntmabs)) then
 endif
 if (idlvo.eq.1) then
    deallocate(energt)
-  if (iclogst.eq.1) then
+  if (iclogst.eq.1 .or. irough .eq. 1 ) then
      deallocate(tempp)
   endif
 endif
