@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -512,11 +512,11 @@ cs_mesh_connect_cells_to_nodal(const cs_mesh_t  *mesh,
 
   if (cell_list != NULL) {
 
-    BFT_MALLOC(extr_cell_idx, mesh->n_cells, cs_lnum_t);
+    BFT_MALLOC(extr_cell_idx, mesh->n_cells_with_ghosts, cs_lnum_t);
 
     /* Initialize index as marker */
 
-    for (cell_id = 0; cell_id < mesh->n_cells; cell_id++)
+    for (cell_id = 0; cell_id < mesh->n_cells_with_ghosts; cell_id++)
       extr_cell_idx[cell_id] = -1;
     for (cell_id = 0; cell_id < cell_list_size; cell_id++) {
       if (cell_list[cell_id] <= mesh->n_cells)
