@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -109,7 +109,7 @@ struct _cs_mesh_location_t {
                                              2: with extended ghost elements */
 
   cs_lnum_t                *elt_list;     /* List of associated elements,
-                                             (1 to n numbering) if non
+                                             (0 to n-1 numbering) if non
                                              trivial (i.e. a subset) */
 
 };
@@ -120,6 +120,22 @@ struct _cs_mesh_location_t {
  * Static global variables
  *============================================================================*/
 
+/*============================================================================
+ * Global variables
+ *============================================================================*/
+
+/* Names associated with location types */
+
+const char  *cs_mesh_location_type_name[] = {N_("none"),
+                                             N_("cells"),
+                                             N_("interior faces"),
+                                             N_("boundary faces"),
+                                             N_("vertices"),
+                                             N_("particles"),
+                                             N_("other")};
+
+/* Location definitions */
+
 static int                  _n_mesh_locations_max = 0;
 static int                  _n_mesh_locations = 0;
 static cs_mesh_location_t  *_mesh_location = NULL;
@@ -540,7 +556,7 @@ cs_mesh_location_get_n_elts(int id)
  *
  * \param[in]  id  id of mesh location
  *
- * \return  pointer to elements list.
+ * \return  pointer to elements list (0 to n-1 numbering).
  */
 /*----------------------------------------------------------------------------*/
 
