@@ -5,7 +5,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2013 EDF S.A.
+  Copyright (C) 1998-2014 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -1229,7 +1229,7 @@ _compute_cell_cen_vertex(const cs_mesh_t  *mesh,
   cs_lnum_t  *_face_vtx_idx = NULL, *_face_vtx_lst = NULL;
   cs_lnum_t  *cell_faces_idx = NULL, *cell_faces_lst = NULL;
 
-  /* Return if there is not enough data (Solcom case except radiative module) */
+  /* Return if there is not enough data */
 
   if (mesh->i_face_vtx_lst == NULL && mesh->b_face_vtx_lst == NULL)
     return;
@@ -1273,7 +1273,7 @@ _compute_cell_cen_vertex(const cs_mesh_t  *mesh,
 
     for (j = cell_faces_idx[cell_id]; j < cell_faces_idx[cell_id + 1]; j++) {
 
-      face_num = cell_faces_lst[j - 1];
+      face_num = CS_ABS(cell_faces_lst[j - 1]);
 
       /* Internal or border face */
 
@@ -1996,7 +1996,7 @@ cs_mesh_quantities_set_cocg_options(int  gradient_option)
 {
   int _gradient_option = CS_ABS(gradient_option);
 
-  assert(_gradient_option <= 6);
+  assert(_gradient_option <= 16);
 
   switch (_gradient_option) {
   case 0:
@@ -2013,6 +2013,22 @@ cs_mesh_quantities_set_cocg_options(int  gradient_option)
     _compute_cocg_s_it = true;
     _compute_cocg_s_lsq = true;
     break;
+  /* deprecated options */
+  case 10:
+    _compute_cocg_s_it = true;
+    break;
+  case 11:
+  case 12:
+  case 13:
+    _compute_cocg_s_lsq = true;
+    break;
+  case 14:
+  case 15:
+  case 16:
+    _compute_cocg_s_it = true;
+    _compute_cocg_s_lsq = true;
+    break;
+
   default:
     break;
   }
