@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -63,6 +63,7 @@ subroutine ppcabs &
 use paramx
 use numvar
 use entsor
+use dimens, only: nvar
 use optcal
 use cstphy
 use cstnum
@@ -83,7 +84,7 @@ implicit none
 
 ! Arguments
 
-double precision rtp(ncelet,*)
+double precision rtp(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 
 ! Local variables
