@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -132,7 +132,7 @@ integer          nvar   , nscal
 
 integer          mbrom
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 
 ! Local variables
@@ -258,7 +258,7 @@ if ( ippmod(iaeros).ge.0 ) then
 
 endif
 
-! ---> Atmospheric Flows
+! ---> Atmospheric Flows (except constant density: ippmod(iatmos) = 0)
 
 if (ippmod(iatmos).ge.1) then
 
