@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -96,7 +96,7 @@ integer          nvar   , nscal
 integer          itypfb(ndimfb)
 integer          izfrad(ndimfb)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 
 ! Local variables
@@ -284,7 +284,7 @@ else
 ( nvar   , nscal  , iappel ,                                     &
   itypfb ,                                                       &
   izfrad ,                                                       &
-  dt     , rtp    , rtpa   , propce ,                            &
+  dt     ,                                                       &
   propce(1,ipproc(icak(1))))
 
 endif
@@ -363,7 +363,7 @@ if (idverl.ge.0) then
       ( nvar   , nscal  ,                                            &
         mode   ,                                                     &
         itypfb ,                                                     &
-        dt     , rtp    , rtpa   , propce ,                          &
+        dt     ,                                                     &
         tparo  , flurdb , tempk(1,1)  )
 
     else
@@ -563,7 +563,6 @@ if (iirayo.eq.2) then
   !==========
   ( itypfb ,                                                       &
     izfrad ,                                                       &
-    rtp    , rtpa   ,                                              &
     coefap , coefbp ,                                              &
     cofafp , cofbfp ,                                              &
     tparo  , bqinci , beps   ,                                     &
@@ -658,7 +657,6 @@ else if (iirayo.eq.1) then
   !==========
   ( itypfb ,                                                       &
     izfrad ,                                                       &
-    rtp    , rtpa   ,                                              &
     coefap , coefbp ,                                              &
     cofafp , cofbfp ,                                              &
     tparo  , bqinci , beps   ,                                     &
@@ -668,8 +666,7 @@ else if (iirayo.eq.1) then
 
   call raysol &
   !==========
- ( rtp    , rtpa   ,                                              &
-   coefap , coefbp ,                                              &
+ ( coefap , coefbp ,                                              &
    cofafp , cofbfp ,                                              &
    flurds , flurdb ,                                              &
    viscf  , viscb  ,                                              &
@@ -712,7 +709,7 @@ call usray5 &
 ( nvar   , nscal  ,                                              &
   itypfb ,                                                       &
   izfrad ,                                                       &
-  dt     , rtp    , rtpa   , propce ,                            &
+  dt     ,                                                       &
   coefap , coefbp ,                                              &
   cofafp , cofbfp ,                                              &
   tparo  , bqinci ,                                              &
