@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -73,10 +73,7 @@ implicit none
 
 ! Local variables
 
-integer          ii, iok , iiscal, iscaok, ipp, nmodpp
-integer          irphas
-character        car4*4
-character*3      num
+integer          iok , iiscal, iscaok, ipp, nmodpp
 
 !===============================================================================
 ! 0. REDEFINITION DU NOMBRE DE PHASES POUR LE CHARBON PULVERISE
@@ -372,9 +369,8 @@ iok = 0
 if (iirayo.gt.0) then
 
 ! Positionnement des pointeurs
-! 4eme passage (les autres sont dans iniusi)
 
-  call varpos(nmodpp)
+  call rayprp
   !==========
 
 ! --> ISUIRD
@@ -394,7 +390,7 @@ if (iirayo.gt.0) then
 ! --> i_quadrature
 !     Selection de la quadrature
   if (iirayo.eq.1) then
-    if (i_quadrature.lt.1 .or. i_quadrature.gt.6) then
+    if (i_quadrature.lt.1 .or. i_quadrature.gt.8) then
       write(nfecra, 4015) i_quadrature
       iok = iok + 1
     endif
@@ -449,139 +445,7 @@ call raydir
 !==========
 
 !===============================================================================
-! 5. POST-PROCESSING
-!===============================================================================
-
-!--> INITIALISATION DES DONNEES POST-PROCESSING
-!    NBRAYF : NOMBRE MAX DES SORTIES DE VARIABLES FACETTES DE BORD
-
-do ii = 1, nbrayf
-  write(car4,'(i4.4)') ii
-  nbrvaf(ii) = 'RAYTFB'//car4
-  irayvf(ii) = 0
-enddo
-
-!--> LUMINENCE
-
-ipp = ipppro(ipproc(ilumin))
-nomvar(ipp)   = 'Lumin'
-ichrvr(ipp)   = 0
-ihisvr(ipp,1) = 0
-ilisvr(ipp)   = 0
-
-!--> VECTEUR DENSITE DE FLUX RADIATIF
-
-!     composante x
-ipp = ipppro(ipproc(iqx))
-nomvar(ipp)   = 'Qxrad'
-ichrvr(ipp)   = 0
-ihisvr(ipp,1) = -1
-ilisvr(ipp)   = 0
-
-!     composante y
-ipp = ipppro(ipproc(iqy))
-nomvar(ipp)   = 'Qyrad'
-ichrvr(ipp)   = 0
-ihisvr(ipp,1) = -1
-ilisvr(ipp)   = 0
-
-!      composante z
-ipp = ipppro(ipproc(iqz))
-nomvar(ipp)   = 'Qzrad'
-ichrvr(ipp)   = 0
-ihisvr(ipp,1) = -1
-ilisvr(ipp)   = 0
-
-!--> TERME SOURCE IMPLICITE
-
-ipp = ipppro(ipproc(itsri(1)))
-nomvar(ipp)   = 'ITSRI'
-ichrvr(ipp)   = 0
-ihisvr(ipp,1) = 0
-ilisvr(ipp)   = 0
-
-!--> TERME SOURCE RADIATIF (ANALYTIQUE/CONSERVATIF/SEMI-ANALYTIQUE)
-
-ipp = ipppro(ipproc(itsre(1)))
-nomvar(ipp)   = 'Srad'
-ichrvr(ipp)   = 0
-ihisvr(ipp,1) = -1
-ilisvr(ipp)   = 0
-
-!--> PART DE L'ABSORPTION DANS LE TERME SOURCE RADIATIF
-
-ipp = ipppro(ipproc(iabs(1)))
-nomvar(ipp)   = 'Absorp'
-ichrvr(ipp)   = 0
-ihisvr(ipp,1) = -1
-ilisvr(ipp)   = 0
-
-!--> PART DE L'EMISSION DANS LE TERME SOURCE RADIATIF
-
-ipp = ipppro(ipproc(iemi(1)))
-nomvar(ipp)   = 'Emiss'
-ichrvr(ipp)   = 0
-ihisvr(ipp,1) = -1
-ilisvr(ipp)   = 0
-
-!--> COEFFICIENT D'ABSORPTION DU MILIEU SEMI-TRANSPARENT
-
-ipp = ipppro(ipproc(icak(1)))
-nomvar(ipp)   = 'CoefAb'
-ichrvr(ipp)   = 0
-ilisvr(ipp)   = 0
-ihisvr(ipp,1) = -1
-
-
-do irphas = 1, nrphas-1
-
-  WRITE(NUM,'(I2)') IRPHAS
-
-!--> TERME SOURCE IMPLICITE
-
-  ipp = ipppro(ipproc(itsri(irphas)))
-  nomvar(ipp)   = 'ITSRI_'//num
-  ichrvr(ipp)   = 0
-  ihisvr(ipp,1) = 0
-  ilisvr(ipp)   = 0
-
-
-!--> TERME SOURCE RADIATIF (ANALYTIQUE/CONSERVATIF/SEMI-ANALYTIQUE)
-
-  ipp = ipppro(ipproc(itsre(irphas)))
-  nomvar(ipp)   = 'Srad_'//num
-  ichrvr(ipp)   = 0
-  ihisvr(ipp,1) = -1
-  ilisvr(ipp)   = 0
-
-!--> PART DE L'ABSORPTION DANS LE TERME SOURCE RADIATIF
-
-  ipp = ipppro(ipproc(iabs(irphas)))
-  nomvar(ipp)   = 'Absorp_'//num
-  ichrvr(ipp)   = 0
-  ihisvr(ipp,1) = -1
-  ilisvr(ipp)   = 0
-
-!--> PART DE L'EMISSION DANS LE TERME SOURCE RADIATIF
-
-  ipp = ipppro(ipproc(iemi(irphas)))
-  nomvar(ipp)   = 'Emiss_'//num
-  ichrvr(ipp)   = 0
-  ihisvr(ipp,1) = -1
-  ilisvr(ipp)   = 0
-
-!--> COEFFICIENT D'ABSORPTION DU MILIEU SEMI-TRANSPARENT
-
-  ipp = ipppro(ipproc(icak(irphas)))
-  nomvar(ipp)   = 'CoefAb_'//num
-  ichrvr(ipp)   = 0
-  ilisvr(ipp)   = 0
-  ihisvr(ipp,1) = -1
-
-enddo
-
-!===============================================================================
-!  6. INITIALISATIONS UTILISATEURS
+!  5. INITIALISATIONS UTILISATEURS
 !                    ^^^^^^^^^^^^
 !===============================================================================
 
@@ -590,38 +454,15 @@ enddo
 
 if (iihmpr.eq.1) then
 
-  ! properties on boundaries
-  do ii = 1, nbrayf
-    call fcnmra(nbrvaf(ii), len(nbrvaf(ii)), ii)
-  enddo
-
-   call uiray4(nbrayf, iirayo, irayvf)
-   !==========
-
-  do ii = 1, nbrayf
-    call cfnmra(nbrvaf(ii), len(nbrvaf(ii)), ii)
-  enddo
-
-  ! properties on cells
-  do ii = 1,nvppmx
-    call fcnmva (nomvar(ii), len(nomvar(ii)), ii)
-    !==========
-  enddo
+  call uiray4(iirayo)
+  !==========
 
   call csenso                                                     &
   !==========
      ( nvppmx, ncapt,  nthist, frhist, ntlist, iecaux,            &
-       ipstdv, ichrvr, ilisvr, ihisvr, tplfmt, isca, iscapp,      &
+       ipstdv, ihisvr, tplfmt, isca, iscapp,                      &
        ipprtp, xyzcap )
 
-  do ii = 1,nvppmx
-    call cfnmva(nomvar(ii), len(nomvar(ii)), ii)
-    !==========
-  enddo
-
-  call nvamem
-  !==========
-
   ! take into acount user modifications
   call usipes(nmodpp)
   !==========
@@ -631,17 +472,6 @@ endif
 call usray1
 !==========
 
-! --> IRAYVF
-!     Choix entre -1 et 1
-if (iirayo.eq.1 .or. iirayo.eq.2) then
-  do ii = 1, nbrayf
-    if (irayvf(ii).ne.1 .and. irayvf(ii).ne.-1) then
-      write(nfecra,4070) nbrvaf(ii), irayvf(ii)
-      iok = iok + 1
-    endif
-  enddo
-endif
-
 !--> Stop si erreur.
 
 if(iok.ne.0) then
@@ -775,25 +605,6 @@ endif
 '@  Verifier usray1.                                          ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@                                                            ',/)
- 4070 format(                                                     &
-'@                                                            ',/,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@                                                            ',/,&
-'@ @@ ATTENTION : RAYONNEMENT : ERREUR A L''ENTREE DES DONNEES',/,&
-'@    =========                                               ',/,&
-'@    INDICATEUR DE SORTIE EN POSTPROCESSING                  ',/,&
-'@    POUR ',A40                                               ,/,&
-'@    NON ADMISSIBLE                                          ',/,&
-'@                                                            ',/,&
-'@  L''indicateur de postprocessing doit etre -1 ou 1         ',/,&
-'@    Il vaut ici IRAYVF = ',I10                               ,/,&
-'@                                                            ',/,&
-'@  Le calcul ne sera pas execute.                            ',/,&
-'@                                                            ',/,&
-'@  Verifier usray1.                                          ',/,&
-'@                                                            ',/,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
 
 
