@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -70,7 +70,7 @@ implicit none
 ! Arguments
 
 integer          nvar, ncelet, ncel
-double precision rtp(ncelet,nvar)
+double precision rtp(ncelet,nflown:nvar)
 
 ! Local variables
 
