@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -55,7 +55,7 @@ subroutine divrit &
 !===============================================================================
 
 use paramx
-use dimens, only: ndimfb
+use dimens, only: ndimfb, nvar
 use numvar
 use entsor
 use optcal
@@ -74,7 +74,7 @@ implicit none
 
 integer          nscal
 integer          iscal
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision xcpp(ncelet)
 double precision smbrs(ncelet)
@@ -87,7 +87,7 @@ integer          nswrgp, imligp, iwarnp
 integer          itypfl
 integer          ivar , ivar0 , iel, ii, jj
 integer          itt
-integer          f_id
+integer          f_id, f_id0
 
 double precision epsrgp, climgp, extrap
 double precision xk, xe, xtt
@@ -116,6 +116,8 @@ double precision, dimension(:), pointer :: brom, crom
 ! 1. Initialization
 !===============================================================================
 
+f_id0 = -1
+
 ! Initializations to avoid compiler warnings
 xtt = 0.d0
 
@@ -162,18 +164,11 @@ call grdcel &
 ! Compute velocity gradient
 iprev  = 0
 inc    = 1
-nswrgp = nswrgr(iu)
-imligp = imligr(iu)
-iwarnp = iwarni(iu)
-epsrgp = epsrgr(iu)
-climgp = climgr(iu)
-extrap = extrag(iu)
 
 ! WARNING: gradv(xyz, uvw, iel)
 
 call field_gradient_vector(ivarfl(iu), iprev, imrgra, inc,  &
-                           nswrgp, iwarnp, imligp,          &
-                           epsrgp, climgp, gradv)
+                           gradv)
 
 ! Find the variance of the thermal scalar
 itt = -1
@@ -300,9 +295,9 @@ if (ityturt(iscal).ne.3) then
 
   call inimav &
   !==========
-  ( ivar   , itypfl ,                                     &
+  ( f_id0  , itypfl ,                                     &
     iflmb0 , init   , inc    , imrgra , nswrgp  , imligp, &
-    iwarnp , nfecra ,                                     &
+    iwarnp ,                                              &
     epsrgp , climgp ,                                     &
     crom   , brom   ,                                     &
     w1     ,                                              &
@@ -359,9 +354,9 @@ else
 
   call inimav &
   !==========
-  ( ivar   , itypfl ,                                     &
+  ( f_id0  , itypfl ,                                     &
     iflmb0 , init   , inc    , imrgra , nswrgp  , imligp, &
-    iwarnp , nfecra ,                                     &
+    iwarnp ,                                              &
     epsrgp , climgp ,                                     &
     crom   , brom   ,                                     &
     w1     ,                                              &
@@ -381,11 +376,7 @@ if ((ityturt(iscal).eq.2.or.ityturt(iscal).eq.3)) then
 
   init = 1
 
-  call divmas &
-  !==========
-   ( ncelet , ncel   , nfac  , nfabor , init   , nfecra ,          &
-     ifacel , ifabor ,                                             &
-     thflxf , thflxb , divut )
+  call divmas(init, thflxf, thflxb, divut)
 
   do iel = 1, ncel
     smbrs(iel) = smbrs(iel) - divut(iel)
