@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -45,7 +45,8 @@
 !> \param[in]     ipp           index for writing
 !> \param[in]     icepdc        index of cells with head loss
 !> \param[in]     icetsm        index of cells with mass source term
-!> \param[in]     itpsmp        type of mass source term for the variables
+!> \param[in]     itypsm        type of mass source term for each variable
+!>                               (see \ref ustsma)
 !> \param[in]     dt            time step (per cell)
 !> \param[in,out] rtp, rtpa     calculated variables at cell centers
 !>                               (at current and previous time steps)
@@ -56,9 +57,8 @@
 !>                              (sans rho volume) uniqt pour iturb=30
 !> \param[in]     gradro        tableau de travail pour grad rom
 !> \param[in]     ckupdc        work array for the head loss
-!> \param[in]     smcelp        variable value associated to the mass source
-!>                               term
-!> \param[in]     gamma         valeur du flux de masse
+!> \param[in]     smacel        value associated to each variable in the mass
+!>                               source terms or mass rate (see \ref ustsma)
 !> \param[in]     viscf         visc*surface/dist aux faces internes
 !> \param[in]     viscb         visc*surface/dist aux faces de bord
 !> \param[in]     tslagr        coupling term for lagrangian
@@ -69,10 +69,10 @@
 subroutine reseps &
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    ivar   , isou   , ipp    ,                                     &
-   icepdc , icetsm , itpsmp ,                                     &
+   icepdc , icetsm , itypsm ,                                     &
    dt     , rtp    , rtpa   , propce ,                            &
    gradv  , produc , gradro ,                                     &
-   ckupdc , smcelp , gamma  ,                                     &
+   ckupdc , smacel ,                                              &
    viscf  , viscb  ,                                              &
    tslagr ,                                                       &
    smbr   , rovsdt )
@@ -92,7 +92,6 @@ use cstphy
 use parall
 use period
 use lagran
-use pointe, only:visten
 use mesh
 use field
 use field_operator
@@ -109,14 +108,13 @@ integer          ncepdp , ncesmp
 integer          ivar   , isou   , ipp
 
 integer          icepdc(ncepdp)
-integer          icetsm(ncesmp), itpsmp(ncesmp)
+integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision produc(6,ncelet), gradv(3, 3, ncelet)
 double precision gradro(ncelet,3)
-double precision ckupdc(ncepdp,6)
-double precision smcelp(ncesmp), gamma(ncesmp)
+double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision viscf(nfac), viscb(nfabor)
 double precision tslagr(ncelet,*)
 double precision smbr(ncelet), rovsdt(ncelet)
@@ -152,6 +150,9 @@ double precision, allocatable, dimension(:) :: weighb
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer ::  crom, cromo
 double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
+double precision, dimension(:,:), pointer :: visten
+
+character(len=80) :: label
 
 !===============================================================================
 
@@ -168,7 +169,8 @@ allocate(weighf(2,nfac))
 allocate(weighb(nfabor))
 
 if(iwarni(ivar).ge.1) then
-  write(nfecra,1000) nomvar(ipp)
+  call field_get_label(ivarfl(ivar), label)
+  write(nfecra,1000) label
 endif
 
 call field_get_val_s(icrom, crom)
@@ -219,13 +221,12 @@ enddo
 ! 2. User source terms
 !===============================================================================
 
-call ustsri                                                       &
-!==========
+call cs_user_turbulence_source_terms &
+!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
-   ivar   ,                                                       &
-   icepdc , icetsm , itpsmp ,                                     &
-   dt     , rtpa   , propce ,                                     &
-   ckupdc , smcelp , gamma  , gradv  , produc ,                   &
+   ivarfl(ivar)    ,                                              &
+   icepdc , icetsm , itypsm ,                                     &
+   ckupdc , smacel ,                                              &
    smbr   , rovsdt )
 
 !     Si on extrapole les T.S.
@@ -286,9 +287,9 @@ if (ncesmp.gt.0) then
   call catsma &
   !==========
  ( ncelet , ncel   , ncesmp , iiun   , isto2t , thetv ,           &
-   icetsm , itpsmp ,                                              &
-   volume , rtpa(1,ivar) , smcelp , gamma  ,                      &
-   smbr   ,  rovsdt , w1 )
+   icetsm , itypsm(:,ivar)  ,                                     &
+   volume , rtpa(:,ivar)    , smacel(:,ivar)   , smacel(:,ipr) ,  &
+   smbr   , rovsdt , w1 )
 
 !       Si on extrapole les TS on met Gamma Pinj dans PROPCE
   if(isto2t.gt.0) then
@@ -446,6 +447,8 @@ endif
 ! Symmetric tensor diffusivity (GGDH)
 if (idften(ivar).eq.6) then
 
+  call field_get_val_v(ivsten, visten)
+
   do iel = 1, ncel
     viscce(1,iel) = visten(1,iel)/sigmae + propce(iel,ipcvis)
     viscce(2,iel) = visten(2,iel)/sigmae + propce(iel,ipcvis)
@@ -463,8 +466,19 @@ if (idften(ivar).eq.6) then
    weighf , weighb ,             &
    viscf  , viscb  )
 
+! Scalar diffusivity
 else
-  call csexit(1)
+
+  do iel = 1, ncel
+    w1(iel) = propce(iel,ipcvis) + idifft(ivar)*propce(iel,ipcvst)/sigmae
+  enddo
+
+  call viscfa                    &
+  !==========
+ ( imvisf ,                      &
+   w1     ,                      &
+   viscf  , viscb  )
+
 endif
 
 !===============================================================================
