@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -53,7 +53,8 @@
 !> \param[in]     ipp           index for writing
 !> \param[in]     icepdc        index of cells with head loss
 !> \param[in]     icetsm        index of cells with mass source term
-!> \param[in]     itpsmp        type of mass source term for the variables
+!> \param[in]     itypsm        type of mass source term for each variable
+!>                               (see \ref ustsma)
 !> \param[in]     dt            time step (per cell)
 !> \param[in,out] rtp, rtpa     calculated variables at cell centers
 !>                               (at current and previous time steps)
@@ -64,9 +65,8 @@
 !> \param[in]     gradro        tableau de travail pour grad rom
 !>                              (sans rho volume) uniqt pour iturb=30
 !> \param[in]     ckupdc        work array for the head loss
-!> \param[in]     smcelp        variable value associated to the mass source
-!>                               term
-!> \param[in]     gamma         valeur du flux de masse
+!> \param[in]     smacel        value associated to each variable in the mass
+!>                               source terms or mass rate (see \ref ustsma)
 !> \param[in]     viscf         visc*surface/dist aux faces internes
 !> \param[in]     viscb         visc*surface/dist aux faces de bord
 !> \param[in]     tslagr        coupling term for lagrangian
@@ -79,10 +79,10 @@
 subroutine resrij &
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    ivar   , isou   , ipp    ,                                     &
-   icepdc , icetsm , itpsmp ,                                     &
+   icepdc , icetsm , itypsm ,                                     &
    dt     , rtp    , rtpa   , propce ,                            &
    produc , gradro ,                                              &
-   ckupdc , smcelp , gamma  ,                                     &
+   ckupdc , smacel ,                                              &
    viscf  , viscb  ,                                              &
    tslage , tslagi ,                                              &
    smbr   , rovsdt )
@@ -102,10 +102,10 @@ use cstnum
 use parall
 use period
 use lagran
-use pointe, only:visten
 use mesh
 use field
 use cs_f_interfaces
+use turbomachinery
 
 !===============================================================================
 
@@ -118,14 +118,13 @@ integer          ncepdp , ncesmp
 integer          ivar   , isou   , ipp
 
 integer          icepdc(ncepdp)
-integer          icetsm(ncesmp), itpsmp(ncesmp)
+integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision produc(6,ncelet)
 double precision gradro(ncelet,3)
-double precision ckupdc(ncepdp,6)
-double precision smcelp(ncesmp), gamma(ncesmp)
+double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision viscf(nfac), viscb(nfabor)
 double precision tslage(ncelet),tslagi(ncelet)
 double precision smbr(ncelet), rovsdt(ncelet)
@@ -151,10 +150,12 @@ double precision epsrsp
 double precision trprod, trrij , deltij
 double precision tuexpr, thets , thetv , thetp1
 double precision d1s3  , d2s3
-double precision matrot(3,3)
+double precision ccorio, matrot(3,3)
+double precision rctse
 
 double precision rvoid(1)
 
+character(len=80) :: label
 double precision, allocatable, dimension(:) :: w1
 double precision, allocatable, dimension(:) :: w7, w8
 double precision, allocatable, dimension(:) :: dpvar
@@ -164,6 +165,7 @@ double precision, allocatable, dimension(:) :: weighb
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer :: crom, cromo
 double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
+double precision, dimension(:,:), pointer :: visten
 
 !===============================================================================
 
@@ -179,8 +181,9 @@ allocate(viscce(6,ncelet))
 allocate(weighf(2,nfac))
 allocate(weighb(nfabor))
 
-if(iwarni(ivar).ge.1) then
-  write(nfecra,1000) nomvar(ipp)
+if (iwarni(ivar).ge.1) then
+  call field_get_label(ivarfl(ivar), label)
+  write(nfecra,1000) label
 endif
 
 call field_get_val_s(icrom, crom)
@@ -223,19 +226,27 @@ do iel = 1, ncel
   rovsdt(iel) = 0.d0
 enddo
 
+! Coefficient of the "Coriolis-type" term
+if (icorio.eq.1) then
+  ! Relative velocity formulation
+  ccorio = 2.d0
+elseif (iturbo.eq.1) then
+  ! Mixed relative/absolute velocity formulation
+  ccorio = 1.d0
+else
+  ccorio = 0.d0
+endif
+
 !===============================================================================
 ! 2. User source terms
 !===============================================================================
-!(le premier argument PRODUC est lu en GRDVIT dans ustsri, mais ce
-! tableau n'est dimensionne et utilise qu'en modele Rij SSG)
 
-call ustsri &
-!==========
+call cs_user_turbulence_source_terms &
+!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
-   ivar   ,                                                       &
-   icepdc , icetsm , itpsmp ,                                     &
-   dt     , rtpa   , propce ,                                     &
-   ckupdc , smcelp , gamma  , produc , produc ,                   &
+   ivarfl(ivar)    ,                                              &
+   icepdc , icetsm , itypsm ,                                     &
+   ckupdc , smacel ,                                              &
    smbr   , rovsdt )
 
 !     Si on extrapole les T.S.
@@ -284,8 +295,8 @@ if (ncesmp.gt.0) then
   call catsma &
   !==========
  ( ncelet , ncel   , ncesmp , iiun   , isto2t , thetv  ,          &
-   icetsm , itpsmp ,                                              &
-   volume , rtpa(1,ivar) , smcelp , gamma  ,                      &
+   icetsm , itypsm(:,ivar)  ,                                     &
+   volume , rtpa(:,ivar)    , smacel(:,ivar)   , smacel(:,ipr) ,  &
    smbr   ,  rovsdt , w1 )
 
 !       Si on extrapole les TS on met Gamma Pinj dans PROPCE
@@ -434,16 +445,16 @@ endif
 ! 6-bis. Coriolis terms in the Phi1 and production
 !===============================================================================
 
-if (icorio.eq.1) then
+if (icorio.eq.1 .or. iturbo.eq.1) then
 
   do iel = 1, ncel
     w7(iel) = 0.d0
   enddo
 
   ! Rotation matrix: dual antisymmetric matrix of the rotation vector omega
-  matrot(1,2) = -omegaz
-  matrot(1,3) =  omegay
-  matrot(2,3) = -omegax
+  matrot(1,2) = -rotax(3)
+  matrot(1,3) =  rotax(2)
+  matrot(2,3) = -rotax(1)
 
   do ii = 1, 3
     matrot(ii,ii) = 0.d0
@@ -483,23 +494,25 @@ if (icorio.eq.1) then
     jj = 3
   endif
 
+  ! Compute Gij: (i,j) component of the Coriolis production
   do iel = 1, ncel
-    ! Compute Gij: (i,j) component of the Coriolis production
     do kk = 1, 3
-      w7(iel) = w7(iel) - 2.d0*( matrot(ii,kk)*rtpa(iel,indrey(jj,kk)) &
+      w7(iel) = w7(iel) - ccorio*( matrot(ii,kk)*rtpa(iel,indrey(jj,kk)) &
                                + matrot(jj,kk)*rtpa(iel,indrey(ii,kk)) )
     enddo
-    ! Coriolis contribution in the Phi1 term:
-    ! (1-C2/2)Gij
-    w7(iel) = crom(iel) * volume(iel)                   &
-            * (1.d0 - 0.5d0*crij2)*w7(iel)
   enddo
 
+  ! Coriolis contribution in the Phi1 term: (1-C2/2)Gij
+  if (icorio.eq.1) then
+    do iel = 1, ncel
+      w7(iel) = crom(iel)*volume(iel)*(1.d0 - 0.5d0*crij2)*w7(iel)
+    enddo
+  endif
+
   ! If source terms are extrapolated
   if (isto2t.gt.0) then
     do iel = 1, ncel
-      propce(iel,iptsta+isou-1) =                                 &
-      propce(iel,iptsta+isou-1) + w7(iel)
+      propce(iel,iptsta+isou-1) = propce(iel,iptsta+isou-1) + w7(iel)
     enddo
   ! Otherwise, directly in smbr
   else
@@ -572,6 +585,8 @@ endif
 ! Symmetric tensor diffusivity (GGDH)
 if (idften(ivar).eq.6) then
 
+  call field_get_val_v(ivsten, visten)
+
   do iel = 1, ncel
     viscce(1,iel) = visten(1,iel) + propce(iel,ipcvis)
     viscce(2,iel) = visten(2,iel) + propce(iel,ipcvis)
@@ -589,8 +604,21 @@ if (idften(ivar).eq.6) then
    weighf , weighb ,             &
    viscf  , viscb  )
 
+! Scalar diffusivity
 else
-  call csexit(1)
+
+  do iel = 1, ncel
+    trrij = 0.5d0 * (rtpa(iel,ir11) + rtpa(iel,ir22) + rtpa(iel,ir33))
+    rctse = crom(iel) * csrij * trrij**2 / rtpa(iel,iep)
+    w1(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse
+  enddo
+
+  call viscfa                    &
+  !==========
+ ( imvisf ,                      &
+   w1     ,                      &
+   viscf  , viscb  )
+
 endif
 
 !===============================================================================
