@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -62,11 +62,11 @@ use paramx
 use numvar
 use entsor
 use optcal
+use dimens, only: nvar
 use cstnum
 use cstphy
 use parall
 use period
-use pointe, only:visten
 use field
 use mesh
 use cs_f_interfaces
@@ -79,7 +79,7 @@ implicit none
 
 integer          nscal , iscal
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision xcpp(ncelet), xut(3,ncelet), xuta(3,ncelet)
 double precision gradv(3,3,ncelet)
@@ -117,7 +117,7 @@ double precision d1s2
 
 double precision rvoid(1)
 
-character*80     fname
+character*80     fname, name
 
 double precision, allocatable, dimension(:,:) :: viscce
 double precision, allocatable, dimension(:) :: viscb
@@ -125,7 +125,7 @@ double precision, allocatable, dimension(:,:,:) :: viscf
 double precision, allocatable, dimension(:,:) :: smbrut
 double precision, allocatable, dimension(:,:,:) :: fimp
 
-double precision, dimension(:,:), pointer :: coefav, cofafv
+double precision, dimension(:,:), pointer :: coefav, cofafv, visten
 double precision, dimension(:,:,:), pointer :: coefbv, cofbfv
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer ::  crom
@@ -158,10 +158,13 @@ call field_get_key_int(ivarfl(iu), kbmasf, iflmab)
 call field_get_val_s(iflmas, imasfl)
 call field_get_val_s(iflmab, bmasfl)
 
+call field_get_val_v(ivsten, visten)
+
 ivar = isca(iscal)
 ipput = ipprtp(ivar)
 if (iwarni(ivar).ge.1) then
-  write(nfecra,1000) nomvar(ipput)//'_turbulent_flux'!FIXME
+  call field_get_label(ivarfl(ipput), name)
+  write(nfecra,1000) trim(name)//'_turbulent_flux'!FIXME
 endif
 
 ! S pour Source, V pour Variable
