@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -53,7 +53,8 @@
 !> \param[in]     ipp           index for writing
 !> \param[in]     icepdc        index of cells with head loss
 !> \param[in]     icetsm        index of cells with mass source term
-!> \param[in]     itpsmp        type of mass source term for the variables
+!> \param[in]     itypsm        type of mass source term for each variable
+!>                               (see \ref ustsma)
 !> \param[in]     dt            time step (per cell)
 !> \param[in,out] rtp, rtpa     calculated variables at cell centers
 !>                               (at current and previous time steps)
@@ -64,9 +65,8 @@
 !> \param[in]     gradro        tableau de travail pour grad rom
 !>                              (sans rho volume) uniqt pour iturb=30
 !> \param[in]     ckupdc        work array for the head loss
-!> \param[in]     smcelp        variable value associated to the mass source
-!>                               term
-!> \param[in]     gamma         valeur du flux de masse
+!> \param[in]     smacel        value associated to each variable in the mass
+!>                               source terms or mass rate (see \ref ustsma)
 !> \param[in]     viscf         visc*surface/dist aux faces internes
 !> \param[in]     viscb         visc*surface/dist aux faces de bord
 !> \param[in]     tslagr        coupling term for lagrangian
@@ -79,10 +79,10 @@
 subroutine resssg &
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    ivar   , isou   , ipp    ,                                     &
-   icepdc , icetsm , itpsmp ,                                     &
+   icepdc , icetsm , itypsm ,                                     &
    dt     , rtp    , rtpa   , propce ,                            &
    gradv  , gradro ,                                              &
-   ckupdc , smcelp , gamma  ,                                     &
+   ckupdc , smacel ,                                              &
    viscf  , viscb  ,                                              &
    tslage , tslagi ,                                              &
    smbr   , rovsdt )
@@ -102,11 +102,11 @@ use cstnum
 use parall
 use period
 use lagran
-use pointe, only: visten
 use mesh
 use field
 use field_operator
 use cs_f_interfaces
+use turbomachinery
 
 !===============================================================================
 
@@ -119,14 +119,13 @@ integer          ncepdp , ncesmp
 integer          ivar   , isou   , ipp
 
 integer          icepdc(ncepdp)
-integer          icetsm(ncesmp), itpsmp(ncesmp)
+integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision gradv(3, 3, ncelet)
 double precision gradro(ncelet,3)
-double precision ckupdc(ncepdp,6)
-double precision smcelp(ncesmp), gamma(ncesmp)
+double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision viscf(nfac), viscb(nfabor)
 double precision tslage(ncelet),tslagi(ncelet)
 double precision smbr(ncelet), rovsdt(ncelet)
@@ -141,7 +140,7 @@ integer          iconvp, idiffp, ndircp, ireslp
 integer          nitmap, nswrsp, ircflp, ischcp, isstpp, iescap
 integer          imgrp , ncymxp, nitmfp
 integer          iptsta
-integer          iprev , inc, iccocg, iphydp, ll
+integer          iprev , inc, iccocg, ll
 integer          imucpp, idftnp, iswdyp
 integer          indrey(3,3)
 integer          icvflb
@@ -158,9 +157,12 @@ double precision d1s2, d1s3, d2s3
 double precision alpha3
 double precision pij, phiij1, phiij2, epsij
 double precision phiijw, epsijw
+double precision ccorio
+double precision rctse
 
 double precision rvoid(1)
 
+character(len=80) :: label
 double precision, allocatable, dimension(:,:) :: grad
 double precision, allocatable, dimension(:) :: w1, w2
 double precision, allocatable, dimension(:) :: w7
@@ -171,6 +173,7 @@ double precision, allocatable, dimension(:) :: weighb
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer :: crom, cromo
 double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
+double precision, dimension(:,:), pointer :: visten
 
 !===============================================================================
 
@@ -190,7 +193,8 @@ iii = 0
 jjj = 0
 
 if (iwarni(ivar).ge.1) then
-  write(nfecra,1000) nomvar(ipp)
+  call field_get_label(ivarfl(ivar), label)
+  write(nfecra,1000) label
 endif
 
 call field_get_val_s(icrom, crom)
@@ -230,19 +234,27 @@ do iel = 1, ncel
   rovsdt(iel) = 0.d0
 enddo
 
+! Coefficient of the "Coriolis-type" term
+if (icorio.eq.1) then
+  ! Relative velocity formulation
+  ccorio = 2.d0
+elseif (iturbo.eq.1) then
+  ! Mixed relative/absolute velocity formulation
+  ccorio = 1.d0
+else
+  ccorio = 0.d0
+endif
+
 !===============================================================================
 ! 2. User source terms
 !===============================================================================
-!(le deuxieme argument gradv est lu en PRODUC dans ustsri, mais ce
-! tableau n'est dimensionne et utilise qu'en modele Rij standard)
 
-call ustsri &
-!==========
+call cs_user_turbulence_source_terms &
+!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
-   ivar   ,                                                       &
-   icepdc , icetsm , itpsmp ,                                     &
-   dt     , rtpa   , propce ,                                     &
-   ckupdc , smcelp , gamma  , gradv  , gradv ,                    &
+   ivarfl(ivar)    ,                                              &
+   icepdc , icetsm , itypsm ,                                     &
+   ckupdc , smacel ,                                              &
    smbr   , rovsdt )
 
 !     Si on extrapole les T.S.
@@ -287,12 +299,12 @@ if (ncesmp.gt.0) then
 !       Entier egal a 1 (pour navsto : nb de sur-iter)
   iiun = 1
 
-!       On incremente SMBR par -Gamma RTPA et ROVSDT par Gamma (*theta)
-  call catsma                                                     &
+! On incremente SMBR par -Gamma RTPA et ROVSDT par Gamma (*theta)
+  call catsma &
   !==========
- ( ncelet , ncel   , ncesmp , iiun   , isto2t , thetv  ,   &
-   icetsm , itpsmp ,                                              &
-   volume , rtpa(1,ivar) , smcelp , gamma  ,                      &
+ ( ncelet , ncel   , ncesmp , iiun   , isto2t , thetv  ,          &
+   icetsm , itypsm(:,ivar)  ,                                     &
+   volume , rtpa(:,ivar)    , smacel(:,ivar)   , smacel(:,ipr) ,  &
    smbr   ,  rovsdt , w1 )
 
 !       Si on extrapole les TS on met Gamma Pinj dans PROPCE
@@ -361,26 +373,19 @@ if (iturb.eq.32) then
   iprev  = 1
   inc    = 1
   iccocg = 1
-  nswrgp = nswrgr(ial)
-  imligp = imligr(ial)
-  iwarnp = iwarni(ial)
-  epsrgp = epsrgr(ial)
-  climgp = climgr(ial)
-  extrap = extrag(ial)
-  iphydp = 0
 
   call field_gradient_scalar(ivarfl(ial), iprev, imrgra, inc,     &
-                             iccocg, nswrgp, iwarnp, imligp,      &
-                             epsrgp, extrap, climgp, grad)
+                             iccocg,                              &
+                             grad)
 
 endif
 
-if (icorio.eq.1) then
+if (icorio.eq.1 .or. iturbo.eq.1) then
 
-  ! Compute the rotation matrix (dual antisymmetric matrix of the rotation vector)
-  matrot(1,2) = -omegaz
-  matrot(1,3) =  omegay
-  matrot(2,3) = -omegax
+  ! Compute the rotation matrix (dual matrix of the rotation vector)
+  matrot(1,2) = -rotax(3)
+  matrot(1,3) =  rotax(2)
+  matrot(2,3) = -rotax(1)
 
   do ii = 1, 3
     matrot(ii,ii) = 0.d0
@@ -459,16 +464,18 @@ do iel=1,ncel
                        rtpa(iel,ir33)*gradv(3, 3, iel) )
 
   ! Rotating frame of reference => "Coriolis production" term
-  if (icorio.eq.1) then
-    do ii = 1, 3
-      do jj = ii, 3
-        do kk = 1, 3
-          xprod(ii,jj) = xprod(ii,jj)                                   &
-                       - 2.d0*( matrot(ii,kk)*rtpa(iel,indrey(jj,kk))   &
-                              + matrot(jj,kk)*rtpa(iel,indrey(ii,kk)) )
+  if (icorio.eq.1 .or. iturbo.eq.1) then
+    if (irotce(iel).gt.0) then
+      do ii = 1, 3
+        do jj = ii, 3
+          do kk = 1, 3
+            xprod(ii,jj) = xprod(ii,jj)                             &
+                 - ccorio*( matrot(ii,kk)*rtpa(iel,indrey(jj,kk))   &
+                 + matrot(jj,kk)*rtpa(iel,indrey(ii,kk)) )
+          enddo
         enddo
       enddo
-    enddo
+    endif
   endif
 
   xprod(2,1) = xprod(1,2)
@@ -701,6 +708,8 @@ endif
 ! Symmetric tensor diffusivity (GGDH)
 if (idften(ivar).eq.6) then
 
+  call field_get_val_v(ivsten, visten)
+
   do iel = 1, ncel
     viscce(1,iel) = visten(1,iel) + propce(iel,ipcvis)
     viscce(2,iel) = visten(2,iel) + propce(iel,ipcvis)
@@ -718,8 +727,21 @@ if (idften(ivar).eq.6) then
    weighf , weighb ,             &
    viscf  , viscb  )
 
+! Scalar diffusivity
 else
-  call csexit(1)
+
+  do iel = 1, ncel
+    trrij = 0.5d0 * (rtpa(iel,ir11) + rtpa(iel,ir22) + rtpa(iel,ir33))
+    rctse = crom(iel) * csrij * trrij**2 / rtpa(iel,iep)
+    w1(iel) = propce(iel,ipcvis) + idifft(ivar)*rctse
+  enddo
+
+  call viscfa                    &
+  !==========
+ ( imvisf ,                      &
+   w1     ,                      &
+   viscf  , viscb  )
+
 endif
 
 !===============================================================================
