@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -100,7 +100,7 @@ integer          ncepdp , ncesmp
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision prdv2f(ncelet)
@@ -130,6 +130,7 @@ double precision hint
 
 double precision rvoid(1)
 
+character(len=80) :: label
 double precision, allocatable, dimension(:) :: viscf, viscb
 double precision, allocatable, dimension(:) :: smbr, rovsdt
 double precision, allocatable, dimension(:,:) :: gradp, gradk
@@ -189,31 +190,17 @@ inc = 1
 iprev = 1
 ivar = iphi
 
-nswrgp = nswrgr(ivar)
-imligp = imligr(ivar)
-iwarnp = iwarni(ivar)
-epsrgp = epsrgr(ivar)
-climgp = climgr(ivar)
-extrap = extrag(ivar)
-
 call field_gradient_scalar(ivarfl(ivar), iprev, imrgra, inc,      &
-                           iccocg, nswrgp, iwarnp, imligp,        &
-                           epsrgp, extrap, climgp, gradp)
+                           iccocg,                                &
+                           gradp)
 
 iccocg = 1
 inc = 1
 ivar = ik
 
-nswrgp = nswrgr(ivar)
-imligp = imligr(ivar)
-iwarnp = iwarni(ivar)
-epsrgp = epsrgr(ivar)
-climgp = climgr(ivar)
-extrap = extrag(ivar)
-
 call field_gradient_scalar(ivarfl(ik), iprev, imrgra, inc,        &
-                           iccocg, nswrgp, iwarnp, imligp,        &
-                           epsrgp, extrap, climgp, gradk)
+                           iccocg,                                &
+                           gradk)
 
 do iel = 1, ncel
   w1(iel) = gradp(1,iel)*gradk(1,iel) &
@@ -236,7 +223,8 @@ endif
 ipp    = ipprtp(ivar)
 
 if(iwarni(ivar).ge.1) then
-  write(nfecra,1100) nomvar(ipp)
+  call field_get_label(ivarfl(ivar), label)
+  write(nfecra,1100) label
 endif
 
 !     S pour Source, V pour Variable
@@ -263,16 +251,15 @@ do iel = 1, ncel
 enddo
 
 !===============================================================================
-! 3.1 TERMES SOURCES  UTILISATEURS
+! 3.1 User source terms
 !===============================================================================
 
-call ustsv2                                                       &
-!==========
+call cs_user_turbulence_source_terms &
+!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
-   ivar   ,                                                       &
+   ivarfl(ivar)    ,                                              &
    icepdc , icetsm , itypsm ,                                     &
-   dt     , rtpa   , propce ,                                     &
-   ckupdc , smacel , prdv2f , w1     ,                            &
+   ckupdc , smacel ,                                              &
    smbr   , rovsdt )
 
 !     Si on extrapole les T.S.
@@ -359,7 +346,7 @@ iphydp = 0
 call itrgrp &
 !==========
  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydp , &
-   iwarnp , nfecra ,                                              &
+   iwarnp ,                                                       &
    epsrgp , climgp , extrap ,                                     &
    rvoid  ,                                                       &
    rtpa(1,iphi)    ,                                              &
@@ -511,7 +498,8 @@ ivar = iphi
 ipp  = ipprtp(ivar)
 
 if(iwarni(ivar).ge.1) then
-  write(nfecra,1100) nomvar(ipp)
+  call field_get_label(ivarfl(ivar), label)
+  write(nfecra,1100) label
 endif
 
 !     S pour Source, V pour Variable
@@ -533,16 +521,15 @@ do iel = 1, ncel
 enddo
 
 !===============================================================================
-! 4.1 TERMES SOURCES  UTILISATEURS
+! 4.1 User source terms
 !===============================================================================
 
-call ustsv2                                                       &
-!==========
+call cs_user_turbulence_source_terms &
+!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
-   ivar   ,                                                       &
+   ivarfl(ivar)    ,                                              &
    icepdc , icetsm , itypsm ,                                     &
-   dt     , rtpa   , propce ,                                     &
-   ckupdc , smacel , prdv2f , w1     ,                            &
+   ckupdc , smacel ,                                              &
    smbr   , rovsdt )
 
 !     Si on extrapole les T.S.
