@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -93,7 +93,7 @@ integer          ncepdp , ncesmp
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision tslagr(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
@@ -230,27 +230,13 @@ iccocg = 1
 inc = 1
 iprev = 1
 
-nswrgp = nswrgr(ik)
-imligp = imligr(ik)
-iwarnp = iwarni(ik)
-epsrgp = epsrgr(ik)
-climgp = climgr(ik)
-extrap = extrag(ik)
-
 call field_gradient_scalar(ivarfl(ik), iprev, imrgra, inc,          &
-                           iccocg, nswrgp, iwarnp, imligp,          &
-                           epsrgp, extrap, climgp, gradk)
-
-nswrgp = nswrgr(iomg)
-imligp = imligr(iomg)
-iwarnp = iwarni(iomg)
-epsrgp = epsrgr(iomg)
-climgp = climgr(iomg)
-extrap = extrag(iomg)
+                           iccocg,                                  &
+                           gradk)
 
 call field_gradient_scalar(ivarfl(iomg), iprev, imrgra, inc,        &
-                           iccocg, nswrgp, iwarnp, imligp,          &
-                           epsrgp, extrap, climgp, grado)
+                           iccocg,                                  &
+                           grado)
 
 do iel = 1, ncel
   gdkgdw(iel) = gradk(1,iel)*grado(1,iel) &
@@ -448,14 +434,21 @@ do iel = 1, ncel
   usimpw(iel) = 0.d0
 enddo
 
-call ustskw &
-!==========
+call cs_user_turbulence_source_terms &
+!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
+   ivarfl(ik)      ,                                              &
    icepdc , icetsm , itypsm ,                                     &
-   dt     , rtpa   , propce ,                                     &
-   ckupdc , smacel , s2kw   , divukw ,                            &
-   gdkgdw , w2     , xf1    ,                                     &
-   smbrk  , smbrw  , usimpk , usimpw )
+   ckupdc , smacel ,                                              &
+   smbrk  , usimpk )
+
+call cs_user_turbulence_source_terms &
+!===================================
+ ( nvar   , nscal  , ncepdp , ncesmp ,                            &
+   ivarfl(iomg)    ,                                              &
+   icepdc , icetsm , itypsm ,                                     &
+   ckupdc , smacel ,                                              &
+   smbrw  , usimpw )
 
 ! If source terms are extrapolated over time
 if (isto2t.gt.0) then
@@ -694,9 +687,7 @@ if (ikecou.eq.1) then
   ! ---> Traitement de k
   ivar   = ik
 
-  ipp    = ipprtp(ivar)
-
-  chaine = nomvar(ipp)
+  call field_get_label(ivarfl(ivar), chaine)
 
   if( idiff(ivar).ge. 1 ) then
 
@@ -748,7 +739,7 @@ if (ikecou.eq.1) then
   !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp , idftnp ,                            &
+   iwarnp , imucpp , idftnp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
    coefa_k , coefb_k , coefaf_k , coefbf_k ,                      &
@@ -766,10 +757,7 @@ if (ikecou.eq.1) then
 
   ! ---> Traitement de omega
   ivar   = iomg
-
-  ipp    = ipprtp(ivar)
-
-  chaine = nomvar(ipp)
+  call field_get_label(ivarfl(ivar), chaine)
 
   if( idiff(ivar).ge. 1 ) then
     do iel = 1, ncel
@@ -820,7 +808,7 @@ if (ikecou.eq.1) then
   !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
-   ipp    , iwarnp , imucpp , idftnp ,                            &
+   iwarnp , imucpp , idftnp ,                                     &
    blencp , epsrgp , climgp , extrap , relaxp , thetap ,          &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
    coefa_o , coefb_o , coefaf_o , coefbf_o ,                      &
