@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -98,7 +98,7 @@ integer          itypfb(nfabor)
 integer          icvflb
 integer          ivoid(1)
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 
@@ -217,20 +217,11 @@ cst3 = 0.9d0
 ! Allocate temporary arrays for gradients calculation
 allocate(gradv(3, 3, ncelet))
 
-iccocg = 1
 inc = 1
 iprev = 1
 
-nswrgp = nswrgr(iu)
-imligp = imligr(iu)
-iwarnp = iwarni(inusa)
-epsrgp = epsrgr(iu)
-climgp = climgr(iu)
-extrap = extrag(iu)
-
 call field_gradient_vector(ivarfl(iu), iprev, imrgra, inc,       &
-                           nswrgp, iwarnp, imligp, epsrgp,       &
-                           climgp, gradv)
+                           gradv)
 
 ! vort = omega**2 = dudy**2 + dvdx**2 + dudz**2 + dwdx**2 + dvdz**2 + dwdy**2
 !                - 2*dudy*dvdx - 2*dudz*dwdx - 2*dvdz*dwdy
@@ -253,16 +244,9 @@ allocate(grad(3,ncelet))
 
 ! Compute the gradient of nusa
 
-nswrgp = nswrgr(inusa)
-imligp = imligr(inusa)
-iwarnp = iwarni(inusa)
-epsrgp = epsrgr(inusa)
-climgp = climgr(inusa)
-extrap = extrag(inusa)
-
 call field_gradient_scalar(ivarfl(inusa), iprev, imrgra, inc,       &
-                           iccocg, nswrgp, iwarnp, imligp,          &
-                           epsrgp, extrap, climgp, grad)
+                           iccocg,                                  &
+                           grad)
 
 ! trgrdn = GRAD(nusa)**2
 do iel = 1, ncel
@@ -408,12 +392,12 @@ do iel = 1, ncel
   tsexp (iel) = 0.d0
 enddo
 
-call ustssa                                                       &
-!==========
+call cs_user_turbulence_source_terms &
+!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
+   ivarfl(inusa)   ,                                              &
    icepdc , icetsm , itypsm ,                                     &
-   dt     , rtpa   , propce ,                                     &
-   ckupdc , smacel , vort   , trgrdu ,                            &
+   ckupdc , smacel ,                                              &
    tsexp  , tsimp )
 
 !===============================================================================
@@ -492,7 +476,7 @@ if (ncesmp.gt.0) then
   call catsma &
   !==========
  ( ncelet , ncel   , ncesmp , iiun   ,                            &
-                              isto2t , thetv ,                    &
+   isto2t , thetv  ,                                              &
    icetsm , itypsm(1,ivar) ,                                      &
    volume , rtpa(1,ivar) , smacel(1,ivar) , smacel(1,ipr) ,       &
    rhssa  , tinssa , w1 )
