@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -69,16 +69,17 @@ subroutine turrij &
 !===============================================================================
 
 use paramx
-use dimens, only: ndimfb
 use lagdim, only: ntersl
 use numvar
 use entsor
 use cstphy
 use optcal
 use lagran
-use pointe, only: coefau, coefbu, ivoid1, rvoid1
+use pointe, only: ivoid1, rvoid1
+use ppincl
 use mesh
 use field
+use field_operator
 
 !===============================================================================
 
@@ -94,7 +95,7 @@ integer          icetsm(ncesmp)
 
 integer, dimension(ncesmp,nvar), target :: itypsm
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
+double precision dt(ncelet), rtp(ncelet,nflown:nvar), rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision ckupdc(ncepdp,6)
 
@@ -110,9 +111,9 @@ integer          ipp   , iwarnp, iclip
 integer          nswrgp, imligp
 integer          iivar
 integer          iitsla
+integer          iprev
 double precision epsrgp, climgp, extrap
-
-logical          ilved
+double precision rhothe
 
 double precision, allocatable, dimension(:) :: viscf, viscb
 double precision, allocatable, dimension(:) :: smbr, rovsdt
@@ -120,8 +121,9 @@ double precision, allocatable, dimension(:,:,:) :: gradv
 double precision, allocatable, dimension(:,:) :: produc
 double precision, allocatable, dimension(:,:) :: gradro
 
-integer,          pointer, dimension(:) :: itpsmp
-double precision, pointer, dimension(:) :: smcelp, gammap, tslage, tslagi
+double precision, pointer, dimension(:) :: tslage, tslagi
+double precision, dimension(:,:), pointer :: coefau
+double precision, dimension(:,:,:), pointer :: coefbu
 double precision, dimension(:), pointer :: brom, crom
 
 !===============================================================================
@@ -130,12 +132,12 @@ double precision, dimension(:), pointer :: brom, crom
 ! 1. Initialization
 !===============================================================================
 
-itpsmp => ivoid1
-smcelp => rvoid1
-gammap => rvoid1
 tslage => rvoid1
 tslagi => rvoid1
 
+call field_get_coefa_v(ivarfl(iu), coefau)
+call field_get_coefb_v(ivarfl(iu), coefbu)
+
 ! Allocate temporary arrays for the turbulence resolution
 allocate(viscf(nfac), viscb(nfabor))
 allocate(smbr(ncelet), rovsdt(ncelet))
@@ -163,26 +165,11 @@ endif
 ! 2.1 Compute the velocity gradient
 !===============================================================================
 
-iccocg = 1
-inc    = 1
+inc = 1
+iprev = 1
 
-nswrgp = nswrgr(iu)
-imligp = imligr(iu)
-iwarnp = iwarni(iu)
-epsrgp = epsrgr(iu)
-climgp = climgr(iu)
-extrap = extrag(iu)
-
-ilved = .false.
-
-! WARNING: gradv(xyz, uvw, iel)
-call grdvec &
-!==========
-( iu     , imrgra , inc    , nswrgp , imligp ,                   &
-  iwarnp , epsrgp , climgp ,                                     &
-  ilved  ,                                                       &
-  rtpa(1,iu) ,  coefau , coefbu,                                 &
-  gradv  )
+call field_gradient_vector(ivarfl(iu), iprev, imrgra, inc,    &
+                           gradv)
 
 !===============================================================================
 ! 2.2 Compute the production term for Rij LRR (iturb =30)
@@ -257,8 +244,36 @@ endif
 ! 3. Compute the density gradient for buoyant terms
 !===============================================================================
 
-if (igrari.eq.1) then
+! Note that the buoyant term is normally expressed in temr of
+! (u'T') or (u'rho') here modelled with a GGDH:
+!   (u'rho') = C * k/eps * R_ij Grad_j(rho)
 
+! Buoyant term for the Atmospheric module
+! (function of the potential temperature)
+if (igrari.eq.1 .and. ippmod(iatmos).ge.1) then
+  ! Allocate a temporary array for the gradient calculation
+  ! Warning, grad(theta) here
+  allocate(gradro(ncelet,3))
+
+  call field_get_val_s(icrom, cromo)
+
+  iprev = 1
+  inc = 1
+  iccocg = 1
+
+  call field_gradient_scalar(ivarfl(isca(iscalt)), 1, imrgra, inc, &
+                             iccocg,                               &
+                             gradro)
+
+  ! gradro stores: rho grad(theta)/theta
+  do iel = 1, ncel
+    rhothe = cromo(iel)/rtpa(iel, isca(iscalt))
+    gradro(1, iel) = rhothe*gradro(1, iel)
+    gradro(2, iel) = rhothe*gradro(2, iel)
+    gradro(3, iel) = rhothe*gradro(3, iel)
+  enddo
+
+else if (igrari.eq.1) then
   ! Allocate a temporary array for the gradient calculation
   allocate(gradro(ncelet,3))
 
@@ -328,22 +343,16 @@ do isou = 1, 6
     tslagi => tslagr(1:ncelet,itsli)
   endif
 
-  if (ncesmp.gt.0) then
-    itpsmp => itypsm(1:ncesmp,ivar)
-    smcelp => smacel(1:ncesmp,ivar)
-    gammap => smacel(1:ncesmp,ipr)
-  endif
-
   ! Rij-epsilon standard (LRR)
   if (iturb.eq.30) then
     call resrij &
     !==========
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    ivar   , isou   , ipp    ,                                     &
-   icepdc , icetsm , itpsmp ,                                     &
+   icepdc , icetsm , itypsm ,                                     &
    dt     , rtp    , rtpa   , propce ,                            &
    produc , gradro ,                                              &
-   ckupdc , smcelp , gammap ,                                     &
+   ckupdc , smacel ,                                              &
    viscf  , viscb  ,                                              &
    tslage , tslagi ,                                              &
    smbr   , rovsdt )
@@ -355,10 +364,10 @@ do isou = 1, 6
     !==========
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    ivar   , isou   , ipp    ,                                     &
-   icepdc , icetsm , itpsmp ,                                     &
+   icepdc , icetsm , itypsm ,                                     &
    dt     , rtp    , rtpa   , propce ,                            &
    gradv  , gradro ,                                              &
-   ckupdc , smcelp , gammap ,                                     &
+   ckupdc , smacel ,                                              &
    viscf  , viscb  ,                                              &
    tslage , tslagi ,                                              &
    smbr   , rovsdt )
@@ -374,20 +383,14 @@ ivar   = iep
 ipp    = ipprtp(ivar)
 isou   = 7
 
-if (ncesmp.gt.0) then
-  itpsmp => itypsm(1:ncesmp,ivar)
-  smcelp => smacel(1:ncesmp,ivar)
-  gammap => smacel(1:ncesmp,ipr)
-endif
-
 call reseps &
 !==========
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    ivar   , isou   , ipp    ,                                     &
-   icepdc , icetsm , itpsmp ,                                     &
+   icepdc , icetsm , itypsm ,                                     &
    dt     , rtp    , rtpa   , propce ,                            &
    gradv  , produc , gradro ,                                     &
-   ckupdc , smcelp , gammap ,                                     &
+   ckupdc , smacel ,                                              &
    viscf  , viscb  ,                                              &
    tslagr ,                                                       &
    smbr   , rovsdt )
