@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -67,13 +67,15 @@ subroutine vissst &
 
 use paramx
 use cstnum
-use pointe, only: s2kw, divukw, ifapat, dispar, coefau, coefbu
+use pointe, only: s2kw, divukw, ifapat, dispar
 use numvar
 use optcal
+use dimens, only: nvar
 use cstphy
 use entsor
 use mesh
 use field
+use field_operator
 
 !===============================================================================
 
@@ -81,24 +83,24 @@ implicit none
 
 ! Arguments
 
-double precision rtpa(ncelet,*)
+double precision rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 
 ! Local variables
 
-integer          iel, iccocg, inc
+integer          iel, inc
 integer          ipcvis, ipcvst
 integer          nswrgp, imligp, iwarnp
-integer          ifacpt
+integer          ifacpt, iprev
 
 double precision d1s3, d2s3
 double precision epsrgp, climgp, extrap
 double precision xk, xw, rom, xmu, xdist, xarg2, xf2
 
-logical          ilved
-
 double precision, allocatable, dimension(:) :: w1
 double precision, dimension(:,:,:), allocatable :: gradv
+double precision, dimension(:,:), pointer :: coefau
+double precision, dimension(:,:,:), pointer :: coefbu
 double precision, dimension(:), pointer :: crom
 
 !===============================================================================
@@ -107,6 +109,9 @@ double precision, dimension(:), pointer :: crom
 ! 1.  INITIALISATION
 !===============================================================================
 
+call field_get_coefa_v(ivarfl(iu), coefau)
+call field_get_coefb_v(ivarfl(iu), coefbu)
+
 ! --- Rang des variables dans PROPCE (prop. physiques au centre)
 ipcvis = ipproc(iviscl)
 ipcvst = ipproc(ivisct)
@@ -127,27 +132,11 @@ d2s3 = 2.d0/3.d0
 ! Allocate temporary arrays for gradients calculation
 allocate(gradv(3,3,ncelet))
 
-iccocg = 1
 inc = 1
+iprev = 1
 
-nswrgp = nswrgr(iu)
-imligp = imligr(iu)
-iwarnp = iwarni(iu)
-epsrgp = epsrgr(iu)
-climgp = climgr(iu)
-extrap = extrag(iu)
-
-ilved = .false.
-
-! WARNING: gradv(xyz, uvw, iel)
-call grdvec &
-!==========
-( iu  , imrgra , inc    ,                               &
-  nswrgr(iu) , imligr(iu) , iwarni(iu) ,                &
-  epsrgr(iu) , climgr(iu) ,                             &
-  ilved  ,                                              &
-  rtpa(1,iu) ,  coefau , coefbu,                        &
-  gradv  )
+call field_gradient_vector(ivarfl(iu), iprev, imrgra, inc,    &
+                           gradv)
 
 ! s2kw = Stain rate of the deviatoric part of the s2kw tensor
 !      = 2 (Sij^D).(Sij^D)
