@@ -4,7 +4,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -25,11 +25,10 @@
 subroutine uslaed &
 !================
 
- ( nvar   , nscal  ,                                              &
-   nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
+ ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
-   itepa  , ibord  ,                                              &
-   dt     , rtp    , propce ,                                     &
+   itepa  ,                                                       &
+   dt     ,                                                       &
    ettp   , ettpa  , tepa   , taup   , tlag   , tempct , tsvar  , &
    auxl1  , auxl2  , auxl3  )
 
@@ -76,8 +75,6 @@ subroutine uslaed &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! nvar             ! i  ! <-- ! total number of variables                      !
-! nscal            ! i  ! <-- ! total number of scalars                        !
 ! nbpmax           ! i  ! <-- ! maximum number of particles allowed            !
 ! nvp              ! i  ! <-- ! number of particle variables                   !
 ! nvp1             ! i  ! <-- ! nvp minus position, fluid and part. velocities !
@@ -88,13 +85,7 @@ subroutine uslaed &
 ! nvisbr           ! i  ! <-- ! number of boundary statistics                  !
 ! itepa            ! ia ! <-- ! particle information (integers)                !
 ! (nbpmax,nivep    !    !     !                                                !
-! ibord            ! ia ! <-- ! number of the boundary face of part./wall      !
-!   (nbpmax)       !    !     ! interaction                                    !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtp              ! ra ! <-- ! transported variables at the current           !
-! (ncelet,*)       !    !     ! and previous time step                         !
-! propce           ! ra ! <-- ! physical properties at cell centers            !
-! (ncelet,*)       !    !     !                                                !
 ! ettp             ! ra ! <-- ! array of the variables associated to           !
 !  (nbpmax,nvp)    !    !     ! the particles at the current time step         !
 ! ettpa            ! ra ! <-- ! array of the variables associated to           !
@@ -128,6 +119,7 @@ use numvar
 use cstphy
 use cstnum
 use optcal
+use dimens, only: nvar
 use entsor
 use lagpar
 use lagran
@@ -139,14 +131,12 @@ implicit none
 
 ! Arguments
 
-integer          nvar   , nscal
 integer          nbpmax , nvp    , nvp1   , nvep  , nivep
 integer          ntersl , nvlsta , nvisbr
 
-integer          itepa(nbpmax,nivep)  , ibord(nbpmax)
+integer          itepa(nbpmax,nivep)
 
-double precision dt(ncelet) , rtp(ncelet,*)
-double precision propce(ncelet,*)
+double precision dt(ncelet)
 double precision ettp(nbpmax,nvp) , ettpa(nbpmax,nvp)
 double precision tepa(nbpmax,nvep)
 double precision taup(nbpmax) , tlag(nbpmax,3) , tempct(nbpmax,2)
@@ -251,9 +241,9 @@ do iiii = 1,nvls
 
   call lagitg                                                     &
   !==========
-   ( nbpmax , nvp    , nvp1   ,                                   &
+   ( nbpmax , nvp    , nvp1   , nivep ,                           &
      ipl    ,                                                     &
-     itepa(1,jisor)  , ibord  ,                                   &
+     itepa  ,                                                     &
      ettp   , ettpa  , auxl1  , auxl2  , tsvar  )
 
 enddo
@@ -276,8 +266,8 @@ subroutine uslafe &
  ( nvar   , nscal  ,                                              &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
-   itepa  , ibord  ,                                              &
-   dt     , rtpa   , rtp    , propce ,                            &
+   itepa  ,                                                       &
+   dt     ,                                                       &
    ettp   , ettpa  , tepa   , statis , stativ ,                   &
    taup   , tlag   , piil   ,                                     &
    tsuf   , tsup   , bx     , tsfext ,                            &
@@ -317,13 +307,7 @@ subroutine uslafe &
 ! nvisbr           ! i  ! <-- ! number of boundary statistics                  !
 ! itepa            ! ia ! <-- ! particle information (integers)                !
 ! (nbpmax,nivep)   !    !     !                                                !
-! ibord(nbpmax)    ! ia ! --> ! if nordre=2, contains the number of the        !
-!                  !    !     ! boundary face of particle/wall interaction     !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtp, rtpa        ! ra ! <-- ! transported variables at cell centers for      !
-! (ncelet,*)       !    !     ! the current and the previous time step         !
-! propce           ! ra ! <-- ! physical properties at cell centers            !
-! (ncelet,*)       !    !     !                                                !
 ! ettp             ! ra ! <-- ! array of the variables associated to           !
 !  (nbpmax,nvp)    !    !     !                                                !
 ! ettpa            ! ra ! <-- ! array of the variables associated to           !
@@ -385,10 +369,9 @@ integer          nvar   , nscal
 integer          nbpmax , nvp    , nvp1   , nvep  , nivep
 integer          ntersl , nvlsta , nvisbr
 
-integer          itepa(nbpmax,nivep) , ibord(nbpmax)
+integer          itepa(nbpmax,nivep)
 
-double precision dt(ncelet) , rtp(ncelet,*) , rtpa(ncelet,*)
-double precision propce(ncelet,*)
+double precision dt(ncelet)
 double precision ettp(nbpmax,nvp) , ettpa(nbpmax,nvp)
 double precision tepa(nbpmax,nvep)
 double precision statis(ncelet,*),stativ(ncelet,*)
@@ -578,7 +561,7 @@ integer          itypfb(nfabor) , itrifb(nfabor)
 integer          itepa(nbpmax,nivep) , ifrlag(nfabor)
 integer          injfac(nbpmax)
 
-double precision dt(ncelet) , rtpa(ncelet,*)
+double precision dt(ncelet) , rtpa(ncelet,nflown:nvar)
 double precision propce(ncelet,*)
 double precision ettp(nbpmax,nvp) , tepa(nbpmax,nvep)
 double precision vagaus(nbpmax,*)
@@ -746,7 +729,7 @@ subroutine uslapr &
    itypfb , itrifb , itepa  , ifrlag ,                            &
    xxpart , yypart , zzpart ,                                     &
    tvpart , uupart , vvpart , wwpart , ddpart , ttpart  ,         &
-   dt     , rtpa   , propce ,                                     &
+   dt     ,                                                       &
    ettp   , tepa   )
 
 !===============================================================================
@@ -802,10 +785,6 @@ subroutine uslapr &
 ! ddpart           !  r ! <-- ! particle diameter                              !
 ! ttpart           !  r ! <-- ! particle temperature                           !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtpa             ! ra ! <-- ! transported variables at the previous          !
-! (ncelet,*)       !    !     ! time step                                      !
-! propce           ! ra ! <-- ! physical properties at cell centers            !
-! (ncelet,*)       !    !     !                                                !
 ! ettp             ! ra ! <-- ! array of the variables associated to           !
 !  (nbpmax,nvp)    !    !     ! the particles at the current time step         !
 ! tepa             ! ra ! <-- ! particle information (real) (statis. weight..) !
@@ -855,8 +834,7 @@ double precision xxpart , yypart , zzpart
 double precision tvpart , uupart , vvpart , wwpart
 double precision ddpart , ttpart
 
-double precision dt(ncelet) , rtpa(ncelet,*)
-double precision propce(ncelet,*)
+double precision dt(ncelet)
 double precision ettp(nbpmax,nvp) , tepa(nbpmax,nvep)
 
 ! Local variables
@@ -977,7 +955,7 @@ subroutine uslaru &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
    itypfb , itrifb , itepa  ,                                     &
-   dt     , rtpa   , propce ,                                     &
+   dt     ,                                                       &
    ettp   , tepa   , vagaus , croule , auxl  ,                    &
    distpa , distyp )
 
@@ -1013,10 +991,6 @@ subroutine uslaru &
 ! itepa            ! ia ! <-- ! particle information (integers)                !
 ! (nbpmax,nivep)   !    !     !                                                !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtpa             ! ra ! <-- ! transported variables at cell centers for      !
-! (ncelet,*)       !    !     ! the previous timestep                          !
-! propce           ! ra ! <-- ! physical properties at cell centers            !
-! (ncelet,*)       !    !     !                                                !
 ! ettp             ! ra ! <-- ! array of the variables associated to           !
 !  (nbpmax,nvp)    !    !     ! the particles at the current time step         !
 ! tepa             ! ra ! <-- ! particle information (real) (statis. weight..) !
@@ -1064,8 +1038,7 @@ integer          ntersl , nvlsta , nvisbr
 integer          itypfb(nfabor) , itrifb(nfabor)
 integer          itepa(nbpmax,nivep)
 
-double precision dt(ncelet), rtpa(ncelet,*)
-double precision propce(ncelet,*)
+double precision dt(ncelet)
 double precision ettp(nbpmax,nvp) , tepa(nbpmax,nvep)
 double precision vagaus(nbpmax,*) , croule(ncelet)
 double precision auxl(nbpmax,3)
@@ -1153,7 +1126,7 @@ subroutine uslast &
  ( nvar   , nscal  ,                                              &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
-   dt     , rtpa   , rtp    , propce ,                            &
+   dt     ,                                                       &
    taup   , tlag   , tempct )
 
 !===============================================================================
@@ -1208,10 +1181,6 @@ subroutine uslast &
 ! nvlsta           ! i  ! <-- ! nb of Lagrangian statistical variables         !
 ! nvisbr           ! i  ! <-- ! number of boundary statistics                  !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtp, rtpa        ! ra ! <-- ! transported variables at cell centers at       !
-! (ncelet,*)       !    !     ! the current and previous time step             !
-! propce           ! ra ! <-- ! physical properties at cell centers            !
-! (ncelet,*)       !    !     !                                                !
 ! taup(nbpmax)     ! ra ! <-- ! particle relaxation time                       !
 ! tlag(nbpmax)     ! ra ! <-- ! relaxation time for the flow                   !
 ! tempct           ! ra ! <-- ! thermal relaxation time                        !
@@ -1251,8 +1220,7 @@ integer          nvar   , nscal
 integer          nbpmax , nvp    , nvp1   , nvep  , nivep
 integer          ntersl , nvlsta , nvisbr
 
-double precision dt(ncelet) , rtp(ncelet,*) , rtpa(ncelet,*)
-double precision propce(ncelet,*)
+double precision dt(ncelet)
 double precision taup(nbpmax) , tlag(nbpmax,3) , tempct(nbpmax,2)
 
 ! Local variables
@@ -1547,7 +1515,7 @@ subroutine uslatc &
    numpt  , itepa  ,                                              &
    rep    , uvwr   , romf   , romp   , xnul   ,                   &
    xcp    , xrkl   , tauc   ,                                     &
-   dt     , rtp    , propce ,                                     &
+   dt     ,                                                       &
    ettp   , ettpa  , tepa   )
 
 !===============================================================================
@@ -1639,10 +1607,6 @@ subroutine uslatc &
 !                  !    !     ! position                                       !
 ! tauc             ! r  ! --> ! thermal relaxation time                        !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtp              ! ra ! <-- ! transported variables at cell centers at       !
-! (ncelet,*)       !    !     ! the current time step                          !
-! propce           ! ra ! <-- ! physical properties at cell centers            !
-! (ncelet,*)       !    !     !                                                !
 ! ettp             ! ra ! <-- ! array of the variables associated to           !
 !  (nbpmax,nvp)    !    !     ! the particles at the current time step         !
 ! ettpa            ! ra ! <-- ! array of the variables associated to           !
@@ -1690,8 +1654,7 @@ integer          itepa(nbpmax,nivep)
 double precision rep    , uvwr   , romf   , romp   , xnul
 double precision xcp    , xrkl   , tauc
 
-double precision dt(ncelet) , rtp(ncelet,*)
-double precision propce(ncelet,*)
+double precision dt(ncelet)
 double precision ettp(nbpmax,nvp) , ettpa(nbpmax,nvp)
 double precision tepa(nbpmax,nvep)
 
@@ -1767,7 +1730,7 @@ subroutine uslatp &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    numpt  , itepa  ,                                              &
    rep    , uvwr   , romf   , romp   , xnul   , taup   ,          &
-   dt     , rtp    , propce ,                                     &
+   dt     ,                                                       &
    ettp   , ettpa  , tepa   )
 
 !===============================================================================
@@ -1842,10 +1805,6 @@ subroutine uslatp &
 !                  !    !     ! particle position                              !
 ! taup             ! r  ! --> ! particle relaxation time                       !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! rtp              ! ra ! <-- ! transported variables at cells centers         !
-! (ncelet,*)       !    !     ! at the previous time step                      !
-! propce           ! ra ! <-- ! physical properties at cell centers            !
-! (ncelet,*)       !    !     !                                                !
 ! ettp             ! ra ! <-- ! array of the variables associated to           !
 !  (nbpmax,nvp)    !    !     ! the particles at the current time step         !
 ! ettpa            ! ra ! <-- ! array of the variables associated to           !
@@ -1892,8 +1851,7 @@ integer          itepa(nbpmax,nivep)
 
 double precision rep    , uvwr   , romf   , romp   , xnul  , taup
 
-double precision dt(ncelet) , rtp(ncelet,*)
-double precision propce(ncelet,*)
+double precision dt(ncelet)
 double precision ettp(nbpmax,nvp) , ettpa(nbpmax,nvp)
 double precision tepa(nbpmax,nvep)
 
