@@ -4,7 +4,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -52,11 +52,11 @@ subroutine usporo
 use paramx
 use numvar
 use optcal
-use pointe
 use cstnum
 use parall
 use period
 use mesh
+use field
 
 !===============================================================================
 
@@ -67,17 +67,21 @@ implicit none
 integer          iel, ii, jj
 double precision x, pormin, pormax, hc, ll, dhc
 
+double precision, dimension(:), pointer :: cpro_porosi
 
 !===============================================================================
 ! TEST_TO_REMOVE_FOR_USE_OF_SUBROUTINE_START
 !===============================================================================
 
-if(1.eq.1) return
+if (1.eq.1) return
 
 !===============================================================================
 ! TEST_TO_REMOVE_FOR_USE_OF_SUBROUTINE_END
 !===============================================================================
 
+! Retrieve porosity field
+call field_get_val_s(ipori, cpro_porosi)
+
 ! Example: fixe a linear by part porosity profile
 
 do iel = 1, ncel
@@ -88,10 +92,10 @@ do iel = 1, ncel
     hc = 1.d0 - dhc + dhc*(2.d0*x-ll)/ll
   endif
 
-  porosi(iel) = hc
+  cpro_porosi(iel) = hc
 
-  pormin = min(pormin,porosi(iel))
-  pormax = max(pormax,porosi(iel))
+  pormin = min(pormin,cpro_porosi(iel))
+  pormax = max(pormax,cpro_porosi(iel))
 enddo
 
 ! Periodicity and parallelism treatment
@@ -101,7 +105,7 @@ if (irangp.ge.0) then
 endif
 
 if (iperio.eq.1.or.irangp.ge.0) then
-  call synsca(porosi)
+  call synsca(cpro_porosi)
 endif
 
 return
