@@ -4,7 +4,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -39,14 +39,11 @@
 !> \param[in]     nvar          total number of variables
 !> \param[in]     nscal         total number of scalars
 !> \param[in]     dt            time step (per cell)
-!> \param[in]     rtp, rtpa     calculated variables at cell centers
-!>                               (at current and previous time steps)
-!> \param[in]     propce        physical properties at cell centers
 !_______________________________________________________________________________
 
-subroutine cs_user_extra_operations &
+subroutine cs_f_user_extra_operations &
  ( nvar   , nscal  ,                                              &
-   dt     , rtpa   , rtp    , propce )
+   dt     )
 
 !===============================================================================
 
@@ -73,6 +70,7 @@ use ppincl
 use mesh
 use field
 use field_operator
+use turbomachinery
 
 !===============================================================================
 
@@ -82,8 +80,7 @@ implicit none
 
 integer          nvar   , nscal
 
-double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
-double precision propce(ncelet,*)
+double precision dt(ncelet)
 
 ! Local variables
 
@@ -92,28 +89,27 @@ integer          iel    , ifac   , ivar
 integer          iel1   , iel2   , ieltsm
 integer          iortho
 integer          inc    , iccocg
-integer          nswrgp , imligp , iwarnp
-integer          ipcvst , iflmas , iflmab , ipccp, ipcvsl
+integer          iflmas , iflmab , ipccp
 integer          iscal
-integer          ncesmp
 integer          ilelt  , nlelt
 
 double precision xrtpa  , xrtp
 double precision xbilan , xbilvl , xbilpa , xbilpt
 double precision xbilsy , xbilen , xbilso , xbildv
 double precision xbilmi , xbilma
-double precision epsrgp , climgp , extrap
 double precision xfluxf , xgamma
-double precision diipbx, diipby, diipbz, distbr
-double precision visct, flumab , xcp , xvsl, ctb1, ctb2
+double precision flumab , ctb1, ctb2
 
 integer, allocatable, dimension(:) :: lstelt
 
-double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
 double precision, allocatable, dimension(:,:) :: grad
 double precision, allocatable, dimension(:) :: treco
+double precision, allocatable, dimension(:) :: xcp
 double precision, dimension(:), pointer :: imasfl, bmasfl
+double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
 double precision, dimension(:), pointer ::  crom
+double precision, dimension(:), pointer :: cpro_visct, cpro_cp
+double precision, dimension(:), pointer :: cvar_scal, cvara_scal
 !< [loc_var_dec]
 
 !===============================================================================
@@ -123,6 +119,7 @@ double precision, dimension(:), pointer ::  crom
 !< [init]
 ! Allocate a temporary array for cells or interior/boundary faces selection
 allocate(lstelt(max(ncel,nfac,nfabor)))
+allocate(xcp(ncel))
 !< [init]
 
 !===============================================================================
@@ -162,9 +159,12 @@ if (inpdt0.eq.0) then
   iscal = iscalt         ! temperature scalar number
   ivar =  isca(iscal)    ! temperature variable number
 
+  call field_get_val_s(ivarfl(ivar), cvar_scal)
+  call field_get_val_prev_s(ivarfl(ivar), cvara_scal)
+
   ! Physical quantity numbers
   call field_get_val_s(icrom, crom)
-  ipcvst = ipproc(ivisct)
+  call field_get_val_s(iprpfl(ivisct), cpro_visct)
 
   ! Pointers to the mass fluxes
   call field_get_key_int(ivarfl(ivar), kimasf, iflmas)
@@ -172,21 +172,26 @@ if (inpdt0.eq.0) then
   call field_get_val_s(iflmas, imasfl)
   call field_get_val_s(iflmab, bmasfl)
 
-  ! We save in ipccp a flag allowing to determine if the specific heat is
-  ! constant (= cp0) or variable. It will be used to compute balances
-  ! (xbilvl is in Joules).
-  if (icp.gt.0) then
-    ipccp  = ipproc(icp   )
-  else
-    ipccp  = 0
-  endif
+  ! The balance is in Joule, so store the specific heat when dealing
+  ! with the Temperature.
 
-  ! We save in ipcvsl a flag allowing to determine if the diffusivity is
-  ! constant (= visls0) or variable. It will be used for diffusive terms.
-  if (ivisls(iscal).gt.0) then
-    ipcvsl = ipproc(ivisls(iscal))
+  if (icp.gt.0) call field_get_val_s(iprpfl(icp), cpro_cp)
+
+  ! If it is a temperature
+  if (itherm.eq.1) then
+    if (icp.gt.0) then
+      do iel = 1, ncel
+        xcp(iel) = cpro_cp(iel)
+      enddo
+    else
+      do iel = 1, ncel
+        xcp(iel) = cp0
+      enddo
+    endif
   else
-    ipcvsl = 0
+    do iel = 1, ncel
+      xcp(iel) = 1.d0
+    enddo
   endif
 
   ! Boundary condition pointers for gradients and advection
@@ -199,42 +204,6 @@ if (inpdt0.eq.0) then
   call field_get_coefaf_s(ivarfl(ivar), cofafp)
   call field_get_coefbf_s(ivarfl(ivar), cofbfp)
 
-  ! --> Synchronization of Cp and Dt
-  !     ----------------------------
-
-  ! To compute fluxes at interior faces, it is necessary to have access
-  ! to variables at neighboring cells. Notably, it is necessary to know
-  ! the specific heat and the time step value. For this,
-
-  ! - in parallel calculations, it is necessary on faces at sub-domain
-  !   boundaries to know the value of these variables in cells from the
-  !   neighboring subdomain.
-  ! - in periodic calculations, it is necessary at periodic faces to know
-  !   the value of these variables in matching periodic cells.
-
-  ! To ensure that these values are up to date, it is necessary to use
-  ! the synchronization routines to update parallel and periodic ghost
-  ! values for Cp and Dt before computing the gradient.
-
-  ! If the calculation is neither parallel nor periodic, the calls may be
-  ! kept, as tests on iperio and irangp ensure generality).
-
-  ! Parallel and periodic update
-
-  if (irangp.ge.0.or.iperio.eq.1) then
-
-    ! update Dt
-    call synsca(dt)
-    !==========
-
-    ! update Cp if variable (otherwise cp0 is used)
-    if (ipccp.gt.0) then
-      call synsca(propce(1,ipccp))
-      !==========
-    endif
-
-  endif
-
   ! --> Compute value reconstructed at I' for boundary faces
 
   allocate(treco(nfabor))
@@ -244,7 +213,7 @@ if (inpdt0.eq.0) then
   ! treco(ifac) (with ifac=1, nfabor)
 
   ! For orthogonal meshes, it is sufficient to assign:
-  ! rtp(iel, ivar) to treco(ifac), with iel=ifabor(ifac)
+  ! cvar_scal(iel) to treco(ifac), with iel=ifabor(ifac)
   ! (this option corresponds to the second branch of the test below,
   ! with iortho different from 0).
 
@@ -261,29 +230,20 @@ if (inpdt0.eq.0) then
 
     inc = 1
     iccocg = 1
-    nswrgp = nswrgr(ivar)
-    imligp = imligr(ivar)
-    iwarnp = iwarni(ivar)
-    epsrgp = epsrgr(ivar)
-    climgp = climgr(ivar)
-    extrap = extrag(ivar)
 
-    call field_gradient_scalar                                             &
+    call field_gradient_scalar &
     !=========================
-      (ivarfl(ivar), 0, imrgra, inc, iccocg, nswrgp, iwarnp, imligp,       &
-       epsrgp, climgp, extrap, grad)
+      (ivarfl(ivar), 0, imrgra, inc, iccocg,                               &
+       grad)
 
     ! - Compute reconstructed value in boundary cells
 
     do ifac = 1, nfabor
       iel = ifabor(ifac)
-      diipbx = diipb(1,ifac)
-      diipby = diipb(2,ifac)
-      diipbz = diipb(3,ifac)
-      treco(ifac) =   rtp(iel,ivar)       &
-                    + diipbx*grad(1,iel)  &
-                    + diipby*grad(2,iel)  &
-                    + diipbz*grad(3,iel)
+      treco(ifac) =   cvar_scal(iel)       &
+                    + diipb(1,ifac)*grad(1,iel)  &
+                    + diipb(2,ifac)*grad(2,iel)  &
+                    + diipb(3,ifac)*grad(3,iel)
     enddo
 
     ! Free memory
@@ -298,7 +258,7 @@ if (inpdt0.eq.0) then
 
     do ifac = 1, nfabor
       iel = ifabor(ifac)
-      treco(ifac) = rtp(iel,ivar)
+      treco(ifac) = cvar_scal(iel)
     enddo
 
   endif
@@ -312,106 +272,54 @@ if (inpdt0.eq.0) then
   ! If it is variable, the density 'rom' has been computed at the beginning
   ! of the time step using the temperature from the previous time step.
 
-  if (ipccp.gt.0) then
-    do iel = 1, ncel
-      xrtpa = rtpa(iel,ivar)
-      xrtp  = rtp (iel,ivar)
-      xbilvl =   xbilvl                                                &
-               + volume(iel) * propce(iel,ipccp) * crom(iel)  &
-                                                 * (xrtpa - xrtp)
-    enddo
-  else
-    do iel = 1, ncel
-      xrtpa = rtpa(iel,ivar)
-      xrtp  = rtp (iel,ivar)
-      xbilvl =   xbilvl  &
-               + volume(iel) * cp0 * crom(iel) * (xrtpa - xrtp)
-    enddo
-  endif
+  do iel = 1, ncel
+    xrtpa = cvara_scal(iel)
+    xrtp  = cvar_scal(iel)
+    xbilvl =   xbilvl                              &
+             + volume(iel) * xcp(iel) * crom(iel)  &
+                           * (xrtpa - xrtp)
+  enddo
 
   ! --> Balance on all faces (interior and boundary), for div(rho u)
   !     ------------------------------------------------------------
 
-  ! Caution: values of Cp and Dt in cells adjacent to interior faces are
-  !          used, which implies having synchronized these values for
-  !          parallelism and periodicity.
+  do ifac = 1, nfac
 
-  ! Note that if Cp is variable, writing a balance on the temperature
-  ! equation is not absolutely correct.
+    iel1 = ifacel(1,ifac)
+    if (iel1.le.ncel) then
+      ctb1 = imasfl(ifac)*xcp(iel1)*cvar_scal(iel1)*dt(iel1)
+    else
+      ctb1 = 0d0
+    endif
 
-  if (ipccp.gt.0) then
-    do ifac = 1, nfac
+    iel2 = ifacel(2,ifac)
+    if (iel2.le.ncel) then
+      ctb2 = imasfl(ifac)*xcp(iel2)*cvar_scal(iel2)*dt(iel2)
+    else
+      ctb2 = 0d0
+    endif
 
-      iel1 = ifacel(1,ifac)
-      if (iel1.le.ncel) then
-        ctb1 = imasfl(ifac)*propce(iel1,ipccp)*rtp(iel1,ivar)
-      else
-        ctb1 = 0d0
-      endif
+    xbildv =  xbildv + (ctb1 - ctb2)
+  enddo
 
-      iel2 = ifacel(2,ifac)
-      if (iel2.le.ncel) then
-        ctb2 = imasfl(ifac)*propce(iel2,ipccp)*rtp(iel2,ivar)
-      else
-        ctb2 = 0d0
-      endif
+  do ifac = 1, nfabor
+    iel = ifabor(ifac)
+    xbildv = xbildv + dt(iel) * xcp(iel)             &
+                              * bmasfl(ifac)         &
+                              * cvar_scal(iel)
+  enddo
 
-      xbildv =  xbildv + (dt(iel1)*ctb1 - dt(iel2)*ctb2)
-    enddo
-
-    do ifac = 1, nfabor
-      iel = ifabor(ifac)
-      xbildv = xbildv + dt(iel) * propce(iel,ipccp)    &
-                                * bmasfl(ifac)         &
-                                * rtp(iel,ivar)
-    enddo
-
-  ! --- if Cp is constant
-
-  else
-    do ifac = 1, nfac
-
-      iel1 = ifacel(1,ifac)
-      if (iel1.le.ncel) then
-        ctb1 = imasfl(ifac)*cp0*rtp(iel1,ivar)
-      else
-        ctb1 = 0d0
-      endif
-
-      iel2 = ifacel(2,ifac)
-      if (iel2.le.ncel) then
-        ctb2 = imasfl(ifac)*cp0*rtp(iel2,ivar)
-      else
-        ctb2 = 0d0
-      endif
-
-      xbildv = xbildv + (dt(iel1) + dt(iel2))*0.5d0*(ctb1 - ctb2)
-    enddo
-
-    do ifac = 1, nfabor
-      iel = ifabor(ifac)
-      xbildv = xbildv + dt(iel) * cp0                  &
-                                * bmasfl(ifac)         &
-                                * rtp(iel,ivar)
-    enddo
-  endif
 
   ! In case of a mass source term, add contribution from Gamma*Tn+1
 
-  ncesmp = ncetsm
-  if (ncesmp.gt.0) then
-    do ieltsm = 1, ncesmp
+  if (ncetsm.gt.0) then
+    do ieltsm = 1, ncetsm
       iel = icetsm(ieltsm)
-      xrtp  = rtp (iel,ivar)
+      xrtp  = cvar_scal(iel)
       xgamma = smacel(ieltsm,ipr)
-      if (ipccp.gt.0) then
-        xbildv =   xbildv                                     &
-                 - volume(iel) * propce(iel,ipccp) * dt(iel)  &
-                               * xgamma * xrtp
-      else
-        xbildv =   xbildv  &
-                 - volume(iel) * cp0 * dt(iel) * xgamma * xrtp
-      endif
+      xbildv =   xbildv                            &
+               - volume(iel) * xcp(iel) * dt(iel)  &
+                             * xgamma * xrtp
     enddo
   endif
 
@@ -432,33 +340,16 @@ if (inpdt0.eq.0) then
     ifac = lstelt(ilelt)
     iel  = ifabor(ifac)   ! associated boundary cell
 
-    ! Geometric variables
-
-    distbr = distb(ifac)
-
     ! Physical variables
 
-    visct  = propce(iel,ipcvst)
     flumab = bmasfl(ifac)
 
-    if (ipccp.gt.0) then
-      xcp = propce(iel,ipccp)
-    else
-      xcp    = cp0
-    endif
-
-    if (ipcvsl.gt.0) then
-      xvsl = propce(iel,ipcvsl)
-    else
-      xvsl = visls0(iscal)
-    endif
-
     ! Contribution to flux from the current face
     ! (diffusion and convection flux, negative if incoming)
 
-    xfluxf = - surfbn(ifac) * dt(iel) * xcp                 &
+    xfluxf = - surfbn(ifac) * dt(iel)                       &
              * (cofafp(ifac) + cofbfp(ifac)*treco(ifac))    &
-           - flumab * dt(iel) * xcp                         &
+           - flumab * dt(iel) * xcp(iel)                    &
              * (coefap(ifac) + coefbp(ifac)*treco(ifac))
 
     xbilpa = xbilpa + xfluxf
@@ -476,33 +367,16 @@ if (inpdt0.eq.0) then
     ifac = lstelt(ilelt)
     iel  = ifabor(ifac)   ! associated boundary cell
 
-    ! Geometric variables
-
-    distbr = distb(ifac)
-
     ! Physical variables
 
-    visct  = propce(iel,ipcvst)
     flumab = bmasfl(ifac)
 
-    if (ipccp.gt.0) then
-      xcp = propce(iel,ipccp)
-    else
-      xcp    = cp0
-    endif
-
-    if (ipcvsl.gt.0) then
-      xvsl = propce(iel,ipcvsl)
-    else
-      xvsl = visls0(iscal)
-    endif
-
     ! Contribution to flux from the current face
     ! (diffusion and convection flux, negative if incoming)
 
-    xfluxf = - surfbn(ifac) * dt(iel) * xcp                 &
+    xfluxf = - surfbn(ifac) * dt(iel)                       &
              * (cofafp(ifac) + cofbfp(ifac)*treco(ifac))    &
-           - flumab * dt(iel) * xcp                         &
+           - flumab * dt(iel) * xcp(iel)                    &
              * (coefap(ifac) + coefbp(ifac)*treco(ifac))
 
     xbilpt = xbilpt + xfluxf
@@ -519,33 +393,16 @@ if (inpdt0.eq.0) then
     ifac = lstelt(ilelt)
     iel  = ifabor(ifac)   ! associated boundary cell
 
-    ! Geometric variables
-
-    distbr = distb(ifac)
-
     ! Physical variables
 
-    visct  = propce(iel,ipcvst)
     flumab = bmasfl(ifac)
 
-    if (ipccp.gt.0) then
-      xcp = propce(iel,ipccp)
-    else
-      xcp    = cp0
-    endif
-
-    if (ipcvsl.gt.0) then
-      xvsl = propce(iel,ipcvsl)
-    else
-      xvsl = visls0(iscal)
-    endif
-
     ! Contribution to flux from the current face
     ! (diffusion and convection flux, negative if incoming)
 
-    xfluxf = - surfbn(ifac) * dt(iel) * xcp                 &
+    xfluxf = - surfbn(ifac) * dt(iel)                       &
              * (cofafp(ifac) + cofbfp(ifac)*treco(ifac))    &
-           - flumab * dt(iel) * xcp                         &
+           - flumab * dt(iel) * xcp(iel)                    &
              * (coefap(ifac) + coefbp(ifac)*treco(ifac))
 
     xbilsy = xbilsy + xfluxf
@@ -562,33 +419,16 @@ if (inpdt0.eq.0) then
     ifac = lstelt(ilelt)
     iel  = ifabor(ifac)   ! associated boundary cell
 
-    ! Geometric variables
-
-    distbr = distb(ifac)
-
     ! Physical variables
 
-    visct  = propce(iel,ipcvst)
     flumab = bmasfl(ifac)
 
-    if (ipccp.gt.0) then
-      xcp = propce(iel,ipccp)
-    else
-      xcp    = cp0
-    endif
-
-    if (ipcvsl.gt.0) then
-      xvsl = propce(iel,ipcvsl)
-    else
-      xvsl = visls0(iscal)
-    endif
-
     ! Contribution to flux from the current face
     ! (diffusion and convection flux, negative if incoming)
 
-    xfluxf = - surfbn(ifac) * dt(iel) * xcp                 &
+    xfluxf = - surfbn(ifac) * dt(iel)                       &
              * (cofafp(ifac) + cofbfp(ifac)*treco(ifac))    &
-           - flumab * dt(iel) * xcp                         &
+           - flumab * dt(iel) * xcp(iel)                    &
              * (coefap(ifac) + coefbp(ifac)*treco(ifac))
 
     xbilen = xbilen + xfluxf
@@ -605,33 +445,16 @@ if (inpdt0.eq.0) then
     ifac = lstelt(ilelt)
     iel  = ifabor(ifac)   ! associated boundary cell
 
-    ! Geometric variables
-
-    distbr = distb(ifac)
-
     ! Physical variables
 
-    visct  = propce(iel,ipcvst)
     flumab = bmasfl(ifac)
 
-    if (ipccp.gt.0) then
-      xcp = propce(iel,ipccp)
-    else
-      xcp    = cp0
-    endif
-
-    if (ipcvsl.gt.0) then
-      xvsl = propce(iel,ipcvsl)
-    else
-      xvsl = visls0(iscal)
-    endif
-
     ! Contribution to flux from the current face
     ! (diffusion and convection flux, negative if incoming)
 
-    xfluxf = - surfbn(ifac) * dt(iel) * xcp                 &
+    xfluxf = - surfbn(ifac) * dt(iel)                       &
              * (cofafp(ifac) + cofbfp(ifac)*treco(ifac))    &
-           - flumab * dt(iel) * xcp                         &
+           - flumab * dt(iel) * xcp(iel)                    &
              * (coefap(ifac) + coefbp(ifac)*treco(ifac))
 
     xbilso = xbilso + xfluxf
@@ -647,25 +470,24 @@ if (inpdt0.eq.0) then
 
   ! We separate mass injections from suctions for better generality
 
-  ncesmp = ncetsm
-  if (ncesmp.gt.0) then
-    do ieltsm = 1, ncesmp
+  if (ncetsm.gt.0) then
+    do ieltsm = 1, ncetsm
       ! depending on the type of injection we use the 'smacell' value
       ! or the ambient temperature
       iel = icetsm(ieltsm)
       xgamma = smacel(ieltsm,ipr)
       if (itypsm(ieltsm,ivar).eq.0 .or. xgamma.lt.0.d0) then
-        xrtp = rtp (iel,ivar)
+        xrtp = cvar_scal(iel)
       else
         xrtp = smacel(ieltsm,ivar)
       endif
-      if (ipccp.gt.0) then
+      if (icp.gt.0) then
         if (xgamma.lt.0.d0) then
           xbilma =   xbilma  &
-                   + volume(iel) * propce(iel,ipccp) * dt(iel) * xgamma * xrtp
+                   + volume(iel) * cpro_cp(iel) * dt(iel) * xgamma * xrtp
         else
           xbilmi =   xbilmi  &
-                   + volume(iel) * propce(iel,ipccp) * dt(iel) * xgamma * xrtp
+                   + volume(iel) * cpro_cp(iel) * dt(iel) * xgamma * xrtp
         endif
       else
         if (xgamma.lt.0.d0) then
@@ -727,7 +549,8 @@ endif ! End of test on inpdt0
 !< [finalize]
 ! Deallocate the temporary array
 deallocate(lstelt)
+deallocate(xcp)
 !< [finalize]
 
 return
-end subroutine cs_user_extra_operations
+end subroutine cs_f_user_extra_operations
