@@ -4,7 +4,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2013 EDF S.A.
+! Copyright (C) 1998-2014 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -39,15 +39,12 @@
 !> \param[in]     nvar          total number of variables
 !> \param[in]     nscal         total number of scalars
 !> \param[in]     dt            time step (per cell)
-!> \param[in]     rtp           calculated variables at cell centers
-!>                               (at current time step)
-!> \param[in]     propce        physical properties at cell centers
 !_______________________________________________________________________________
 
 
 subroutine cs_user_initialization &
  ( nvar   , nscal  ,                                              &
-   dt     , rtp    , propce )
+   dt     )
 
 !===============================================================================
 
@@ -76,6 +73,7 @@ use ppcpfu
 use cs_coal_incl
 use cs_fuel_incl
 use mesh
+use field
 
 !===============================================================================
 
@@ -85,7 +83,7 @@ implicit none
 
 integer          nvar   , nscal
 
-double precision dt(ncelet), rtp(ncelet,*), propce(ncelet,*)
+double precision dt(ncelet)
 
 ! Local variables
 
@@ -100,6 +98,17 @@ double precision xkent, xeent, d2s3
 double precision wmh2o,wmco2,wmn2,wmo2,dmas
 
 integer, allocatable, dimension(:) :: lstelt
+
+double precision, dimension(:), pointer :: cvar_k, cvar_ep, cvar_phi, cvar_fb
+double precision, dimension(:), pointer :: cvar_omg, cvar_nusa
+double precision, dimension(:), pointer :: cvar_r11, cvar_r22, cvar_r33
+double precision, dimension(:), pointer :: cvar_r12, cvar_r13, cvar_r23
+double precision, dimension(:), pointer :: cvar_xch, cvar_xck, cvar_np
+double precision, dimension(:), pointer :: cvar_h2, cvar_scalt
+double precision, dimension(:), pointer :: cvar_f1m, cvar_f2m, cvar_f3m
+double precision, dimension(:), pointer :: cvar_f6m, cvar_f7m, cvar_f3mc2
+double precision, dimension(:), pointer :: cvar_yco2, cvar_yhcn, cvar_yno
+double precision, dimension(:), pointer :: cvar_taire
 !< [loc_var_dec]
 
 !===============================================================================
@@ -135,44 +144,60 @@ if (isuite.eq.0) then
 ! ---- TURBULENCE
 
   if (itytur.eq.2) then
+    call field_get_val_s(ivarfl(ik), cvar_k)
+    call field_get_val_s(ivarfl(iep), cvar_ep)
 
     do iel = 1, ncel
-      rtp(iel,ik)  = xkent
-      rtp(iel,iep) = xeent
+      cvar_k(iel)  = xkent
+      cvar_ep(iel) = xeent
     enddo
 
   elseif (itytur.eq.3) then
+    call field_get_val_s(ivarfl(ir11), cvar_r11)
+    call field_get_val_s(ivarfl(ir22), cvar_r22)
+    call field_get_val_s(ivarfl(ir33), cvar_r33)
+    call field_get_val_s(ivarfl(ir12), cvar_r12)
+    call field_get_val_s(ivarfl(ir13), cvar_r13)
+    call field_get_val_s(ivarfl(ir23), cvar_r23)
+    call field_get_val_s(ivarfl(iep), cvar_ep)
 
     do iel = 1, ncel
-      rtp(iel,ir11) = d2s3*xkent
-      rtp(iel,ir22) = d2s3*xkent
-      rtp(iel,ir33) = d2s3*xkent
-      rtp(iel,ir12) = 0.d0
-      rtp(iel,ir13) = 0.d0
-      rtp(iel,ir23) = 0.d0
-      rtp(iel,iep)  = xeent
+      cvar_r11(iel) = d2s3*xkent
+      cvar_r22(iel) = d2s3*xkent
+      cvar_r33(iel) = d2s3*xkent
+      cvar_r12(iel) = 0.d0
+      cvar_r13(iel) = 0.d0
+      cvar_r23(iel) = 0.d0
+      cvar_ep(iel)  = xeent
     enddo
 
   elseif (iturb.eq.50) then
+    call field_get_val_s(ivarfl(ik), cvar_k)
+    call field_get_val_s(ivarfl(iep), cvar_ep)
+    call field_get_val_s(ivarfl(iphi), cvar_phi)
+    call field_get_val_s(ivarfl(ifb), cvar_fb)
 
     do iel = 1, ncel
-      rtp(iel,ik)   = xkent
-      rtp(iel,iep)  = xeent
-      rtp(iel,iphi) = d2s3
-      rtp(iel,ifb)  = 0.d0
+      cvar_k(iel)   = xkent
+      cvar_ep(iel)  = xeent
+      cvar_phi(iel) = d2s3
+      cvar_fb(iel)  = 0.d0
     enddo
 
   elseif (iturb.eq.60) then
+    call field_get_val_s(ivarfl(ik), cvar_k)
+    call field_get_val_s(ivarfl(iomg), cvar_omg)
 
     do iel = 1, ncel
-      rtp(iel,ik)   = xkent
-      rtp(iel,iomg) = xeent/cmu/xkent
+      cvar_k(iel)   = xkent
+      cvar_omg(iel) = xeent/cmu/xkent
     enddo
 
   elseif (iturb.eq.70) then
+    call field_get_val_s(ivarfl(inusa), cvar_nusa)
 
     do iel = 1, ncel
-      rtp(iel,inusa) = cmu*xkent**2/xeent
+      cvar_nusa(iel) = cmu*xkent**2/xeent
     enddo
 
   endif
@@ -191,12 +216,17 @@ if (isuite.eq.0) then
   do icla = 1, nclacp
     icha = ichcor(icla)
 
+    call field_get_val_s(ivarfl(isca(ixch(icla))), cvar_xch)
+    call field_get_val_s(ivarfl(isca(ixck(icla))), cvar_xck)
+    call field_get_val_s(ivarfl(isca(inp(icla))), cvar_np)
+    call field_get_val_s(ivarfl(isca(ih2(icla))), cvar_h2)
+
     do iel = 1, ncel
 
-      rtp(iel,isca(ixch(icla))) = zero
-      rtp(iel,isca(ixck(icla))) = zero
-      rtp(iel,isca(inp(icla) )) = zero
-      rtp(iel,isca(ih2(icla)))  = zero
+      cvar_xch(iel) = zero
+      cvar_xck(iel) = zero
+      cvar_np(iel) = zero
+      cvar_h2(iel)  = zero
     enddo
   enddo
 
@@ -228,33 +258,46 @@ if (isuite.eq.0) then
   call cs_coal_htconvers1(mode, h1init, coefe, f1mc, f2mc, t1init)
  !============================
 
+  call field_get_val_s(ivarfl(isca(iscalt)), cvar_scalt)
+
   do iel = 1, ncel
-    rtp(iel,isca(iscalt)) = h1init
+    cvar_scalt(iel) = h1init
   enddo
 
 ! ------ Transported variables for the mix (passive scalars, variance)
 
   do icha = 1, ncharb
+    call field_get_val_s(ivarfl(isca(if1m(icha))), cvar_f1m)
+    call field_get_val_s(ivarfl(isca(if2m(icha))), cvar_f2m)
     do iel = 1, ncel
-      rtp(iel,isca(if1m(icha))) = zero
-      rtp(iel,isca(if2m(icha))) = zero
+      cvar_f1m(iel) = zero
+      cvar_f2m(iel) = zero
     enddo
   enddo
 
+  call field_get_val_s(ivarfl(isca(if3m)), cvar_f3m)
+  call field_get_val_s(ivarfl(isca(if3mc2)), cvar_f3mc2)
+  call field_get_val_s(ivarfl(isca(if6m)), cvar_f6m)
+  call field_get_val_s(ivarfl(isca(if7m)), cvar_f7m)
+  call field_get_val_s(ivarfl(isca(iyco2)), cvar_yco2)
+  call field_get_val_s(ivarfl(isca(iyhcn)), cvar_yhcn)
+  call field_get_val_s(ivarfl(isca(iyno)), cvar_yno)
+  call field_get_val_s(ivarfl(isca(itaire)), cvar_taire)
+
   do iel = 1, ncel
 
-    rtp(iel,isca(if3m)) = zero
+    cvar_f3m(iel) = zero
 
     if ( ihtco2 .eq. 1 ) then
-      rtp(iel,isca(if3mc2)) = zero
+      cvar_f3mc2(iel) = zero
     endif
 
     if ( noxyd .ge. 2 ) then
-      rtp(iel,isca(if6m)) = zero
+      cvar_f6m(iel) = zero
     endif
 
     if ( noxyd .eq. 3 ) then
-      rtp(iel,isca(if7m)) = zero
+      cvar_f7m(iel) = zero
     endif
 
     if ( ieqco2.ge.1 ) then
@@ -269,14 +312,14 @@ if (isuite.eq.0) then
               +oxyh2o(ioxy)*wmh2o+oxyco2(ioxy)*wmco2 )
       xco2 = oxyco2(ioxy)*wmco2/dmas
 
-      rtp(iel,isca(iyco2)) = oxyco2(ioxy)*wmco2/dmas
+      cvar_yco2(iel) = oxyco2(ioxy)*wmco2/dmas
 
     endif
 
     if ( ieqnox .eq. 1 ) then
-      rtp(iel,isca(iyhcn)) = 0.d0
-      rtp(iel,isca(iyno )) = 0.d0
-      rtp(iel,isca(itaire)) = 293.d0
+      cvar_yhcn(iel) = 0.d0
+      cvar_yno(iel) = 0.d0
+      cvar_taire(iel) = 293.d0
     endif
 
   enddo
